;;; -*- coding: japanese-shift-jis-unix -*-
;;; auditory-disp-table-jp.el:
;;;     This module defines an explanatory-reading dictionary of 2-byte
;;;     Japanese characters and provides some functions to access it.
;;;
;;; $Id: auditory-disp-table-jp.el,v 1.12 2001/10/08 08:14:32 inoue Exp $
;;; Copyright 2000, bep <http://www.argv.org/bep/>
;;;   Based on Prof. Jun Ishikawa <ishikawa@u-shizuoka-ken.ac.jp> 's
;;;   dictionaries, kanji.org and kigou.org.
;;;   dictionaries are maintained by Hirohiko Honda
;;
;; this dictionary has 4 fields:
;; 1) Key: Kanji or other 2-byte Japanese char ""
;; 2) Value 1: read one char according to a cursor movement ""
;; 3) Value 2: explain Kanji to identify it while Kana-Kanji translation ""
;; 4) Value 3: almost same as 3) but explain Kanji in detail.

(require 'cl)
;(require 'auditory-disp-table)
(put 'auditory-display-table 'char-table-extra-slots 6) ;Ƃ肠

(defvar auditory-display-table-jp
  (make-char-table 'auditory-display-table)
  "char-table from a Japanese character and corresponding explanatory readings"
)

;
(defun bep-get-phonetic-string (char &optional field)
  "Return the phonetic string, the 2nd field of dic, for this CHAR."
  (interactive "sChar:\nnField:")
  (let ((dummy-array ["dummy" "dummy" "dummy"]))
    (or (aref
	 (or
	  (aref auditory-display-table-jp (string-to-char char))
	  (fillarray dummy-array char)) ; avoid error and return char itself
	 (if field field 0))
	" ")))

(defun bep-get-char-type (char)
  "Return the symbol of char-type for this CHAR."
  (aref
   (or
    (aref auditory-display-table-jp char)
    [nil nil nil nil]) ; avoid error and return char itself
   3))

(defun bep-get-cursor-string (char)
  "Return the short phonetic string (2nd field) of CHAR."
  (interactive "sChar:\n")
  (bep-get-phonetic-string char 0))

(defun bep-get-explanatory-string (char)
  "Return the explanatory string (3rd field) of CHAR."
  (interactive "sChar:\n")
  (bep-get-phonetic-string char 1))

(defun bep-get-long-explanatory-string (char)
  "Return the detail explanatory string (4th field) of CHAR."
  (interactive "sChar:\n")
  (bep-get-phonetic-string char 2))

;; fill auditory-display-table-jp
(mapcar
 (function
  (lambda (dictionary)
    (aset auditory-display-table-jp
          (string-to-char (first dictionary)) ; Key
          (vector                             ; Values
                  (second dictionary)
                  (third dictionary)
                  (fourth dictionary)
		  (fifth dictionary)))))
'( ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
("" "}" "}" "}" katakana)
("" "JMqL" "JMqL" "JMqL" katakana)
("" "JMgW" "JMgW" "JMgW" katakana)
("" "e" "e" "e" katakana)
("" "iJe" "iJe" "iJe" katakana)
("" "" "Im@I" "Im@I" katakana)
("" "@" "ATqm@A" "ATqm@A" katakana)
("" "B" "Cnm@C" "Cnm@C" katakana)
("" "D" "EGmm@E" "EGmm@E" katakana)
("" "F" "GCSm@G" "GCSm@G" katakana)
("" "H" "IITJm@I" "IITJm@I" katakana)
("" "" "}g @" "}gm@" katakana)
("" "" "~m@" "~m@" katakana)
("" "" "Vmm@" "Vmm@" katakana)
("" "b" "cJm@c" "cJm@c" katakana)
("" "`[I" "`[I" "`[I" katakana)
("" "A" "ATqm@A" "ATqm@A" katakana)
("" "C" "Cnm@C" "Cnm@C" katakana)
("" "E" "EGmm@E" "EGmm@E" katakana)
("" "G" "GCSm@G" "GCSm@G" katakana)
("" "I" "IITJm@I" "IITJm@I" katakana)
("" "J" "JZm@J" "JZm@J" katakana)
("" "L" "Lbem@L" "Lbem@L" katakana)
("" "N" "Num@N" "Num@N" katakana)
("" "P" "PVLm@P" "PVLm@P" katakana)
("" "R" "Rhm@R" "Rhm@R" katakana)
("" "T" "TNm@T" "TNm@T" katakana)
("" "V" "Vum@V" "Vum@V" katakana)
("" "X" "XYm@X" "XYm@X" katakana)
("" "Z" "ZJCm@Z" "ZJCm@Z" katakana)
("" "\" "\om@\" "\om@\" katakana)
("" "^" "^oRm@^" "^oRm@^" katakana)
("" "`" "`hm@`" "`hm@`" katakana)
("" "c" "cJm@c" "cJm@c" katakana)
("" "e" "eK~m@e" "eK~m@e" katakana)
("" "g" "g[L[m@g" "g[L[m@g" katakana)
("" "i" "iSm@i" "iSm@i" katakana)
("" "j" "jzm@j" "jzm@j" katakana)
("" "k" "k}Ym@k" "k}Ym@k" katakana)
("" "l" "lY~m@l" "lY~m@l" katakana)
("" "m" "mnm@m" "mnm@m" katakana)
("" "n" "nKLm@n" "nKLm@n" katakana)
("" "q" "qR[Lm@q" "qR[Lm@q" katakana)
("" "t" "tWTm@t" "tWTm@t" katakana)
("" "w" "wCm@w" "wCm@w" katakana)
("" "z" "zPm@z" "zPm@z" katakana)
("" "}" "}b`m@}" "}b`m@}" katakana)
("" "~" "~JTm@~" "~JTm@~" katakana)
("" "" "Zm@" "Zm@" katakana)
("" "" "CWm@" "CWm@" katakana)
("" "" "~Wm@" "~Wm@" katakana)
("" "" "}gm@" "}gm@" katakana)
("" "" "~m@" "~m@" katakana)
("" "" "Vmm@" "Vmm@" katakana)
("" "" "WIm@" "WIm@" katakana)
("" "" "Sm@" "Sm@" katakana)
("" "" "XCm@" "XCm@" katakana)
("" "" "Qm@" "Qm@" katakana)
("" "" "[}m@" "[}m@" katakana)
("" "" "rm@" "rm@" katakana)
("" "" "IV}Cm@" "IV}Cm@" katakana)
("" "_Ne" "_Ne" "_Ne" katakana)
("" "n_Ne" "n_Ne" "n_Ne" katakana)
("@" "Xy[X" "Xy[X" "Xy[X" jp-other)
("A" "e" "e" "e" jp-other)
("B" "}" "}" "}" jp-other)
("C" "J}" "J}" "J}" jp-other)
("D" "sIh" "sIh" "sIh" jp-other)
("E" "iJe" "iJe" "iJe" jp-other)
("F" "R" "R" "R" jp-other)
("G" "Z~R" "Z~R" "Z~R" jp-other)
("H" "Mt" "Mt" "Mt" jp-other)
("I" "J^t" "J^t" "J^t" jp-other)
("J" "_Ne" "_Ne" "_Ne" jp-other)
("K" "n_Ne" "n_Ne" "n_Ne" jp-other)
("L" "ANTeBM[" "ANTeBM[" "ANTeBM[" jp-other)
("M" "ANTO[u" "ANTO[u" "ANTO[u" jp-other)
("N" "EEg" "EEg" "EEg" jp-other)
("O" "xLW[" "xLW[" "xLW[" jp-other)
("P" "I[o[C" "I[o[C" "I[o[C" jp-other)
("Q" "A_[" "A_[" "A_[" jp-other)
("R" "J^JiNJGV" "J^JiNJGV" "J^JiNJGV" jp-other)
("S" "J^Ji_NeNJGV" "J^Ji_NeNJGV" "J^Ji_NeNJGV" jp-other)
("T" "qKiNJGV" "qKiNJGV" "qKiNJGV" jp-other)
("U" "qKi_NeNJGV" "qKi_NeNJGV" "qKi_NeNJGV" jp-other)
("V" "IiWN" "IiWN" "IiWN" jp-other)
("W" "h[W[" "h[W[" "h[W[" jp-other)
("X" "NJGVLS[" "NJGVLS[" "NJGVLS[" jp-other)
("Y" "V" "V" "V" jp-other)
("Z" "JX[W[" "JX[W[" "JX[W[" jp-other)
("[" "`[I" "`[I" "`[I" jp-katakana)
("\" "_bV" "_bV" "_bV" jp-other)
("]" "nCt" "nCt" "nCt" jp-other)
("^" "XbV" "XbV" "XbV" jp-other)
("_" "obNXbV" "obNXbV" "obNXbV" jp-other)
("`" "i~Z" "i~Z" "i~Z" jp-other)
("a" "wCR[" "wCR[" "wCR[" jp-other)
("b" "^eZ" "^eZ" "^eZ" jp-other)
("c" "Te" "Te" "Te" jp-other)
("d" "je" "je" "je" jp-other)
("e" "q_C[t" "q_C[t" "q_C[t" jp-other)
("f" "~MC[t" "~MC[t" "~MC[t" jp-other)
("g" "q_jW[C[t" "q_jW[C[t" "q_jW[C[t" jp-other)
("h" "~MjW[C[t" "~MjW[C[t" "~MjW[C[t" jp-other)
("i" "JbRqL" "JbRqL" "JbRqL" jp-other)
("j" "JbRgW" "JbRgW" "JbRgW" jp-other)
("k" "LbR[" "LbR[" "LbR[" jp-other)
("l" "gWLbR[" "gWLbR[" "gWLbR[" jp-other)
("m" "_CJbRqL" "_CJbRqL" "_CJbRqL" jp-other)
("n" "_CJbRgW" "_CJbRgW" "_CJbRgW" jp-other)
("o" "`[JbRqL" "`[JbRqL" "`[JbRqL" jp-other)
("p" "`[JbRgW" "`[JbRgW" "`[JbRgW" jp-other)
("q" "}JbR" "}JbR" "}JbR" jp-other)
("r" "gW}JbR" "gW}JbR" "gW}JbR" jp-other)
("s" "jW[}JbR" "jW[}JbR" "jW[}JbR" jp-other)
("t" "gWjW[}JbR" "gWjW[}JbR" "gWjW[}JbR" jp-other)
("u" "JMqL" "JMqL" "JMqL" jp-other)
("v" "JMgW" "JMgW" "JMgW" jp-other)
("w" "jW[JM" "jW[JM" "jW[JM" jp-other)
("x" "jW[JMgW" "jW[JMgW" "jW[JMgW" jp-other)
("y" "X~cL" "X~cL" "X~cL" jp-other)
("z" "X~cLgW" "X~cLgW" "X~cLgW" jp-other)
("{" "vX" "vX" "vX" jp-other)
("|" "}CiX" "}CiX" "}CiX" jp-other)
("}" "vX}CiX" "vX}CiX" "vX}CiX" jp-other)
("~" "JP" "JP" "JP" jp-other)
("" "" "" "" jp-other)
("" "CR[" "CR[" "CR[" jp-other)
("" "mbgCR[" "mbgCR[" "mbgCR[" jp-other)
("" "V[i" "V[i" "V[i" jp-other)
("" "_Ci" "_Ci" "_Ci" jp-other)
("" "V[iCR[" "V[iCR[" "V[iCR[" jp-other)
("" "_CiCR[" "_CiCR[" "_CiCR[" jp-other)
("" "Q_C" "Q_C" "Q_C" jp-other)
("" "Gj" "Gj" "Gj" jp-other)
("" "_ZC" "_ZC" "_ZC" jp-other)
("" "WZC" "WZC" "WZC" jp-other)
("" "h" "h" "h" jp-other)
("" "t" "t" "t" jp-other)
("" "r[" "r[" "r[" jp-other)
("" "hV[" "hV[" "hV[" jp-other)
("" "G}[N" "G}[N" "G}[N" jp-other)
("" "h" "h" "h" jp-other)
("" "Zg" "Zg" "Zg" jp-other)
("" "|h" "|h" "|h" jp-other)
("" "p[Zg" "p[Zg" "p[Zg" jp-other)
("" "V[v" "V[v" "V[v" jp-other)
("" "ApTh" "ApTh" "ApTh" jp-other)
("" "AX^XN" "AX^XN" "AX^XN" jp-other)
("" "Abg" "Abg" "Abg" jp-other)
("" "ZNV" "ZNV" "ZNV" jp-other)
("" "V{V" "V{V" "V{V" jp-other)
("" "N{V" "N{V" "N{V" jp-other)
("" "V}" "V}" "V}" jp-other)
("" "N}" "N}" "N}" jp-other)
("" "jW[}" "jW[}" "jW[}" jp-other)
("" "qVK^" "qVK^" "qVK^" jp-other)
("" "NqVK^" "NqVK^" "NqVK^" jp-other)
("" "VJN" "VJN" "VJN" jp-other)
("" "NVJN" "NVJN" "NVJN" jp-other)
("" "TJN" "TJN" "TJN" jp-other)
("" "NTJN" "NTJN" "NTJN" jp-other)
("" "MNTJN" "MNTJN" "MNTJN" jp-other)
("" "MNNTJN" "MNNTJN" "MNNTJN" jp-other)
("" "RWV" "RWV" "RWV" jp-other)
("" "[r" "[r" "[r" jp-other)
("" "~MWV" "~MWV" "~MWV" jp-other)
("" "q_WV" "q_WV" "q_WV" jp-other)
("" "EGWV" "EGWV" "EGWV" jp-other)
("" "V^WV" "V^WV" "V^WV" jp-other)
("" "NMLS[" "NMLS[" "NMLS[" jp-other)
("" "]NX" "]NX" "]NX" jp-other)
("" "ggVetN" "ggVetN" "ggVetN" jp-other)
("" "uuV[S[" "uuV[S[" "uuV[S[" jp-other)
("" "uuItN" "uuItN" "uuItN" jp-other)
("" "VtuV[S[" "VtuV[S[" "VtuV[S[" jp-other)
("" "VuItN" "VuItN" "VuItN" jp-other)
("" "KbyCV[S[" "KbyCV[S[" "KbyCV[S[" jp-other)
("" "L[c[V[S[" "L[c[V[S[" "L[c[V[S[" jp-other)
("" "S[ZcLS[" "S[ZcLS[" "S[ZcLS[" jp-other)
("" "ZcLS[" "ZcLS[" "ZcLS[" jp-other)
("" "qeCLS[" "qeCLS[" "qeCLS[" jp-other)
("" "S[CLS[" "S[CLS[" "S[CLS[" jp-other)
("" "h[`LS[" "h[`LS[" "h[`LS[" jp-other)
("" "tc[QeCV" "tc[QeCV" "tc[QeCV" jp-other)
("" "\UCQeCV" "\UCQeCV" "\UCQeCV" jp-other)
("" "JNLS[" "JNLS[" "JNLS[" jp-other)
("" "XC`N" "XC`N" "XC`N" jp-other)
("" "RLS[" "RLS[" "RLS[" jp-other)
("" "EhfB[" "EhfB[" "EhfB[" jp-other)
("" "iuLS[" "iuLS[" "iuLS[" jp-other)
("" "cljqgVCLS[" "cljqgVCLS[" "cljqgVCLS[" jp-other)
("" "zghqgVC" "zghqgVC" "zghqgVC" jp-other)
("" "qW[j`CTCLS[" "qW[j`CTCLS[" "qW[j`CTCLS[" jp-other)
("" "qW[jI[LCLS[" "qW[jI[LCLS[" "qW[jI[LCLS[" jp-other)
("" "RLS[" "RLS[" "RLS[" jp-other)
("" "\[WLS[" "\[WLS[" "\[WLS[" jp-other)
("" "qCLS[" "qCLS[" "qCLS[" jp-other)
("" "i[ioLS[" "i[ioLS[" "i[ioLS[" jp-other)
("" "ZLuLS[" "ZLuLS[" "ZLuLS[" jp-other)
("" "jW[ZLuLS[" "jW[ZLuLS[" "jW[ZLuLS[" jp-other)
("" "IOXg[" "IOXg[" "IOXg[" jp-other)
("" "p[~" "p[~" "p[~" jp-other)
("" "V[v" "V[v" "V[v" jp-other)
("" "tbg" "tbg" "tbg" jp-other)
("" "Iv" "Iv" "Iv" jp-other)
("" "_K[" "_K[" "_K[" jp-other)
("" "_u_K[" "_u_K[" "_u_K[" jp-other)
("" "_NLS[" "_NLS[" "_NLS[" jp-other)
("O" "[" "XEWm [" "XEWm [" jp-number)
("P" "C`" "XEWm C`" "XEWm C`" jp-number)
("Q" "[" "XEWm [" "XEWm [" jp-number)
("R" "T" "XEWm T" "XEWm T" jp-number)
("S" "" "XEWm " "XEWm " jp-number)
("T" "S" "XEWm S" "XEWm S" jp-number)
("U" "N" "XEWm N" "XEWm N" jp-number)
("V" "ii" "XEWm ii" "XEWm ii" jp-number)
("W" "n`" "XEWm n`" "XEWm n`" jp-number)
("X" "L[" "XEWm L[" "XEWm L[" jp-number)
("`" "G[" "At@" "At@" jp-alpha)
("a" "r[" "u{[" "u{[" jp-alpha)
("b" "V[" "`[[" "`[[" jp-alpha)
("c" "f[" "f^" "f^" jp-alpha)
("d" "C[" "GR[" "GR[" jp-alpha)
("e" "Gt" "tHbNXgbg" "tHbNXgbg" jp-alpha)
("f" "W[" "St" "St" jp-alpha)
("g" "GC`" "ze" "ze" jp-alpha)
("h" "AC" "CfBA" "CfBA" jp-alpha)
("i" "WF[" "WGbg" "WGbg" jp-alpha)
("j" "P[" "L" "L" jp-alpha)
("k" "G" "[}" "[}" jp-alpha)
("l" "G" "}CN" "}CN" jp-alpha)
("m" "Gk" "mxo[" "mxo[" jp-alpha)
("n" "I[" "IXJ[" "IXJ[" jp-alpha)
("o" "s[" "pp" "pp" jp-alpha)
("p" "L[" "PxbN" "PxbN" jp-alpha)
("q" "A[" "~I" "~I" jp-alpha)
("r" "GX" "VG" "VG" jp-alpha)
("s" "eB[" "^S" "^S" jp-alpha)
("t" "[" "jtH[" "jtH[" jp-alpha)
("u" "uC" "rN^[" "rN^[" jp-alpha)
("v" "_u[" "ECXL[" "ECXL[" jp-alpha)
("w" "GbNX" "GbNXC" "GbNXC" jp-alpha)
("x" "C" "L[" "L[" jp-alpha)
("y" "[bg" "Y" "Y" jp-alpha)
("" "G[" "At@" "At@" jp-alpha)
("" "r[" "u{[" "u{[" jp-alpha)
("" "V[" "`[[" "`[[" jp-alpha)
("" "f[" "f^" "f^" jp-alpha)
("" "C[" "GR[" "GR[" jp-alpha)
("" "Gt" "tHbNXgbg" "tHbNXgbg" jp-alpha)
("" "W[" "St" "St" jp-alpha)
("" "GC`" "ze" "ze" jp-alpha)
("" "AC" "CfBA" "CfBA" jp-alpha)
("" "WF[" "WGbg" "WGbg" jp-alpha)
("" "P[" "L" "L" jp-alpha)
("" "G" "[}" "[}" jp-alpha)
("" "G" "}CN" "}CN" jp-alpha)
("" "Gk" "mxo[" "mxo[" jp-alpha)
("" "I[" "IXJ[" "IXJ[" jp-alpha)
("" "s[" "pp" "pp" jp-alpha)
("" "L[" "PxbN" "PxbN" jp-alpha)
("" "A[" "~I" "~I" jp-alpha)
("" "GX" "VG" "VG" jp-alpha)
("" "eB[" "^S" "^S" jp-alpha)
("" "[" "jtH[" "jtH[" jp-alpha)
("" "uC" "rN^[" "rN^[" jp-alpha)
("" "_u[" "ECXL[" "ECXL[" jp-alpha)
("" "GbNX" "GbNXC" "GbNXC" jp-alpha)
("" "C" "L[" "L[" jp-alpha)
("" "[bg" "Y" "Y" jp-alpha)
("" "A" "ATqm A" "ATqm A" jp-hiragana)
("" "A" "ATqm A" "ATqm A" jp-hiragana)
("" "C" "Cnm C" "Cnm C" jp-hiragana)
("" "C" "Cnm C" "Cnm C" jp-hiragana)
("" "E" "EGmm E" "EGmm E" jp-hiragana)
("" "E" "EGmm E" "EGmm E" jp-hiragana)
("" "G" "GCSm G" "GCSm G" jp-hiragana)
("" "G" "GCSm G" "GCSm G" jp-hiragana)
("" "I" "IITJm I" "IITJm I" jp-hiragana)
("" "I" "IITJm I" "IITJm I" jp-hiragana)
("" "J" "JZm J" "JZm J" jp-hiragana)
("" "K" "JZm Jj _Ne" "JZm Jj _Ne" jp-hiragana)
("" "L" "Lbem L" "Lbem L" jp-hiragana)
("" "M" "Lbem Lj _Ne" "Lbem Lj _Ne" jp-hiragana)
("" "N" "Num N" "Num N" jp-hiragana)
("" "O" "Num Nj _Ne" "Num Nj _Ne" jp-hiragana)
("" "P" "PVLm P" "PVLm P" jp-hiragana)
("" "Q" "PVLm Pj _Ne" "PVLm Pj _Ne" jp-hiragana)
("" "R" "Rhm R" "Rhm R" jp-hiragana)
("" "S" "Rhm Rj _Ne" "Rhm Rj _Ne" jp-hiragana)
("" "T" "TNm T" "TNm T" jp-hiragana)
("" "U" "TNm Tj _Ne" "TNm Tj _Ne" jp-hiragana)
("" "V" "Vum V" "Vum V" jp-hiragana)
("" "W" "Vum Vj _Ne" "Vum Vj _Ne" jp-hiragana)
("" "X" "XYm X" "XYm X" jp-hiragana)
("" "Y" "XYm Xj _Ne" "XYm Xj _Ne" jp-hiragana)
("" "Z" "ZJCm Z" "ZJCm Z" jp-hiragana)
("" "[" "ZJCm Zj _Ne" "ZJCm Zj _Ne" jp-hiragana)
("" "\" "\om \" "\om \" jp-hiragana)
("" "]" "\om \j _Ne" "\om \j _Ne" jp-hiragana)
("" "^" "^oRm ^" "^oRm ^" jp-hiragana)
("" "_" "^oRm ^j _Ne" "^oRm ^j _Ne" jp-hiragana)
("" "`" "`hm `" "`hm `" jp-hiragana)
("" "a" "`hm `j _Ne" "`hm `j _Ne" jp-hiragana)
("" "c" "cJm c" "cJm c" jp-hiragana)
("" "c" "cJm c" "cJm c" jp-hiragana)
("" "d" "cJm c" "cJm c" jp-hiragana)
("" "e" "eK~m e" "eK~m e" jp-hiragana)
("" "f" "eK~m ej _Ne" "eK~m ej _Ne" jp-hiragana)
("" "g" "gELEm g" "gELEm g" jp-hiragana)
("" "h" "gELEm gj _Ne" "gELEm gj _Ne" jp-hiragana)
("" "i" "iSm i" "iSm i" jp-hiragana)
("" "j" "jzm j" "jzm j" jp-hiragana)
("" "k" "k}Ym k" "k}Ym k" jp-hiragana)
("" "l" "lY~m l" "lY~m l" jp-hiragana)
("" "m" "mnm m" "mnm m" jp-hiragana)
("" "n" "nKLm n" "nKLm n" jp-hiragana)
("" "o" "nKLm nj _Ne" "nKLm nj _Ne" jp-hiragana)
("" "p" "nKLm nj n_Ne" "nKLm nj n_Ne" jp-hiragana)
("" "q" "qRELm q" "qRELm q" jp-hiragana)
("" "r" "qRELm qj _Ne" "qRELm qj _Ne" jp-hiragana)
("" "s" "qRELm qj n_Ne" "qRELm qj n_Ne" jp-hiragana)
("" "t" "tWTm t" "tWTm t" jp-hiragana)
("" "u" "tWTm tj _Ne" "tWTm tj _Ne" jp-hiragana)
("" "v" "tWTm tj n_Ne" "tWTm tj n_Ne" jp-hiragana)
("" "w" "wCm w" "wCm w" jp-hiragana)
("" "x" "wCm wj _Ne" "wCm wj _Ne" jp-hiragana)
("" "y" "wCm wj n_Ne" "wCm wj n_Ne" jp-hiragana)
("" "z" "zPm z" "zPm z" jp-hiragana)
("" "{" "zPm zj _Ne" "zPm zj _Ne" jp-hiragana)
("" "|" "zPm zj n_Ne" "zPm zj n_Ne" jp-hiragana)
("" "}" "}b`m }" "}b`m }" jp-hiragana)
("" "~" "~JTm ~" "~JTm ~" jp-hiragana)
("" "" "Zm " "Zm " jp-hiragana)
("" "" "CWm " "CWm " jp-hiragana)
("" "" "~Wm " "~Wm " jp-hiragana)
("" "" "}gm " "}gm " jp-hiragana)
("" "" "}gm " "}gm " jp-hiragana)
("" "" "~m " "~m " jp-hiragana)
("" "" "~m " "~m " jp-hiragana)
("" "" "Vmm " "Vmm " jp-hiragana)
("" "" "Vmm " "Vmm " jp-hiragana)
("" "" "WIm " "WIm " jp-hiragana)
("" "" "Sm " "Sm " jp-hiragana)
("" "" "XCm " "XCm " jp-hiragana)
("" "" "Qm " "Qm " jp-hiragana)
("" "" "[}m " "[}m " jp-hiragana)
("" "" "rm " "rm " jp-hiragana)
("" "" "rm " "rm " jp-hiragana)
("" "C" "C" "C" jp-hiragana)
("" "G" "G" "G" jp-hiragana)
("" "" "IV}Cm " "IV}Cm " jp-hiragana)
("" "" "IV}Cm " "IV}Cm " jp-hiragana)
("@" "A" "ATqm A" "ATqm A" jp-katakana)
("A" "A" "ATqm A" "ATqm A" jp-katakana)
("B" "C" "Cnm C" "Cnm C" jp-katakana)
("C" "C" "Cnm C" "Cnm C" jp-katakana)
("D" "E" "EGmm E" "EGmm E" jp-katakana)
("E" "E" "EGmm E" "EGmm E" jp-katakana)
("F" "G" "GCSm G" "GCSm G" jp-katakana)
("G" "G" "GCSm G" "GCSm G" jp-katakana)
("H" "I" "IITJm I" "IITJm I" jp-katakana)
("I" "I" "IITJm I" "IITJm I" jp-katakana)
("J" "J" "JZm J" "JZm J" jp-katakana)
("K" "K" "JZm Jj _Ne" "JZm Jj _Ne" jp-katakana)
("L" "L" "Lbem L" "Lbem L" jp-katakana)
("M" "M" "Lbem Lj _Ne" "Lbem Lj _Ne" jp-katakana)
("N" "N" "Num N" "Num N" jp-katakana)
("O" "O" "Num Nj _Ne" "Num Nj _Ne" jp-katakana)
("P" "P" "PVLm P" "PVLm P" jp-katakana)
("Q" "Q" "PVLm Pj _Ne" "PVLm Pj _Ne" jp-katakana)
("R" "R" "Rhm R" "Rhm R" jp-katakana)
("S" "S" "Rhm Rj _Ne" "Rhm Rj _Ne" jp-katakana)
("T" "T" "TNm T" "TNm T" jp-katakana)
("U" "U" "TNm Tj _Ne" "TNm Tj _Ne" jp-katakana)
("V" "V" "Vum V" "Vum V" jp-katakana)
("W" "W" "Vum Vj _Ne" "Vum Vj _Ne" jp-katakana)
("X" "X" "XYm X" "XYm X" jp-katakana)
("Y" "Y" "XYm Xj _Ne" "XYm Xj _Ne" jp-katakana)
("Z" "Z" "ZJCm Z" "ZJCm Z" jp-katakana)
("[" "[" "ZJCm Zj _Ne" "ZJCm Zj _Ne" jp-katakana)
("\" "\" "\om \" "\om \" jp-katakana)
("]" "]" "\om \j _Ne" "\om \j _Ne" jp-katakana)
("^" "^" "^oRm ^" "^oRm ^" jp-katakana)
("_" "_" "^oRm ^j _Ne" "^oRm ^j _Ne" jp-katakana)
("`" "`" "`hm `" "`hm `" jp-katakana)
("a" "a" "`hm `j _Ne" "`hm `j _Ne)" jp-katakana)
("b" "c" "cJm c" "cJm c" jp-katakana)
("c" "c" "cJm c" "cJm c" jp-katakana)
("d" "d" "cJm c" "cJm c" jp-katakana)
("e" "e" "eK~m e" "eK~m e" jp-katakana)
("f" "f" "eK~m ej _Ne" "eK~m ej _Ne" jp-katakana)
("g" "g" "gELEm g" "gELEm g" jp-katakana)
("h" "h" "gELEm gj _Ne" "gELEm gj _Ne" jp-katakana)
("i" "i" "iSm i" "iSm i" jp-katakana)
("j" "j" "jzm j" "jzm j" jp-katakana)
("k" "k" "k}Ym k" "k}Ym k" jp-katakana)
("l" "l" "lY~m l" "lY~m l" jp-katakana)
("m" "m" "mnm m" "mnm m" jp-katakana)
("n" "n" "nKLm n" "nKLm n" jp-katakana)
("o" "o" "nKLm nj _Ne" "nKLm nj _Ne" jp-katakana)
("p" "p" "nKLm nj n_Ne" "nKLm nj n_Ne" jp-katakana)
("q" "q" "qRELm q" "qRELm q" jp-katakana)
("r" "r" "qRELm qj _Ne" "qRELm qj _Ne" jp-katakana)
("s" "s" "qRELm qj n_Ne" "qRELm qj n_Ne" jp-katakana)
("t" "t" "tWTm t" "tWTm t" jp-katakana)
("u" "u" "tWTm tj _Ne" "tWTm tj _Ne" jp-katakana)
("v" "v" "tWTm tj n_Ne" "tWTm tj n_Ne" jp-katakana)
("w" "w" "wCm w" "wCm w" jp-katakana)
("x" "x" "wCm wj _Ne" "wCm wj _Ne" jp-katakana)
("y" "y" "wCm wj n_Ne" "wCm wj n_Ne" jp-katakana)
("z" "z" "zPm z" "zPm z" jp-katakana)
("{" "{" "zPm zj _Ne" "zPm zj _Ne" jp-katakana)
("|" "|" "zPm zj n_Ne" "zPm zj n_Ne" jp-katakana)
("}" "}" "}b`m }" "}b`m }" jp-katakana)
("~" "~" "~JTm ~" "~JTm ~" jp-katakana)
("" "" "Zm " "Zm " jp-katakana)
("" "" "CWm " "CWm " jp-katakana)
("" "" "~Wm " "~Wm " jp-katakana)
("" "" "}gm " "}gm " jp-katakana)
("" "" "}gm " "}gm " jp-katakana)
("" "" "~m " "~m " jp-katakana)
("" "" "~m " "~m " jp-katakana)
("" "" "Vmm " "Vmm " jp-katakana)
("" "" "Vmm " "Vmm " jp-katakana)
("" "" "WIm " "WIm " jp-katakana)
("" "" "Sm " "Sm " jp-katakana)
("" "" "XCm " "XCm " jp-katakana)
("" "" "Qm " "Qm " jp-katakana)
("" "" "[}m " "[}m " jp-katakana)
("" "" "rm " "rm " jp-katakana)
("" "" "" "" jp-katakana)
("" "" "IV}Cm " "IV}Cm " jp-katakana)
("" "" "" "" jp-katakana)
("" "J" "J" "J" jp-katakana)
("" "J" "J" "J" jp-katakana)
("" "IIWAt@" "IIWAt@" "IIWAt@" jp-greek)
("" "IIWx[^" "IIWx[^" "IIWx[^" jp-greek)
("" "IIWK}" "IIWK}" "IIWK}" jp-greek)
("" "IIWf^" "IIWf^" "IIWf^" jp-greek)
("" "IIWCvV" "IIWCvV" "IIWCvV" jp-greek)
("" "IIWWF[^" "IIWWF[^" "IIWWF[^" jp-greek)
("" "IIWC[^" "IIWC[^" "IIWC[^" jp-greek)
("" "IIWV[^" "IIWV[^" "IIWV[^" jp-greek)
("" "IIWCI[^" "IIWCI[^" "IIWCI[^" jp-greek)
("" "IIWJbp" "IIWJbp" "IIWJbp" jp-greek)
("" "IIW_" "IIW_" "IIW_" jp-greek)
("" "IIW~[" "IIW~[" "IIW~[" jp-greek)
("" "IIWj[" "IIWj[" "IIWj[" jp-greek)
("" "IIWNV[" "IIWNV[" "IIWNV[" jp-greek)
("" "IIWI~N" "IIWI~N" "IIWI~N" jp-greek)
("" "IIWpC" "IIWpC" "IIWpC" jp-greek)
("" "IIW[" "IIW[" "IIW[" jp-greek)
("" "IIWVO}" "IIWVO}" "IIWVO}" jp-greek)
("" "IIW^E" "IIW^E" "IIW^E" jp-greek)
("" "IIWEvV" "IIWEvV" "IIWEvV" jp-greek)
("" "IIWtF[" "IIWtF[" "IIWtF[" jp-greek)
("" "IIWL[" "IIWL[" "IIWL[" jp-greek)
("" "IIWvV[" "IIWvV[" "IIWvV[" jp-greek)
("" "IIWIK" "IIWIK" "IIWIK" jp-greek)
("" "At@" "At@" "At@" jp-greek)
("" "x[^" "x[^" "x[^" jp-greek)
("" "K}" "K}" "K}" jp-greek)
("" "f^" "f^" "f^" jp-greek)
("" "CvV" "CvV" "CvV" jp-greek)
("" "WF[^" "WF[^" "WF[^" jp-greek)
("" "C[^" "C[^" "C[^" jp-greek)
("" "V[^" "V[^" "V[^" jp-greek)
("" "CI[^" "CI[^" "CI[^" jp-greek)
("" "Jbp" "Jbp" "Jbp" jp-greek)
("" "_" "_" "_" jp-greek)
("" "~[" "~[" "~[" jp-greek)
("" "j[" "j[" "j[" jp-greek)
("" "NV[" "NV[" "NV[" jp-greek)
("" "I~N" "I~N" "I~N" jp-greek)
("" "pC" "pC" "pC" jp-greek)
("" "[" "[" "[" jp-greek)
("" "VO}" "VO}" "VO}" jp-greek)
("" "^E" "^E" "^E" jp-greek)
("" "EvV" "EvV" "EvV" jp-greek)
("" "tF[" "tF[" "tF[" jp-greek)
("" "L[" "L[" "L[" jp-greek)
("" "vV[" "vV[" "vV[" jp-greek)
("" "IK" "IK" "IK" jp-greek)
("@" "A[" "A[" "A[" jp-cyrillic)
("A" "x[" "x[" "x[" jp-cyrillic)
("B" "uG[" "uG[" "uG[" jp-cyrillic)
("C" "Q[" "Q[" "Q[" jp-cyrillic)
("D" "f[" "f[" "f[" jp-cyrillic)
("E" "CG[" "CG[" "CG[" jp-cyrillic)
("F" "[" "[" "[" jp-cyrillic)
("G" "WG[" "WG[" "WG[" jp-cyrillic)
("H" "[[" "[[" "[[" jp-cyrillic)
("I" "C[" "C[" "C[" jp-cyrillic)
("J" "CN[gJ" "CN[gJ" "CN[gJ" jp-cyrillic)
("K" "J[" "J[" "J[" jp-cyrillic)
("L" "G" "G" "G" jp-cyrillic)
("M" "G" "G" "G" jp-cyrillic)
("N" "Gk" "Gk" "Gk" jp-cyrillic)
("O" "I[" "I[" "I[" jp-cyrillic)
("P" "y[S" "y[S" "y[S" jp-cyrillic)
("Q" "GS" "GS" "GS" jp-cyrillic)
("R" "GXS" "GXS" "GXS" jp-cyrillic)
("S" "e[S" "e[S" "e[S" jp-cyrillic)
("T" "E[S" "E[S" "E[S" jp-cyrillic)
("U" "GtS" "GtS" "GtS" jp-cyrillic)
("V" "n[S" "n[S" "n[S" jp-cyrillic)
("W" "cG[" "cG[" "cG[" jp-cyrillic)
("X" "`F[" "`F[" "`F[" jp-cyrillic)
("Y" "V[" "V[" "V[" jp-cyrillic)
("Z" "VV[" "VV[" "VV[" jp-cyrillic)
("[" "hr[hCG" "hr[hCG" "hr[hCG" jp-cyrillic)
("\" "EC[" "EC[" "EC[" jp-cyrillic)
("]" "CG~[tL[" "CG~[tL[" "CG~[tL[" jp-cyrillic)
("^" "G[" "G[" "G[" jp-cyrillic)
("_" "[" "[" "[" jp-cyrillic)
("`" "[" "[" "[" jp-cyrillic)
("p" "A[S" "A[S" "A[S" jp-cyrillic)
("q" "x[S" "x[S" "x[S" jp-cyrillic)
("r" "uG[S" "uG[S" "uG[S" jp-cyrillic)
("s" "Q[S" "Q[S" "Q[S" jp-cyrillic)
("t" "f[S" "f[S" "f[S" jp-cyrillic)
("u" "CG[S" "CG[S" "CG[S" jp-cyrillic)
("v" "[S" "[S" "[S" jp-cyrillic)
("w" "WG[S" "WG[S" "WG[S" jp-cyrillic)
("x" "[[S" "[[S" "[[S" jp-cyrillic)
("y" "C[S" "C[S" "C[S" jp-cyrillic)
("z" "CN[gJS" "CN[gJS" "CN[gJS" jp-cyrillic)
("{" "J[S" "J[S" "J[S" jp-cyrillic)
("|" "GS" "GS" "GS" jp-cyrillic)
("}" "GS" "GS" "GS" jp-cyrillic)
("~" "GkS" "GkS" "GkS" jp-cyrillic)
("" "I[S" "I[S" "I[S" jp-cyrillic)
("" "y[S" "y[S" "y[S" jp-cyrillic)
("" "GS" "GS" "GS" jp-cyrillic)
("" "GXS" "GXS" "GXS" jp-cyrillic)
("" "e[S" "e[S" "e[S" jp-cyrillic)
("" "E[S" "E[S" "E[S" jp-cyrillic)
("" "GtS" "GtS" "GtS" jp-cyrillic)
("" "n[S" "n[S" "n[S" jp-cyrillic)
("" "cG[S" "cG[S" "cG[S" jp-cyrillic)
("" "`F[S" "`F[S" "`F[S" jp-cyrillic)
("" "V[S" "V[S" "V[S" jp-cyrillic)
("" "VV[S" "VV[S" "VV[S" jp-cyrillic)
("" "hr[hCiYi[NjS" "hr[hCiYi[NjS" "hr[hCiYi[NjS" jp-cyrillic)
("" "EC[S" "EC[S" "EC[S" jp-cyrillic)
("" "~[tL[S" "~[tL[S" "~[tL[S" jp-cyrillic)
("" "G[S" "G[S" "G[S" jp-cyrillic)
("" "[S" "[S" "[S" jp-cyrillic)
("" "[S" "[S" "[S" jp-cyrillic)
("" "PCZ" "PCZ" "PCZ" jp-other)
("" "PCZ" "PCZ" "PCZ" jp-other)
("" "~Mz\V^z\" "~Mz\V^z\" "~Mz\V^z\" jp-other)
("" "q_z\V^z\" "q_z\V^z\" "q_z\V^z\" jp-other)
("" "q_z\EGz\" "q_z\EGz\" "q_z\EGz\" jp-other)
("" "~Mz\EGz\" "~Mz\EGz\" "~Mz\EGz\" jp-other)
("" "~Mz\^ez\" "~Mz\^ez\" "~Mz\^ez\" jp-other)
("" "Rz\V^z\" "Rz\V^z\" "Rz\V^z\" jp-other)
("" "q_z\^ez\" "q_z\^ez\" "q_z\^ez\" jp-other)
("" "Rz\EGz\" "Rz\EGz\" "Rz\EGz\" jp-other)
("" "Rz\^ez\" "Rz\^ez\" "Rz\^ez\" jp-other)
("" "~Mtg^etg" "~Mtg^etg" "~Mtg^etg" jp-other)
("" "RtgV^tg" "RtgV^tg" "RtgV^tg" jp-other)
("" "q_tg^etg" "q_tg^etg" "q_tg^etg" jp-other)
("" "RtgEGtg" "RtgEGtg" "RtgEGtg" jp-other)
("" "Rtg^etg" "Rtg^etg" "Rtg^etg" jp-other)
("" "~Mz\^etg" "~Mz\^etg" "~Mz\^etg" jp-other)
("" "RtgV^z\" "RtgV^z\" "RtgV^z\" jp-other)
("" "q_z\^etg" "q_z\^etg" "q_z\^etg" jp-other)
("" "RtgEGz\" "RtgEGz\" "RtgEGz\" jp-other)
("" "Rtg^ez\" "Rtg^ez\" "Rtg^ez\" jp-other)
("" "~Mtg^ez\" "~Mtg^ez\" "~Mtg^ez\" jp-other)
("" "Rz\V^tg" "Rz\V^tg" "Rz\V^tg" jp-other)
("" "q_tg^ez\" "q_tg^ez\" "q_tg^ez\" jp-other)
("" "Rz\EGtg" "Rz\EGtg" "Rz\EGtg" jp-other)
("" "Rz\^etg" "Rz\^etg" "Rz\^etg" jp-other)
("@" "}C`" "}C`" "}C`" jp-other)
("A" "}j" "}j" "}j" jp-other)
("B" "}T" "}T" "}T" jp-other)
("C" "}" "}" "}" jp-other)
("D" "}S" "}S" "}S" jp-other)
("E" "}N" "}N" "}N" jp-other)
("F" "}ii" "}ii" "}ii" jp-other)
("G" "}n`" "}n`" "}n`" jp-other)
("H" "}L[" "}L[" "}L[" jp-other)
("I" "}W[" "}W[" "}W[" jp-other)
("J" "}W[C`" "}W[C`" "}W[C`" jp-other)
("K" "}W[j" "}W[j" "}W[j" jp-other)
("L" "}W[T" "}W[T" "}W[T" jp-other)
("M" "}W[" "}W[" "}W[" jp-other)
("N" "}W[S" "}W[S" "}W[S" jp-other)
("O" "}W[N" "}W[N" "}W[N" jp-other)
("P" "}W[ii" "}W[ii" "}W[ii" jp-other)
("Q" "}W[n`" "}W[n`" "}W[n`" jp-other)
("R" "}W[L[" "}W[L[" "}W[L[" jp-other)
("S" "}jW[" "}jW[" "}jW[" jp-other)
("T" "C`" "[}XEWm C`" "[}XEWm C`" jp-other)
("U" "j[" "[}XEWm j[" "[}XEWm j[" jp-other)
("V" "T" "[}XEWm T" "[}XEWm T" jp-other)
("W" "" "[}XEWm " "[}XEWm " jp-other)
("X" "S" "[}XEWm S" "[}XEWm S" jp-other)
("Y" "N" "[}XEWm N" "[}XEWm N" jp-other)
("Z" "ii" "[}XEWm ii" "[}XEWm ii" jp-other)
("[" "n`" "[}XEWm n`" "[}XEWm n`" jp-other)
("\" "L[" "[}XEWm L[" "[}XEWm L[" jp-other)
("]" "W[" "[}XEWm W[" "[}XEWm W[" jp-other)
("_" "~" "~" "~" jp-other)
("`" "L" "L" "L" jp-other)
("a" "Z`" "Z`" "Z`" jp-other)
("b" "[g" "[g" "[g" jp-other)
("c" "O" "O" "O" jp-other)
("d" "g" "g" "g" jp-other)
("e" "A[" "A[" "A[" jp-other)
("f" "wN^[" "wN^[" "wN^[" jp-other)
("g" "bg" "bg" "bg" jp-other)
("h" "bg" "bg" "bg" jp-other)
("i" "J[" "J[" "J[" jp-other)
("j" "h" "h" "h" jp-other)
("k" "Zg" "Zg" "Zg" jp-other)
("l" "p[Zg" "p[Zg" "p[Zg" jp-other)
("m" "~o[" "~o[" "~o[" jp-other)
("n" "y[W" "y[W" "y[W" jp-other)
("o" "~[g" "~[g" "~[g" jp-other)
("p" "Z`[g" "Z`[g" "Z`[g" jp-other)
("q" "L[g" "L[g" "L[g" jp-other)
("r" "~O" "~O" "~O" jp-other)
("s" "LO" "LO" "LO" jp-other)
("t" "V[V[" "V[V[" "V[V[" jp-other)
("u" "wCz[[g" "wCz[[g" "wCz[[g" jp-other)
("~" "wCZC" "wCZC" "wCZC" jp-other)
("" "io[" "io[" "io[" jp-other)
("" "JuVLKCV" "JuVLKCV" "JuVLKCV" jp-other)
("" "foSE" "foSE" "foSE" jp-other)
("" "}miJjEG" "}miJjEG" "}miJjEG" jp-other)
("" "}miJj`E" "}miJj`E" "}miJj`E" jp-other)
("" "}miJjV^" "}miJjV^" "}miJjV^" jp-other)
("" "}miJjq_" "}miJjq_" "}miJjq_" jp-other)
("" "}miJj~M" "}miJj~M" "}miJj~M" jp-other)
("" "JuVLKCV" "JuVLKCV" "JuVLKCV" jp-other)
("" "EQKCV" "EQKCV" "EQKCV" jp-other)
("" "_CqE" "_CqE" "_CqE" jp-other)
("" "CW" "CW" "CW" jp-other)
("" "^CV[" "^CV[" "^CV[" jp-other)
("" "V[" "V[" "V[" jp-other)
("" "LW}^g[S[" "LW}^g[S[" "LW}^g[S[" jp-other)
("" "S[h[" "S[h[" "S[h[" jp-other)
("" "ZLuLS[" "ZLuLS[" "ZLuLS[" jp-other)
("" "V[JCZLu" "V[JCZLu" "V[JCZLu" jp-other)
("" "VO}" "VO}" "VO}" jp-other)
("" "wCz[R" "wCz[R" "wCz[R" jp-other)
("" "XC`N" "XC`N" "XC`N" jp-other)
("" "JNh" "JNh" "JNh" jp-other)
("" "`bJN" "`bJN" "`bJN" jp-other)
("" "TJNPC" "TJNPC" "TJNPC" jp-other)
("" "i[io" "i[io" "i[io" jp-other)
("" "Lbv" "Lbv" "Lbv" jp-other)
("" "Jbv" "Jbv" "Jbv" jp-other)
("" "A" "AWAm A" "AWAm A" jp-kanji)
("" "A" "A[g Xm A" "A[g Xm A" jp-kanji)
("" "A" "rWm A" "rWm A" jp-kanji)
("" "A" "A~_ucm A" "A~_ucm A" jp-kanji)
("" "AC" "Am AC" "Am AC" jp-kanji)
("" "AC" "ACWm AC" "ACWm AC" jp-kanji)
("" "AC" "ACTcm AC" "ACTcm AC" jp-kanji)
("" "AC" "ACm AC" "ACm AC" jp-kanji)
("" "z[" "z[`Nm AE" "z[`Nm AE" jp-kanji)
("" "L" "nim AIC" "nim AIC" jp-kanji)
("" "Z" "AJCm AJl" "AJCm AJl" jp-kanji)
("" "L" "Jm AL" "Jm AL" jp-kanji)
("" "AN" "Cm AN" "Cm AN" jp-kanji)
("" "AN" "jMm AN" "jMm AN" jp-kanji)
("" "AN" "AcCm AN" "AcCm AN" jp-kanji)
("" "LN" "LNm ATq" "LNm ATq" jp-kanji)
("" "AV" "AVQm AV" "AVQm AV" jp-kanji)
("" "AV" "VNucm AV" "VNucm AV" jp-kanji)
("" "\[" "TJim AW" "TJim AW" jp-kanji)
("" "V" "Lm AYT" "Lm AYT" jp-kanji)
("" "Ac" "AcNm Ac" "AcNm Ac" jp-kanji)
("" "Ac" "Om Ac" "Om Ac" jp-kanji)
("" "L[" "AcJEm L[" "AcJEm L[" jp-kanji)
("" "Ae" "Aeim Ae" "Aeim Ae" jp-kanji)
("" "Al" "AlSm Al" "AlSm Al" jp-kanji)
("" "{[" "R`[m Au" "R`[m Au" jp-kanji)
("" "C" "^xmm A" "^xmm A" jp-kanji)
("" "P" "Pm A" "Pm A" jp-kanji)
("" "[" "AMkm A" "AMkm A" jp-kanji)
("" "A" "TJim A" "TJim A" jp-kanji)
("" "N" "Nm AC" "Nm AC" jp-kanji)
("" "A" "]Nm A" "]Nm A" jp-kanji)
("" "AZ" "Lmm AZ" "Lmm AZ" jp-kanji)
("" "A" "XCm A" "XCm A" jp-kanji)
("" "A" "CIm A" "CIm A" jp-kanji)
("" "A" "A}m A" "A}m A" jp-kanji)
("" "A" "NCm A" "NCm A" jp-kanji)
("" "A" "AiCm A" "AiCm A" jp-kanji)
("" "A" "~m A" "~m A" jp-kanji)
("" "A" "Nm A" "Nm A" jp-kanji)
("" "L[" "N_mm AY" "N_mm AY" jp-kanji)
("" "C" "bem C" "bem C" jp-kanji)
("" "C" "CYng[m C" "CYng[m C" jp-kanji)
("" "C" "NCm C" "NCm C" jp-kanji)
("" "C" "m C" "m C" jp-kanji)
("" "C" "GCm C" "GCm C" jp-kanji)
("" "C" "JRm C" "JRm C" jp-kanji)
("" "C" "GrXm C" "GrXm C" jp-kanji)
("" "C" "_lm C" "_lm C" jp-kanji)
("" "C" "IhXm C" "IhXm C" jp-kanji)
("" "C" "V[Cm C" "V[Cm C" jp-kanji)
("" "C" "IEm C" "IEm C" jp-kanji)
("" "C" "C~m C" "C~m C" jp-kanji)
("" "C" "iOTm C" "iOTm C" jp-kanji)
("" "C" "TVCm C" "TVCm C" jp-kanji)
("" "C" "CXm C" "CXm C" jp-kanji)
("" "C" "^m C" "^m C" jp-kanji)
("" "C" "JVR}m C" "JVR}m C" jp-kanji)
("" "C" "Rgim C" "Rgim C" jp-kanji)
("" "C" "EcXm C" "EcXm C" jp-kanji)
("" "C" "CWCVm C" "CWCVm C" jp-kanji)
("" "C" "RCgm C" "RCgm C" jp-kanji)
("" "C" "CuNm C" "CuNm C" jp-kanji)
("" "C" "iGm C" "iGm C" jp-kanji)
("" "C" "Rm C" "Rm C" jp-kanji)
("" "C" "Cm C" "Cm C" jp-kanji)
("" "C" "`KEm C" "`KEm C" jp-kanji)
("" "C" "CVm C" "CVm C" jp-kanji)
("" "C" "CVm C" "CVm C" jp-kanji)
("" "C" "Chm C" "Chm C" jp-kanji)
("" "KC" "W[jVm C" "W[jVm C" jp-kanji)
("" "CL" "`CLm CL" "`CLm CL" jp-kanji)
("" "CN" "\_cm CN" "\_cm CN" jp-kanji)
("" "CN" "tNCNm CN" "tNCNm CN" jp-kanji)
("" "L" "C\xm C\" "C\xm C\" jp-kanji)
("" "C`" "JX[Wm C`" "JX[Wm C`" jp-kanji)
("" "C`" "CLm V}m C`" "CLm V}m C`" jp-kanji)
("" "Cc" "Atm Cc" "Atm Cc" jp-kanji)
("" "Cc" "mKXm Cc" "mKXm Cc" jp-kanji)
("" "g[" "Cizm Cl" "Cizm Cl" jp-kanji)
("" "V" "gQm Co" "gQm Co" jp-kanji)
("" "C" "Tc}Cm C" "Tc}Cm C" jp-kanji)
("" "WN" "TJim CV" "TJim CV" jp-kanji)
("" "C" "Xm C" "Xm C" jp-kanji)
("" "C" "VVm C" "VVm C" jp-kanji)
("" "C" "mhm C" "mhm C" jp-kanji)
("" "C" "eCm C" "eCm C" jp-kanji)
("" "C" "QCm C" "QCm C" jp-kanji)
("" "C" "RCm C" "RCm C" jp-kanji)
("" "C" "qNm C" "qNm C" jp-kanji)
("" "C" "mm C" "mm C" jp-kanji)
("" "C" "~_m C" "~_m C" jp-kanji)
("" "C" "^lm C" "^lm C" jp-kanji)
("" "C" "RJQm C" "RJQm C" jp-kanji)
("@" "C" "r[Cm C" "r[Cm C" jp-kanji)
("A" "C" "JQm C" "JQm C" jp-kanji)
("B" "C" "JNXm C" "JNXm C" jp-kanji)
("C" "C" "Cm C" "Cm C" jp-kanji)
("D" "C`" "iKTm C`" "iKTm C`" jp-kanji)
("E" "E" "~Mm E" "~Mm E" jp-kanji)
("F" "E" "E`[m E" "E`[m E" jp-kanji)
("G" "E" "JXm E" "JXm E" jp-kanji)
("H" "E" "nlm E" "nlm E" jp-kanji)
("I" "E" "EGm E" "EGm E" jp-kanji)
("J" "E" "Am E" "Am E" jp-kanji)
("K" "{[" "W[jVm E" "W[jVm E" jp-kanji)
("L" "eC" "gm E" "gm E" jp-kanji)
("M" "L" "Lm EJKE" "Lm EJKE" jp-kanji)
("N" "`[" "W[jVm EV" "W[jVm EV" jp-kanji)
("O" "^C" "^Cm EX" "^Cm EX" jp-kanji)
("P" "L[" "L[m EX" "L[m EX" jp-kanji)
("Q" "J" "Jm EY" "Jm EY" jp-kanji)
("R" "L" "Lm E\" "Lm E\" jp-kanji)
("S" "oC" "oCm E^" "oCm E^" jp-kanji)
("T" "Ec" "[Ecm Ec" "[Ecm Ec" jp-kanji)
("U" "Ec" "Cm Ec" "Cm Ec" jp-kanji)
("V" "}" "}m EiM" "}m EiM" jp-kanji)
("W" "{" "{m Eo" "{m Eo" jp-kanji)
("X" "L[" "L[m E}" "L[m E}" jp-kanji)
("Y" "E" "zm E" "zm E" jp-kanji)
("Z" "J" "Jm E" "Jm E" jp-kanji)
("[" "W" "Wm E[" "Wm E[" jp-kanji)
("\" "\" "\m ET" "\m ET" jp-kanji)
("]" "E" "CEm E" "CEm E" jp-kanji)
("^" "E" "nRum E" "nRum E" jp-kanji)
("_" "E" "Nm E" "Nm E" jp-kanji)
("`" "G" "jm GS}" "jm GS}" jp-kanji)
("a" "W" "Wm GT" "Wm GT" jp-kanji)
("b" "GC" "qGCUm GC" "qGCUm GC" jp-kanji)
("c" "GC" "Cgim GC" "Cgim GC" jp-kanji)
("d" "GC" "~hSm GC" "~hSm GC" jp-kanji)
("e" "GC" "JQm GC" "JQm GC" jp-kanji)
("f" "GC" "Ecm GC" "Ecm GC" jp-kanji)
("g" "GC" "qNm GC" "qNm GC" jp-kanji)
("h" "GC" "TJGm GC" "TJGm GC" jp-kanji)
("i" "GC" "iKCm GC" "iKCm GC" jp-kanji)
("j" "GC" "IOm GC" "IOm GC" jp-kanji)
("k" "GC" "m GC" "m GC" jp-kanji)
("l" "GC" "XCV[m GC" "XCV[m GC" jp-kanji)
("m" "GC" "~`m GC" "~`m GC" jp-kanji)
("n" "GC" "mMm GC" "mMm GC" jp-kanji)
("o" "GC" "mMm ]NW" "mMm ]NW" jp-kanji)
("p" "GC" "GCSm GC" "GCSm GC" jp-kanji)
("q" "GC" "}m GC" "}m GC" jp-kanji)
("r" "GC" "m GC" "m GC" jp-kanji)
("s" "GC" "XhCm GC" "XhCm GC" jp-kanji)
("t" "GL" "GL^Cm GL" "GL^Cm GL" jp-kanji)
("u" "GL" "GLr[m GL" "GLr[m GL" jp-kanji)
("v" "GL" "GLm GL" "GLm GL" jp-kanji)
("w" "GL" "eCVom GL" "eCVom GL" jp-kanji)
("x" "Gc" "Rum Gc" "Rum Gc" jp-kanji)
("y" "Gc" "GbPm Gc" "GbPm Gc" jp-kanji)
("z" "Gc" "RXm Gc" "RXm Gc" jp-kanji)
("{" "Gc" "Gcm Gc" "Gcm Gc" jp-kanji)
("|" "J" "LmGm L" "LmGm L" jp-kanji)
("}" "G" "Cg[m G" "Cg[m G" jp-kanji)
("~" "G" "}m G" "}m G" jp-kanji)
("" "G" "\mm G" "\mm G" jp-kanji)
("" "G" "ZLm G" "ZLm G" jp-kanji)
("" "G" "A}~m G" "A}~m G" jp-kanji)
("" "G" "E^Qm G" "E^Qm G" jp-kanji)
("" "G" "mrm G" "mrm G" jp-kanji)
("" "G" "Em G" "Em G" jp-kanji)
("" "G" "IIEm G" "IIEm G" jp-kanji)
("" "G" "I[Gm G" "I[Gm G" jp-kanji)
("" "G" "\[m G" "\[m G" jp-kanji)
("" "G" "GQLm G" "GQLm G" jp-kanji)
("" "G" "zm Im G" "zm Im G" jp-kanji)
("" "G" "JG_}m G" "JG_}m G" jp-kanji)
("" "G" "Pm G" "Pm G" jp-kanji)
("" "G" "com G" "com G" jp-kanji)
("" "G" "Tm G" "Tm G" jp-kanji)
("" "G" "[cGm G" "[cGm G" jp-kanji)
("" "G" "cm G" "cm G" jp-kanji)
("" "G" "R[WGm G" "R[WGm G" jp-kanji)
("" "G" "NTm \mm G" "NTm \mm G" jp-kanji)
("" "G" "gICm G" "gICm G" jp-kanji)
("" "G" "i}m G" "i}m G" jp-kanji)
("" "G" "IVhm G" "IVhm G" jp-kanji)
("" "G" "VIm G" "VIm G" jp-kanji)
("" "I" "IPm I" "IPm I" jp-kanji)
("" "I" "L^iCm I" "L^iCm I" jp-kanji)
("" "IC" "ICCm IC" "ICCm IC" jp-kanji)
("" "I[" "I[gcm I[" "I[gcm I[" jp-kanji)
("" "I[" "`[I[m I[" "`[I[m I[" jp-kanji)
("" "I[" "INm I[" "INm I[" jp-kanji)
("" "I[" "Nm I[" "Nm I[" jp-kanji)
("" "I[" "R^Gm I[" "R^Gm I[" jp-kanji)
("" "I[" "IXm I[" "IXm I[" jp-kanji)
("" "I[" "TJm I[" "TJm I[" jp-kanji)
("" "I[" "Rm I[" "Rm I[" jp-kanji)
("" "I[" "ZCI[m I[" "ZCI[m I[" jp-kanji)
("" "I[" "iOm I[" "iOm I[" jp-kanji)
("" "I[" "I[T}m I[" "I[T}m I[" jp-kanji)
("" "I[" "ILim I[" "ILim I[" jp-kanji)
("" "I[" "tX}m I[" "tX}m I[" jp-kanji)
("" "I[" "EOCXm I[" "EOCXm I[" jp-kanji)
("" "I[" "Jm I[" "Jm I[" jp-kanji)
("" "I[" "LCm I[" "LCm I[" jp-kanji)
("" "IJ" "IJ}m IJ" "IJ}m IJ" jp-kanji)
("" "`[" "`[m IL" "`[m IL" jp-kanji)
("" "e" "NTm IM" "NTm IM" jp-kanji)
("" "IN" "JX[Wm IN" "JX[Wm IN" jp-kanji)
("" "" "m IN" "m IN" jp-kanji)
("" "IN" "LINm IN" "LINm IN" jp-kanji)
("" "IN" "INr[m IN" "INr[m IN" jp-kanji)
("" "[" "eIPm IP" "eIPm IP" jp-kanji)
("" "{" "IXXm IX" "IXXm IX" jp-kanji)
("" "Ic" "R[Icm Ic" "R[Icm Ic" jp-kanji)
("" "G" "rim I" "rim I" jp-kanji)
("" "IV" "Vm IX" "Vm IX" jp-kanji)
("" "I" "IWm I" "IWm I" jp-kanji)
("" "I" "A^^Jm I" "A^^Jm I" jp-kanji)
("" "I" "I_Jm I" "I_Jm I" jp-kanji)
("" "I" "Igm I" "Igm I" jp-kanji)
("" "J" "V^m J" "V^m J" jp-kanji)
("" "J" "oPm J" "oPm J" jp-kanji)
("" "J" "Jm J" "Jm J" jp-kanji)
("" "i" "ijm J" "ijm J" jp-kanji)
("" "J" "IgMoiVm J" "IgMoiVm J" jp-kanji)
("" "J" "A^Cm J" "A^Cm J" jp-kanji)
("" "J" "JWm J" "JWm J" jp-kanji)
("" "J" "NGm J" "NGm J" jp-kanji)
("" "J" "LJm J" "LJm J" jp-kanji)
("" "J" "JtNm J" "JtNm J" jp-kanji)
("" "J" "icm J" "icm J" jp-kanji)
("" "J" "m J" "m J" jp-kanji)
("" "J" "CGm J" "CGm J" jp-kanji)
("" "J" "XNiCm J" "XNiCm J" jp-kanji)
("" "J" "Jm J" "Jm J" jp-kanji)
("" "J" "q}m J" "q}m J" jp-kanji)
("" "J" "n^Xm J" "n^Xm J" jp-kanji)
("" "J" "JPm J" "JPm J" jp-kanji)
("" "J" "E^m J" "E^m J" jp-kanji)
("" "J" "Jm J" "Jm J" jp-kanji)
("" "J" "qm J" "qm J" jp-kanji)
("" "J" "Vm Em J" "Vm Em J" jp-kanji)
("" "J" "UCm J" "UCm J" jp-kanji)
("" "J" "RNcm J" "RNcm J" jp-kanji)
("" "J" "JZOm J" "JZOm J" jp-kanji)
("" "J" "JW[KLm J" "JW[KLm J" jp-kanji)
("" "J" "nim J" "nim J" jp-kanji)
("" "J" "SCm J" "SCm J" jp-kanji)
("" "J" "iXm J" "iXm J" jp-kanji)
("" "J" "jcm J" "jcm J" jp-kanji)
("" "J" "`[Jm J" "`[Jm J" jp-kanji)
("" "J" "JVm J" "JVm J" jp-kanji)
("" "J" "Grm J" "Grm J" jp-kanji)
("" "J" "J_Cm J" "J_Cm J" jp-kanji)
("" "J" "J}VCm J" "J}VCm J" jp-kanji)
("" "J" "Jcm J" "Jcm J" jp-kanji)
("" "J" "VJm J" "VJm J" jp-kanji)
("" "J" "XMm J" "XMm J" jp-kanji)
("" "J" "JX~m J" "JX~m J" jp-kanji)
("" "J" "Vm J" "Vm J" jp-kanji)
("" "K" "jJm K" "jJm K" jp-kanji)
("" "K" "KrTm K" "KrTm K" jp-kanji)
("" "K" "m K" "m K" jp-kanji)
("" "K" "Lom K" "Lom K" jp-kanji)
("" "K" "Km K" "Km K" jp-kanji)
("" "K" "tXm K" "tXm K" jp-kanji)
("" "K" "m K" "m K" jp-kanji)
("" "K" "Vm K" "Vm K" jp-kanji)
("" "K" "VNKm K" "VNKm K" jp-kanji)
("" "K" "~rJm K" "~rJm K" jp-kanji)
("" "K" "KLm K" "KLm K" jp-kanji)
("" "K" "JSm K" "JSm K" jp-kanji)
("" "JC" "JC]Gm JC" "JC]Gm JC" jp-kanji)
("" "JC" "AEm JC" "AEm JC" jp-kanji)
("" "JC" "gNm JC" "gNm JC" jp-kanji)
("" "JC" "}m JC" "}m JC" jp-kanji)
("" "JC" "J^}m JC" "J^}m JC" jp-kanji)
("" "JC" "RXm JC" "RXm JC" jp-kanji)
("" "JC" "Om JC" "Om JC" jp-kanji)
("" "JC" "RRCm JC" "RRCm JC" jp-kanji)
("" "JC" "AVCm JC" "AVCm JC" jp-kanji)
("" "JC" "NCm JC" "NCm JC" jp-kanji)
("" "JC" "JCJCm JC" "JCJCm JC" jp-kanji)
("" "JC" "icJVCm JC" "icJVCm JC" jp-kanji)
("" "JC" "C}Vm JC" "C}Vm JC" jp-kanji)
("" "JC" "[JCm JC" "[JCm JC" jp-kanji)
("" "JC" "A^m JC" "A^m JC" jp-kanji)
("@" "JC" "TLKPm JC" "TLKPm JC" jp-kanji)
("A" "JC" "cSm JC" "cSm JC" jp-kanji)
("B" "JC" "LJCm JC" "LJCm JC" jp-kanji)
("C" "JC" "E~m JC" "E~m JC" jp-kanji)
("D" "JC" "nCm JC" "nCm JC" jp-kanji)
("E" "JC" "ZJCm JC" "ZJCm JC" jp-kanji)
("F" "JC" "~im JC" "~im JC" jp-kanji)
("G" "JC" "Gm JC" "Gm JC" jp-kanji)
("H" "JC" "AN^m JC" "AN^m JC" jp-kanji)
("I" "JC" "h[ucm Jj" "h[ucm Jj" jp-kanji)
("J" "JC" "qNm JC" "qNm JC" jp-kanji)
("K" "JC" "JC_m JC" "JC_m JC" jp-kanji)
("L" "JC" "JCKm JC" "JCKm JC" jp-kanji)
("M" "KC" "KCZm KC" "KCZm KC" jp-kanji)
("N" "KC" "_KCm KC" "_KCm KC" jp-kanji)
("O" "KC" "\gm KC" "\gm KC" jp-kanji)
("P" "KC" "ZLm KC" "ZLm KC" jp-kanji)
("Q" "KC" "KChNm KC" "KChNm KC" jp-kanji)
("R" "KC" "KPm KC" "KPm KC" jp-kanji)
("S" "KC" "tKCm KC" "tKCm KC" jp-kanji)
("T" "KC" "IIlm KC" "IIlm KC" jp-kanji)
("U" "KC" "nem KC" "nem KC" jp-kanji)
("V" "KC" "KCVm KC" "KCVm KC" jp-kanji)
("W" "KC" "P_Vm KC" "P_Vm KC" jp-kanji)
("X" "KC" "}`m KC" "}`m KC" jp-kanji)
("Y" "KC" "g[KCm KC" "g[KCm KC" jp-kanji)
("Z" "KC" "Cm KC" "Cm KC" jp-kanji)
("[" "KC" "KCRcm KC" "KCRcm KC" jp-kanji)
("\" "JC" "iKTm JC" "iKTm JC" jp-kanji)
("]" "PC" "PCm JI" "PCm JI" jp-kanji)
("^" "A" "h[ucm JG" "h[ucm JG" jp-kanji)
("_" "G" "JLlm JL" "JLlm JL" jp-kanji)
("`" "V" "N_mm JL" "N_mm JL" jp-kanji)
("a" "C" "JCm JL" "JCm JL" jp-kanji)
("b" "R[" "JMom JM" "JMom JM" jp-kanji)
("c" "JN" "JNCcm L[W" "JNCcm L[W" jp-kanji)
("d" "JN" "CJNXm JN" "CJNXm JN" jp-kanji)
("e" "JN" "ImImm JN" "Im Imm JN" jp-kanji)
("f" "JN" "Nm JN" "Nm JN" jp-kanji)
("g" "JN" "JN_Cm JN" "JN_Cm JN" jp-kanji)
("h" "JN" "JNnm JN" "JNnm JN" jp-kanji)
("i" "JN" "JNQm JN" "JNQm JN" jp-kanji)
("j" "JN" "QVJNm JN" "QVJNm JN" jp-kanji)
("k" "JN" "Jm JN" "Jm JN" jp-kanji)
("l" "JN" "Gm JN" "Gm JN" jp-kanji)
("m" "JN" "^VJm JN" "^VJm JN" jp-kanji)
("n" "JN" "V[JNm JN" "V[JNm JN" jp-kanji)
("o" "JN" "I{Gm JN" "I{Gm JN" jp-kanji)
("p" "JN" "cmm JN" "cmm JN" jp-kanji)
("q" "JN" "IhXm JN" "IhXm JN" jp-kanji)
("r" "JN" "Nxm JN" "Nxm JN" jp-kanji)
("s" "JN" "JNm JN" "JNm JN" jp-kanji)
("t" "JN" "JN[m JN" "JN[m JN" jp-kanji)
("u" "JN" "w_em JN" "w_em JN" jp-kanji)
("v" "JN" "Jm JN" "Jm JN" jp-kanji)
("w" "KN" "}ium KN" "}ium KN" jp-kanji)
("x" "KN" "^Pm KN" "^Pm KN" jp-kanji)
("y" "KN" "^m VCm KN" "^m VCm KN" jp-kanji)
("z" "KN" "q^Cm KN" "q^Cm KN" jp-kanji)
("{" "KN" "ASm KN" "ASm KN" jp-kanji)
("|" "J" "JPSGm JP" "JPSGm JP" jp-kanji)
("}" "[" "[m JT" "[m JT" jp-kanji)
("~" "P" "JVm Lm JV" "JVm Lm JV" jp-kanji)
("" "L[" "JVnm JV" "JVnm JV" jp-kanji)
("" "r" "JW{[m JW" "JW{[m JW" jp-kanji)
("" "V[" "TJim JWJ" "TJim JWJ" jp-kanji)
("" "J^" "jCK^m J^" "jCK^m J^" jp-kanji)
("" "Jc" "m Jc" "m Jc" jp-kanji)
("" "Jc" "JbTCm Jc" "JbTCm Jc" jp-kanji)
("" "Jc" "JbR[m Jc" "JbR[m Jc" jp-kanji)
("" "Jc" "\[Jcm Jc" "\[Jcm Jc" jp-kanji)
("" "Jc" "Jch[m Jc" "Jch[m Jc" jp-kanji)
("" "Jc" "JNm Jc" "JNm Jc" jp-kanji)
("" "Jc" "iJm Jc" "iJm Jc" jp-kanji)
("" "Jc" "Jbg[m Jc" "Jbg[m Jc" jp-kanji)
("" "Jc" "JbVNm Jc" "JbVNm Jc" jp-kanji)
("" "Jc" "JJcm Jc" "JJcm Jc" jp-kanji)
("" "\" "Jc}^m Jc" "Jc}^m Jc" jp-kanji)
("" "P" "TJim JcI" "TJim JcI" jp-kanji)
("" "L[" "lKCK JiE" "lKCK JiE" jp-kanji)
("" "J" "nim uVm Jo" "nim uVm Jo" jp-kanji)
("" "J" "Lm Jo" "Lm Jo" jp-kanji)
("" "z[" "Jm Jo" "Jm Jo" jp-kanji)
("" "Ju" "JuVLm Ju" "JuVLm Ju" jp-kanji)
("" "g[" "Cm Jug" "Cm Jug" jp-kanji)
("" "\[" "CVm J}h" "CVm J}h" jp-kanji)
("" "z" "NTm K}" "NTm K}" jp-kanji)
("" "t" "ixJ}m J}" "ixJ}m J}" jp-kanji)
("" "" "J}Nrm J}" "J}Nrm J}" jp-kanji)
("" "R[" "nf Jm J" "nf Jm J" jp-kanji)
("" "I[" "gm J" "gm J" jp-kanji)
("" "nN" "JVm ]NW" "JVm ]NW" jp-kanji)
("" "`" "{[m J" "{[m J" jp-kanji)
("" "P" "Pm J" "Pm J" jp-kanji)
("" "VN" "CKm J" "CKm J" jp-kanji)
("" "KC" "KCm J" "KCm J" jp-kanji)
("" "KC" "Jm RNW" "Jm RNW" jp-kanji)
("" "K" "Km J" "Km J" jp-kanji)
("" "J" "JNm J" "JNm J" jp-kanji)
("" "J" "JKNm J" "JKNm J" jp-kanji)
("" "J" "Jm J" "Jm J" jp-kanji)
("" "J" "TCm J" "TCm J" jp-kanji)
("" "J" "jbJVm J" "jbJVm J" jp-kanji)
("" "J" "Jxm J" "Jxm J" jp-kanji)
("" "J" "XXm J" "XXm J" jp-kanji)
("" "J" "}Nm J" "}Nm J" jp-kanji)
("" "J" "um J" "um J" jp-kanji)
("" "J" "^Gm J" "^Gm J" jp-kanji)
("" "J" "JV}VCm J" "JV}VCm J" jp-kanji)
("" "J" "J[m J" "J[m J" jp-kanji)
("" "J" "Jm J" "Jm J" jp-kanji)
("" "J" "J_Cm J" "J_Cm J" jp-kanji)
("" "J" "zXm J" "zXm J" jp-kanji)
("" "J" "~Lm J" "~Lm J" jp-kanji)
("" "J" "YEm J" "YEm J" jp-kanji)
("" "J" "JWZCm J" "JWZCm J" jp-kanji)
("" "J" "im J" "im J" jp-kanji)
("" "J" "CJm J" "CJm J" jp-kanji)
("" "J" "JGm J" "JGm J" jp-kanji)
("" "J" "[Jm J" "[Jm J" jp-kanji)
("" "J" "~Jm J" "~Jm J" jp-kanji)
("" "J" "Jm J" "Jm J" jp-kanji)
("" "J" "qcMm J" "qcMm J" jp-kanji)
("" "J" "bJm J" "bJm J" jp-kanji)
("" "J" "Rum J" "Rum J" jp-kanji)
("" "J" "AZm J" "AZm J" jp-kanji)
("" "J" "JWm J" "JWm J" jp-kanji)
("" "J" "^jm J" "^jm J" jp-kanji)
("" "J" "\\Om J" "\\Om J" jp-kanji)
("" "J" "JL[m J" "JL[m J" jp-kanji)
("" "J" "A}Cm J" "A}Cm J" jp-kanji)
("" "J" "JSNm J" "JSNm J" jp-kanji)
("" "J" "JStm J" "JStm J" jp-kanji)
("" "J" "TIm J" "TIm J" jp-kanji)
("" "J" "N_m J" "N_m J" jp-kanji)
("" "J" "J^m J" "J^m J" jp-kanji)
("" "J" "Cm J" "Cm J" jp-kanji)
("" "J" "Jdm J" "Jdm J" jp-kanji)
("" "J" "eK~m J" "eK~m J" jp-kanji)
("" "J" "Lm J" "Lm J" jp-kanji)
("" "J" "OJm J" "OJm J" jp-kanji)
("" "J" "CkVm J" "CkVm J" jp-kanji)
("" "J" "~m J" "~m J" jp-kanji)
("" "J" "CTm J" "CTm J" jp-kanji)
("" "J" "ckNm J" "ckNm J" jp-kanji)
("" "J" "JLm J" "JLm J" jp-kanji)
("" "J" "Jxcm J" "Jxcm J" jp-kanji)
("" "J" "AC_m J" "AC_m J" jp-kanji)
("" "J" "q}m J" "q}m J" jp-kanji)
("" "J" "ZLm J" "ZLm J" jp-kanji)
("" "J" "I`Cm J" "I`Cm J" jp-kanji)
("" "J" "JRNm J" "JRNm J" jp-kanji)
("" "J" "J^m J" "J^m J" jp-kanji)
("" "J" "J^m ]NW" "J^m ]NW" jp-kanji)
("" "K" "}m K" "}m K" jp-kanji)
("" "K" "tNm K" "tNm K" jp-kanji)
("" "K" "LVm K" "LVm K" jp-kanji)
("" "K" "KNcm K" "KNcm K" jp-kanji)
("" "K" "KOm K" "KOm K" jp-kanji)
("" "K" "r[Lm K" "r[Lm K" jp-kanji)
("" "K" "}iRm K" "}iRm K" jp-kanji)
("" "K" "Cm K" "Cm K" jp-kanji)
("" "K" "eA\um K" "eA\um K" jp-kanji)
("" "K" "jZm K" "jZm K" jp-kanji)
("" "K" "gm K" "gm K" jp-kanji)
("" "K" "J^Nim K" "J^Nim K" jp-kanji)
("" "K" "JIm K" "JIm K" jp-kanji)
("" "K" "lKEm K" "lKEm K" jp-kanji)
("" "L" "N_em L" "N_em L" jp-kanji)
("" "L" "JuLm L" "JuLm L" jp-kanji)
("" "L" "AuiCm L" "AuiCm L" jp-kanji)
("" "L" "Rum L" "Rum L" jp-kanji)
("" "L" "Ecm L" "Ecm L" jp-kanji)
("" "L" "gm L" "gm L" jp-kanji)
("" "L" "L~[m L" "L~[m L" jp-kanji)
("" "L" "EVCm L" "EVCm L" jp-kanji)
("" "L" "m L" "m L" jp-kanji)
("" "L" "uLem L" "uLem L" jp-kanji)
("" "L" "L{[m L" "L{[m L" jp-kanji)
("" "L" "CNm L" "CNm L" jp-kanji)
("" "L" "Cm L" "Cm L" jp-kanji)
("" "L" "tEm L" "tEm L" jp-kanji)
("" "L" "cNGm L" "cNGm L" jp-kanji)
("" "L" "n^m L" "n^m L" jp-kanji)
("" "L" "Xfjm L" "Xfjm L" jp-kanji)
("" "L" "L^Cm L" "L^Cm L" jp-kanji)
("" "L" "V[Mm L" "V[Mm L" jp-kanji)
("" "L" "Xem L" "Xem L" jp-kanji)
("@" "L" "LJCm L" "LJCm L" jp-kanji)
("A" "L" "JGm L" "JGm L" jp-kanji)
("B" "L" "L[g Xm L" "L[g Xm L" jp-kanji)
("C" "L" "N[Lm L" "N[Lm L" jp-kanji)
("D" "L" "LJVm L" "LJVm L" jp-kanji)
("E" "L" "LL `z[m L" "LL `z[m L" jp-kanji)
("F" "L" "Cmm L" "Cmm L" jp-kanji)
("G" "L" "LZcm L" "LZcm L" jp-kanji)
("H" "L" "}m L" "}m L" jp-kanji)
("I" "L" "jWbZCLm L" "jWbZCLm L" jp-kanji)
("J" "L" "RLfm L" "RLfm L" jp-kanji)
("K" "L" "L\Nm L" "L\Nm L" jp-kanji)
("L" "L" "VXm L" "VXm L" jp-kanji)
("M" "L" "g[gCm L" "g[gCm L" jp-kanji)
("N" "L" "ILm L" "ILm L" jp-kanji)
("O" "L" "Lh[m L" "Lh[m L" jp-kanji)
("P" "L" "JKNm L" "JKNm L" jp-kanji)
("Q" "L" "EGm L" "EGm L" jp-kanji)
("R" "L" "LoZm L" "LoZm L" jp-kanji)
("S" "L" "Ijm L" "Ijm L" jp-kanji)
("T" "L" "Jm L" "Jm L" jp-kanji)
("U" "M" "Ccm M" "Ccm M" jp-kanji)
("V" "M" "MVLm M" "MVLm M" jp-kanji)
("W" "M" "QCMm M" "QCMm M" jp-kanji)
("X" "M" "xMm M" "xMm M" jp-kanji)
("Y" "M" "^m M" "^m M" jp-kanji)
("Z" "M" "Um M" "Um M" jp-kanji)
("[" "M" "MRum M" "MRum M" jp-kanji)
("\" "M" "AUNm M" "AUNm M" jp-kanji)
("]" "M" "MZCm M" "MZCm M" jp-kanji)
("^" "M" "E^KEm M" "E^KEm M" jp-kanji)
("_" "M" "MIV[Wm M" "MIV[Wm M" jp-kanji)
("`" "M" "Mm M" "Mm M" jp-kanji)
("a" "M" "Vm A" "Vm A" jp-kanji)
("b" "M" "V~m M" "V~m M" jp-kanji)
("c" "M" "MJCm M" "MJCm M" jp-kanji)
("d" "LN" "XNEm LN" "XNEm LN" jp-kanji)
("e" "LN" "nim LN" "nim LN" jp-kanji)
("f" "LN" "P}m LN" "P}m LN" jp-kanji)
("g" "L`" "_CL`m L`" "_CL`m L`" jp-kanji)
("h" "Lc" "hm Lc" "hm Lc" jp-kanji)
("i" "Lc" "LcGm Lc" "LcGm Lc" jp-kanji)
("j" "Lc" "LL[m Lc" "LL[m Lc" jp-kanji)
("k" "Lc" "^`oim Lc" "^`oim Lc" jp-kanji)
("l" "Lc" "cm Lc" "cm Lc" jp-kanji)
("m" "`" "Lk^m `" "Lk^m `" jp-kanji)
("n" "V" "LldJm Ll" "LldJm Ll" jp-kanji)
("o" "V" "g[Lrm Lr" "g[Lrm Lr" jp-kanji)
("p" "LN" "{[LNm LN" "{[LNm LN" jp-kanji)
("q" "LN" "ILNT}m LN" "ILNT}m LN" jp-kanji)
("r" "LN" "AVm LN" "AVm LN" jp-kanji)
("s" "MN" "VC^Qm MN" "VC^Qm MN" jp-kanji)
("t" "MN" "MNem MN" "MNem MN" jp-kanji)
("u" "L[" "IJm L[" "IJm L[" jp-kanji)
("v" "L[" "qTVCm L[" "qTVCm L[" jp-kanji)
("w" "L[" "A_m L[" "A_m L[" jp-kanji)
("x" "L[" "Xm L[" "Xm L[" jp-kanji)
("y" "L[" "Ium L[" "Ium L[" jp-kanji)
("z" "L[" "X[m L[" "X[m L[" jp-kanji)
("{" "L[" "~m L[" "~m L[" jp-kanji)
("|" "L[" "~m L[" "~m L[" jp-kanji)
("}" "L[" "C\Om L[" "C\Om L[" jp-kanji)
("~" "L[" "XNEm L[" "XNEm L[" jp-kanji)
("" "L[" "N`m L[" "N`m L[" jp-kanji)
("" "L[" "gm L[" "gm L[" jp-kanji)
("" "L[" "Nm L[" "Nm L[" jp-kanji)
("" "L[" "iNm L[" "iNm L[" jp-kanji)
("" "L[" "IL[m L[" "IL[m L[" jp-kanji)
("" "L[" "^}m L[" "^}m L[" jp-kanji)
("" "L[" "Lm L[" "Lm L[" jp-kanji)
("" "L[" "L}m L[" "L}m L[" jp-kanji)
("" "L[" "ICm L[" "ICm L[" jp-kanji)
("" "L[" "O[hm L[" "O[hm L[" jp-kanji)
("" "L[" "^_Xm L[" "^_Xm L[" jp-kanji)
("" "L[" "L[[m L[" "L[[m L[" jp-kanji)
("" "L[" "tCm L[" "tCm L[" jp-kanji)
("" "M[" "EVm M[" "EVm M[" jp-kanji)
("" "L" "Tm L" "Tm L" jp-kanji)
("" "L" "Cm L" "Cm L" jp-kanji)
("" "L" "LWm L" "LWm L" jp-kanji)
("" "L" "Rom L" "Rom L" jp-kanji)
("" "L" "RLm L" "RLm L" jp-kanji)
("" "L" "AQm L" "AQm L" jp-kanji)
("" "L" "ALm L" "ALm L" jp-kanji)
("" "L" "LGCm L" "LGCm L" jp-kanji)
("" "L" "Xm L" "Xm L" jp-kanji)
("" "L" "Lm L" "Lm L" jp-kanji)
("" "L" "mRMm L" "mRMm L" jp-kanji)
("" "M" "MR[m M" "MR[m M" jp-kanji)
("" "M" "ghm M" "ghm M" jp-kanji)
("" "M" "TJim M" "TJim M" jp-kanji)
("" "L[" "gIm L[" "gIm L[" jp-kanji)
("" "L[" "L[lm L[" "L[lm L[" jp-kanji)
("" "L[" "L[gm L[" "L[gm L[" jp-kanji)
("" "L[" "\iGm L[" "\iGm L[" jp-kanji)
("" "L[" "jL[m L[" "jL[m L[" jp-kanji)
("" "L[" "JL[m L[" "JL[m L[" jp-kanji)
("" "L[" "L[{[m L[m L[W" "L[{[m L[m L[W" jp-kanji)
("" "L[" "L\Em L[" "L\Em L[" jp-kanji)
("" "L[" "gm L[" "gm L[" jp-kanji)
("" "L[" "L[{[m L[" "L[{[m L[" jp-kanji)
("" "L[" "L[Nm L[" "L[Nm L[" jp-kanji)
("" "L[" "^_Xm L[" "^_Xm L[" jp-kanji)
("" "L[" "NL[m L[" "NL[m L[" jp-kanji)
("" "L[" "TPum L[" "TPum L[" jp-kanji)
("" "L[" "L[{Nm L[" "L[{Nm L[" jp-kanji)
("" "L[" "TJCm L[" "TJCm L[" jp-kanji)
("" "L[" "nU}m L[" "nU}m L[" jp-kanji)
("" "L[" "cCm L[" "cCm L[" jp-kanji)
("" "L[" "WL[Wcm L[" "WL[Wcm L[" jp-kanji)
("" "L[" "IrGm L[" "IrGm L[" jp-kanji)
("" "L[" "I\m L[" "I\m L[" jp-kanji)
("" "L[" "EEVCm L[" "EEVCm L[" jp-kanji)
("" "L[" "nTm L[" "nTm L[" jp-kanji)
("" "L[" "IVGm L[" "IVGm L[" jp-kanji)
("" "L[" "nVm L[" "nVm L[" jp-kanji)
("" "L[" "W[L[m L[" "W[L[m L[" jp-kanji)
("" "L[" "NEm L[" "NEm L[" jp-kanji)
("" "L[" "Z}Cm L[" "Z}Cm L[" jp-kanji)
("" "L[" "^m L[" "^m L[" jp-kanji)
("" "L[" "lm L[" "lm L[" jp-kanji)
("" "L[" "IrJXm L[" "IrJXm L[" jp-kanji)
("" "L[" "IRm L[" "IRm L[" jp-kanji)
("" "L[" "\om L[" "\om L[" jp-kanji)
("" "L[" "RL[m L[" "RL[m L[" jp-kanji)
("" "L[" "JK~m L[" "JK~m L[" jp-kanji)
("" "L[" "qrNm L[" "qrNm L[" jp-kanji)
("" "L[" "L[Gm L[" "L[Gm L[" jp-kanji)
("" "L[" "IhNm L[" "IhNm L[" jp-kanji)
("" "M[" "AIOm M[" "AIOm M[" jp-kanji)
("" "M[" "Rm M[" "Rm M[" jp-kanji)
("" "M[" "M[Vm M[" "M[Vm M[" jp-kanji)
("" "M[" "AJcLm M[" "AJcLm M[" jp-kanji)
("" "M[" "Um M[" "Um M[" jp-kanji)
("" "LN" "[rLNm LN" "[rLNm LN" jp-kanji)
("" "LN" "}Km LN" "}Km LN" jp-kanji)
("" "LN" "Lm LN" "Lm LN" jp-kanji)
("" "MN" "^}m MN" "^}m MN" jp-kanji)
("" "g[" "VNucm L" "VNucm L" jp-kanji)
("" "L[g" "iKTm L" "iKTm L" jp-kanji)
("" "L" "YJm L" "YJm L" jp-kanji)
("" "L" "cgm L" "cgm L" jp-kanji)
("" "L" "wCLm L" "wCLm L" jp-kanji)
("" "L" "L`Nm L" "L`Nm L" jp-kanji)
("" "L" "jVLm L" "jVLm L" jp-kanji)
("" "L" "ITm L" "ITm L" jp-kanji)
("" "L" "Rum L" "Rum L" jp-kanji)
("" "L" "LeCm L" "LeCm L" jp-kanji)
("" "L" "Rgm L" "Rgm L" jp-kanji)
("" "L" "LVm L" "LVm L" jp-kanji)
("" "L" "gm L" "gm L" jp-kanji)
("" "L" "XWm L" "XWm L" jp-kanji)
("" "L" "L`[m L" "L`[m L" jp-kanji)
("" "L" "Zm L" "Zm L" jp-kanji)
("" "L" "oCLm L" "oCLm L" jp-kanji)
("" "L" "GAVm L" "GAVm L" jp-kanji)
("" "L" "Gm L" "Gm L" jp-kanji)
("" "L" "ccVfm L" "ccVfm L" jp-kanji)
("" "L" "`JCm L" "`JCm L" jp-kanji)
("" "L" "Jlm L" "Jlm L" jp-kanji)
("" "M" "M~m M" "M~m M" jp-kanji)
("" "M" "MCm M" "MCm M" jp-kanji)
("" "L[" "JX[Wm N" "JX[Wm N" jp-kanji)
("" "N" "Num N" "Num N" jp-kanji)
("" "N" "nCNm N" "nCNm N" jp-kanji)
("" "N" "NJNZCm N" "NJNZCm N" jp-kanji)
("" "N" "eOm N" "eOm N" jp-kanji)
("" "N" "NCVm N" "NCVm N" jp-kanji)
("" "N" "NPCm N" "NPCm N" jp-kanji)
("" "N" "NVm N" "NVm N" jp-kanji)
("" "N" "J_m N" "J_m N" jp-kanji)
("" "N" "JPm N" "JPm N" jp-kanji)
("" "N" "E}j IJm N" "E}j IJm N" jp-kanji)
("" "N" "R}m N" "R}m N" jp-kanji)
("" "O" "h[Om O" "h[Om O" jp-kanji)
("" "O" "IJm O" "IJm O" jp-kanji)
("" "O" "OrWm O" "OrWm O" jp-kanji)
("" "N[" "N`wm N[" "N`wm N[" jp-kanji)
("" "N[" "\m N[" "\m N[" jp-kanji)
("" "O[" "O[[m O[" "O[[m O[" jp-kanji)
("" "O[" "O[m O[" "O[m O[" jp-kanji)
("" "O[" "\[O[m O[" "\[O[m O[" jp-kanji)
("" "O[" "X~m O[" "X~m O[" jp-kanji)
("" "Z" "NVUVm NV" "NVUVm NV" jp-kanji)
("" "Zc" "NVPYm NV" "NVPYm NV" jp-kanji)
("" "Z" "NVm NV" "NVm NV" jp-kanji)
("" "NY" "NYJSm NY" "NYJSm NY" jp-kanji)
("" "Nc" "NcWNm Nc" "NcWNm Nc" jp-kanji)
("@" "Nc" "zm Nc" "zm Nc" jp-kanji)
("A" "Nc" "h[Ncm Nc" "h[Ncm Nc" jp-kanji)
("B" "g[" "g[m Nc" "g[m Nc" jp-kanji)
("C" "J" "NcV^m Nc" "NcV^m Nc" jp-kanji)
("D" "q" "E}m Nc" "E}m Nc" jp-kanji)
("E" "N{" "N{`m N{" "N{`m N{" jp-kanji)
("F" "[" "h[ucm N}" "h[ucm N}" jp-kanji)
("G" "C" "N}hm N}" "N}hm N}" jp-kanji)
("H" "N" "NgRm N" "NgRm N" jp-kanji)
("I" "c" "N_mm N" "N_mm N" jp-kanji)
("J" "\[" "Nm \[" "Nm \[" jp-kanji)
("K" "\[" "Nm \[" "Nm \[" jp-kanji)
("L" "V[" "XL Nm N" "XL Nm N" jp-kanji)
("M" "N" "NV[m N" "NV[m N" jp-kanji)
("N" "N" "L~m N" "L~m N" jp-kanji)
("O" "N" "JIm N" "JIm N" jp-kanji)
("P" "N" "Nm N" "Nm N" jp-kanji)
("Q" "O" "m O" "m O" jp-kanji)
("R" "O" "O^Cm O" "O^Cm O" jp-kanji)
("S" "O" "RIm O" "RIm O" jp-kanji)
("T" "P" "nbPm P" "nbPm P" jp-kanji)
("U" "P" "PTm P" "PTm P" jp-kanji)
("V" "P" "LUm L" "LUm L" jp-kanji)
("W" "PC" "JJm PC" "JJm PC" jp-kanji)
("X" "PC" "J^Nm PC" "J^Nm PC" jp-kanji)
("Y" "PC" "PCocm PC" "PCocm PC" jp-kanji)
("Z" "PC" "Ajm PC" "Ajm PC" jp-kanji)
("[" "PC" "nCPCm PC" "nCPCm PC" jp-kanji)
("\" "PC" "c` t^cm PC" "c` t^cm PC" jp-kanji)
("]" "PC" "PCZLm PC" "PCZLm PC" jp-kanji)
("^" "PC" "IIK^m J^" "IIK^m J^" jp-kanji)
("_" "PC" "`Mm PC" "`Mm PC" jp-kanji)
("`" "PC" "J^`m PC" "J^`m PC" jp-kanji)
("a" "PC" "R~`m PC" "R~`m PC" jp-kanji)
("b" "PC" "Om PC" "Om PC" jp-kanji)
("c" "PC" "PCVNm PC" "PCVNm PC" jp-kanji)
("d" "PC" "PCKm PC" "PCKm PC" jp-kanji)
("e" "PC" "CRCm PC" "CRCm PC" jp-kanji)
("f" "PC" "JJQm PC" "JJQm PC" jp-kanji)
("g" "PC" "^YTGm PC" "^YTGm PC" jp-kanji)
("h" "PC" "E}Em PC" "E}Em PC" jp-kanji)
("i" "PC" "t[PCm PC" "t[PCm PC" jp-kanji)
("j" "PC" "Jcm PC" "Jcm PC" jp-kanji)
("k" "PC" "PCRNm PC" "PCRNm PC" jp-kanji)
("l" "PC" "A[m PC" "A[m PC" jp-kanji)
("m" "PC" "PCRm PC" "PCRm PC" jp-kanji)
("n" "PC" "JPCYm PC" "JPCYm PC" jp-kanji)
("o" "PC" "PCUCm PC" "PCUCm PC" jp-kanji)
("p" "PC" "cOm PC" "cOm PC" jp-kanji)
("q" "PC" "ciOm PC" "ciOm PC" jp-kanji)
("r" "PC" "PCVm PC" "PCVm PC" jp-kanji)
("s" "PC" "NLm PC" "NLm PC" jp-kanji)
("t" "PC" "Com PC" "Com PC" jp-kanji)
("u" "PC" "z^m PC" "z^m PC" jp-kanji)
("v" "PC" "nJm PC" "nJm PC" jp-kanji)
("w" "PC" "[fm PC" "[fm PC" jp-kanji)
("x" "PC" "PCTcm PC" "PCTcm PC" jp-kanji)
("y" "PC" "JCm PC" "JCm PC" jp-kanji)
("z" "PC" "Nrm PC" "Nrm PC" jp-kanji)
("{" "PC" "jgm PC" "jgm PC" jp-kanji)
("|" "QC" "QCWcm QC" "QCWcm QC" jp-kanji)
("}" "QC" "JGm QC" "JGm QC" jp-kanji)
("~" "QC" "NWm QC" "NWm QC" jp-kanji)
("" "QL" "GQLm QL" "GQLm QL" jp-kanji)
("" "QL" "zRm QL" "zRm QL" jp-kanji)
("" "QL" "Ecm QL" "Ecm QL" jp-kanji)
("" "QL" "nQVCm QL" "nQVCm QL" jp-kanji)
("" "QL" "XL}m QL" "XL}m QL" jp-kanji)
("" "R[" "R[m P^" "R[m P^" jp-kanji)
("" "Pc" "S[Pcm Pc" "S[Pcm Pc" jp-kanji)
("" "Pc" "JPm Pc" "JPm Pc" jp-kanji)
("" "Pc" "Lm Pc" "Lm Pc" jp-kanji)
("" "Pc" "CTMCm Pc" "CTMCm Pc" jp-kanji)
("" "Pc" "Aim Pc" "Aim Pc" jp-kanji)
("" "Pc" "Xum Pc" "Xum Pc" jp-kanji)
("" "Pc" "`m Pc" "`m Pc" jp-kanji)
("" "Pc" "Pcxcm Pc" "Pcxcm Pc" jp-kanji)
("" "Qc" "cLm Qc" "cLm Qc" jp-kanji)
("" "P" "WPm P" "WPm P" jp-kanji)
("" "P" "PNm P" "PNm P" jp-kanji)
("" "P" "Em P" "Em P" jp-kanji)
("" "P" "XRJm P" "XRJm P" jp-kanji)
("" "P" "Jlm P" "Jlm P" jp-kanji)
("" "P" "JuPm P" "JuPm P" jp-kanji)
("" "P" "cMm P" "cMm P" jp-kanji)
("" "P" "PJm P" "PJm P" jp-kanji)
("" "P" "^CLPm P" "^CLPm P" jp-kanji)
("" "P" "J^Cm P" "J^Cm P" jp-kanji)
("" "P" "LEm P" "LEm P" jp-kanji)
("" "P" "^em P" "^em P" jp-kanji)
("" "P" "P|[m P" "P|[m P" jp-kanji)
("" "P" "JPm P" "JPm P" jp-kanji)
("" "P" "RuVm P" "RuVm P" jp-kanji)
("" "P" "}Nm P" "}Nm P" jp-kanji)
("" "P" "PeCm P" "PeCm P" jp-kanji)
("" "P" "Pm P" "Pm P" jp-kanji)
("" "P" "PCm P" "PCm P" jp-kanji)
("" "P" "Ckm P" "Ckm P" jp-kanji)
("" "P" "PW[m P" "PW[m P" jp-kanji)
("" "P" "gOm P" "gOm P" jp-kanji)
("" "P" "XYm P" "XYm P" jp-kanji)
("" "P" "Lkm P" "Lkm P" jp-kanji)
("" "P" "gh[tPm P" "gh[tPm P" jp-kanji)
("" "P" "J^m P" "J^m P" jp-kanji)
("" "P" "~m P" "~m P" jp-kanji)
("" "P" "PLm P" "PLm P" jp-kanji)
("" "P" "JVRCm P" "JVRCm P" jp-kanji)
("" "P" "mLm P" "mLm P" jp-kanji)
("" "P" "cJEm P" "cJEm P" jp-kanji)
("" "P" "JMm P" "JMm P" jp-kanji)
("" "P" "PVCm P" "PVCm P" jp-kanji)
("" "P" "PrL[m P" "PrL[m P" jp-kanji)
("" "P" "PCPm P" "PCPm P" jp-kanji)
("" "P" "ZbPm P" "ZbPm P" jp-kanji)
("" "Q" "gm Q" "gm Q" jp-kanji)
("" "Q" "nm Q" "nm Q" jp-kanji)
("" "Q" "LrVCm Q" "LrVCm Q" jp-kanji)
("" "Q" "}{Vm Q" "}{Vm Q" jp-kanji)
("" "Q" "cm Q" "cm Q" jp-kanji)
("" "Q" "wm Q" "wm Q" jp-kanji)
("" "Q" "~igm Q" "~igm Q" jp-kanji)
("" "Q" "[Qm Q" "[Qm Q" jp-kanji)
("" "Q" "Am Q" "Am Q" jp-kanji)
("" "Q" "QKbLm Q" "QKbLm Q" jp-kanji)
("" "Q" "tio^m Q" "tio^m Q" jp-kanji)
("" "Q" "CEm Q" "CEm Q" jp-kanji)
("" "Q" "RgUm Q" "RgUm Q" jp-kanji)
("" "Q" "JMm Q" "JMm Q" jp-kanji)
("" "R" "_RgVem R" "_RgVem R" jp-kanji)
("" "R" "RZCm R" "RZCm R" jp-kanji)
("" "R" "tCm R" "tCm R" jp-kanji)
("" "R" "um R" "um R" jp-kanji)
("" "R" "J^m R" "J^m R" jp-kanji)
("" "R" "V[gm R" "V[gm R" jp-kanji)
("" "R" "RhNm R" "RhNm R" jp-kanji)
("" "R" "Imm R" "Imm R" jp-kanji)
("" "R" "\[Rm R" "\[Rm R" jp-kanji)
("" "R" "JbRm R" "JbRm R" jp-kanji)
("" "R" "gm R" "gm R" jp-kanji)
("" "R" "Gm R" "Gm R" jp-kanji)
("" "R" "Jm R" "Jm R" jp-kanji)
("" "R" "~YE~m R" "~YE~m R" jp-kanji)
("" "R" "Lclm R" "Lclm R" jp-kanji)
("" "R" "mm R" "mm R" jp-kanji)
("" "R" "nJ}m R" "nJ}m R" jp-kanji)
("" "R" "}^m R" "}^m R" jp-kanji)
("" "R" "GrXm R" "GrXm R" jp-kanji)
("" "R" "Rm R" "Rm R" jp-kanji)
("" "R" "gm R" "gm R" jp-kanji)
("" "R" "zRm R" "zRm R" jp-kanji)
("" "R" "}^Km R" "}^Km R" jp-kanji)
("" "R" "gbRm R" "gbRm R" jp-kanji)
("" "R" "gEm R" "gEm R" jp-kanji)
("" "R" "JG~m R" "JG~m R" jp-kanji)
("" "R" "cd~m R" "cd~m R" jp-kanji)
("" "S" "JX[Wm S" "JX[Wm S" jp-kanji)
("" "S" "^KCm S" "^KCm S" jp-kanji)
("" "S" "S`[m S" "S`[m S" jp-kanji)
("" "S" "V[Sm S" "V[Sm S" jp-kanji)
("" "S" "StNm S" "StNm S" jp-kanji)
("" "S" "m S" "m S" jp-kanji)
("" "S" "SNm S" "SNm S" jp-kanji)
("" "S" "m`m S" "m`m S" jp-kanji)
("" "S" "Im S" "Im S" jp-kanji)
("" "S" "Tgm S" "Tgm S" jp-kanji)
("" "S" "AIMm S" "AIMm S" jp-kanji)
("" "S" "Sm S" "Sm S" jp-kanji)
("" "S" "TSm S" "TSm S" jp-kanji)
("" "S" "SCVm S" "SCVm S" jp-kanji)
("" "S" "J^m S" "J^m S" jp-kanji)
("" "S" "A}m S" "A}m S" jp-kanji)
("" "S" "}m S" "}m S" jp-kanji)
("" "S" "_CS~m S" "_CS~m S" jp-kanji)
("" "Rc" "RWLm Rc" "RWLm Rc" jp-kanji)
("" "" "TJim RC" "TJim RC" jp-kanji)
("" "R[" "}Wm R[" "}Wm R[" jp-kanji)
("" "R[" "~Cm R[" "~Cm R[" jp-kanji)
("" "R[" "R[VNm R[" "R[VNm R[" jp-kanji)
("" "R[" "\[[m R[" "\[[m R[" jp-kanji)
("" "R[" "M[R[m R[" "M[R[m R[" jp-kanji)
("" "R[" "qJm R[" "qJm R[" jp-kanji)
("" "R[" "IIPm R[" "IIPm R[" jp-kanji)
("" "R[" "R[[Vm R[" "R[[Vm R[" jp-kanji)
("" "R[" "LNm R[" "LNm R[" jp-kanji)
("" "R[" "R[oCm R[" "R[oCm R[" jp-kanji)
("" "R[" "AcCm R[" "AcCm R[" jp-kanji)
("" "R[" "N`m R[" "N`m R[" jp-kanji)
("" "R[" "Nm R[" "Nm R[" jp-kanji)
("@" "R[" "LTLm R[" "LTLm R[" jp-kanji)
("A" "R[" "mhm R[" "mhm R[" jp-kanji)
("B" "R[" "^R[m R[" "^R[m R[" jp-kanji)
("C" "R[" "AJm R[" "AJm R[" jp-kanji)
("D" "R[" "Rmm R[" "Rmm R[" jp-kanji)
("E" "R[" "R[Vm R[" "R[Vm R[" jp-kanji)
("F" "R[" "`[R[m R[" "`[R[m R[" jp-kanji)
("G" "R[" "R[_Cm R[" "R[_Cm R[" jp-kanji)
("H" "R[" "R[TNm R[" "R[TNm R[" jp-kanji)
("I" "R[" "^N~m R[" "^N~m R[" jp-kanji)
("J" "R[" "`}^m R[" "`}^m R[" jp-kanji)
("K" "R[" "TCCm R[" "TCCm R[" jp-kanji)
("L" "R[" "qCm R[" "qCm R[" jp-kanji)
("M" "R[" "JmGm R[" "JmGm R[" jp-kanji)
("N" "R[" "CGXm R[" "CGXm R[" jp-kanji)
("O" "R[" "R[{[m R[" "R[{[m R[" jp-kanji)
("P" "R[" "clm R[" "clm R[" jp-kanji)
("Q" "R[" "Aem R[" "Aem R[" jp-kanji)
("R" "R[" "nR[m R[" "nR[m R[" jp-kanji)
("S" "R[" "JJm R[" "JJm R[" jp-kanji)
("T" "R[" "qJGm R[" "qJGm R[" jp-kanji)
("U" "R[" "Zm R[" "Zm R[" jp-kanji)
("V" "R[" "^Jum R[" "^Jum R[" jp-kanji)
("W" "R[" "ALJm R[" "ALJm R[" jp-kanji)
("X" "R[" "Tm R[" "Tm R[" jp-kanji)
("Y" "R[" "NCm R[" "NCm R[" jp-kanji)
("Z" "R[" "KbR[m R[" "KbR[m R[" jp-kanji)
("[" "R[" "tTOm R[" "tTOm R[" jp-kanji)
("\" "R[" "J}Gm R[" "J}Gm R[" jp-kanji)
("]" "R[" "Gm R[" "Gm R[" jp-kanji)
("^" "R[" "R[YCm R[" "R[YCm R[" jp-kanji)
("_" "R[" "R[[m R[" "R[[m R[" jp-kanji)
("`" "R[" "~igm R[" "~igm R[" jp-kanji)
("a" "R[" "~]m R[" "~]m R[" jp-kanji)
("b" "R[" "R[Icm R[" "R[Icm R[" jp-kanji)
("c" "R[" "R[^CVm R[" "R[^CVm R[" jp-kanji)
("d" "R[" "J^Cm R[" "J^Cm R[" jp-kanji)
("e" "R[" "QR[m R[" "QR[m R[" jp-kanji)
("f" "R[" "kJm R[" "kJm R[" jp-kanji)
("g" "R[" "NiCm R[" "NiCm R[" jp-kanji)
("h" "R[" "JPqm R[" "JPqm R[" jp-kanji)
("i" "R[" "V{m R[" "V{m R[" jp-kanji)
("j" "R[" "cim R[" "cim R[" jp-kanji)
("k" "R[" "^KXm R[" "^KXm R[" jp-kanji)
("l" "R[" "JKGm R[" "JKGm R[" jp-kanji)
("m" "R[" "EiYNm R[" "EiYNm R[" jp-kanji)
("n" "R[" "qWm R[" "qWm R[" jp-kanji)
("o" "R[" "tNR[m R[" "tNR[m R[" jp-kanji)
("p" "R[" "R[Nm R[" "R[Nm R[" jp-kanji)
("q" "R[" "R[N[Lm R[" "R[N[Lm R[" jp-kanji)
("r" "R[" "Am R[" "Am R[" jp-kanji)
("s" "R[" "CNm R[" "CNm R[" jp-kanji)
("t" "R[" "nJm R[" "nJm R[" jp-kanji)
("u" "R[" "R[_m R[" "R[_m R[" jp-kanji)
("v" "R[" "~cOm R[" "~cOm R[" jp-kanji)
("w" "R[" "JEm R[" "JEm R[" jp-kanji)
("x" "R[" "R[KCm R[" "R[KCm R[" jp-kanji)
("y" "R[" "R[\m R[" "R[\m R[" jp-kanji)
("z" "R[" "R[Um R[" "R[Um R[" jp-kanji)
("{" "R[" "AKlm R[" "AKlm R[" jp-kanji)
("|" "R[" "ebR[m R[" "ebR[m R[" jp-kanji)
("}" "R[" "^CR[Lm R[" "^CR[Lm R[" jp-kanji)
("~" "R[" "Im R[" "Im R[" jp-kanji)
("" "R[" "R[Nm R[" "R[Nm R[" jp-kanji)
("" "R[" "JIm R[" "JIm R[" jp-kanji)
("" "R[" "^JCm R[" "^JCm R[" jp-kanji)
("" "R[" "R[m CPm R[" "R[m CPm R[" jp-kanji)
("" "S[" "J^Cm S[" "J^Cm S[" jp-kanji)
("" "S[" "IrJXm S[" "IrJXm S[" jp-kanji)
("" "S[" "S[Cm S[" "S[Cm S[" jp-kanji)
("" "S[" "AEm S[" "AEm S[" jp-kanji)
("" "S[" "J{m S[" "J{m S[" jp-kanji)
("" "S[" "S[m S[" "S[m S[" jp-kanji)
("" "S[" "zm S[" "zm S[" jp-kanji)
("" "S[" "S[Jom S[" "S[Jom S[" jp-kanji)
("" "S[" "ghNm S[" "ghNm S[" jp-kanji)
("" "LN" "LNm R[W" "LNm R[W" jp-kanji)
("" "RN" "RNtNm RN" "RNtNm RN" jp-kanji)
("" "RN" "LUm RN" "LUm RN" jp-kanji)
("" "RN" "cQm RN" "cQm RN" jp-kanji)
("" "RN" "Njm RN" "Njm RN" jp-kanji)
("" "RN" "RNcm RN" "RNcm RN" jp-kanji)
("" "RN" "URNm RN" "URNm RN" jp-kanji)
("" "RN" "NOCm RN" "NOCm RN" jp-kanji)
("" "RN" "Nm RN" "Nm RN" jp-kanji)
("" "SN" "WSNm SN" "WSNm SN" jp-kanji)
("" "N" "RXm N" "RXm N" jp-kanji)
("" "[" "AVRVm RV" "AVRVm RV" jp-kanji)
("" "\" "ZCm RVL" "ZCm RVL" jp-kanji)
("" "Rc" "^`}`m Rc" "^`}`m Rc" jp-kanji)
("" "Rc" "zm Rc" "zm Rc" jp-kanji)
("" "Rc" "zlm Rc" "zlm Rc" jp-kanji)
("" "nN" "R}Ckm R}" "R}Ckm R}" jp-kanji)
("" "R" "[VRm R" "[VRm R" jp-kanji)
("" "V" "R_Pm Rm" "R_Pm Rm" jp-kanji)
("" "R" "RmSm R" "RmSm R" jp-kanji)
("" "R" "C}m R" "C}m R" jp-kanji)
("" "R" "R}m R" "R}m R" jp-kanji)
("" "R" "PRm R" "PRm R" jp-kanji)
("" "R" "JCRm R" "JCRm R" jp-kanji)
("" "R" "PbRm R" "PbRm R" jp-kanji)
("" "R" "Em R" "Em R" jp-kanji)
("" "R" "R_m R" "R_m R" jp-kanji)
("" "R" "^\Km R" "^\Km R" jp-kanji)
("" "R" "R`[m R" "R`[m R" jp-kanji)
("" "R" "lbRm R" "lbRm R" jp-kanji)
("" "R" "R|[m R" "R|[m R" jp-kanji)
("" "R" "}Wm R" "}Wm R" jp-kanji)
("" "R" "RZLm R" "RZLm R" jp-kanji)
("" "R" "RCm R" "RCm R" jp-kanji)
("" "R" "EVgm R" "EVgm R" jp-kanji)
("" "R" "^}VCm R" "^}VCm R" jp-kanji)
("" "T" "XRVm T" "XRVm T" jp-kanji)
("" "T" "zTm T" "zTm T" jp-kanji)
("" "T" "R[Tem T" "R[Tem T" jp-kanji)
("" "T" "VTXm T" "VTXm T" jp-kanji)
("" "T" "TKmm T" "TKmm T" jp-kanji)
("" "T" "q_m T" "q_m T" jp-kanji)
("" "T" "TXm T" "TXm T" jp-kanji)
("" "T" "WTm T" "WTm T" jp-kanji)
("" "T" "WSNm T^m T" "WSNm T^m T" jp-kanji)
("" "T" "AUJm T" "AUJm T" jp-kanji)
("" "T" "Xim T" "Xim T" jp-kanji)
("" "T" "TMm T" "TMm T" jp-kanji)
("" "T" "NTm T" "NTm T" jp-kanji)
("" "T" "PTm T" "PTm T" jp-kanji)
("" "U" "}_iVm U" "}_iVm U" jp-kanji)
("" "U" "Xm U" "Xm U" jp-kanji)
("" "U" "UZcm U" "UZcm U" jp-kanji)
("" "TC" "tTCm TC" "tTCm TC" jp-kanji)
("" "TC" "IXm TC" "IXm TC" jp-kanji)
("" "TC" "t^^rm TC" "t^^rm TC" jp-kanji)
("" "TC" "bgm TC" "bgm TC" jp-kanji)
("" "TC" "m TC" "m TC" jp-kanji)
("" "TC" "[TCm TC" "[TCm TC" jp-kanji)
("" "TC" "c}m TC" "c}m TC" jp-kanji)
("" "TC" "TCV[m TC" "TCV[m TC" jp-kanji)
("" "TC" "Chm TC" "Chm TC" jp-kanji)
("" "TC" "TCm[m TC" "TCm[m TC" jp-kanji)
("" "TC" "gm TC" "gm TC" jp-kanji)
("" "TC" "TCoCm TC" "TCoCm TC" jp-kanji)
("" "TC" "gVm TC" "gVm TC" jp-kanji)
("" "TC" "Xm TC" "Xm TC" jp-kanji)
("" "TC" "UCm TC" "UCm TC" jp-kanji)
("" "TC" "TCnCm TC" "TCnCm TC" jp-kanji)
("" "TC" "h[ucm TC" "h[ucm TC" jp-kanji)
("" "TC" "N_Nm TC" "N_Nm TC" jp-kanji)
("" "TC" "gfm TC" "gfm TC" jp-kanji)
("" "TC" "}cm TC" "}cm TC" jp-kanji)
("" "TC" "VTCm TC" "VTCm TC" jp-kanji)
("" "TC" "z\Cm TC" "z\Cm TC" jp-kanji)
("" "TC" "TCm TC" "TCm TC" jp-kanji)
("" "TC" "ToNm TC" "ToNm TC" jp-kanji)
("" "TC" "mZm TC" "mZm TC" jp-kanji)
("" "TC" "}hMm TC" "}hMm TC" jp-kanji)
("" "UC" "NUCm UC" "NUCm UC" jp-kanji)
("" "UC" "Am UC" "Am UC" jp-kanji)
("" "UC" "UCNm UC" "UCNm UC" jp-kanji)
("" "UC" "c~m UC" "c~m UC" jp-kanji)
("" "UC" "UCTm UC" "UCTm UC" jp-kanji)
("" "S" "TGm S" "TGm S" jp-kanji)
("" "n" "TJm n" "TJm n" jp-kanji)
("" "n" "nVm n" "nVm n" jp-kanji)
("" "JC" "TJCVm TJC" "TJCVm TJC" jp-kanji)
("" "V" "J~m Lm TJL" "J~m Lm TJL" jp-kanji)
("" "R[" "TPm TJi" "TPm TJi" jp-kanji)
("" "V[" "TNm V[" "TNm V[" jp-kanji)
("" "L" "~TLm TL" "~TLm TL" jp-kanji)
("" "L" "TC^}m TC" "TC^}m TC" jp-kanji)
("" "L" "CVwm L" "CVwm L" jp-kanji)
("" "" "gm TM" "gm TM" jp-kanji)
("" "TN" "cNm TN" "cNm TN" jp-kanji)
("" "TN" "PYm TN" "PYm TN" jp-kanji)
("" "TN" "NEm TN" "NEm TN" jp-kanji)
("" "TN" "V{m TN" "V{m TN" jp-kanji)
("" "TN" "TNlm TN" "TNlm TN" jp-kanji)
("" "TN" "cC^`m TN" "cC^`m TN" jp-kanji)
("" "TN" "JRCm TN" "JRCm TN" jp-kanji)
("" "TN" "Z}Cm TN" "Z}Cm TN" jp-kanji)
("" "TN" "TNNm TN" "TNNm TN" jp-kanji)
("" "TN" "TNCm TN" "TNCm TN" jp-kanji)
("" "TN" "TNm TN" "TNm TN" jp-kanji)
("" "I[" "TNm I[" "TNm I[" jp-kanji)
("" "PC" "TJim TP" "TJim TP" jp-kanji)
("" "ZC" "VNucm TT" "VNucm TT" jp-kanji)
("" "V" "Xv[m TW" "Xv[m TW" jp-kanji)
("" "Tc" "xbTcm Tc" "xbTcm Tc" jp-kanji)
("" "Tc" "Xm Tc" "Xm Tc" jp-kanji)
("@" "Tc" "PCTcm Tc" "PCTcm Tc" jp-kanji)
("A" "Tc" "ACTcm Tc" "ACTcm Tc" jp-kanji)
("B" "Tc" "gm Tc" "gm Tc" jp-kanji)
("C" "Tc" "}Tcm Tc" "}Tcm Tc" jp-kanji)
("D" "Tc" "t_m Tc" "t_m Tc" jp-kanji)
("E" "Tc" "RXm Tc" "RXm Tc" jp-kanji)
("F" "Tc" "Tc}m Tc" "Tc}m Tc" jp-kanji)
("G" "Uc" "tNUcm Uc" "tNUcm Uc" jp-kanji)
("H" "R[" "TcLm T" "TcLm T" jp-kanji)
("I" "ZC" "TJim To" "TJim To" jp-kanji)
("J" "nc" "ToNm nc" "ToNm nc" jp-kanji)
("K" "V[" "Trm V[" "Trm V[" jp-kanji)
("L" "R[" "TJim T" "TJim T" jp-kanji)
("M" "T" "Tm xC" "Tm xC" jp-kanji)
("N" "TC" "TXm TC" "TXm TC" jp-kanji)
("O" "T" "JX[Wm T" "JX[Wm T" jp-kanji)
("P" "T" "JTm T" "JTm T" jp-kanji)
("Q" "T" "}Cm T" "}Cm T" jp-kanji)
("R" "T" "}m T" "}m T" jp-kanji)
("S" "T" "~Wm T" "~Wm T" jp-kanji)
("T" "T" "}Nm T" "}Nm T" jp-kanji)
("U" "T" "`m T" "`m T" jp-kanji)
("V" "T" "ToVm T" "ToVm T" jp-kanji)
("W" "T" "T[m T" "T[m T" jp-kanji)
("X" "T" "TSV[m T" "TSV[m T" jp-kanji)
("Y" "T" "Em T" "Em T" jp-kanji)
("Z" "T" "TX[m T" "TX[m T" jp-kanji)
("[" "T" "Acm T" "Acm T" jp-kanji)
("\" "T" "JCRm T" "JCRm T" jp-kanji)
("]" "T" "^^Gm T" "^^Gm T" jp-kanji)
("^" "T" "Tsm T" "Tsm T" jp-kanji)
("_" "T" "XbpCm T" "XbpCm T" jp-kanji)
("`" "T" "oTm T" "oTm T" jp-kanji)
("a" "U" "Lm U" "Lm U" jp-kanji)
("b" "U" "VoNm U" "VoNm U" jp-kanji)
("c" "U" "mRm U" "mRm U" jp-kanji)
("d" "V" "cJGm V" "cJGm V" jp-kanji)
("e" "V" "jxj Rm V" "jxj Rm V" jp-kanji)
("f" "V" "EJKEm V" "EJKEm V" jp-kanji)
("g" "V" "cJEm V" "cJEm V" jp-kanji)
("h" "V" "TXm V" "TXm V" jp-kanji)
("i" "V" "cJTm V" "cJTm V" jp-kanji)
("j" "V" "LVm V" "LVm V" jp-kanji)
("k" "V" "cOm V" "cOm V" jp-kanji)
("l" "" "JX[Wm V" "JX[Wm V" jp-kanji)
("m" "V" "TCm V" "TCm V" jp-kanji)
("n" "V" "nWm V" "nWm V" jp-kanji)
("o" "V" "Alm V" "Alm V" jp-kanji)
("p" "V" "XK^m V" "XK^m V" jp-kanji)
("q" "V" "Rhm R" "Rhm R" jp-kanji)
("r" "V" "VJolm V" "VJolm V" jp-kanji)
("s" "V" "V`[\m V" "V`[\m V" jp-kanji)
("t" "V" "VV[m V" "VV[m V" jp-kanji)
("u" "V" "RRUXm V" "RRUXm V" jp-kanji)
("v" "V" "IEm V" "IEm V" jp-kanji)
("w" "V" "rm V" "rm V" jp-kanji)
("x" "V" "TTGm V" "TTGm V" jp-kanji)
("y" "V" "cgm V" "cgm V" jp-kanji)
("z" "V" "Rm V" "Rm V" jp-kanji)
("{" "V" "zhRXm V" "zhRXm V" jp-kanji)
("|" "V" "lm V" "lm V" jp-kanji)
("}" "V" "G_m V" "G_m V" jp-kanji)
("~" "V" "g}m V" "g}m V" jp-kanji)
("" "V" "Vkm V" "Vkm V" jp-kanji)
("" "V" "EWm V" "EWm V" jp-kanji)
("" "V" "VVm V" "VVm V" jp-kanji)
("" "V" "tNVm V" "tNVm V" jp-kanji)
("" "V" "^Vm V" "^Vm V" jp-kanji)
("" "V" "Cgm V" "Cgm V" jp-kanji)
("" "V" "J~m V" "J~m V" jp-kanji)
("" "V" "TLm V" "TLm V" jp-kanji)
("" "V" "eAVm V" "eAVm V" jp-kanji)
("" "V" "Aum V" "Aum V" jp-kanji)
("" "V" "C^m V" "C^m V" jp-kanji)
("" "V" "~m V" "~m V" jp-kanji)
("" "V" "Rgom V" "Rgom V" jp-kanji)
("" "V" "JVm V" "JVm V" jp-kanji)
("" "V" "^Xm V" "^Xm V" jp-kanji)
("" "V" "UbVm V" "UbVm V" jp-kanji)
("" "V" "V LJm V" "V LJm V" jp-kanji)
("" "V" "Vzm V" "Vzm V" jp-kanji)
("" "V" "^}m V" "^}m V" jp-kanji)
("" "V" "Xm V" "Xm V" jp-kanji)
("" "V" "JEm V" "JEm V" jp-kanji)
("" "V" "nm V" "nm V" jp-kanji)
("" "W" "Rgm W" "Rgm W" jp-kanji)
("" "W" "jm W" "jm W" jp-kanji)
("" "W" "TCm W" "TCm W" jp-kanji)
("" "W" "CNWm W" "CNWm W" jp-kanji)
("" "W" "JWm W" "JWm W" jp-kanji)
("" "W" "em W" "em W" jp-kanji)
("" "W" "CcNVm W" "CcNVm W" jp-kanji)
("" "W" "cm W" "cm W" jp-kanji)
("" "W" "gLm W" "gLm W" jp-kanji)
("" "W" "cMm W" "cMm W" jp-kanji)
("" "W" "VQm W" "VQm W" jp-kanji)
("" "W" "ITm W" "ITm W" jp-kanji)
("" "W" "VJm W" "VJm W" jp-kanji)
("" "W" "eVm Cm W" "eVm Cm W" jp-kanji)
("" "W" "r[Lm W" "r[Lm W" jp-kanji)
("" "W" "WVNm W" "WVNm W" jp-kanji)
("" "W" "VXm W" "VXm W" jp-kanji)
("" "W" "VR[Vem W" "VR[Vem W" jp-kanji)
("" "W" "~~m W" "~~m W" jp-kanji)
("" "W" "~YJm W" "~YJm W" jp-kanji)
("" "W" "}Nm W" "}Nm W" jp-kanji)
("" "W" "m W" "m W" jp-kanji)
("" "ZL" "VIm ZL" "VIm ZL" jp-kanji)
("" "N" "VJm N" "VJm N" jp-kanji)
("" "VL" "z[VLm VL" "z[VLm VL" jp-kanji)
("" "VL" "`VLm VL" "`VLm VL" jp-kanji)
("" "f" "gm VM" "gm VM" jp-kanji)
("" "WN" "eWNm WN" "eWNm WN" jp-kanji)
("" "WN" "JPWNm WN" "JPWNm WN" jp-kanji)
("" "VV" "W[jNm VV" "W[jNm VV" jp-kanji)
("" "_" "VYNm _" "VYNm _" jp-kanji)
("" "ii" "JX[Wm V`" "JX[Wm V`" jp-kanji)
("" "Vc" "VJm Vc" "VJm Vc" jp-kanji)
("" "Vc" "gm Vc" "gm Vc" jp-kanji)
("" "Vc" "EViEm Vc" "EViEm Vc" jp-kanji)
("" "Vc" "Vbgm Vc" "Vbgm Vc" jp-kanji)
("" "Vc" "L[Vcm Vc" "L[Vcm Vc" jp-kanji)
("" "Vc" "RgSgNm Vc" "RgSgNm Vc" jp-kanji)
("" "Vc" "Vm Vc" "Vm Vc" jp-kanji)
("" "Vc" "EVm Vc" "EVm Vc" jp-kanji)
("" "Vc" "}Cm Vc" "}Cm Vc" jp-kanji)
("" "Vc" "zVcm Vc" "zVcm Vc" jp-kanji)
("" "Wc" "~mm Wc" "~mm Wc" jp-kanji)
("" "z[" "Vg~m z[" "Vg~m z[" jp-kanji)
("" "ZC" "VmUTm Vm" "VmUTm Vm" jp-kanji)
("" "V" "Vmum TC" "Vmum TC" jp-kanji)
("" "V" "VoJm Vo" "VoJm Vo" jp-kanji)
("" "V" "Vom V" "Vom V" jp-kanji)
("" "" "VoVom " "VoVom " jp-kanji)
("" "YC" "Vxm YC" "Vxm YC" jp-kanji)
("" "R[" "V}E}m V}" "V}E}m V}" jp-kanji)
("" "V" "R[Vm V" "R[Vm V" jp-kanji)
("" "V" "EcXm V" "EcXm V" jp-kanji)
("" "V" "Cm V" "Cm V" jp-kanji)
("" "V" "Xem V" "Xem V" jp-kanji)
("" "V" "Xm V" "Xm V" jp-kanji)
("" "V" "iim V" "iim V" jp-kanji)
("" "V" "jm V" "jm V" jp-kanji)
("" "V" "VJCm V" "VJCm V" jp-kanji)
("" "V" "EXMkm V" "EXMkm V" jp-kanji)
("" "V" "mm V" "mm V" jp-kanji)
("" "V" "A}m V" "A}m V" jp-kanji)
("" "V" "N}m V" "N}m V" jp-kanji)
("" "V" "TGMm V" "TGMm V" jp-kanji)
("" "W" "wrm W" "wrm W" jp-kanji)
("" "W" "RV}m W" "RV}m W" jp-kanji)
("" "VN" "Jm VN" "Jm VN" jp-kanji)
("" "VN" "qVNm VN" "qVNm VN" jp-kanji)
("" "VN" "VNn`m VN" "VNn`m VN" jp-kanji)
("" "VN" "Lm qVNm VN" "Lm qVNm VN" jp-kanji)
("" "VN" "VNlcm VN" "VNlcm VN" jp-kanji)
("" "VN" "_VNm VN" "_VNm VN" jp-kanji)
("" "VN" "Nm VN" "Nm VN" jp-kanji)
("" "VN" "JCVNm VN" "JCVNm VN" jp-kanji)
("" "VN" "XYm VN" "XYm VN" jp-kanji)
("" "WN" "JCm WN" "JCm WN" jp-kanji)
("" "WN" "TrVCm WN" "TrVCm WN" jp-kanji)
("" "WN" "Cm WN" "Cm WN" jp-kanji)
("" "WN" "WbLm WN" "WbLm WN" jp-kanji)
("" "V" "kVm V" "kVm V" jp-kanji)
("" "V" "gm V" "gm V" jp-kanji)
("" "V" "}m V" "}m V" jp-kanji)
("" "V" "em V" "em V" jp-kanji)
("" "V" "AJm V" "AJm V" jp-kanji)
("" "V" "Rgm V" "Rgm V" jp-kanji)
("" "V" "Jm V" "Jm V" jp-kanji)
("" "V" "VUm V" "VUm V" jp-kanji)
("" "V" "^lm V" "^lm V" jp-kanji)
("" "V" "V[m V" "V[m V" jp-kanji)
("" "V" "ILm V" "ILm V" jp-kanji)
("" "V" "TPm V" "TPm V" jp-kanji)
("" "V" "Nrm V" "Nrm V" jp-kanji)
("" "W" "WL[m W" "WL[m W" jp-kanji)
("" "W" "EPm W" "EPm W" jp-kanji)
("" "W" "mEm W" "mEm W" jp-kanji)
("" "W" "RguLm W" "RguLm W" jp-kanji)
("" "W" "TYPm W" "TYPm W" jp-kanji)
("" "W" "Lm W" "Lm W" jp-kanji)
("" "W" "qm W" "qm W" jp-kanji)
("" "W" "W[m W" "W[m W" jp-kanji)
("" "V[" "gm V[" "gm V[" jp-kanji)
("" "V[" "ITm V[" "ITm V[" jp-kanji)
("" "V[" "}m V[" "}m V[" jp-kanji)
("@" "V[" "V[L[m V[" "V[L[m V[" jp-kanji)
("A" "V[" "cNm V[" "cNm V[" jp-kanji)
("B" "V[" "L[V[m V[" "L[V[m V[" jp-kanji)
("C" "V[" "V[m V[" "V[m V[" jp-kanji)
("D" "V[" "ECm V[" "ECm V[" jp-kanji)
("E" "V[" "q[m V[" "q[m V[" jp-kanji)
("F" "V[" "iJXm X" "iJXm X" jp-kanji)
("G" "V[" "qCfm V[" "qCfm V[" jp-kanji)
("H" "V[" "ALm V[" "ALm V[" jp-kanji)
("I" "V[" "Im V[" "Im V[" jp-kanji)
("J" "V[" "VV[m V[" "VV[m V[" jp-kanji)
("K" "V[" "iEm V[" "iEm V[" jp-kanji)
("L" "V[" "NTCm V[" "NTCm V[" jp-kanji)
("M" "V[" "tlm V[" "tlm V[" jp-kanji)
("N" "V[" "V[V[m V[" "V[V[m V[" jp-kanji)
("O" "V[" "V[MCm V[" "V[MCm V[" jp-kanji)
("P" "V[" "I\Em V[" "I\Em V[" jp-kanji)
("Q" "V[" "IV[m V[" "IV[m V[" jp-kanji)
("R" "V[" "Pm V[" "Pm V[" jp-kanji)
("S" "V[" "V[{Nm V[" "V[{Nm V[" jp-kanji)
("T" "V[" "V[JVm V[" "V[JVm V[" jp-kanji)
("U" "V[" "V[`[m V[" "V[`[m V[" jp-kanji)
("V" "V[" "NCm V[" "NCm V[" jp-kanji)
("W" "V[" "Acm V[" "Acm V[" jp-kanji)
("X" "V[" "~jNCm V[" "~jNCm V[" jp-kanji)
("Y" "W[" "jxm W[" "jxm W[" jp-kanji)
("Z" "W[" "Xm W[" "Xm W[" jp-kanji)
("[" "W[" "W[um W[" "W[um W[" jp-kanji)
("\" "W[" "JX[Wm W[" "JX[Wm W[" jp-kanji)
("]" "W[" "V^KEm W[" "V^KEm W[" jp-kanji)
("^" "W[" "W[om W[" "W[om W[" jp-kanji)
("_" "W[" "Jm W[" "Jm W[" jp-kanji)
("`" "W[" "Vm W[" "Vm W[" jp-kanji)
("a" "W[" "VuCm W[" "VuCm W[" jp-kanji)
("b" "W[" "Pmm W[" "Pmm W[" jp-kanji)
("c" "W[" "^em W[" "^em W[" jp-kanji)
("d" "W[" "ICm W[" "ICm W[" jp-kanji)
("e" "W[" "PW[m W[" "PW[m W[" jp-kanji)
("f" "VN" "IWm VN" "IWm VN" jp-kanji)
("g" "VN" "cgjm VN" "cgjm VN" jp-kanji)
("h" "VN" "hm VN" "hm VN" jp-kanji)
("i" "VN" "VNWm VN" "VNWm VN" jp-kanji)
("j" "VN" "CEm VN" "CEm VN" jp-kanji)
("k" "VN" "`am VN" "`am VN" jp-kanji)
("l" "VN" "ccVm VN" "ccVm VN" jp-kanji)
("m" "WN" "WN`[m WN" "WN`[m WN" jp-kanji)
("n" "WN" "Em WN" "Em WN" jp-kanji)
("o" "Vc" "fm Vc" "fm Vc" jp-kanji)
("p" "Wc" "VWcm Wc" "VWcm Wc" jp-kanji)
("q" "Wc" "mxm Wc" "mxm Wc" jp-kanji)
("r" "V" "gVm V" "gVm V" jp-kanji)
("s" "V" "PVCm V" "PVCm V" jp-kanji)
("t" "V" "nm V" "nm V" jp-kanji)
("u" "V" "}^^Nm V" "}^^Nm V" jp-kanji)
("v" "V" "VR[m V" "VR[m V" jp-kanji)
("w" "V" "NQm V" "NQm V" jp-kanji)
("x" "V" "Vom V" "Vom V" jp-kanji)
("y" "W" "qWm W" "qWm W" jp-kanji)
("z" "W" "WJLm W" "WJLm W" jp-kanji)
("{" "W" "QWm W" "QWm W" jp-kanji)
("|" "W" "Lm ^em W" "Lm ^em W" jp-kanji)
("}" "W" "WVNm W" "WVNm W" jp-kanji)
("~" "W" "AcCm W" "AcCm W" jp-kanji)
("" "W" "Wrm W" "Wrm W" jp-kanji)
("" "W" "EIEm W" "EIEm W" jp-kanji)
("" "W" "^em W" "^em W" jp-kanji)
("" "W" "WXCm W" "WXCm W" jp-kanji)
("" "W" "Om W" "Om W" jp-kanji)
("" "W" "WVm W" "WVm W" jp-kanji)
("" "W" "LUPm W" "LUPm W" jp-kanji)
("" "W" "Wom W" "Wom W" jp-kanji)
("" "V" "Vm V" "Vm V" jp-kanji)
("" "V" "ncm V" "ncm V" jp-kanji)
("" "V" "gRm V" "gRm V" jp-kanji)
("" "V" "AcCm V" "AcCm V" jp-kanji)
("" "V" "AP{mm V" "AP{mm V" jp-kanji)
("" "V" "iMTm V" "iMTm V" jp-kanji)
("" "V" "V~m V" "V~m V" jp-kanji)
("" "V" "Im V" "Im V" jp-kanji)
("" "V" "PCTcVm V" "PCTcVm V" jp-kanji)
("" "V" "JNm V" "JNm V" jp-kanji)
("" "V" "JVm V" "JVm V" jp-kanji)
("" "V" "Cm V" "Cm V" jp-kanji)
("" "V" "CbVm V" "CbVm V" jp-kanji)
("" "W" "^XPm W" "^XPm W" jp-kanji)
("" "W" "WWVm W" "WWVm W" jp-kanji)
("" "W" "Iim W" "Iim W" jp-kanji)
("" "W" "nVKLm W" "nVKLm W" jp-kanji)
("" "W" "Im W" "Im W" jp-kanji)
("" "W" "Xm W" "Xm W" jp-kanji)
("" "W" "XLm W" "XLm W" jp-kanji)
("" "W" "m]Nm W" "m]Nm W" jp-kanji)
("" "V[" "LYm V[" "LYm V[" jp-kanji)
("" "V[" "cOiEm V[" "cOiEm V[" jp-kanji)
("" "V[" "Jcm V[" "Jcm V[" jp-kanji)
("" "V[" "^N~m V[" "^N~m V[" jp-kanji)
("" "V[" "}Xm V[" "}Xm V[" jp-kanji)
("" "V[" "Xm V[" "Xm V[" jp-kanji)
("" "V[" "~nm V[" "~nm V[" jp-kanji)
("" "V[" "ALiEm V[" "ALiEm V[" jp-kanji)
("" "V[" "KbV[_m V[" "KbV[_m V[" jp-kanji)
("" "V[" "im V[" "im V[" jp-kanji)
("" "V[" "XXm V[" "XXm V[" jp-kanji)
("" "V[" "JPm V[" "JPm V[" jp-kanji)
("" "V[" "V[tm V[" "V[tm V[" jp-kanji)
("" "V[" "Cm V[" "Cm V[" jp-kanji)
("" "V[" "V[Om V[" "V[Om V[" jp-kanji)
("" "V[" "`CTCm V[" "`CTCm V[" jp-kanji)
("" "V[" "XNiCm V[" "XNiCm V[" jp-kanji)
("" "V[" "iIm V[" "iIm V[" jp-kanji)
("" "V[" "V[m V[" "V[m V[" jp-kanji)
("" "V[" "Jm V[" "Jm V[" jp-kanji)
("" "V[" "Rm V[" "Rm V[" jp-kanji)
("" "V[" "ALJm V[" "ALJm V[" jp-kanji)
("" "V[" "EP^}Em V[" "EP^}Em V[" jp-kanji)
("" "V[" "V[Nm V[" "V[Nm V[" jp-kanji)
("" "V[" "}lNm V[" "}lNm V[" jp-kanji)
("" "V[" "^iSRm V[" "^iSRm V[" jp-kanji)
("" "V[" "XoCm V[" "XoCm V[" jp-kanji)
("" "V[" "m{m V[" "m{m V[" jp-kanji)
("" "V[" "q t^cm V[" "q t^cm V[" jp-kanji)
("" "V[" "V[m V[" "V[m V[" jp-kanji)
("" "V[" "XCV[m V[" "XCV[m V[" jp-kanji)
("" "V[" "}cm V[" "}cm V[" jp-kanji)
("" "V[" "RYGm V[" "RYGm V[" jp-kanji)
("" "V[" "NXm Lm V[" "NXm Lm V[" jp-kanji)
("" "V[" "LRm V[" "LRm V[" jp-kanji)
("" "V[" "k}m V[" "k}m V[" jp-kanji)
("" "V[" "LGm V[" "LGm V[" jp-kanji)
("" "V[" "^m V[" "^m V[" jp-kanji)
("" "V[" "V[im V[" "V[im V[" jp-kanji)
("" "V[" "Nm V[" "Nm V[" jp-kanji)
("" "V[" "RQm V[" "RQm V[" jp-kanji)
("" "V[" "em V[" "em V[" jp-kanji)
("" "V[" "}Cm V[" "}Cm V[" jp-kanji)
("" "V[" "nuNm V[" "nuNm V[" jp-kanji)
("" "V[" "KXm V[" "KXm V[" jp-kanji)
("" "V[" "TSV[m V[" "TSV[m V[" jp-kanji)
("" "V[" "nbV[m V[" "nbV[m V[" jp-kanji)
("" "V[" "giGm V[" "giGm V[" jp-kanji)
("" "V[" "uV[m V[" "uV[m V[" jp-kanji)
("" "V[" "Em V[" "Em V[" jp-kanji)
("" "V[" "\IEm V[" "\IEm V[" jp-kanji)
("" "V[" "V[JCVm V[" "V[JCVm V[" jp-kanji)
("" "V[" "V[][Km V[" "V[][Km V[" jp-kanji)
("" "V[" "niV[um V[" "niV[um V[" jp-kanji)
("" "V[" "}Rm V[" "}Rm V[" jp-kanji)
("" "V[" "oV[m V[" "oV[m V[" jp-kanji)
("" "V[" "V[gcm V[" "V[gcm V[" jp-kanji)
("" "V[" "m V[" "m V[" jp-kanji)
("" "V[" "\V[m V[" "\V[m V[" jp-kanji)
("" "V[" "AJXm V[" "AJXm V[" jp-kanji)
("" "V[" "~Rgmm V[" "~Rgmm V[" jp-kanji)
("" "V[" "NVCm V[" "NVCm V[" jp-kanji)
("" "V[" "][m V[" "][m V[" jp-kanji)
("" "V[" "zm V[" "zm V[" jp-kanji)
("" "V[" "V[m V[" "V[m V[" jp-kanji)
("" "V[" "hm V[" "hm V[" jp-kanji)
("" "V[" "V[LT}m V[" "V[LT}m V[" jp-kanji)
("" "V[" "Jlm V[" "Jlm V[" jp-kanji)
("" "V[" "TVTm V[" "TVTm V[" jp-kanji)
("" "V[" "Tm V[" "Tm V[" jp-kanji)
("" "W[" "EGm W[" "EGm W[" jp-kanji)
("" "W[" "^Pm W[" "^Pm W[" jp-kanji)
("" "W[" "W[wQm W[" "W[wQm W[" jp-kanji)
("" "W[" "mm W[" "mm W[" jp-kanji)
("" "W[" "W[_m W[" "W[_m W[" jp-kanji)
("" "W[" "A}m W[" "A}m W[" jp-kanji)
("" "W[" "Vm W[" "Vm W[" jp-kanji)
("" "W[" "om W[" "om W[" jp-kanji)
("" "W[" "c`m W[" "c`m W[" jp-kanji)
("" "W[" "IW[Tm W[" "IW[Tm W[" jp-kanji)
("" "W[" "clm W[" "clm W[" jp-kanji)
("" "W[" "iTPm W[" "iTPm W[" jp-kanji)
("" "W[" "~_m W[" "~_m W[" jp-kanji)
("" "W[" "W[Nm W[" "W[Nm W[" jp-kanji)
("" "W[" "cGm W[" "cGm W[" jp-kanji)
("" "W[" "Lm W[" "Lm W[" jp-kanji)
("" "W[" "W[L[m W[" "W[L[m W[" jp-kanji)
("" "W[" "^^~m W[" "^^~m W[" jp-kanji)
("" "W[" "~mm W[" "~mm W[" jp-kanji)
("" "W[" "Xm W[" "Xm W[" jp-kanji)
("" "W[" "Ym W[" "Ym W[" jp-kanji)
("" "W[" "W[][m W[" "W[][m W[" jp-kanji)
("" "W[" "eW[m W[" "eW[m W[" jp-kanji)
("" "VN" "^mm VN" "^mm VN" jp-kanji)
("" "VN" "njm VN" "njm VN" jp-kanji)
("" "VN" "JUm VN" "JUm VN" jp-kanji)
("@" "VN" "tNm VN" "tNm VN" jp-kanji)
("A" "VN" "EGm VN" "EGm VN" jp-kanji)
("B" "VN" "tGm VN" "tGm VN" jp-kanji)
("C" "VN" "[\Nm VN" "[\Nm VN" jp-kanji)
("D" "VN" "Im VN" "Im VN" jp-kanji)
("E" "VN" "VNM[m VN" "VNM[m VN" jp-kanji)
("F" "C" "Cm VN" "Cm VN" jp-kanji)
("G" "VN" "Tm VN" "Tm VN" jp-kanji)
("H" "VN" "^xm VN" "^xm VN" jp-kanji)
("I" "VN" "Vom VN" "Vom VN" jp-kanji)
("J" "WN" "nYJVm WN" "nYJVm WN" jp-kanji)
("K" "R[" "Vm R[" "Vm R[" jp-kanji)
("L" "V" "mrm V" "mrm V" jp-kanji)
("M" "V" "VWm V" "VWm V" jp-kanji)
("N" "V" "IJXm V" "IJXm V" jp-kanji)
("O" "V" "N`rm V" "N`rm V" jp-kanji)
("P" "V" "nm V" "nm V" jp-kanji)
("Q" "V" "lm V" "lm V" jp-kanji)
("R" "V" "VTm V" "VTm V" jp-kanji)
("S" "V" "RRm V" "RRm V" jp-kanji)
("T" "V" "ccVm V" "ccVm V" jp-kanji)
("U" "V" "tm V" "tm V" jp-kanji)
("V" "V" "A^VCm V" "A^VCm V" jp-kanji)
("W" "V" "Vm Njm V" "Vm Njm V" jp-kanji)
("X" "V" "m V" "m V" jp-kanji)
("Y" "V" "nVo~m V" "nVo~m V" jp-kanji)
("Z" "V" "q^Xm V" "q^Xm V" jp-kanji)
("[" "V" "tJCm V" "tJCm V" jp-kanji)
("\" "V" "[Xm V" "[Xm V" jp-kanji)
("]" "V" "t[Vm V" "t[Vm V" jp-kanji)
("^" "V" "VWcm V" "VWcm V" jp-kanji)
("_" "V" "J~m V" "J~m V" jp-kanji)
("`" "V" "Jm }Gm V" "Jm }Gm V" jp-kanji)
("a" "V" "VVm V" "VVm V" jp-kanji)
("b" "V" "_CWm V" "_CWm V" jp-kanji)
("c" "V" "N_mm V" "N_mm V" jp-kanji)
("d" "V" "^LMm V" "^LMm V" jp-kanji)
("e" "V" "Im V" "Im V" jp-kanji)
("f" "V" "~m V" "~m V" jp-kanji)
("g" "V" "~m V" "~m V" jp-kanji)
("h" "V" "JCm V" "JCm V" jp-kanji)
("i" "V" "XXm V" "XXm V" jp-kanji)
("j" "V" "nm V" "nm V" jp-kanji)
("k" "V" "tGm V" "tGm V" jp-kanji)
("l" "W" "qgm W" "qgm W" jp-kanji)
("m" "W" "WMm W" "WMm W" jp-kanji)
("n" "W" "nm W" "nm W" jp-kanji)
("o" "W" "`m W" "`m W" jp-kanji)
("p" "W" "~um W" "~um W" jp-kanji)
("q" "W" "Wm W" "Wm W" jp-kanji)
("r" "W" "nin_m W" "nin_m W" jp-kanji)
("s" "W" "cNXm W" "cNXm W" jp-kanji)
("t" "W" "W][m W" "W][m W" jp-kanji)
("u" "W" "^Ylm W" "^Ylm W" jp-kanji)
("v" "W" "W\Nm W" "W\Nm W" jp-kanji)
("w" "W" "W`m W" "W`m W" jp-kanji)
("x" "W" "W^Cm W" "W^Cm W" jp-kanji)
("y" "X" "^Xm X" "^Xm X" jp-kanji)
("z" "X" "Xm X" "Xm X" jp-kanji)
("{" "X" "XxJNm X" "XxJNm X" jp-kanji)
("|" "TN" "Xm TN" "Xm TN" jp-kanji)
("}" "Y" "nJm Y" "nJm Y" jp-kanji)
("~" "`[" "`[{[m `[" "`[{[m `[" jp-kanji)
("" "Y" "YVm Y" "YVm Y" jp-kanji)
("" "XC" "tNm XC" "tNm XC" jp-kanji)
("" "XC" "^m XC" "^m XC" jp-kanji)
("" "XC" "QXCm XC" "QXCm XC" jp-kanji)
("" "XC" "IXm XC" "IXm XC" jp-kanji)
("" "XC" "~Ym XC" "~Ym XC" jp-kanji)
("" "XC" "XCWm XC" "XCWm XC" jp-kanji)
("" "XC" "lm XC" "lm XC" jp-kanji)
("" "XC" "CLim XC" "CLim XC" jp-kanji)
("" "XC" "~hm XC" "~hm XC" jp-kanji)
("" "XC" "IgGm XC" "IgGm XC" jp-kanji)
("" "XC" "gQm XC" "gQm XC" jp-kanji)
("" "XC" "Em XC" "Em XC" jp-kanji)
("" "XC" "Lm XC" "Lm XC" jp-kanji)
("" "XC" "cm XC" "cm XC" jp-kanji)
("" "YC" "V^KEm YC" "V^KEm YC" jp-kanji)
("" "YC" "~Ym YC" "~Ym YC" jp-kanji)
("" "YC" "RcYCm YC" "RcYCm YC" jp-kanji)
("" "X[" "g[gum X[" "g[gum X[" jp-kanji)
("" "X[" "JTm X[" "JTm X[" jp-kanji)
("" "X[" "JYm X[" "JYm X[" jp-kanji)
("" "X[" "X[WNm X[" "X[WNm X[" jp-kanji)
("" "X[" "X[ZCm X[" "X[ZCm X[" jp-kanji)
("" "X[" "qim X[" "qim X[" jp-kanji)
("" "L" "XGm L" "XGm L" jp-kanji)
("" "T" "XMm T" "XMm T" jp-kanji)
("" "V[" "XMm RNW" "XMm RNW" jp-kanji)
("" "J" "XKm J" "XKm J" jp-kanji)
("" "n" "XRum n" "XRum n" jp-kanji)
("" "WN" "gm XY" "gm XY" jp-kanji)
("" "L" "X\m L" "X\m L" jp-kanji)
("" "`[" "Xm `[" "Xm `[" jp-kanji)
("" "V[" "Xm V[" "Xm V[" jp-kanji)
("" "X" "iKTm X" "iKTm X" jp-kanji)
("" "Z" "m Z" "m Z" jp-kanji)
("" "Z" "Zgm Z" "Zgm Z" jp-kanji)
("" "Z" "Elm Z" "Elm Z" jp-kanji)
("" "[" "Rm [" "Rm [" jp-kanji)
("" "ZC" "XSCm ZC" "XSCm ZC" jp-kanji)
("" "ZC" "ZCMm ZC" "ZCMm ZC" jp-kanji)
("" "ZC" "CLICm ZC" "CLICm ZC" jp-kanji)
("" "ZC" "EWm ZC" "EWm ZC" jp-kanji)
("" "ZC" "ZCtNVm ZC" "ZCtNVm ZC" jp-kanji)
("" "ZC" "ZCVcm ZC" "ZCVcm ZC" jp-kanji)
("" "ZC" "im ZC" "im ZC" jp-kanji)
("" "ZC" "ZCWm ZC" "ZCWm ZC" jp-kanji)
("" "ZC" "ggmGm ZC" "ggmGm ZC" jp-kanji)
("" "ZC" "zVm ZC" "zVm ZC" jp-kanji)
("" "ZC" "nm ZC" "nm ZC" jp-kanji)
("" "ZC" "Xm ZC" "Xm ZC" jp-kanji)
("" "ZC" "gXVm ZC" "gXVm ZC" jp-kanji)
("" "ZC" "^_VCm ZC" "^_VCm ZC" jp-kanji)
("" "ZC" "LCm ZC" "LCm ZC" jp-kanji)
("" "ZC" "MZCm ZC" "MZCm ZC" jp-kanji)
("" "ZC" "CLm ZC" "CLm ZC" jp-kanji)
("" "ZC" "TJm ZC" "TJm ZC" jp-kanji)
("" "ZC" "ZCVm ZC" "ZCVm ZC" jp-kanji)
("" "ZC" "qWm ZC" "qWm ZC" jp-kanji)
("" "ZC" "RGm ZC" "RGm ZC" jp-kanji)
("" "ZC" "ZC][m ZC" "ZC][m ZC" jp-kanji)
("" "ZC" "jVm ZC" "jVm ZC" jp-kanji)
("" "ZC" "}Rgm ZC" "}Rgm ZC" jp-kanji)
("" "ZC" "`JEm ZC" "`JEm ZC" jp-kanji)
("" "ZC" "REm ZC" "REm ZC" jp-kanji)
("" "ZC" "Nm ZC" "Nm ZC" jp-kanji)
("" "ZC" "Tm ZC" "Tm ZC" jp-kanji)
("" "ZC" "AIm ZC" "AIm ZC" jp-kanji)
("" "ZC" "VYJm ZC" "VYJm ZC" jp-kanji)
("" "ZC" "CbZCm ZC" "CbZCm ZC" jp-kanji)
("" "[C" "[CVm [C" "[CVm [C" jp-kanji)
("" "[C" "Cm [C" "Cm [C" jp-kanji)
("" "ZL" "ZLKm ZL" "ZLKm ZL" jp-kanji)
("" "ZL" "UZLm ZL" "UZLm ZL" jp-kanji)
("" "ZL" "IVCm ZL" "IVCm ZL" jp-kanji)
("" "ZL" "VZLm ZL" "VZLm ZL" jp-kanji)
("" "ZL" "V]Pm ZL" "V]Pm ZL" jp-kanji)
("" "ZL" "JVm ZL" "JVm ZL" jp-kanji)
("" "ZL" "uZLm ZL" "uZLm ZL" jp-kanji)
("" "ZL" "CVm ZL" "CVm ZL" jp-kanji)
("" "ZL" "cm ZL" "cm ZL" jp-kanji)
("" "ZL" "RZLm ZL" "RZLm ZL" jp-kanji)
("" "ZL" "ZCZLm ZL" "ZCZLm ZL" jp-kanji)
("" "ZL" "ZLYCm ZL" "ZLYCm ZL" jp-kanji)
("" "ZL" "Zm ZL" "Zm ZL" jp-kanji)
("" "ZL" "AJm ZL" "AJm ZL" jp-kanji)
("" "ZL" "AVAgm ZL" "AVAgm ZL" jp-kanji)
("" "ZL" "Agm L[W" "Agm L[W" jp-kanji)
("" "ZL" "ZLJNm ZL" "ZLJNm ZL" jp-kanji)
("" "Zc" "Lm Zc" "Lm Zc" jp-kanji)
("" "Zc" "ZbVm Zc" "ZbVm Zc" jp-kanji)
("" "Zc" "cOm Zc" "cOm Zc" jp-kanji)
("" "Zc" "ZbV[m Zc" "ZbV[m Zc" jp-kanji)
("" "Zc" "Im Zc" "Im Zc" jp-kanji)
("" "Zc" "[Pm Zc" "[Pm Zc" jp-kanji)
("" "Zc" "Zbg[m Zc" "Zbg[m Zc" jp-kanji)
("" "Zc" "tVm Zc" "tVm Zc" jp-kanji)
("" "Zc" "gNm Zc" "gNm Zc" jp-kanji)
("" "Zc" "Lm Zc" "Lm Zc" jp-kanji)
("" "[c" "^Gm [c" "^Gm [c" jp-kanji)
("" "[c" "V^m [c" "V^m [c" jp-kanji)
("" "[" "R`[m Z~" "R`[m Z~" jp-kanji)
("" "Z" "Zjm Z" "Zjm Z" jp-kanji)
("" "Z" "TLm Z" "TLm Z" jp-kanji)
("" "Z" "^Cm Z" "^Cm Z" jp-kanji)
("" "Z" "EiEm Z" "EiEm Z" jp-kanji)
("" "Z" "Zfm Z" "Zfm Z" jp-kanji)
("" "Z" "bpm Z" "bpm Z" jp-kanji)
("" "Z" "gKm Z" "gKm Z" jp-kanji)
("" "Z" "Jm Z" "Jm Z" jp-kanji)
("" "Z" "^^JEm Z" "^^JEm Z" jp-kanji)
("" "Z" "I[Mm Z" "I[Mm Z" jp-kanji)
("" "Z" "ZWm Z" "ZWm Z" jp-kanji)
("" "Z" "rm Z" "rm Z" jp-kanji)
("" "Z" "Z_m Z" "Z_m Z" jp-kanji)
("" "Z" "CY~m Z" "CY~m Z" jp-kanji)
("" "Z" "ATCm Z" "ATCm Z" jp-kanji)
("" "Z" "AEm Z" "AEm Z" jp-kanji)
("" "Z" "\m Z" "\m Z" jp-kanji)
("" "Z" "q\m Z" "q\m Z" jp-kanji)
("" "Z" "Cm Z" "Cm Z" jp-kanji)
("" "Z" "AIm Z" "AIm Z" jp-kanji)
("" "Z" "Zom Z" "Zom Z" jp-kanji)
("" "Z" "EKcm Z" "EKcm Z" jp-kanji)
("" "Z" "^Pj }Gm Z" "^Pj }Gm Z" jp-kanji)
("" "Z" "Cgm Z" "Cgm Z" jp-kanji)
("@" "Z" "Zm[m Z" "Zm[m Z" jp-kanji)
("A" "Z" "Z{[m Z" "Z{[m Z" jp-kanji)
("B" "Z" "CZm Z" "CZm Z" jp-kanji)
("C" "Z" "^KGm Z" "^KGm Z" jp-kanji)
("D" "Z" "tlm Z" "tlm Z" jp-kanji)
("E" "Z" "XXm Z" "XXm Z" jp-kanji)
("F" "Z" "ZTNm Z" "ZTNm Z" jp-kanji)
("G" "Z" "CVCm Z" "CVCm Z" jp-kanji)
("H" "Z" "WbZm Z" "WbZm Z" jp-kanji)
("I" "Z" "Gum Z" "Gum Z" jp-kanji)
("J" "Z" "Zgm Z" "Zgm Z" jp-kanji)
("K" "Z" "[jm Z" "[jm Z" jp-kanji)
("L" "Z" "Zecm Z" "Zecm Z" jp-kanji)
("M" "Z" "qNm Z" "qNm Z" jp-kanji)
("N" "Z" "AUJm Z" "AUJm Z" jp-kanji)
("O" "[" "}Gm [" "}Gm [" jp-kanji)
("P" "[" "Cm [" "Cm [" jp-kanji)
("Q" "[" "[Nm [" "[Nm [" jp-kanji)
("R" "[" "V[m [" "V[m [" jp-kanji)
("S" "[" "}b^Nm [" "}b^Nm [" jp-kanji)
("T" "[" "[V[m [" "[V[m [" jp-kanji)
("U" "[" "cNEm [" "cNEm [" jp-kanji)
("V" "[" "I[m [" "I[m [" jp-kanji)
("W" "Z`[g" "iKTm Z`" "iKTm Z`" jp-kanji)
("X" "\" "~\m \" "~\m \" jp-kanji)
("Y" "\" "\][m \" "\][m \" jp-kanji)
("Z" "\" "P\m \" "P\m \" jp-kanji)
("[" "\" "INm \" "INm \" jp-kanji)
("\" "\" "L\Wm \" "L\Wm \" jp-kanji)
("]" "\" "\[\tm \" "\[\tm \" jp-kanji)
("^" "\" "ZC\m \" "ZC\m \" jp-kanji)
("_" "\" "lEm \" "lEm \" jp-kanji)
("`" "\" "\XCm \" "\XCm \" jp-kanji)
("a" "\" "EgCm \" "EgCm \" jp-kanji)
("b" "\" "CVYGm \" "CVYGm \" jp-kanji)
("c" "\" "\Zm \" "\Zm \" jp-kanji)
("d" "\" "\[Cm \" "\[Cm \" jp-kanji)
("e" "\" "ACm \" "ACm \" jp-kanji)
("f" "\" "gm \" "gm \" jp-kanji)
("g" "\" "Nm \" "Nm \" jp-kanji)
("h" "\" "~KGm \" "~KGm \" jp-kanji)
("i" "\" "Eb^Gm \" "Eb^Gm \" jp-kanji)
("j" "\" "nom \" "nom \" jp-kanji)
("k" "\" "TJm{m \" "TJm{m \" jp-kanji)
("l" "\" "lY~m \" "lY~m \" jp-kanji)
("m" "\[" "\[m \[" "\[m \[" jp-kanji)
("n" "\[" "\[cm \[" "\[cm \[" jp-kanji)
("o" "\[" "t^Sm \[" "t^Sm \[" jp-kanji)
("p" "\[" "NTm \[" "NTm \[" jp-kanji)
("q" "\[" "Nm \[" "Nm \[" jp-kanji)
("r" "\[" "tNm " "tNm " jp-kanji)
("s" "\[" "\[lm \[" "\[lm \[" jp-kanji)
("t" "\[" "Jifm \[" "Jifm \[" jp-kanji)
("u" "\[" "TJm \[" "TJm \[" jp-kanji)
("v" "\[" "\[m Njm \[" "\[m Njm \[" jp-kanji)
("w" "\[" "`\[m \[" "`\[m \[" jp-kanji)
("x" "\[" "Om \[" "Om \[" jp-kanji)
("y" "\[" "\[[m \[" "\[[m \[" jp-kanji)
("z" "\[" "Q\[m \[" "Q\[m \[" jp-kanji)
("{" "\[" "TKXm \[" "TKXm \[" jp-kanji)
("|" "\[" "nNm \[" "nNm \[" jp-kanji)
("}" "\[" "TXm \[" "TXm \[" jp-kanji)
("~" "\[" "\[nm \[" "\[nm \[" jp-kanji)
("" "\[" "Acm \[" "Acm \[" jp-kanji)
("" "\[" "nCm \[" "nCm \[" jp-kanji)
("" "\[" "I][Vm \[" "I][Vm \[" jp-kanji)
("" "\[" "Xm \[" "Xm \[" jp-kanji)
("" "\[" "m \[" "m \[" jp-kanji)
("" "\[" "XC\[m \[" "XC\[m \[" jp-kanji)
("" "\[" "ROm \[" "ROm \[" jp-kanji)
("" "\[" "JNm \[" "JNm \[" jp-kanji)
("" "\[" "A\Em \[" "A\Em \[" jp-kanji)
("" "\[" "Zm \[" "Zm \[" jp-kanji)
("" "\[" "ACm \[" "ACm \[" jp-kanji)
("" "\[" "}hm \[" "}hm \[" jp-kanji)
("" "\[" "JXm \[" "JXm \[" jp-kanji)
("" "\[" "\[S[m \[" "\[S[m \[" jp-kanji)
("" "\[" "Cgwm \[" "Cgwm \[" jp-kanji)
("" "\[" "\[Cm \[" "\[Cm \[" jp-kanji)
("" "\[" "NTm \[" "NTm \[" jp-kanji)
("" "\[" "xb\[m \[" "xb\[m \[" jp-kanji)
("" "\[" "z[m \[" "z[m \[" jp-kanji)
("" "\[" "AICm \[" "AICm \[" jp-kanji)
("" "\[" "m \[" "m \[" jp-kanji)
("" "\[" "\IEm \[" "\IEm \[" jp-kanji)
("" "\[" "nVm \[" "nVm \[" jp-kanji)
("" "\[" "INm \[" "INm \[" jp-kanji)
("" "\[" "\[O[m \[" "\[O[m \[" jp-kanji)
("" "\[" "Jlwm " "Jlwm " jp-kanji)
("" "\[" "Vm \[" "Vm \[" jp-kanji)
("" "\[" "TOm \[" "TOm \[" jp-kanji)
("" "][" "h[][m ][" "h[][m ][" jp-kanji)
("" "][" "}Xm ][" "}Xm ][" jp-kanji)
("" "][" "jNm ][" "jNm ][" jp-kanji)
("" "][" "V][m ][" "V][m ][" jp-kanji)
("" "][" "Nm ][" "Nm ][" jp-kanji)
("" "][" "INm ][" "INm ][" jp-kanji)
("" "][" "cNm ][" "cNm ][" jp-kanji)
("" "\N" "EiKXm \N" "EiKXm \N" jp-kanji)
("" "\N" "Km \N" "Km \N" jp-kanji)
("" "\N" "mbgm \N" "mbgm \N" jp-kanji)
("" "\N" "\NUm \N" "\NUm \N" jp-kanji)
("" "\N" "CLm \N" "CLm \N" jp-kanji)
("" "\N" "cJ}Gm \N" "cJ}Gm \N" jp-kanji)
("" "\N" "^om \N" "^om \N" jp-kanji)
("" "\N" "nJm \N" "nJm \N" jp-kanji)
("" "\N" "AVm \N" "AVm \N" jp-kanji)
("" "\N" "nCm \N" "nCm \N" jp-kanji)
("" "]N" "]NSm ]N" "]NSm ]N" jp-kanji)
("" "]N" "]NXm ]N" "]NXm ]N" jp-kanji)
("" "]N" "JC]Nm ]N" "JC]Nm ]N" jp-kanji)
("" "]N" "J]Nm ]N" "J]Nm ]N" jp-kanji)
("" "]N" "cdNm ]N" "cdNm ]N" jp-kanji)
("" "\c" "\cM[m \c" "\cM[m \c" jp-kanji)
("" "V[" "Lmm \f" "Lmm \f" jp-kanji)
("" "L" "\mm \" "\mm \" jp-kanji)
("" "Z" "\Em Z" "\Em Z" jp-kanji)
("" "\" "\UCm \" "\UCm \" jp-kanji)
("" "\" "}Sm \" "}Sm \" jp-kanji)
("" "\" "g[gCm \" "g[gCm \" jp-kanji)
("" "\" "\RiEm \" "\RiEm \" jp-kanji)
("" "\" "m \" "m \" jp-kanji)
("" "\" "\VNm \" "\VNm \" jp-kanji)
("" "^" "^jm ^" "^jm ^" jp-kanji)
("" "^" "IICm ^" "IICm ^" jp-kanji)
("" "^" "tgCm ^C" "tgCm ^C" jp-kanji)
("" "^" "g[^m ^" "g[^m ^" jp-kanji)
("" "^" "AUNm ^" "AUNm ^" jp-kanji)
("" "_" "_GLm _" "_GLm _" jp-kanji)
("" "_" "_Nm _" "_Nm _" jp-kanji)
("" "_" "_L[m _" "_L[m _" jp-kanji)
("" "_" "^C_m _" "^C_m _" jp-kanji)
("" "_" "Ecm _" "Ecm _" jp-kanji)
("" "_" "Lwm JWm _" "Lwm JWm _" jp-kanji)
("" "_" "tlm JWm _" "tlm JWm _" jp-kanji)
("" "_" "_GPCm _" "_GPCm _" jp-kanji)
("" "_" "A~_ucm _" "A~_ucm _" jp-kanji)
("" "_" "_KVm _" "_KVm _" jp-kanji)
("" "_" "q_m _" "q_m _" jp-kanji)
("" "^C" "J_m ^C" "J_m ^C" jp-kanji)
("" "^C" "EY^JCm ^C" "EY^JCm ^C" jp-kanji)
("" "^C" "cCm ^C" "cCm ^C" jp-kanji)
("" "^C" "^Gm ^C" "^Gm ^C" jp-kanji)
("" "^C" "^CUm ^C" "^CUm ^C" jp-kanji)
("" "^C" "Irm ^C" "Irm ^C" jp-kanji)
("" "^C" "}cm ^C" "}cm ^C" jp-kanji)
("" "^C" "i}Pm ^C" "i}Pm ^C" jp-kanji)
("" "^C" "^Chm ^C" "^Chm ^C" jp-kanji)
("" "^C" "C^_Nm ^C" "C^_Nm ^C" jp-kanji)
("" "^C" "JG_}m ^C" "JG_}m ^C" jp-kanji)
("" "^C" "A^Cm ^C" "A^Cm ^C" jp-kanji)
("" "^C" "ghRIm ^C" "ghRIm ^C" jp-kanji)
("" "^C" "nm ^C" "nm ^C" jp-kanji)
("" "^C" "m ^C" "m ^C" jp-kanji)
("" "^C" "RPm ^C" "RPm ^C" jp-kanji)
("" "^C" "tNm ^C" "tNm ^C" jp-kanji)
("" "^C" "JXm ^C" "JXm ^C" jp-kanji)
("" "^C" "V]Nm ^C" "V]Nm ^C" jp-kanji)
("" "^C" "^Czm ^C" "^Czm ^C" jp-kanji)
("" "^C" "wC^Cm ^C" "wC^Cm ^C" jp-kanji)
("" "^C" "}Y~m ^C" "}Y~m ^C" jp-kanji)
("" "`[" "TJim ^C" "TJim ^C" jp-kanji)
("" "_C" "_Cm _C" "_Cm _C" jp-kanji)
("" "_C" "_ChRm _C" "_ChRm _C" jp-kanji)
("" "_C" "IILCm _C" "IILCm _C" jp-kanji)
("" "_C" "_CC`m _C" "_CC`m _C" jp-kanji)
("" "_C" "_CS~m _C" "_CS~m _C" jp-kanji)
("" "_C" "_CCm _C" "_CCm _C" jp-kanji)
("" "I[" "gm ^J" "gm ^J" jp-kanji)
("" "^L" "^Lc{m ^L" "^Lc{m ^L" jp-kanji)
("" "^L" "L[JWm ^L" "L[JWm ^L" jp-kanji)
("" "^N" "^bL[m ^N" "^bL[m ^N" jp-kanji)
("" "^N" "^N{Nm ^N" "^N{Nm ^N" jp-kanji)
("" "^N" "W^Nm ^N" "W^Nm ^N" jp-kanji)
("" "^N" "^Nncm ^N" "^Nncm ^N" jp-kanji)
("" "^N" "TC^Nm ^N" "TC^Nm ^N" jp-kanji)
("" "^N" "JC^Nm ^N" "JC^Nm ^N" jp-kanji)
("" "^N" "Tm ^N" "Tm ^N" jp-kanji)
("" "^N" "Z^NLm ^N" "Z^NLm ^N" jp-kanji)
("" "^N" "^N}m ^N" "^N}m ^N" jp-kanji)
("" "^N" "^NWVm ^N" "^NWVm ^N" jp-kanji)
("" "^N" "h[^Nm ^N" "h[^Nm ^N" jp-kanji)
("" "_N" "jSm _N" "jSm _N" jp-kanji)
("" "_N" "V[_Nm _N" "V[_Nm _N" jp-kanji)
("" "W[" "}c^Pm ^P" "}c^Pm ^P" jp-kanji)
("" "L" "^RAQm ^R" "^RAQm ^R" jp-kanji)
("" "V[" "E~m ^R" "E~m ^R" jp-kanji)
("" "V" "^_C}m ^_" "^_C}m ^_" jp-kanji)
("@" "R[" "^^Nm R[" "^^Nm R[" jp-kanji)
("A" "^" "Zc]Nm ^_V" "Zc]Nm ^_V" jp-kanji)
("B" "^`" "\N^cm ^c" "\N^cm ^c" jp-kanji)
("C" "V" "W[jVm ^c" "W[jVm ^c" jp-kanji)
("D" "_c" "EoEm _c" "EoEm _c" jp-kanji)
("E" "_c" "kOm _c" "kOm _c" jp-kanji)
("F" "\" "z[KNm ^c~" "z[KNm ^c~" jp-kanji)
("G" "W" "^eSgm ^e" "^eSgm ^e" jp-kanji)
("H" "e" "^hcNm ^h" "^hcNm ^h" jp-kanji)
("I" "z[" "z_im ^i" "z_im ^i" jp-kanji)
("J" "RN" "^jm RN" "^jm RN" jp-kanji)
("K" "" "h[ucm ^kL" "h[ucm ^kL" jp-kanji)
("L" "Zc" "TJim ^" "TJim ^" jp-kanji)
("M" "\" "TJ_m ^" "TJ_m ^" jp-kanji)
("N" "_" "_\m _" "_\m _" jp-kanji)
("O" "^" "^lm ^" "^lm ^" jp-kanji)
("P" "^" "^Ccm ^" "^Ccm ^" jp-kanji)
("Q" "^" "iQNm ^" "iQNm ^" jp-kanji)
("R" "^" "^JCm ^" "^JCm ^" jp-kanji)
("S" "^" "jiEm ^" "jiEm ^" jp-kanji)
("T" "^" "TOm ^" "TOm ^" jp-kanji)
("U" "^" "K^m ^" "K^m ^" jp-kanji)
("V" "^" "^jV[m ^" "^jV[m ^" jp-kanji)
("W" "^" "ACm ^" "ACm ^" jp-kanji)
("X" "^" "^Um ^" "^Um ^" jp-kanji)
("Y" "^" "X~m ^" "X~m ^" jp-kanji)
("Z" "^" "~WJCm ^" "~WJCm ^" jp-kanji)
("[" "^" "nVm ^" "nVm ^" jp-kanji)
("\" "^" "q[^m ^" "q[^m ^" jp-kanji)
("]" "^" "ILem ^" "ILem ^" jp-kanji)
("^" "^" "tPm ^" "tPm ^" jp-kanji)
("_" "^" "^W[m ^" "^W[m ^" jp-kanji)
("`" "^" "^pNm ^" "^pNm ^" jp-kanji)
("a" "^" "^W[m ^" "^W[m ^" jp-kanji)
("b" "^" "L^Gm ^" "L^Gm ^" jp-kanji)
("c" "_" "_^Cm _" "_^Cm _" jp-kanji)
("d" "_" "_W[m _" "_W[m _" jp-kanji)
("e" "_" "qNm _" "qNm _" jp-kanji)
("f" "_" "^cm _" "^cm _" jp-kanji)
("g" "_" "A^^JCm _" "A^^JCm _" jp-kanji)
("h" "_" "Z_m _" "Z_m _" jp-kanji)
("i" "_" "JC_m _" "JC_m _" jp-kanji)
("j" "_" "IgRm _" "IgRm _" jp-kanji)
("k" "_" "\[_m _" "\[_m _" jp-kanji)
("l" "`" "A^Cm `" "A^Cm `" jp-kanji)
("m" "`" "Vm `" "Vm `" jp-kanji)
("n" "`" "Wm `" "Wm `" jp-kanji)
("o" "`" "m `" "m `" jp-kanji)
("p" "`" "nWm `" "nWm `" jp-kanji)
("q" "`" "`Gm `" "`Gm `" jp-kanji)
("r" "`" "CPm `" "CPm `" jp-kanji)
("s" "`" "`Jm `" "`Jm `" jp-kanji)
("t" "`" "[`m `" "[`m `" jp-kanji)
("u" "`" "INm `" "INm `" jp-kanji)
("v" "`" "C^Xm `" "C^Xm `" jp-kanji)
("w" "`" "Vm Nm N" "Vm Nm N" jp-kanji)
("x" "`" "INm `" "INm `" jp-kanji)
("y" "`" "S`\[m `" "S`\[m `" jp-kanji)
("z" "`N" "LYNm `N" "LYNm `N" jp-kanji)
("{" "`N" "`NV[m `N" "`NV[m `N" jp-kanji)
("|" "`N" "^Pm `N" "^Pm `N" jp-kanji)
("}" "`N" "`NSm `N" "`NSm `N" jp-kanji)
("~" "`N" "^NGm `N" "^NGm `N" jp-kanji)
("" "`N" "`NWm `N" "`NWm `N" jp-kanji)
("" "`c" "`cWm `c" "`cWm `c" jp-kanji)
("" "`c" "`b\Nm `c" "`b\Nm `c" jp-kanji)
("" "`" "m~mm `" "m~mm `" jp-kanji)
("" "`N" "`NVm `N" "`NVm `N" jp-kanji)
("" "`N" "cNm `N" "cNm `N" jp-kanji)
("" "`[" "iJm `[" "iJm `[" jp-kanji)
("" "`[" "iJ}m `[" "iJ}m `[" jp-kanji)
("" "`[" "E`[m `[" "E`[m `[" jp-kanji)
("" "`[" "`[Wcm `[" "`[Wcm `[" jp-kanji)
("" "`[" "`[Vcm `[" "`[Vcm `[" jp-kanji)
("" "`[" "qm `[" "qm `[" jp-kanji)
("" "`[" "nVm `[" "nVm `[" jp-kanji)
("" "`[" "\\Om `[" "\\Om `[" jp-kanji)
("" "`[" "Vm `[" "Vm `[" jp-kanji)
("" "`[" "Zb`[m `[" "Zb`[m `[" jp-kanji)
("" "`[" "Sxm `[" "Sxm `[" jp-kanji)
("" "`[" "V[`[m `[" "V[`[m `[" jp-kanji)
("" "`[" "Cmm `[" "Cmm `[" jp-kanji)
("" "`[" "`[VW[m `[" "`[VW[m `[" jp-kanji)
("" "`" "Lm CbVm `" "Lm CbVm `" jp-kanji)
("" "`" "^CPm `" "^CPm `" jp-kanji)
("" "`" "CmVVm `" "CmVVm `" jp-kanji)
("" "`" "ATm CbVm `" "ATm CbVm `" jp-kanji)
("" "`" "C`WVCm `" "C`WVCm `" jp-kanji)
("" "`" "^NGm `" "^NGm `" jp-kanji)
("" "`[" "`[hm `[" "`[hm `[" jp-kanji)
("" "`[" "LUXm `[" "LUXm `[" jp-kanji)
("" "`[" "`[Nm `[" "`[Nm `[" jp-kanji)
("" "`[" "Vxm `[" "Vxm `[" jp-kanji)
("" "`[" "`[ACm `[" "`[ACm `[" jp-kanji)
("" "`[" "C`W[m `[" "C`W[m `[" jp-kanji)
("" "`[" "e`[m `[" "e`[m `[" jp-kanji)
("" "`[" "g`[m `[" "g`[m `[" jp-kanji)
("" "`[" "gEm `[" "gEm `[" jp-kanji)
("" "`[" "nm `[" "nm `[" jp-kanji)
("" "`[" "zm `[" "zm `[" jp-kanji)
("" "`[" "gN`[m `[" "gN`[m `[" jp-kanji)
("" "`[" "RVm `[" "RVm `[" jp-kanji)
("" "`[" "Chm `[" "Chm `[" jp-kanji)
("" "`[" "mLm `[" "mLm `[" jp-kanji)
("" "`[" "ATm `[" "ATm `[" jp-kanji)
("" "`[" "VIm `[" "VIm `[" jp-kanji)
("" "`[" "t_m `[" "t_m `[" jp-kanji)
("" "`[" "}`m `[" "}`m `[" jp-kanji)
("" "`[" "iKm `[" "iKm `[" jp-kanji)
("" "`[" "LNm `[" "LNm `[" jp-kanji)
("" "`[" "tNm `[" "tNm `[" jp-kanji)
("" "`[" "_C`[m `[" "_C`[m `[" jp-kanji)
("" "`[" "R`[m `[" "R`[m `[" jp-kanji)
("" "`[" "Vxm `[" "Vxm `[" jp-kanji)
("" "`[" "}Vmm `[" "}Vmm `[" jp-kanji)
("" "`[" "RGm `[" "RGm `[" jp-kanji)
("" "`[" "gum `[" "gum `[" jp-kanji)
("" "`[" "I`[Vm `[" "I`[Vm `[" jp-kanji)
("" "`[" "iKCm `[" "iKCm `[" jp-kanji)
("" "`[" "C^_Lm `[" "C^_Lm `[" jp-kanji)
("" "`[" "gm `[" "gm `[" jp-kanji)
("" "`N" "~Rgm m `N" "~Rgm m `N" jp-kanji)
("" "`N" "nJhm `N" "nJhm `N" jp-kanji)
("" "`N" "iIm `N" "iIm `N" jp-kanji)
("" "`" "m `" "m `" jp-kanji)
("" "`" "VYm `" "VYm `" jp-kanji)
("" "`" "YVCm `" "YVCm `" jp-kanji)
("" "`" "`Mm `" "`Mm `" jp-kanji)
("" "`" "VYm `" "VYm `" jp-kanji)
("" "`" "`cm `" "`cm `" jp-kanji)
("" "V" "IIcm c" "IIcm c" jp-kanji)
("" "cC" "cCNm cC" "cCNm cC" jp-kanji)
("" "cC" "Lm VC" "Lm VC" jp-kanji)
("" "cC" "Ld`m cC" "Ld`m cC" jp-kanji)
("" "cC" "IEm cC" "IEm cC" jp-kanji)
("" "cC" "eCecm cC" "eCecm cC" jp-kanji)
("" "c[" "C^Cm c[" "C^Cm c[" jp-kanji)
("" "c[" "gIm c[" "gIm c[" jp-kanji)
("" "cJ" "nJm cJ" "nJm cJ" jp-kanji)
("" "{" "Lm cK" "Lm cK" jp-kanji)
("" "JN" "cJm JN" "cJm JN" jp-kanji)
("" "L" "cLPLm cL" "cLPLm cL" jp-kanji)
("" "f" "cN_m f" "cN_m f" jp-kanji)
("" "V" "cPmm cP" "cPmm cP" jp-kanji)
("" "c" "UNm UN" "UNm UN" jp-kanji)
("" "cW" "cWMm cW" "cWMm cW" jp-kanji)
("" "`[" "VNucm c^" "VNucm c^" jp-kanji)
("" "eC" "cdm eC" "cdm eC" jp-kanji)
("" "KN" "J^im co" "J^im co" jp-kanji)
("" "`" "Lm coL" "Lm coL" jp-kanji)
("" "JC" "cuXm JC" "cuXm JC" jp-kanji)
("" "wC" "c{m wC" "c{m wC" jp-kanji)
("" "R" "c{m R" "c{m R" jp-kanji)
("" "W" "c}m W" "c}m W" jp-kanji)
("" "`[" "Imm cM" "Imm cM" jp-kanji)
("" "\[" "cm \[" "cm \[" jp-kanji)
("" "`[" "coVm c" "coVm c" jp-kanji)
("" "`[" "cm `[" "cm `[" jp-kanji)
("" "JN" "gm c" "gm c" jp-kanji)
("" "eC" "eCVm eC" "eCVm eC" jp-kanji)
("" "eC" "qNCm eC" "qNCm eC" jp-kanji)
("" "eC" "eCVm eC" "eCVm eC" jp-kanji)
("" "eC" "^eCm eC" "^eCm eC" jp-kanji)
("" "eC" "\m eC" "\m eC" jp-kanji)
("" "eC" "eCVNm eC" "eCVNm eC" jp-kanji)
("" "eC" "VeCm eC" "VeCm eC" jp-kanji)
("" "eC" "cc~m eC" "cc~m eC" jp-kanji)
("" "eC" "T_m eC" "T_m eC" jp-kanji)
("" "eC" "eCI[m eC" "eCI[m eC" jp-kanji)
("" "eC" "\Rm eC" "\Rm eC" jp-kanji)
("" "eC" "jm eC" "jm eC" jp-kanji)
("" "eC" "z[eCm eC" "z[eCm eC" jp-kanji)
("" "eC" "Ig[gm eC" "Ig[gm eC" jp-kanji)
("" "eC" "eC[m eC" "eC[m eC" jp-kanji)
("" "eC" "eCR[m eC" "eCR[m eC" jp-kanji)
("" "eC" "~ eCXm eC" "~ eCXm eC" jp-kanji)
("" "eC" "eCL[m eC" "eCL[m eC" jp-kanji)
("" "eC" "nVSm eC" "nVSm eC" jp-kanji)
("" "eC" "~Mm eC" "~Mm eC" jp-kanji)
("" "eC" "CJm eC" "CJm eC" jp-kanji)
("" "eC" "VXwm eC" "VXwm eC" jp-kanji)
("" "eC" "zhm eC" "zhm eC" jp-kanji)
("" "eC" "V}m eC" "V}m eC" jp-kanji)
("" "eC" "tlm eC" "tlm eC" jp-kanji)
("" "eC" "eCZCm eC" "eCZCm eC" jp-kanji)
("" "eC" "ALm eC" "ALm eC" jp-kanji)
("" "eC" "qdm eC" "qdm eC" jp-kanji)
("" "eC" "eCVm eC" "eCVm eC" jp-kanji)
("@" "eC" "eC^Nm eC" "eC^Nm eC" jp-kanji)
("A" "eC" "Njm im eC" "Njm im eC" jp-kanji)
("B" "eC" "NMm eC" "NMm eC" jp-kanji)
("C" "eC" "JiGm eC" "JiGm eC" jp-kanji)
("D" "fC" "hm fC" "hm fC" jp-kanji)
("E" "eL" "cm eL" "cm eL" jp-kanji)
("F" "eL" "kLfm eL" "kLfm eL" jp-kanji)
("G" "eL" "eL ~J^m eL" "eL ~J^m eL" jp-kanji)
("H" "eL" "VYNm eL" "VYNm eL" jp-kanji)
("I" "eL" "}gm eL" "}gm eL" jp-kanji)
("J" "eL" "tGm eL" "tGm eL" jp-kanji)
("K" "eL" "eLI[m eL" "eLI[m eL" jp-kanji)
("L" "eL" "Jum eL" "Jum eL" jp-kanji)
("M" "fL" "I{m fL" "I{m fL" jp-kanji)
("N" "ec" "ecKNm ec" "ecKNm ec" jp-kanji)
("O" "ec" "ecm ec" "ecm ec" jp-kanji)
("P" "ec" "ebLm ec" "ebLm ec" jp-kanji)
("Q" "ec" "_`m ec" "_`m ec" jp-kanji)
("R" "ec" "R[ecm ec" "R[ecm ec" jp-kanji)
("S" "ec" "R[ucm ec" "R[ucm ec" jp-kanji)
("T" "e" "mm e" "mm e" jp-kanji)
("U" "e" "EYm e" "EYm e" jp-kanji)
("V" "e" "A}m e" "A}m e" jp-kanji)
("W" "e" "e{[m e" "e{[m e" jp-kanji)
("X" "e" "~Zm e" "~Zm e" jp-kanji)
("Y" "e" "\Gm e" "\Gm e" jp-kanji)
("Z" "e" "}gCm e" "}gCm e" jp-kanji)
("[" "e" "A}Cm e" "A}Cm e" jp-kanji)
("\" "e" "nm e" "nm e" jp-kanji)
("]" "e" "RKm e" "RKm e" jp-kanji)
("^" "e" "e}cm e" "e}cm e" jp-kanji)
("_" "e" "eWm e" "eWm e" jp-kanji)
("`" "f" "c^Gm f" "c^Gm f" jp-kanji)
("a" "hm" "gmm f" "gmm f" jp-kanji)
("b" "f" "hm f" "hm f" jp-kanji)
("c" "f" "^{m f" "^{m f" jp-kanji)
("d" "f" "fm f" "fm f" jp-kanji)
("e" "g" "h[ucm ETM" "h[ucm ETM" jp-kanji)
("f" "g" "nNm g" "nNm g" jp-kanji)
("g" "g" "JLlm g" "JLlm g" jp-kanji)
("h" "g" "km g" "km g" jp-kanji)
("i" "g" "Vbgm g" "Vbgm g" jp-kanji)
("j" "g" "g\m g" "g\m g" jp-kanji)
("k" "g" "gzm g" "gzm g" jp-kanji)
("l" "g" "zNgm g" "zNgm g" jp-kanji)
("m" "g" "m g" "m g" jp-kanji)
("n" "g" "^m g" "^m g" jp-kanji)
("o" "g" "m{m g" "m{m g" jp-kanji)
("p" "g" "liVJYm g" "liVJYm g" jp-kanji)
("q" "g" "JPm g" "JPm g" jp-kanji)
("r" "g" "g`[m g" "g`[m g" jp-kanji)
("s" "g" "~Rm g" "~Rm g" jp-kanji)
("t" "g" "bLm g" "bLm g" jp-kanji)
("u" "g" "gCVm g" "gCVm g" jp-kanji)
("v" "C" "~KNm g" "~KNm g" jp-kanji)
("w" "h" "cgm h" "cgm h" jp-kanji)
("x" "h" "^r^rm h" "^r^rm h" jp-kanji)
("y" "h" "c`m h" "c`m h" jp-kanji)
("z" "h" "bRm h" "bRm h" jp-kanji)
("{" "h" "CJm h" "CJm h" jp-kanji)
("|" "g[" "^Im g[" "^Im g[" jp-kanji)
("}" "g[" "g[m g[" "g[m g[" jp-kanji)
("~" "g[" "tm g[" "tm g[" jp-kanji)
("" "g[" "RIm g[" "RIm g[" jp-kanji)
("" "g[" "J^im g[" "J^im g[" jp-kanji)
("" "g[" "Jm g[" "Jm g[" jp-kanji)
("" "g[" "erg[m g[" "erg[m g[" jp-kanji)
("" "g[" "cc~m g[" "cc~m g[" jp-kanji)
("" "g[" "KCg[Mm g[" "KCg[Mm g[" jp-kanji)
("" "g[" "XMm g[" "XMm g[" jp-kanji)
("" "g[" "V}m g[" "V}m g[" jp-kanji)
("" "g[" "}wm V}" "}wm V}" jp-kanji)
("" "g[" "C^m g[" "C^m g[" jp-kanji)
("" "g[" "iQm g[" "iQm g[" jp-kanji)
("" "g[" "mm g[" "mm g[" jp-kanji)
("" "g[" "qKVm g[" "qKVm g[" jp-kanji)
("" "g[" "N_mm " "N_mm " jp-kanji)
("" "g[" "g[Rcm g[" "g[Rcm g[" jp-kanji)
("" "g[" "lm g[" "lm g[" jp-kanji)
("" "g[" "kXm g[" "kXm g[" jp-kanji)
("" "g[" "g[^Xm g[" "g[^Xm g[" jp-kanji)
("" "g[" "m g[" "m g[" jp-kanji)
("" "g[" "hg[m g[" "hg[m g[" jp-kanji)
("" "g[" "AJm g[" "AJm g[" jp-kanji)
("" "g[" "gVrm L[W" "gVrm L[W" jp-kanji)
("" "g[" "A^m g[" "A^m g[" jp-kanji)
("" "g[" "Vg[m g[" "Vg[m g[" jp-kanji)
("" "g[" "Ng[m g[" "Ng[m g[" jp-kanji)
("" "ih" "qgVCm g[" "qgVCm g[" jp-kanji)
("" "g[" "R^Gm g[" "R^Gm g[" jp-kanji)
("" "g[" "ccm g[" "ccm g[" jp-kanji)
("" "g[" "Tg[m g[" "Tg[m g[" jp-kanji)
("" "g[" "g[\cm g[" "g[\cm g[" jp-kanji)
("" "g[" "C^m g[" "C^m g[" jp-kanji)
("" "g[" "Rbg[m g[" "Rbg[m g[" jp-kanji)
("" "g[" "z[g[m g[" "z[g[m g[" jp-kanji)
("" "g[" "tWm g[" "tWm g[" jp-kanji)
("" "g[" "Ecm g[" "Ecm g[" jp-kanji)
("" "g[" "g[Vm g[" "g[Vm g[" jp-kanji)
("" "g[" "}m g[" "}m g[" jp-kanji)
("" "g[" "tm g[" "tm g[" jp-kanji)
("" "g[" "jQm g[" "jQm g[" jp-kanji)
("" "g[" "XPm g[" "XPm g[" jp-kanji)
("" "g[" "Au~m g[" "Au~m g[" jp-kanji)
("" "g[" "g[Lm g[" "g[Lm g[" jp-kanji)
("" "g[" "A^}m g[" "A^}m g[" jp-kanji)
("" "g[" "tbg[m g[" "tbg[m g[" jp-kanji)
("" "g[" "^^JEm g[" "^^JEm g[" jp-kanji)
("" "h[" "n^Nm h[" "n^Nm h[" jp-kanji)
("" "h[" "ESNm h[" "ESNm h[" jp-kanji)
("" "h[" "IiWm h[" "IiWm h[" jp-kanji)
("" "h[" "VNh[m h[" "VNh[m h[" jp-kanji)
("" "h[" "~`rNm h[" "~`rNm h[" jp-kanji)
("" "h[" "ARKm h[" "ARKm h[" jp-kanji)
("" "h[" "h[`Nm h[" "h[`Nm h[" jp-kanji)
("" "h[" "zm h[" "zm h[" jp-kanji)
("" "h[" "qg~m h[" "qg~m h[" jp-kanji)
("" "h[" "xm h[" "xm h[" jp-kanji)
("" "h[" "h[^Cm h[" "h[^Cm h[" jp-kanji)
("" "h[" "uh[m h[" "uh[m h[" jp-kanji)
("" "h[" "~`m h[" "~`m h[" jp-kanji)
("" "h[" "L]Nm h[" "L]Nm h[" jp-kanji)
("" "g[Q" "}m g[Q" "}m g[Q" jp-kanji)
("" "z[" "gm im gL" "gm im gL" jp-kanji)
("" "gN" "gNCm gN" "gNCm gN" jp-kanji)
("" "gN" "Gm gN" "Gm gN" jp-kanji)
("" "gN" "gNKm gN" "gNKm gN" jp-kanji)
("" "gN" "h[gNm gN" "h[gNm gN" jp-kanji)
("" "gN" "gNxcm gN" "gNxcm gN" jp-kanji)
("" "gN" "JgNm gN" "JgNm gN" jp-kanji)
("" "gN" "nQm gN" "nQm gN" jp-kanji)
("" "gN" "LgNm gN" "LgNm gN" jp-kanji)
("" "hN" "hNNm hN" "hNNm hN" jp-kanji)
("" "hN" "qgm hN" "qgm hN" jp-kanji)
("" "hN" "m hN" "m hN" jp-kanji)
("" "}" "g`MPm g`" "g`MPm g`" jp-kanji)
("" "V[" "g`m Lm V[" "g`m Lm V[" jp-kanji)
("" "gc" "I[gcm gc" "I[gcm gc" jp-kanji)
("" "gc" "cNm gc" "cNm gc" jp-kanji)
("" "_" "Lm gh}c" "Lm gh}c" jp-kanji)
("" "JC" "ghPm P" "ghPm P" jp-kanji)
("" "G" "gm gr" "gm gr" jp-kanji)
("" "Z" "g}m g}" "g}m g}" jp-kanji)
("" "C" "W[jVm g" "W[jVm g" jp-kanji)
("" "[" "W[jVm g" "W[jVm g" jp-kanji)
("" "ZC" "iKgm g" "iKgm g" jp-kanji)
("" "g" "ITm g" "ITm g" jp-kanji)
("" "g" "gfm g" "gfm g" jp-kanji)
("" "g" "AcCm g" "AcCm g" jp-kanji)
("" "g" "gR[m g" "gR[m g" jp-kanji)
("" "g" "Rgm g" "Rgm g" jp-kanji)
("" "g" "u^m g" "u^m g" jp-kanji)
("" "g" "g\[m g" "g\[m g" jp-kanji)
("" "g" "gL[m g" "gL[m g" jp-kanji)
("" "h" "mm h" "mm h" jp-kanji)
("" "h" "Nm h" "Nm h" jp-kanji)
("" "h" "juCm h" "juCm h" jp-kanji)
("" "i" "iNm i" "iNm i" jp-kanji)
("" "i" "_im i" "_im i" jp-kanji)
("" "iC" "E`m iC" "E`m iC" jp-kanji)
("" "T" "iKm T" "iKm T" jp-kanji)
("" "V" "[iMm iM" "[iMm iM" jp-kanji)
("" "`" "iMi^m iM" "iMi^m iM" jp-kanji)
("" "C" "i]i]m i]" "i]i]m i]" jp-kanji)
("" "i_" "i_Vm i_" "i_Vm i_" jp-kanji)
("" "ic" "icCm ic" "icCm ic" jp-kanji)
("" "J" "ixJ}m ix" "ixJ}m ix" jp-kanji)
("" "V[" "im Lm i" "im Lm i" jp-kanji)
("" "W" "iW~m i" "iW~m i" jp-kanji)
("" "W[" "im W[" "im W[" jp-kanji)
("" "ec" "A[~`m ie" "A[~`m ie" jp-kanji)
("" "i" "~i~m i" "~i~m i" jp-kanji)
("" "i" "NXm Lm i" "NXm Lm i" jp-kanji)
("" "i" "Jm i" "Jm i" jp-kanji)
("" "i" "YJVCm i" "YJVCm i" jp-kanji)
("" "W" "I}Gm iW" "I}Gm iW" jp-kanji)
("" "j[" "JX[Wm j" "JX[Wm j" jp-kanji)
("" "j" "A}m j" "A}m j" jp-kanji)
("" "j[" "VCj cJE j" "VCj cJE j" jp-kanji)
("" "j" "WCm W" "WCm W" jp-kanji)
("" "N" "JIm jIC" "JIm jIC" jp-kanji)
("" "V" "jMEm V" "jMEm V" jp-kanji)
("" "jN" "LjNm jN" "LjNm jN" jp-kanji)
("" "R[" "jWm R[" "jWm R[" jp-kanji)
("" "jW[" "qgWm jW[" "qgWm jW[" jp-kanji)
("" "j`" "j`[rm j`" "j`[rm j`" jp-kanji)
("" "j[" "``m j[" "``m j[" jp-kanji)
("" "j[" "nCm j[" "nCm j[" jp-kanji)
("@" "j" "jCm j" "jCm j" jp-kanji)
("A" "j[" "j[\m j[" "j[\m j[" jp-kanji)
("B" "L[" "VNcm j" "VNcm j" jp-kanji)
("C" "j" "}JZm j" "}JZm j" jp-kanji)
("D" "j" "jVm j" "jVm j" jp-kanji)
("E" "j" "Vmum j" "Vmum j" jp-kanji)
("F" "j" "~gm j" "~gm j" jp-kanji)
("G" "W" "km W" "km W" jp-kanji)
("H" "l" "lMm lC" "lMm lC" jp-kanji)
("I" "l" "lCm NW" "lCm NW" jp-kanji)
("J" "lC" "eClCm lC" "eClCm lC" jp-kanji)
("K" "\[" "VNcm lM" "VNcm lM" jp-kanji)
("L" "r[" "lRm r[" "lRm r[" jp-kanji)
("M" "lc" "AcCm lc" "AcCm lc" jp-kanji)
("N" "l" "gVm l" "gVm l" jp-kanji)
("O" "l" "lucm l" "lucm l" jp-kanji)
("P" "l" "lUm l" "lUm l" jp-kanji)
("Q" "l" "m l" "m l" jp-kanji)
("R" "l" "Gm l" "Gm l" jp-kanji)
("S" "l" "lom l" "lom l" jp-kanji)
("T" "iC" "iCVm m" "iCVm m" jp-kanji)
("U" "m" "\Kmm m" "\Kmm m" jp-kanji)
("V" "m" "WCm L" "WCm L" jp-kanji)
("W" "" "mnm mm RW" "mnm mm RW" jp-kanji)
("X" "m[" "tNm m[" "tNm m[" jp-kanji)
("Y" "m[" "i~m m[" "i~m m[" jp-kanji)
("Z" "m[" "RCm m[" "RCm m[" jp-kanji)
("[" "m[" "ITm m[" "ITm m[" jp-kanji)
("\" "m[" "m[Nm m[" "m[Nm m[" jp-kanji)
("]" "m[" "Ym[m m[" "Ym[m m[" jp-kanji)
("^" "m[" "E~m m[" "E~m m[" jp-kanji)
("_" "m[" "m[~m m[" "m[~m m[" jp-kanji)
("`" "V" "m]Nm V" "m]Nm V" jp-kanji)
("a" "V" "Vm m~" "Vm m~" jp-kanji)
("b" "n" "gGm n" "gGm n" jp-kanji)
("c" "n" "nANm n" "nANm n" jp-kanji)
("d" "n" "^l }Nm n" "^l }Nm n" jp-kanji)
("e" "n" "nVm n" "nVm n" jp-kanji)
("f" "n" "TCm n" "TCm n" jp-kanji)
("g" "n" "i~m n" "i~m n" jp-kanji)
("h" "n" "nocm n" "nocm n" jp-kanji)
("i" "n" "KbLm rm " "KbLm rm " jp-kanji)
("j" "n" "um n" "um n" jp-kanji)
("k" "o" "IoATm o" "IoATm o" jp-kanji)
("l" "o" "oZCm o" "oZCm o" jp-kanji)
("m" "o" "oV[m o" "oV[m o" jp-kanji)
("n" "o" "E}m o" "E}m o" jp-kanji)
("o" "nC" "nCNm nC" "nCNm nC" jp-kanji)
("p" "nC" "X^m nC" "X^m nC" jp-kanji)
("q" "nC" "IKm nC" "IKm nC" jp-kanji)
("r" "nC" "nCXCm nC" "nCXCm nC" jp-kanji)
("s" "nC" "um nC" "um nC" jp-kanji)
("t" "nC" "TJYLm nC" "TJYLm nC" jp-kanji)
("u" "nC" "Tm TJYL" "Tm TJYL" jp-kanji)
("v" "nC" "t_m nC" "t_m nC" jp-kanji)
("w" "nC" "Zm nC" "Zm nC" jp-kanji)
("x" "nC" "iC][m nC" "iC][m nC" jp-kanji)
("y" "nC" "ZpCm nC" "ZpCm nC" jp-kanji)
("z" "nC" "Nom nC" "Nom nC" jp-kanji)
("{" "oC" "ToCm oC" "ToCm oC" jp-kanji)
("|" "oC" "c`JEm oC" "c`JEm oC" jp-kanji)
("}" "oC" "oCJCm oC" "oCJCm oC" jp-kanji)
("~" "oC" "Em oC" "Em oC" jp-kanji)
("" "oC" "A}CuVm E" "A}CuVm E" jp-kanji)
("" "oC" "XXm oC" "XXm oC" jp-kanji)
("" "oC" "[oCm oC" "[oCm oC" jp-kanji)
("" "oC" "JEm oC" "JEm oC" jp-kanji)
("" "oC" "Em oC" "Em oC" jp-kanji)
("" "oC" "oCV[m oC" "oCV[m oC" jp-kanji)
("" "oC" "oCVm oC" "oCVm oC" jp-kanji)
("" "V" "nEm V" "nEm V" jp-kanji)
("" "[" "Vm nG" "Vm nG" jp-kanji)
("" "r" "nJm V[" "nJm V[" jp-kanji)
("" "V" "nMm nM" "nMm nM" jp-kanji)
("" "V[" "nim nM" "nim nM" jp-kanji)
("" "nN" "IWm nN" "IWm nN" jp-kanji)
("" "nN" "nNZCm nN" "nNZCm nN" jp-kanji)
("" "nN" "nJZm nN" "nJZm nN" jp-kanji)
("" "nN" "nNVm nN" "nNVm nN" jp-kanji)
("" "nN" "JVm nN" "JVm nN" jp-kanji)
("" "nN" "g}m nN" "g}m nN" jp-kanji)
("" "nN" "Vm nN" "Vm nN" jp-kanji)
("" "nN" "LpNm nN" "LpNm nN" jp-kanji)
("" "nN" "TPJXm nN" "TPJXm nN" jp-kanji)
("" "nN" "ZpNm nN" "ZpNm nN" jp-kanji)
("" "nN" "EXCm nN" "EXCm nN" jp-kanji)
("" "nN" "Z}m nN" "Z}m nN" jp-kanji)
("" "oN" "TXm oN" "TXm oN" jp-kanji)
("" "oN" "ToNm oN" "ToNm oN" jp-kanji)
("" "oN" "oNQLm oN" "oNQLm oN" jp-kanji)
("" "oN" "Vom oN" "Vom oN" jp-kanji)
("" "oN" "oN_Cm oN" "oN_Cm oN" jp-kanji)
("" "oN" "oNm oN" "oNm oN" jp-kanji)
("" "oN" "Mm oN" "Mm oN" jp-kanji)
("" "J" "nR_em nR" "nR_em nR" jp-kanji)
("" "\[" "nRm \[" "nRm \[" jp-kanji)
("" "RN" "^jACm nU}" "^jACm nU}" jp-kanji)
("" "`" "^x nV" "^x nV" jp-kanji)
("" "`[" "nWm `[" "nWm `[" jp-kanji)
("" "Jc" "V^nYm nY" "V^nYm nY" jp-kanji)
("" "" "Lm n[" "Lm n[" jp-kanji)
("" "}" "n^m n^" "n^m n^" jp-kanji)
("" "L" "qtm n_" "qtm n_" jp-kanji)
("" "n^" "n^Pm f" "n^Pm f" jp-kanji)
("" "n^" "nNfm n^P" "nNfm n^P" jp-kanji)
("" "n`" "JX[Wm n`" "JX[Wm n`" jp-kanji)
("" "n`" "Cncm nc" "Cncm nc" jp-kanji)
("" "nc" "nccm nc" "nccm nc" jp-kanji)
("" "nc" "nb^cm nc" "nb^cm nc" jp-kanji)
("" "nc" "nbR[m nc" "nbR[m nc" jp-kanji)
("" "nc" "J~m nc" "J~m nc" jp-kanji)
("" "oc" "Lm oc" "Lm oc" jp-kanji)
("" "oc" "c~g ocm oc" "c~g ocm oc" jp-kanji)
("" "oc" "kNm oc" "kNm oc" jp-kanji)
("" "oc" "CJ_m oc" "CJ_m oc" jp-kanji)
("" "oc" "UCocm oc" "UCocm oc" jp-kanji)
("" "L[" "gm ng" "gm ng" jp-kanji)
("" "V" "niVJm niV" "niVJm niV" jp-kanji)
("" "R[" "nim JN" "nim JN" jp-kanji)
("" "R[" "JCm n}O" "JCm n}O" jp-kanji)
("" "W" "gm nuT" "gm nuT" jp-kanji)
("" "n" "giEm n" "giEm n" jp-kanji)
("" "n" "n_m n" "n_m n" jp-kanji)
("" "n" "iJom n" "iJom n" jp-kanji)
("" "n" "\m n" "\m n" jp-kanji)
("" "n" "\Nm n" "\Nm n" jp-kanji)
("" "n" "bgm z" "bgm z" jp-kanji)
("" "n" "Epm n" "Epm n" jp-kanji)
("" "n" "}_m n" "}_m n" jp-kanji)
("" "n" "C^m n" "C^m n" jp-kanji)
("" "n" "nm n" "nm n" jp-kanji)
("" "n" "qCm n" "qCm n" jp-kanji)
("" "n" "Vbpm n" "Vbpm n" jp-kanji)
("" "n" "IJXm n" "IJXm n" jp-kanji)
("" "n" "n`[m n" "n`[m n" jp-kanji)
("" "n" "A[m n" "A[m n" jp-kanji)
("" "n" "VQm n" "VQm n" jp-kanji)
("" "n" "Cbpm n" "Cbpm n" jp-kanji)
("" "n" "nVm n" "nVm n" jp-kanji)
("" "n" "noCm n" "noCm n" jp-kanji)
("" "n" "nCm n" "nCm n" jp-kanji)
("" "n" "Pm n" "Pm n" jp-kanji)
("" "n" "YEm n" "YEm n" jp-kanji)
("" "n" "nvm n" "nvm n" jp-kanji)
("" "n" "Vm n" "Vm n" jp-kanji)
("" "o" "oJCm o" "oJCm o" jp-kanji)
("" "o" "ATom o" "ATom o" jp-kanji)
("" "o" "oO~m o" "oO~m o" jp-kanji)
("" "o" "Som o" "Som o" jp-kanji)
("" "o" "oWNm o" "oWNm o" jp-kanji)
("" "o" "oVm o" "oVm o" jp-kanji)
("" "o" "om o" "om o" jp-kanji)
("" "q" "q]Nm q" "q]Nm q" jp-kanji)
("" "q" "CVCm q" "CVCm q" jp-kanji)
("" "q" "qeCm q" "qeCm q" jp-kanji)
("" "q" "ILTLm q" "ILTLm q" jp-kanji)
("" "q" "qTVm q" "qTVm q" jp-kanji)
("" "q" "Jm q" "Jm q" jp-kanji)
("" "q" "JiVCm q" "JiVCm q" jp-kanji)
("" "q" "grm q" "grm q" jp-kanji)
("" "q" "qnm q" "qnm q" jp-kanji)
("" "q" "q[Gm q" "q[Gm q" jp-kanji)
("" "q" "AK Am q" "AK Am q" jp-kanji)
("" "q" "Nxm q" "Nxm q" jp-kanji)
("" "q" "qj[Lm q" "qj[Lm q" jp-kanji)
("" "q" "cJm q" "cJm q" jp-kanji)
("" "q" "Jm q" "Jm q" jp-kanji)
("" "q" "CVu~m q" "CVu~m q" jp-kanji)
("" "q" "qm q" "qm q" jp-kanji)
("" "q" "qCm q" "qCm q" jp-kanji)
("" "q" "qm q" "qm q" jp-kanji)
("" "q" "RGm q" "RGm q" jp-kanji)
("" "q" "R[m q" "R[m q" jp-kanji)
("" "q" "q{[m q" "q{[m q" jp-kanji)
("" "q" "cCXm q" "cCXm q" jp-kanji)
("" "q" "TPm q" "TPm q" jp-kanji)
("" "q" "qW[VLm q" "qW[VLm q" jp-kanji)
("" "q" "gum q" "gum q" jp-kanji)
("" "q" "gCm q" "gCm q" jp-kanji)
("" "n" "qm n" "qm n" jp-kanji)
("" "r" "\iGm r" "\iGm r" jp-kanji)
("" "r" "Im r" "Im r" jp-kanji)
("" "r" "rZCucm r" "rZCucm r" jp-kanji)
("" "r" "rm Lm r" "rm Lm r" jp-kanji)
("" "r" "rVem r" "rVem r" jp-kanji)
("" "r" "rRm r" "rRm r" jp-kanji)
("" "r" "}m r" "}m r" jp-kanji)
("" "r" "EcNVCm r" "EcNVCm r" jp-kanji)
("@" "r" "nim r" "nim r" jp-kanji)
("A" "V[" "Lm qCM" "Lm qCM" jp-kanji)
("B" "nC" "VNucm qG" "VNucm qG" jp-kanji)
("C" "qL" "CbsLm qL" "CbsLm qL" jp-kanji)
("D" "qL" "AVm qL" "AVm qL" jp-kanji)
("E" "V" "N`qQm qQ" "N`qQm qQ" jp-kanji)
("F" "qR" "qRlm qR" "qRlm qR" jp-kanji)
("G" "Vc" "qUm Vc" "qUm Vc" jp-kanji)
("H" "[" "qVK^m qV" "qVK^m qV" jp-kanji)
("I" "`[" "Efm qW" "Efm qW" jp-kanji)
("J" "qc" "^XPm qc" "^XPm qc" jp-kanji)
("K" "qc" "JiYm qc" "JiYm qc" jp-kanji)
("L" "qc" "qbZCm qc" "qbZCm qc" jp-kanji)
("M" "qc" "tfm qc" "tfm qc" jp-kanji)
("N" "qc" "qbpNm qc" "qbpNm qc" jp-kanji)
("O" "JC" "Lm qm L" "Lm qm L" jp-kanji)
("P" "L" "qm L" "qm L" jp-kanji)
("Q" "G" "TCGm q" "TCGm q" jp-kanji)
("R" "`[" "Irqm q" "Irqm q" jp-kanji)
("S" "qN" "JX[Wm qN" "JX[Wm qN" jp-kanji)
("T" "r[" "A}m r[" "A}m r[" jp-kanji)
("U" "q[" "^m q[" "^m q[" jp-kanji)
("V" "q[" "}_m q[" "}_m q[" jp-kanji)
("W" "q[" "q[VLm q[" "q[VLm q[" jp-kanji)
("X" "q[" "RIm q[" "RIm q[" jp-kanji)
("Y" "q[" "^_Em q[" "^_Em q[" jp-kanji)
("Z" "q[" "q[^m q[" "q[^m q[" jp-kanji)
("[" "q[" "g[q[m q[" "g[q[m q[" jp-kanji)
("\" "q[" "AXm q[" "AXm q[" jp-kanji)
("]" "q[" "q[om q[" "q[om q[" jp-kanji)
("^" "q[" "h[ucm q[" "h[ucm q[" jp-kanji)
("_" "r[" "I^}m r[" "I^}m r[" jp-kanji)
("`" "r[" "GKNm r[" "GKNm r[" jp-kanji)
("a" "r[" "}Cm r[" "}Cm r[" jp-kanji)
("b" "r[" "WJm r[" "WJm r[" jp-kanji)
("c" "r[" "iGm r[" "iGm r[" jp-kanji)
("d" "r[" "CJm r[" "CJm r[" jp-kanji)
("e" "r[" "m g r[" "m g r[" jp-kanji)
("f" "T" "mrm q" "mrm q" jp-kanji)
("g" "`c" "Vm q" "Vm q" jp-kanji)
("h" "L" "TJim q" "TJim q" jp-kanji)
("i" "q" "Vim q" "Vim q" jp-kanji)
("j" "q" "Lj XMm AL" "Lj XMm AL" jp-kanji)
("k" "q" "t~j um q" "t~j um q" jp-kanji)
("l" "q" "n}m q" "n}m q" jp-kanji)
("m" "q" "qVm q" "qVm q" jp-kanji)
("n" "q" "}YVCm q" "}YVCm q" jp-kanji)
("o" "q" "qLNm q" "qLNm q" jp-kanji)
("p" "q" "qpm q" "qpm q" jp-kanji)
("q" "r" "rV[m r" "rV[m r" jp-kanji)
("r" "r" "KXrm r" "KXrm r" jp-kanji)
("s" "t" "tJm[m t" "tJm[m t" jp-kanji)
("t" "t" "cPm t" "cPm t" jp-kanji)
("u" "t" "ngom t" "ngom t" jp-kanji)
("v" "t" "Ibgm t" "Ibgm t" jp-kanji)
("w" "t" "tWm t" "tWm t" jp-kanji)
("x" "t" "gm t" "gm t" jp-kanji)
("y" "t" "gm ]NW" "gm ]NW" jp-kanji)
("z" "t" "kmm t" "kmm t" jp-kanji)
("{" "t" "ZCtm t" "ZCtm t" jp-kanji)
("|" "t" "RCm t" "RCm t" jp-kanji)
("}" "t" "tWm t" "tWm t" jp-kanji)
("~" "t" "VNm t" "VNm t" jp-kanji)
("" "t" "Imm t" "Imm t" jp-kanji)
("" "t" "tc[m t" "tc[m t" jp-kanji)
("" "t" "ENm t" "ENm t" jp-kanji)
("" "t" "``m t" "``m t" jp-kanji)
("" "t" "tS[m t" "tS[m t" jp-kanji)
("" "t" "NTm t" "NTm t" jp-kanji)
("" "t" "qtm t" "qtm t" jp-kanji)
("" "t" "t[m t" "t[m t" jp-kanji)
("" "t" "KNtm t" "KNtm t" jp-kanji)
("" "t" "}Pm t" "}Pm t" jp-kanji)
("" "t" "evm t" "evm t" jp-kanji)
("" "t" "INm t" "INm t" jp-kanji)
("" "t" "MtPm t" "MtPm t" jp-kanji)
("" "t" "RUgwm t" "RUgwm t" jp-kanji)
("" "u" "Aihm u" "Aihm u" jp-kanji)
("" "u" "u[m u" "u[m u" jp-kanji)
("" "u" "uVm u" "uVm u" jp-kanji)
("" "u" "}Em u" "}Em u" jp-kanji)
("" "u" "uh[m u" "uh[m u" jp-kanji)
("" "u" "Tm u\m u" "Tm u\m u" jp-kanji)
("" "u" "wm u" "wm u" jp-kanji)
("" "t[" "t[g[m t[" "t[g[m t[" jp-kanji)
("" "t[" "Lm JGf" "Lm JGf" jp-kanji)
("" "t[" "J[m t[" "J[m t[" jp-kanji)
("" "V[" "l tNm tN" "l tNm tN" jp-kanji)
("" "" "VNucm tL" "VNucm tL" jp-kanji)
("" "tN" "tZm tN" "tZm tN" jp-kanji)
("" "tN" "tNM[m tN" "tNM[m tN" jp-kanji)
("" "tN" "tbJcm tN" "tbJcm tN" jp-kanji)
("" "tN" "nom tN" "nom tN" jp-kanji)
("" "tN" "[tNm tN" "[tNm tN" jp-kanji)
("" "tN" "R[tNm tN" "R[tNm tN" jp-kanji)
("" "tN" "nm tN" "nm tN" jp-kanji)
("" "tN" "tNUcm tN" "tNUcm tN" jp-kanji)
("" "tN" "IIEm tN" "IIEm tN" jp-kanji)
("" "G" "t`m G" "t`m G" jp-kanji)
("" "tc" "tb\m tc" "tb\m tc" jp-kanji)
("" "tc" "nEm tc" "nEm tc" jp-kanji)
("" "tc" "Nm tc" "Nm tc" jp-kanji)
("" "uc" "zgPm uc" "zgPm uc" jp-kanji)
("" "uc" "mm uc" "mm uc" jp-kanji)
("" "t" "TJim ti" "TJim ti" jp-kanji)
("" "u" "Pm u" "Pm u" jp-kanji)
("" "t" "Zbvm t" "Zbvm t" jp-kanji)
("" "t" "tNm t" "tNm t" jp-kanji)
("" "t" "Rtm t" "Rtm t" jp-kanji)
("" "t" "CLhIm t" "CLhIm t" jp-kanji)
("" "t" "t\[m t" "t\[m t" jp-kanji)
("" "t" "tVm t" "tVm t" jp-kanji)
("" "t" "tEm t" "tEm t" jp-kanji)
("" "t" "Rim t" "Rim t" jp-kanji)
("" "t" "N\m t" "N\m t" jp-kanji)
("" "t" "}Mm t" "}Mm t" jp-kanji)
("" "t" "tCLm t" "tCLm t" jp-kanji)
("" "u" "t~m u" "t~m u" jp-kanji)
("" "u" "LNm u" "LNm u" jp-kanji)
("" "wC" "qmGm wC" "qmGm wC" jp-kanji)
("" "wC" "AZm wC" "AZm wC" jp-kanji)
("" "wC" "wC^Cm wC" "wC^Cm wC" jp-kanji)
("" "wC" "JLlm wC" "JLlm wC" jp-kanji)
("" "wC" "VwCm wC" "VwCm wC" jp-kanji)
("" "wC" "^Cm wC" "^Cm wC" jp-kanji)
("" "wC" "wCKCm wC" "wCKCm wC" jp-kanji)
("" "wC" "gbem G" "gbem G" jp-kanji)
("" "wC" "i~m wC" "i~m wC" jp-kanji)
("" "wC" "um wC" "um wC" jp-kanji)
("" "wC" "gWm wC" "gWm wC" jp-kanji)
("" "wC" "wCJm wC" "wCJm wC" jp-kanji)
("" "xC" "Rm xC" "Rm xC" jp-kanji)
("" "y[W" "yCWm Pc" "yCWm Pc" jp-kanji)
("" "wL" "wL`m wL" "wL`m wL" jp-kanji)
("" "wL" "Jxm wL" "Jxm wL" jp-kanji)
("" "wL" "NZm wL" "NZm wL" jp-kanji)
("" "wL" "AICm wL" "AICm wL" jp-kanji)
("" "xc" "Jm xc" "Jm xc" jp-kanji)
("" "xc" "C`xcm xc" "C`xcm xc" jp-kanji)
("" "xc" "PCxcm xc" "PCxcm xc" jp-kanji)
("" "wC" "JUVm wC" "JUVm wC" jp-kanji)
("" "w" "J^m w" "J^m w" jp-kanji)
("" "w" "Jm w" "Jm w" jp-kanji)
("" "w" "J^m w" "J^m w" jp-kanji)
("" "w" "wV[m w" "wV[m w" jp-kanji)
("" "w" "wV[m w" "wV[m w" jp-kanji)
("" "w" "V[wm w" "V[wm w" jp-kanji)
("" "w" "JGXm w" "JGXm w" jp-kanji)
("" "w" "wm w" "wm w" jp-kanji)
("" "x" "xm x" "xm x" jp-kanji)
("" "x" "xL[m x" "xL[m x" jp-kanji)
("" "x" "uxm x" "uxm x" jp-kanji)
("" "x" "xPCm x" "xPCm x" jp-kanji)
("" "x" "`m x" "`m x" jp-kanji)
("" "z" "^cm z" "^cm z" jp-kanji)
("" "z" "z\[m z" "z\[m z" jp-kanji)
("" "z" "zm ZCW" "zm ZCW" jp-kanji)
("" "z" "n^Pm z" "n^Pm z" jp-kanji)
("" "z" "gGm z" "gGm z" jp-kanji)
("" "z" "ANm z" "ANm z" jp-kanji)
("" "z" "nWm z" "nWm z" jp-kanji)
("" "z" "IMiEm z" "IMiEm z" jp-kanji)
("" "z" "zTm z" "zTm z" jp-kanji)
("" "XC" "Cizm z" "Cizm z" jp-kanji)
("" "{" "cmm {" "cmm {" jp-kanji)
("" "{" "nJm {" "nJm {" jp-kanji)
("" "{" "V^Em {" "V^Em {" jp-kanji)
("" "{" "c`mGm {" "c`mGm {" jp-kanji)
("" "{" "Nm {" "Nm {" jp-kanji)
("" "{" "nnm {" "nnm {" jp-kanji)
("" "{" "{Lm {" "{Lm {" jp-kanji)
("" "{" "{Tcm {" "{Tcm {" jp-kanji)
("" "z[" "iEm z[" "iEm z[" jp-kanji)
("" "z[" "z[L[m z[" "z[L[m z[" jp-kanji)
("" "z[" "ccm z[" "ccm z[" jp-kanji)
("" "z[" "IJm z[" "IJm z[" jp-kanji)
("" "z[" "z[h[m z[" "z[h[m z[" jp-kanji)
("" "z[" "^e}cm z[" "^e}cm z[" jp-kanji)
("" "z[" "^Jm z[" "^Jm z[" jp-kanji)
("" "z[" "~lm z[" "~lm z[" jp-kanji)
("" "z[" "~lm ZCW" "~lm ZCW" jp-kanji)
("" "z[" "NYm z[" "NYm z[" jp-kanji)
("" "z[" "z[`[m z[" "z[`[m z[" jp-kanji)
("" "z[" "C_Nm z[" "C_Nm z[" jp-kanji)
("" "z[" "TTQm z[" "TTQm z[" jp-kanji)
("" "z[" "nicm z[" "nicm z[" jp-kanji)
("" "z[" "J^m z[" "J^m z[" jp-kanji)
("" "z[" "g_`m z[" "g_`m z[" jp-kanji)
("@" "z[" "z[cm z[" "z[cm z[" jp-kanji)
("A" "z[" "Am z[" "Am z[" jp-kanji)
("B" "z[" "Jb|[m z[" "Jb|[m z[" jp-kanji)
("C" "z[" "^Cz[m z[" "^Cz[m z[" jp-kanji)
("D" "z[" "kEm z[" "kEm z[" jp-kanji)
("E" "z[" "h[z[m z[" "h[z[m z[" jp-kanji)
("F" "z[" "JoVCm z[" "JoVCm z[" jp-kanji)
("G" "z[" "Gm z[" "Gm z[" jp-kanji)
("H" "z[" "z[Cm z[" "z[Cm z[" jp-kanji)
("I" "z[" "R`[m n`" "R`[m n`" jp-kanji)
("J" "z[" "zm z[" "zm z[" jp-kanji)
("K" "z[" "IgYm z[" "IgYm z[" jp-kanji)
("L" "z[" "^Jm z[" "^Jm z[" jp-kanji)
("M" "z[" "Njm z[" "Njm z[" jp-kanji)
("N" "z[" "zRTLm z[" "zRTLm z[" jp-kanji)
("O" "z[" "ALm z[" "ALm z[" jp-kanji)
("P" "z[" "z[I[m z[" "z[I[m z[" jp-kanji)
("Q" "z[" "IIgm z[" "IIgm z[" jp-kanji)
("R" "{[" "g{VCm {[" "g{VCm {[" jp-kanji)
("S" "{[" "iCm {[" "iCm {[" jp-kanji)
("T" "{[" "J^m {[" "J^m {[" jp-kanji)
("U" "{[" "JC{[m {[" "JC{[m {[" jp-kanji)
("V" "{[" "{b`m {[" "{b`m {[" jp-kanji)
("W" "{[" "T}^Qm {[" "T}^Qm {[" jp-kanji)
("X" "{[" "{[Vm {[" "{[Vm {[" jp-kanji)
("Y" "{[" "Xm {[" "Xm {[" jp-kanji)
("Z" "{[" "C\KVCm {[" "C\KVCm {[" jp-kanji)
("[" "{[" "tTm {[" "tTm {[" jp-kanji)
("\" "{[" "Aom {[" "Aom {[" jp-kanji)
("]" "{[" "m]m {[" "m]m {[" jp-kanji)
("^" "{[" "ijKVm {[" "ijKVm {[" jp-kanji)
("_" "{[" "R{[m {[" "R{[m {[" jp-kanji)
("`" "{[" "IJXm {[" "IJXm {[" jp-kanji)
("a" "{[" "cOm {[" "cOm {[" jp-kanji)
("b" "{[" "V{[m {[" "V{[m {[" jp-kanji)
("c" "{[" "tNm {[" "tNm {[" jp-kanji)
("d" "{[" "nJm {[" "nJm {[" jp-kanji)
("e" "{[" "[{[m {[" "[{[m {[" jp-kanji)
("f" "{[" "{[GLm {[" "{[GLm {[" jp-kanji)
("g" "{[" "zRm {[" "zRm {[" jp-kanji)
("h" "{[" "tZOm {[" "tZOm {[" jp-kanji)
("i" "oC" "CkK zG" "CkK zG" jp-kanji)
("j" "L[" "zby^m zI" "zby^m zI" jp-kanji)
("k" "zN" "L^m {N" "L^m {N" jp-kanji)
("l" "{N" "^Vm {N" "^Vm {N" jp-kanji)
("m" "{N" "EiCm {N" "EiCm {N" jp-kanji)
("n" "{N" "X~m {N" "X~m {N" jp-kanji)
("o" "{N" "{Ncm {N" "{Ncm {N" jp-kanji)
("p" "{N" "{Ngcm {N" "{Ngcm {N" jp-kanji)
("q" "{N" "}Lm {N" "}Lm {N" jp-kanji)
("r" "{N" "c}VCm {N" "c}VCm {N" jp-kanji)
("s" "{N" "iSJi{N" "iSJi{N" jp-kanji)
("t" "R[" "[tNm {^" "[tNm {^" jp-kanji)
("u" "{c" "{bpcm {c" "{bpcm {c" jp-kanji)
("v" "{c" "{cNm {c" "{cNm {c" jp-kanji)
("w" "^C" "zghm ^C" "zghm ^C" jp-kanji)
("x" "Nc" "zm z" "zm z" jp-kanji)
("y" "R[" "zoVm z" "zoVm z" jp-kanji)
("z" "z" "z\[m z" "z\[m z" jp-kanji)
("{" "z" "gm z" "gm z" jp-kanji)
("|" "z" "qKGm z" "qKGm z" jp-kanji)
("}" "{" "wC{m {" "wC{m {" jp-kanji)
("~" "{" "I{m {" "I{m {" jp-kanji)
("" "}" "}Tcm }" "}Tcm }" jp-kanji)
("" "}" "~KNm }" "~KNm }" jp-kanji)
("" "}" "}z[m }" "}z[m }" jp-kanji)
("" "}" "ATm }" "ATm }" jp-kanji)
("" "}C" "Em }C" "Em }C" jp-kanji)
("" "}C" "C[gm }C" "C[gm }C" jp-kanji)
("" "}C" "NCm }C" "NCm }C" jp-kanji)
("" "}C" "C`}Cm }C" "C`}Cm }C" jp-kanji)
("" "}C" "}Cj`m }C" "}Cj`m }C" jp-kanji)
("" "}C" "iKTm }C" "iKTm }C" jp-kanji)
("" "e" "Lm }Lm L[W" "Lm }Lm L[W" jp-kanji)
("" "}N" "J[em }N" "J[em }N" jp-kanji)
("" "}N" "R}Nm }N" "R}Nm }N" jp-kanji)
("" "`" "}Nm `" "}Nm `" jp-kanji)
("" "[" "TJim }O" "TJim }O" jp-kanji)
("" "ZC" "}Tm }T" "}Tm }T" jp-kanji)
("" "\" "TJim }X" "TJim }X" jp-kanji)
("" "V[" "Lm }Xm ]NW" "Lm }Xm ]NW" jp-kanji)
("" "GL" "}^m GL" "}^m GL" jp-kanji)
("" "e" "t^}^m }^" "t^}^m }^" jp-kanji)
("" "[" "}^m [" "}^m [" jp-kanji)
("" "}c" "}bTcm }c" "}bTcm }c" jp-kanji)
("" "}c" "XGm }c" "XGm }c" jp-kanji)
("" "}c" "q}cm }c" "q}cm }c" jp-kanji)
("" "Lc" "C^m }f" "C^m }f" jp-kanji)
("" "W" "ZcrSm }}" "ZcrSm }}" jp-kanji)
("" "P" "PVm }" "PVm }" jp-kanji)
("" "}" "qg}m }" "qg}m }" jp-kanji)
("" "}" "JX[Wm }" "JX[Wm }" jp-kanji)
("" "}" "W}m }" "W}m }" jp-kanji)
("" "}" "~cm }" "~cm }" jp-kanji)
("" "}" "}Km }" "}Km }" jp-kanji)
("" "}" "cNTm }" "cNTm }" jp-kanji)
("" "~" "AWm ~" "AWm ~" jp-kanji)
("" "~" "~Cm ~" "~Cm ~" jp-kanji)
("" "~" "~Nm ~" "~Nm ~" jp-kanji)
("" "V" "W[jVm ~" "W[jVm ~" jp-kanji)
("" "L" "TJi g ~" "TJi g ~" jp-kanji)
("" "R[" "~TLm R[" "~TLm R[" jp-kanji)
("" "~c" "q~cm ~c" "q~cm ~c" jp-kanji)
("" "~c" "~co`m ~c" "~co`m ~c" jp-kanji)
("" "\[" "~igm \[" "~igm \[" jp-kanji)
("" "T" "~mVm ~m" "~mVm ~m" jp-kanji)
("" "W" "~mm l" "~mm l" jp-kanji)
("" "~N" "~NnNm ~N" "~NnNm ~N" jp-kanji)
("" "~[" "~[Am ~[" "~[Am ~[" jp-kanji)
("" "~[g" "iKTm ~" "iKTm ~" jp-kanji)
("" "~" "^~m ~" "^~m ~" jp-kanji)
("" "~" "lm ~" "lm ~" jp-kanji)
("" "" "cgm " "cgm " jp-kanji)
("" "" "m " "m " jp-kanji)
("" "" "iCm " "iCm " jp-kanji)
("" "" "II^Vm " "II^Vm " jp-kanji)
("" "" "zRm " "zRm " jp-kanji)
("" "" "Lm " "Lm " jp-kanji)
("" "" "I[m " "I[m " jp-kanji)
("" "[" "Lm N" "Lm N" jp-kanji)
("" "R" "niRm R" "niRm R" jp-kanji)
("" "X" "Xm W[" "Xm W[" jp-kanji)
("" "C" "~[m C" "~[m C" jp-kanji)
("" "C" "i}Gm i" "i}Gm i" jp-kanji)
("" "C" "Cm`m C" "Cm`m C" jp-kanji)
("" "C" "AJCm C" "AJCm C" jp-kanji)
("" "C" "Cm C" "Cm C" jp-kanji)
("" "C" "}Em C" "}Em C" jp-kanji)
("" "C" "C`m C" "C`m C" jp-kanji)
("" "C" "iNm C" "iNm C" jp-kanji)
("" "C" "ICCm C" "ICCm C" jp-kanji)
("" "q" "EVwm X" "EVwm X" jp-kanji)
("" "c" "zrm c" "zrm c" jp-kanji)
("" "" "}kKm " "}kKm " jp-kanji)
("" "" "^m Lm " "^m Lm " jp-kanji)
("" "" "^m " "^m " jp-kanji)
("" "" "[m " "[m " jp-kanji)
("" "" "Iem " "Iem " jp-kanji)
("" "" "Ehm " "Ehm " jp-kanji)
("" "" "TNm " "TNm " jp-kanji)
("" "" "z[m " "z[m " jp-kanji)
("" "" "VQm " "VQm " jp-kanji)
("" "[" "{[Qm {[" "{[Qm {[" jp-kanji)
("" "[" "[Vm [" "[Vm [" jp-kanji)
("" "[" "Pm [" "Pm [" jp-kanji)
("" "[" "^P_PVCm [" "^P_PVCm [" jp-kanji)
("" "[" "[Wm [" "[Wm [" jp-kanji)
("" "[" "A~m [" "A~m [" jp-kanji)
("" "[" "V[[m [" "V[[m [" jp-kanji)
("" "[" "[Rm [" "[Rm [" jp-kanji)
("" "`" "[Pm `" "[Pm `" jp-kanji)
("" "N" "Lm N" "Lm N" jp-kanji)
("" "N" "_}m N" "_}m N" jp-kanji)
("" "N" "m N" "m N" jp-kanji)
("" "N" "WCm N" "WCm N" jp-kanji)
("" "`" "`m `" "`m `" jp-kanji)
("" "wC" "^xm `" "^xm `" jp-kanji)
("" "[" "bgm [" "bgm [" jp-kanji)
("" "C" "hm C" "hm C" jp-kanji)
("" "W" "~Km ~" "~Km ~" jp-kanji)
("" "ZC" "Em ZC" "Em ZC" jp-kanji)
("" "" "gEm " "gEm " jp-kanji)
("" "" "_Gm " "_Gm " jp-kanji)
("" "" "Vm " "Vm " jp-kanji)
("" "" "Jhm " "Jhm " jp-kanji)
("" "" "ITm " "ITm " jp-kanji)
("" "" "im " "im " jp-kanji)
("" "" "Lm " "Lm " jp-kanji)
("" "" "m " "m " jp-kanji)
("" "" "WWCm " "WWCm " jp-kanji)
("" "" "}^CRNm " "}^CRNm " jp-kanji)
("" "" "mnm m" "mnm m" jp-kanji)
("" "" "WE}m " "WE}m " jp-kanji)
("" "V" "~m " "~m " jp-kanji)
("" "N" "NoCm N" "NoCm N" jp-kanji)
("" "N" "NVm GL" "NVm GL" jp-kanji)
("" "N" "N\Nm N" "N\Nm N" jp-kanji)
("" "N" "NXm N" "NXm N" jp-kanji)
("" "N" "zNm N" "zNm N" jp-kanji)
("" "N" "Ihm N" "Ihm N" jp-kanji)
("" "ZC" "XNjm ZC" "XNjm ZC" jp-kanji)
("" "[" "iMm [" "iMm [" jp-kanji)
("" "\[" "uCVm u" "uCVm u" jp-kanji)
("" "" "RNWm " "RNWm " jp-kanji)
("" "" "^mVCm " "^mVCm " jp-kanji)
("" "" "VJm " "VJm " jp-kanji)
("" "" "Aum " "Aum " jp-kanji)
("" "" "CXm " "CXm " jp-kanji)
("@" "" "TgXm " "TgXm " jp-kanji)
("A" "" "Vcm " "Vcm " jp-kanji)
("B" "C" "CCcm C" "CCcm C" jp-kanji)
("C" "[" "WCm [" "WCm [" jp-kanji)
("D" "[" "TVCm [" "TVCm [" jp-kanji)
("E" "[" "CTm [" "CTm [" jp-kanji)
("F" "[" "gm [" "gm [" jp-kanji)
("G" "[" "Xm [" "Xm [" jp-kanji)
("H" "[" "[Cm [" "[Cm [" jp-kanji)
("I" "[" "nJm [" "nJm [" jp-kanji)
("J" "[" "ECm [" "ECm [" jp-kanji)
("K" "[" "IWMm [" "IWMm [" jp-kanji)
("L" "[" "Am [" "Am [" jp-kanji)
("M" "[" "Lm Y" "Lm Y" jp-kanji)
("N" "[" "uVK [m N" "uVK [m N" jp-kanji)
("O" "[" "Nm [" "Nm [" jp-kanji)
("P" "[" "[m [" "[m [" jp-kanji)
("Q" "[" "nJm [" "nJm [" jp-kanji)
("R" "[" "[m [" "[m [" jp-kanji)
("S" "[" "^XPm [" "^XPm [" jp-kanji)
("T" "[" "[tNm [" "[tNm [" jp-kanji)
("U" "[" "T\Em [" "T\Em [" jp-kanji)
("V" "[" "A\um [" "A\um [" jp-kanji)
("W" "[" "m [" "m [" jp-kanji)
("X" "[" "[rm [" "[rm [" jp-kanji)
("Y" "[" "IXm [" "IXm [" jp-kanji)
("Z" "[" "gPm [" "gPm [" jp-kanji)
("[" "ZL" "[K^m [" "[K^m [" jp-kanji)
("\" "" "\[m " "\[m " jp-kanji)
("]" "" "A}m " "A}m " jp-kanji)
("^" "" "A^Gm " "A^Gm " jp-kanji)
("_" "" "z}m " "z}m " jp-kanji)
("`" "" "JcOm " "JcOm " jp-kanji)
("a" "" "AYPm " "AYPm " jp-kanji)
("b" "[" "gEm [" "gEm [" jp-kanji)
("c" "[" "ITiCm [" "ITiCm [" jp-kanji)
("d" "[" "AVCm [" "AVCm [" jp-kanji)
("e" "[" "iC[m [" "iC[m [" jp-kanji)
("f" "[" "{[m [" "{[m [" jp-kanji)
("g" "[" "AQm [" "AQm [" jp-kanji)
("h" "[" "m [" "m [" jp-kanji)
("i" "[" "[cm [" "[cm [" jp-kanji)
("j" "[" "[rm [" "[rm [" jp-kanji)
("k" "[" "[Wm [" "[Wm [" jp-kanji)
("l" "T}" "T}m [" "T}m [" jp-kanji)
("m" "[" "ZC[m [" "ZC[m [" jp-kanji)
("n" "[" "gPm [" "gPm [" jp-kanji)
("o" "[" "[Km [" "[Km [" jp-kanji)
("p" "[" "`Cm [" "`Cm [" jp-kanji)
("q" "[" "J}m [" "J}m [" jp-kanji)
("r" "[" "qcWm [" "qcWm [" jp-kanji)
("s" "[" "JKNm [" "JKNm [" jp-kanji)
("t" "[" "nm [" "nm [" jp-kanji)
("u" "[" "t[m [" "t[m [" jp-kanji)
("v" "[" "Cm [" "Cm [" jp-kanji)
("w" "[" "E^Cm [" "E^Cm [" jp-kanji)
("x" "[" "Ihm [" "Ihm [" jp-kanji)
("y" "[" "nJm [" "nJm [" jp-kanji)
("z" "[" "^C[m [" "^C[m [" jp-kanji)
("{" "[" "ViEm [" "ViEm [" jp-kanji)
("|" "N" "RRcLm N" "RRcLm N" jp-kanji)
("}" "N" "ITGm N" "ITGm N" jp-kanji)
("~" "N" "zbXm N" "zbXm N" jp-kanji)
("" "N" "RGm N" "RGm N" jp-kanji)
("" "N" "Arm N" "Arm N" jp-kanji)
("" "N" "NWcm N" "NWcm N" jp-kanji)
("" "N" "coTm N" "coTm N" jp-kanji)
("" "f" "hKm h" "hKm h" jp-kanji)
("" "" "V[m " "V[m " jp-kanji)
("" "" "lWm " "lWm " jp-kanji)
("" "" "n_Jm " "n_Jm " jp-kanji)
("" "C" "L^m C" "L^m C" jp-kanji)
("" "C" "AJUm C" "AJUm C" jp-kanji)
("" "C" "^mm C" "^mm C" jp-kanji)
("" "C" "J~im C" "J~im C" jp-kanji)
("" "N" "N[m N" "N[m N" jp-kanji)
("" "N" "Jm N" "Jm N" jp-kanji)
("" "N" "I`m N" "I`m N" jp-kanji)
("" "N" "Nm[m N" "Nm[m N" jp-kanji)
("" "" "~_m " "~_m " jp-kanji)
("" "" "^}Sm " "^}Sm " jp-kanji)
("" "" "AVm " "AVm " jp-kanji)
("" "" "TGMm " "TGMm " jp-kanji)
("" "" "nm " "nm " jp-kanji)
("" "" "ACm " "ACm " jp-kanji)
("" "" "nim " "nim " jp-kanji)
("" "" "~m " "~m " jp-kanji)
("" "" "Vm " "Vm " jp-kanji)
("" "" "Njm " "Njm " jp-kanji)
("" "" "LVm " "LVm " jp-kanji)
("" "" "N_mm X" "N_mm X" jp-kanji)
("" "" "N_mm iV" "N_mm iV" jp-kanji)
("" "" "ZCm " "ZCm " jp-kanji)
("" "" "W[m " "W[m " jp-kanji)
("" "" "Qm " "Qm " jp-kanji)
("" "" "Em " "Em " jp-kanji)
("" "" "VXwm E" "VXwm E" jp-kanji)
("" "" "Tgm " "Tgm " jp-kanji)
("" "" "nim " "nim " jp-kanji)
("" "N" "^CNm N" "^CNm N" jp-kanji)
("" "c" "z[cm c" "z[cm c" jp-kanji)
("" "c" "qLCm c" "qLCm c" jp-kanji)
("" "c" "^cm c" "^cm c" jp-kanji)
("" "c" "Om c" "Om c" jp-kanji)
("" "N" "N_cm N" "N_cm N" jp-kanji)
("" "N" "V[Nm N" "V[Nm N" jp-kanji)
("" "[" "ZCm [" "ZCm [" jp-kanji)
("" "[" "iKm [" "iKm [" jp-kanji)
("" "[" "^CPm [" "^CPm [" jp-kanji)
("" "[" "[L[m [" "[L[m [" jp-kanji)
("" "[" "gm [" "gm [" jp-kanji)
("" "[" "[Am [" "[Am [" jp-kanji)
("" "[" "cum [" "cum [" jp-kanji)
("" "[" "[Lm [" "[Lm [" jp-kanji)
("" "[" "[O[m [" "[O[m [" jp-kanji)
("" "[" "^cm ZCW" "^cm ZCW" jp-kanji)
("" "" "nm " "nm " jp-kanji)
("" "" "nJm " "nJm " jp-kanji)
("" "" "^rm " "^rm " jp-kanji)
("" "" "zm " "zm " jp-kanji)
("" "[" "[V[m [" "[V[m [" jp-kanji)
("" "[" "[[m [" "[[m [" jp-kanji)
("" "[" "h[[m [" "h[[m [" jp-kanji)
("" "[" "t^cm [" "t^cm [" jp-kanji)
("" "[" "[Km [" "[Km [" jp-kanji)
("" "[" "hNV[m [" "hNV[m [" jp-kanji)
("" "[" "[m [" "[m [" jp-kanji)
("" "[" "nm [" "nm [" jp-kanji)
("" "[" "XYVCm [" "XYVCm [" jp-kanji)
("" "[" "Jm [" "Jm [" jp-kanji)
("" "[" "`[m [" "`[m [" jp-kanji)
("" "[" "C[m [" "C[m [" jp-kanji)
("" "[" "[Zm [" "[Zm [" jp-kanji)
("" "[" "Jem [" "Jem [" jp-kanji)
("" "[" "Cm [" "Cm [" jp-kanji)
("" "[" "}Rgjm [" "}Rgjm [" jp-kanji)
("" "[" "Njm im [" "Njm im [" jp-kanji)
("" "[" "nJm [" "nJm [" jp-kanji)
("" "[" "~TTMm [" "~TTMm [" jp-kanji)
("" "[" "[hm [" "[hm [" jp-kanji)
("" "N" "`Jm N" "`Jm N" jp-kanji)
("" "N" "~hm N" "~hm N" jp-kanji)
("" "" "m " "m " jp-kanji)
("" "" "^Cm " "^Cm " jp-kanji)
("" "" "nVm " "nVm " jp-kanji)
("" "" "TrVCm " "TrVCm " jp-kanji)
("" "" "R[ucm " "R[ucm " jp-kanji)
("" "" "R[m " "R[m " jp-kanji)
("" "" "m]m " "m]m " jp-kanji)
("" "" "m " "m " jp-kanji)
("" "" "gim " "gim " jp-kanji)
("" "" "ERm " "ERm " jp-kanji)
("" "" "Lm " "Lm " jp-kanji)
("" "" "W[m " "W[m " jp-kanji)
("" "C" "g[Cm C" "g[Cm C" jp-kanji)
("" "C" "i~_m C" "i~_m C" jp-kanji)
("" "C" "CVm C" "CVm C" jp-kanji)
("" "C" "uCm C" "uCm C" jp-kanji)
("" "C" "CCm C" "CCm C" jp-kanji)
("" "C" "CWm C" "CWm C" jp-kanji)
("" "C" "^gGm C" "^gGm C" jp-kanji)
("" "C" "qGm C" "qGm C" jp-kanji)
("" "C" "nQm C" "nQm C" jp-kanji)
("" "C" "~lm C" "~lm C" jp-kanji)
("" "C" "Cm C" "Cm C" jp-kanji)
("" "C" "C[m C" "C[m C" jp-kanji)
("" "C" "CMm C" "CMm C" jp-kanji)
("" "C" "~~iOTm C" "~~iOTm C" jp-kanji)
("" "C" "XYm C" "XYm C" jp-kanji)
("" "C" "hCm C" "hCm C" jp-kanji)
("" "[" "[m C" "[m C" jp-kanji)
("" "C" "^}m C" "^}m C" jp-kanji)
("" "C" "EVCm C" "EVCm C" jp-kanji)
("" "C" "lCm C" "lCm C" jp-kanji)
("" "L" "R~m L" "R~m L" jp-kanji)
("" "L" "LVm L" "LVm L" jp-kanji)
("" "c" "ZCcm c" "ZCcm c" jp-kanji)
("" "c" "Igm c" "Igm c" jp-kanji)
("" "c" "nQVCm c" "nQVCm c" jp-kanji)
("" "c" "TPm c" "TPm c" jp-kanji)
("" "" "oCm " "oCm " jp-kanji)
("" "" "RCm " "RCm " jp-kanji)
("" "" "Am " "Am " jp-kanji)
("" "" "TUi~m " "TUi~m " jp-kanji)
("" "" "Km " "Km " jp-kanji)
("" "" "X_m " "X_m " jp-kanji)
("" "" "lm " "lm " jp-kanji)
("" "" "~~wm " "~~wm " jp-kanji)
("@" "" "nXm " "nXm " jp-kanji)
("A" "" "cim " "cim " jp-kanji)
("B" "" "Jlwm " "Jlwm " jp-kanji)
("C" "" "\g[m " "\g[m " jp-kanji)
("D" "" "Wm " "Wm " jp-kanji)
("E" "" "Om " "Om " jp-kanji)
("F" "" "_m " "_m " jp-kanji)
("G" "" "Cm " "Cm " jp-kanji)
("H" "" "h[m " "h[m " jp-kanji)
("I" "" "cm " "cm " jp-kanji)
("J" "[" "[h[m [" "[h[m [" jp-kanji)
("K" "[" "VoVom [" "VoVom [" jp-kanji)
("L" "[" "[Jm [" "[Jm [" jp-kanji)
("M" "[" "eA\um [" "eA\um [" jp-kanji)
("N" "[" "[hNm [" "[hNm [" jp-kanji)
("O" "[" "[m [" "[m [" jp-kanji)
("P" "[" "NcOm [" "NcOm [" jp-kanji)
("Q" "[" "i~m [" "i~m [" jp-kanji)
("R" "[" "m [" "m [" jp-kanji)
("S" "[" "[m [" "[m [" jp-kanji)
("T" "[" "IIJ~m [" "IIJ~m [" jp-kanji)
("U" "[" "JSm [" "JSm [" jp-kanji)
("V" "[" "ICm [" "ICm [" jp-kanji)
("W" "[" "[Am [" "[Am [" jp-kanji)
("X" "[" "[\Nm [" "[\Nm [" jp-kanji)
("Y" "[" "[m [" "[m [" jp-kanji)
("Z" "N" "JX[Wm N" "JX[Wm N" jp-kanji)
("[" "N" "TNm N" "TNm N" jp-kanji)
("\" "N" "N_Jm N" "N_Jm N" jp-kanji)
("]" "N" "bRcm N" "bRcm N" jp-kanji)
("^" "N" "NIm N" "NIm N" jp-kanji)
("_" "" "Sm " "Sm " jp-kanji)
("`" "" "}gm " "}gm " jp-kanji)
("a" "" "Om " "Om " jp-kanji)
("b" "" "niVm " "niVm " jp-kanji)
("c" "C" "Km C" "Km C" jp-kanji)
("d" "C" "Cm C" "Cm C" jp-kanji)
("e" "L[" "Lm L[" "Lm L[" jp-kanji)
("f" "N" "}hEm N" "}hEm N" jp-kanji)
("g" "N" "t`m N" "t`m N" jp-kanji)
("h" "V[" "gm V" "gm V" jp-kanji)
("i" "R[" "^m L[W" "^m L[W" jp-kanji)
("j" "R[" "R[m ^" "R[m ^" jp-kanji)
("k" "KN" "h[ucm j" "h[ucm j" jp-kanji)
("l" "^" "rm ^" "rm ^" jp-kanji)
("m" "R[" "m R[" "m R[" jp-kanji)
("n" "Pc" "rm Pc" "rm Pc" jp-kanji)
("o" "" "Ro`m " "Ro`m " jp-kanji)
("p" "" "CGm " "CGm " jp-kanji)
("q" "" "`m " "`m " jp-kanji)
("r" "" "Efm " "Efm " jp-kanji)
("" "C`" "C`m L[W" "C`m L[W" jp-kanji)
("" "JC" "A^Gm JC" "A^Gm JC" jp-kanji)
("" "q" "IILCm q" "IILCm q" jp-kanji)
("" "J" "qTVm J" "qTVm J" jp-kanji)
("" "J" "AQ}Lm J" "AQ}Lm J" jp-kanji)
("" "`" "em VV" "em VV" jp-kanji)
("" "h" "hum h" "hum h" jp-kanji)
("" "wc" "mm wc" "mm wc" jp-kanji)
("" "KC" "Jm KC" "Jm KC" jp-kanji)
("" "JC" "\Nm JC" "\Nm JC" jp-kanji)
("" "W[" "mm L[W" "mm L[W" jp-kanji)
("" "" "~_m L[W" "~_m L[W" jp-kanji)
("" "Pc" "nl{[m Pc" "nl{[m Pc" jp-kanji)
("" "" "m L[W" "m L[W" jp-kanji)
("" "W" "Rgm L[W" "Rgm L[W" jp-kanji)
("" "W" "mrm W" "mrm W" jp-kanji)
("" "j[" "X[Wm jm L[W" "X[Wm jm L[W" jp-kanji)
("" "E" "Nm E" "Nm E" jp-kanji)
("" "A" "Am L[W" "Am L[W" jp-kanji)
("" "LN" "Lm LN" "Lm LN" jp-kanji)
("" "g[" "ixu^m g[" "ixu^m g[" jp-kanji)
("" "R[" "^Jum R[" "^Jum R[" jp-kanji)
("" "L[" "~Rm ]NW" "~Rm ]NW" jp-kanji)
("" "nN" "Cm `C" "Cm `C" jp-kanji)
("" "^" "}Rgm ^" "}Rgm ^" jp-kanji)
("" "W[" "V^KEm W[" "V^KEm W[" jp-kanji)
("" "W[" "m W[" "m W[" jp-kanji)
("" "\N" "zmJm \N" "zmJm \N" jp-kanji)
("" "t" "^Im t" "^Im t" jp-kanji)
("" "h[" "n^Nm NW" "n^Nm NW" jp-kanji)
("" "W[" "cGm W[" "cGm W[" jp-kanji)
("" "W" "nJm W" "nJm W" jp-kanji)
("" "W" "Wm ]NW" "Wm ]NW" jp-kanji)
("" "Z" "ZpNm Z" "ZpNm Z" jp-kanji)
("" "JC" "Cm JC" "Cm JC" jp-kanji)
("" "R[" "^Jum R[" "^Jum R[" jp-kanji)
("" "Cc" "Ccjm Cc" "Ccjm Cc" jp-kanji)
("" "R" "RPm R" "RPm R" jp-kanji)
("" "tc" "zgPm L[W" "zgPm L[W" jp-kanji)
("" "N" "ZVm N" "ZVm N" jp-kanji)
("" "^" "rVCm _" "rVCm _" jp-kanji)
("" "eC" "^^Ym eC" "^^Ym eC" jp-kanji)
("" "Lc" "jxj V" "jxj V" jp-kanji)
("" "V" "ISm V" "ISm V" jp-kanji)
("" "V" "jxj V" "jxj V" jp-kanji)
("" "^" "rVCm ^" "rVCm ^" jp-kanji)
("" "`[" "JCm `[" "JCm `[" jp-kanji)
("" "nC" "Irm nC" "Irm nC" jp-kanji)
("" "nN" "jxj qN" "jxj qN" jp-kanji)
("" "[" "XXm [" "XXm [" jp-kanji)
("" "[" "Ccm [" "Ccm [" jp-kanji)
("" "C" "Nm L[W" "Nm L[W" jp-kanji)
("" "" "}Cm " "}Cm " jp-kanji)
("" "W" "jxj cNX" "jxj cNX" jp-kanji)
("" "P" "jxj ~" "jxj ~" jp-kanji)
("" "V" "}cm V" "}cm V" jp-kanji)
("" "\" "}iC^m \" "}iC^m \" jp-kanji)
("" "t" "gRm t" "gRm t" jp-kanji)
("" "x" "jxj " "jxj " jp-kanji)
("" "[" "qgK^m [" "qgK^m [" jp-kanji)
("" "" "jxj Tg" "jxj Tg" jp-kanji)
("" "" "jxj " "jxj " jp-kanji)
("" "eC" "IJQm eC" "IJQm eC" jp-kanji)
("" "V" "jxj N}" "jxj N}" jp-kanji)
("" "L" "jxj L" "jxj L" jp-kanji)
("" "L" "ISm L" "ISm L" jp-kanji)
("" "Nc" "jxj Nc" "jxj Nc" jp-kanji)
("" "QC" "^QCm QC" "^QCm QC" jp-kanji)
("" "R[" "jxj \" "jxj \" jp-kanji)
("" "\c" "ZKm \c" "ZKm \c" jp-kanji)
("" "\c" "ZKm ]NW" "ZKm ]NW" jp-kanji)
("" "VN" "Cm VN" "Cm VN" jp-kanji)
("" "V[" "jxj V[" "jxj V[" jp-kanji)
("" "Z" "jxj AI" "jxj AI" jp-kanji)
("" "^N" "jxj ^N" "jxj ^N" jp-kanji)
("" "q" "Vxm q" "Vxm q" jp-kanji)
("" "t" "EcNm t" "EcNm t" jp-kanji)
("" "" "jxj " "jxj " jp-kanji)
("" "[" "jxj [" "jxj [" jp-kanji)
("" "G" "GQcm G" "GQcm G" jp-kanji)
("" "J" "Jm L[W" "Jm L[W" jp-kanji)
("" "JC" "AEm L[W" "AEm L[W" jp-kanji)
("" "JC" "JCZCVm JC" "JCZCVm JC" jp-kanji)
("" "K" "jZmm K" "jZmm K" jp-kanji)
("" "PC" "Qm PC" "Qm PC" jp-kanji)
("" "T" "~iXm T" "~iXm T" jp-kanji)
("" "V" "Tem V" "Tem V" jp-kanji)
("" "\[" "ZVCm \[" "ZVCm \[" jp-kanji)
("" "g[" "kXm g[" "kXm g[" jp-kanji)
("" "JC" "JCCm JC" "JCCm JC" jp-kanji)
("" "R[" "iEm R[" "iEm R[" jp-kanji)
("" "t" "JVYNm t" "JVYNm t" jp-kanji)
("" "E" "ZVm E" "ZVm E" jp-kanji)
("" "S[" "ISm S[" "ISm S[" jp-kanji)
("@" "Z" "ZMm Z" "ZMm Z" jp-kanji)
("A" "Z" "Zjm Z" "Zjm Z" jp-kanji)
("B" "f" "c^Gm L[W" "c^Gm L[W" jp-kanji)
("C" "[" "ZVm [" "ZVm [" jp-kanji)
("D" "L" "jxj L" "jxj L" jp-kanji)
("E" "M" "Ccm L[W" "Ccm L[W" jp-kanji)
("F" "M[" "lKEm M[" "lKEm M[" jp-kanji)
("G" "Z" "Zm L[W" "Zm L[W" jp-kanji)
("H" "Z" "ZGcm Z" "ZGcm Z" jp-kanji)
("I" "h[" "jxj x" "jxj x" jp-kanji)
("J" "J" "A^Cm L[W" "A^Cm L[W" jp-kanji)
("K" "L[" "^Im L[" "^Im L[" jp-kanji)
("L" "P" "Pm L[W" "Pm L[W" jp-kanji)
("M" "V" "XOm V" "XOm V" jp-kanji)
("N" "m[" "jxj m E" "jxj m E" jp-kanji)
("O" "" "jxj J" "jxj J" jp-kanji)
("P" "ZC" "iJ}m ZC" "iJ}m ZC" jp-kanji)
("Q" "`[" "`[m `[" "`[m `[" jp-kanji)
("R" "{[" "jxj " "jxj " jp-kanji)
("S" "C" "JCCm C" "JCCm C" jp-kanji)
("T" "_" "jxj i" "jxj i" jp-kanji)
("U" "C" "jxj C" "jxj C" jp-kanji)
("V" "Q" "jxj Q" "jxj Q" jp-kanji)
("W" "g[" "XOm g[" "XOm g[" jp-kanji)
("X" "W" "qgAVm W" "qgAVm W" jp-kanji)
("Y" "Sc" "ScScm Sc" "ScScm Sc" jp-kanji)
("Z" "W" "Rhm L[W" "Rhm L[W" jp-kanji)
("[" "_" "gJGm _" "gJGm _" jp-kanji)
("\" "g" "ETMm CW" "ETMm CW" jp-kanji)
("]" "L[" "I\m L[" "I\m L[" jp-kanji)
("^" "L[" "L\[m L[" "L\[m L[" jp-kanji)
("_" "[" "[m L[W" "[m L[W" jp-kanji)
("`" "" "CGm " "CGm " jp-kanji)
("a" "PC" "WWm CbV" "WWm CbV" jp-kanji)
("b" "L" "lKEm L" "lKEm L" jp-kanji)
("c" "PC" "GK}Gm PC" "GK}Gm PC" jp-kanji)
("d" "JC" "}m ZCW" "}m ZCW" jp-kanji)
("e" "Tc" "Tcm L[W" "Tcm L[W" jp-kanji)
("f" "[" "[L[m [" "[L[m [" jp-kanji)
("g" "PC" "ALJm PC" "ALJm PC" jp-kanji)
("h" "`[" "Jugm `[" "Jugm `[" jp-kanji)
("i" "R[" "J}Gm R[" "J}Gm R[" jp-kanji)
("j" "x" "Jm x" "Jm x" jp-kanji)
("k" "xL" "Jm xL" "Jm xL" jp-kanji)
("l" "G" "kMkm G" "kMkm G" jp-kanji)
("m" "R[" "QR[m R[" "QR[m R[" jp-kanji)
("n" "`[" "cJm `[" "cJm `[" jp-kanji)
("o" "V" "EcXm L[W" "EcXm L[W" jp-kanji)
("p" "xL" "Lm xL" "Lm xL" jp-kanji)
("q" "q[" "jXCjq[" "jXCjq[" jp-kanji)
("r" "Pc" "jXCj Pc" "jXCj Pc" jp-kanji)
("s" "S" "TGm CW" "TGm CW" jp-kanji)
("t" "`[" "jXCj iJ" "jXCj iJ" jp-kanji)
("u" "q[" "jXCj ~Y" "jXCj ~Y" jp-kanji)
("v" "L[" "jXCj L[" "jXCj L[" jp-kanji)
("w" "c" "jXCj c" "jXCj c" jp-kanji)
("x" "R" "jXCj J^C" "jXCj J^C" jp-kanji)
("y" "[" "jXCj L[" "jXCj L[" jp-kanji)
("z" "" "jXCj " "jXCj " jp-kanji)
("{" "L" "cNGm L" "cNGm L" jp-kanji)
("|" "V" "Vm L[W" "Vm L[W" jp-kanji)
("}" "t[" "J[m RKV" "J[m RKV" jp-kanji)
("~" "q[" "^m q[" "^m q[" jp-kanji)
("" "I[" "IIgm I[" "IIgm I[" jp-kanji)
("" "J" "EPoRm J" "EPoRm J" jp-kanji)
("" "J" "nRm L[W" "nRm L[W" jp-kanji)
("" "j" "J^im ]NW" "J^im ]NW" jp-kanji)
("" "Z" "PYm Z" "PYm Z" jp-kanji)
("" "Pc" "GOm Pc" "GOm Pc" jp-kanji)
("" "t" "tPCm t" "tPCm t" jp-kanji)
("" "S[" "S[m ]NW" "S[m ]NW" jp-kanji)
("" "T" "PYm T" "PYm T" jp-kanji)
("" "Jc" "PYm Jc" "PYm Jc" jp-kanji)
("" "R" "GOm R" "GOm R" jp-kanji)
("" "Zc" "Zcim Zc" "Zcim Zc" jp-kanji)
("" "\[" "nWm \[" "nWm \[" jp-kanji)
("" "PC" "bg[j PC" "bg[j PC" jp-kanji)
("" "RN" "QRNW[m RN" "QRNW[m RN" jp-kanji)
("" "c" "nccm c" "nccm c" jp-kanji)
("" "L" "bg[j L" "bg[j L" jp-kanji)
("" "eL" "bg[j GL" "bg[j GL" jp-kanji)
("" "Z" "Z_m Z" "Z_m Z" jp-kanji)
("" "KC" "KCg[m KC" "KCg[m KC" jp-kanji)
("" "W[" "A}m L[W" "A}m L[W" jp-kanji)
("" "g[" "bg[j g[" "bg[j g[" jp-kanji)
("" "\[" "bg[j X" "bg[j X" jp-kanji)
("" "q[" "kXm q[" "kXm q[" jp-kanji)
("" "P" "Pm L[W" "Pm L[W" jp-kanji)
("" "P" "Pm ]NW" "Pm ]NW" jp-kanji)
("" "P" "J^im cM" "J^im cM" jp-kanji)
("" "P" "Com cM" "Com cM" jp-kanji)
("" "wL" "TNm wL" "TNm wL" jp-kanji)
("" "UC" "NXm L[W" "NXm L[W" jp-kanji)
("" "x" "bg[m x" "bg[m x" jp-kanji)
("" "x" "J^im x" "J^im x" jp-kanji)
("" "N" "Nj `J" "Nj `J" jp-kanji)
("" "V[" "cgm V[" "cgm V[" jp-kanji)
("" "L`" "Vj `J" "Vj `J" jp-kanji)
("" "P" "Pm L[W" "Pm L[W" jp-kanji)
("" "PC" "cCm PC" "cCm PC" jp-kanji)
("" "PC" "L[j `J" "L[j `J" jp-kanji)
("" "LN" "cgm LN" "cgm LN" jp-kanji)
("" "[" "[m L[W" "[m L[W" jp-kanji)
("" "ZL" "`Jm ZL" "`Jm ZL" jp-kanji)
("" "\[" "Xj `J" "Xj `J" jp-kanji)
("" "`N" "^_Xm `N" "^_Xm `N" jp-kanji)
("" "N" "AZm N" "AZm N" jp-kanji)
("" "N" "CTIm L[W" "CTIm L[W" jp-kanji)
("" "C" "nQ}Xm L[W" "nQ}Xm L[W" jp-kanji)
("" "J" "XXm L[W" "XXm L[W" jp-kanji)
("" "z[" "cc~K}G" "cc~K}G" jp-kanji)
("" "\[" "\[\[m \[" "\[\[m \[" jp-kanji)
("" "L[" "L[hm L[" "L[hm L[" jp-kanji)
("" "e" "^j cc~K}G" "^j cc~K}G" jp-kanji)
("" "z" "nEm z" "nEm z" jp-kanji)
("" "tN" "ztNm tN" "ztNm tN" jp-kanji)
("" "z[" "qTSm z[" "qTSm z[" jp-kanji)
("" "q" "ACN`m q" "ACN`m q" jp-kanji)
("" "z[" "nRK}G" "nRK}G" jp-kanji)
("" "R[" "phm nR" "phm nR" jp-kanji)
("" "C" "Ac}m C" "Ac}m C" jp-kanji)
("" "L" "g{VCm L" "g{VCm L" jp-kanji)
("" "" "JK~oRm " "JK~oRm " jp-kanji)
("" "PC" "JNVK}G" "JNVK}G" jp-kanji)
("" "N" "Nm L[W" "Nm L[W" jp-kanji)
("" "\c" "\cm ]NW" "\cm ]NW" jp-kanji)
("" "\[" "NTm \[" "NTm \[" jp-kanji)
("" "ZC" "m L[W" "m L[W" jp-kanji)
("" "L" "NTm L" "NTm L" jp-kanji)
("" "o" "}Wm o" "}Wm o" jp-kanji)
("" "W" "jXCm W" "jXCm W" jp-kanji)
("" "x" "ZbJ`m x" "ZbJ`m x" jp-kanji)
("" "Zc" "tVdNm Zc" "tVdNm Zc" jp-kanji)
("" "V" "TJYLm V" "TJYLm V" jp-kanji)
("" "{[" "ETMm CW" "ETMm CW" jp-kanji)
("" "LN" "V]Nm L[W" "V]Nm L[W" jp-kanji)
("" "J" "}Lm L[W" "}Lm L[W" jp-kanji)
("" "J" "K_m J" "K_m J" jp-kanji)
("" "{[" "{[_Cm {[" "{[_Cm {[" jp-kanji)
("" "V" "Jm V" "Jm V" jp-kanji)
("" "J" "Jm ]NW" "Jm ]NW" jp-kanji)
("" "Pc" "\mm Pc" "\mm Pc" jp-kanji)
("" "V" "Vxm V" "Vxm V" jp-kanji)
("" "V[" "V[m ]NW" "V[m ]NW" jp-kanji)
("" "V" "m V" "m V" jp-kanji)
("" "T" "}Cm L[W" "}Cm L[W" jp-kanji)
("" "T" "EoEm T" "EoEm T" jp-kanji)
("" "\[" "\[m L[W" "\[m L[W" jp-kanji)
("" "\[" "ILim \[" "ILim \[" jp-kanji)
("" "}" "}_m }" "}_m }" jp-kanji)
("" "V[" "Qm V[" "Qm V[" jp-kanji)
("" "eC" "eClCm eC" "eClCm eC" jp-kanji)
("" "g[" "~_m g[" "~_m g[" jp-kanji)
("" "n" "bpm p" "bpm p" jp-kanji)
("" "j[" "N`wj nC" "N`wj nC" jp-kanji)
("" "N" "iQNm N" "iQNm N" jp-kanji)
("" "C" "N`wj EV" "N`wj EV" jp-kanji)
("" "K" "N`wj Lo" "N`wj Lo" jp-kanji)
("" "M" "|hm M" "|hm M" jp-kanji)
("" "R[" "mhm R[" "mhm R[" jp-kanji)
("" "R[" "zGm R[" "zGm R[" jp-kanji)
("" "Z" "XXm Z" "XXm Z" jp-kanji)
("" "gc" "gcxm gc" "gcxm gc" jp-kanji)
("" "t" "N`wj P" "N`wj P" jp-kanji)
("" "" "P`m " "P`m " jp-kanji)
("" "tB[g" "^Cm tB[g" "^Cm tB[g" jp-kanji)
("" "GC" "E^Em ]NW" "E^Em ]NW" jp-kanji)
("" "J" "VJm J" "VJm J" jp-kanji)
("" "L[" "gKm L[" "gKm L[" jp-kanji)
("" "Q" "cuNm Q" "cuNm Q" jp-kanji)
("" "R" "N`wj E" "N`wj E" jp-kanji)
("" "R[" "N`wj R[" "N`wj R[" jp-kanji)
("" "V" "\Vm V" "\Vm V" jp-kanji)
("" "W" "mEm L[W" "mEm L[W" jp-kanji)
("" "V" "ENm V" "ENm V" jp-kanji)
("" "\" "\VNm \" "\VNm \" jp-kanji)
("" "h" "N`wj bR" "N`wj bR" jp-kanji)
("" "gc" "niVJm niV" "niVJm niV" jp-kanji)
("" "t" "N`wj t" "N`wj t" jp-kanji)
("" "z[" "zGm z[" "zGm z[" jp-kanji)
("" "AC" "nNm AC" "nNm AC" jp-kanji)
("" "KN" "IhNm L[W" "IhNm L[W" jp-kanji)
("" "J" "J[m J" "J[m J" jp-kanji)
("" "L" "Jm L" "Jm L" jp-kanji)
("" "R[" "Jm R[" "Jm R[" jp-kanji)
("" "R[" "hLm R[" "hLm R[" jp-kanji)
("" "R[" "N`wj S[" "N`wj S[" jp-kanji)
("" "V" "nJm V" "nJm V" jp-kanji)
("@" "V" "^m V" "^m V" jp-kanji)
("A" "V" "N`wj jV" "N`wj jV" jp-kanji)
("B" "^" "N`wj ^N" "N`wj ^N" jp-kanji)
("C" "[" "N`wj [" "N`wj [" jp-kanji)
("D" "J" "Jm P" "Jm P" jp-kanji)
("E" "R[" "N`wj CN" "N`wj CN" jp-kanji)
("F" "J" "E^m J" "E^m J" jp-kanji)
("G" "K" "N`wj " "N`wj " jp-kanji)
("H" "L" "N`wj }" "N`wj }" jp-kanji)
("I" "S" "N`wj S" "N`wj S" jp-kanji)
("J" "R[" "N`wj T" "N`wj T" jp-kanji)
("K" "R[" "z[R[m R[" "z[R[m R[" jp-kanji)
("L" "RN" "iNm RN" "iNm RN" jp-kanji)
("M" "z" "zj[Cm z" "zj[Cm z" jp-kanji)
("N" "[" "TGYm [" "TGYm [" jp-kanji)
("O" "I" "N`wj ICe" "N`wj ICe" jp-kanji)
("P" "KC" "N`wj KC" "N`wj KC" jp-kanji)
("Q" "K" "tNm K" "tNm K" jp-kanji)
("R" "R[" "N`wj \" "N`wj \" jp-kanji)
("S" "V[" "Em V[" "Em V[" jp-kanji)
("T" "Zc" "XXm Zc" "XXm Zc" jp-kanji)
("U" "^N" "N`wj ^N" "N`wj ^N" jp-kanji)
("V" "^" "P^Jm ^" "P^Jm ^" jp-kanji)
("W" "^" "NEm ^" "NEm ^" jp-kanji)
("X" "e" "Eim e" "Eim e" jp-kanji)
("Y" "C" "N`wj h" "N`wj h" jp-kanji)
("Z" "J" "N`wj " "N`wj " jp-kanji)
("[" "JC" "N`oVm JC" "N`oVm JC" jp-kanji)
("\" "JN" "JbPcm JN" "JbPcm JN" jp-kanji)
("]" "JN" "JNm CW" "JNm CW" jp-kanji)
("^" "J" "JZCm J" "JZCm J" jp-kanji)
("_" "L" "iQNm L" "iQNm L" jp-kanji)
("`" "V" "^_jm V" "^_jm V" jp-kanji)
("a" "V[" "iNm V[" "iNm V[" jp-kanji)
("b" "[" "[\Nm [" "[\Nm [" jp-kanji)
("c" "\N" "iNm \N" "iNm \N" jp-kanji)
("d" "^" "^m L[W" "^m L[W" jp-kanji)
("e" "eC" "iNm eC" "iNm eC" jp-kanji)
("f" "i" "N`wj ~i~" "N`wj ~i~" jp-kanji)
("g" "" "TgXm " "TgXm " jp-kanji)
("h" "" "bpm " "bpm " jp-kanji)
("i" "[" "zKJm [" "zKJm [" jp-kanji)
("j" "I" "IGcm I" "IGcm I" jp-kanji)
("k" "L[" "JOm L[" "JOm L[" jp-kanji)
("l" "T" "iQNm T" "iQNm T" jp-kanji)
("m" "T" "VKm T" "VKm T" jp-kanji)
("n" "V" "VR[qm V" "VR[qm V" jp-kanji)
("o" "V" "AUPEm V" "AUPEm V" jp-kanji)
("p" "V" "N`wj }Rg" "N`wj }Rg" jp-kanji)
("q" "I[" "nNm I[" "nNm I[" jp-kanji)
("r" "S[" "J}rXVC" "J}rXVC" jp-kanji)
("s" "TN" "N`wj ZL" "N`wj ZL" jp-kanji)
("t" "\[" "\\mJXm \[" "\\mJXm \[" jp-kanji)
("u" "\[" "ZLm \[" "ZLm \[" jp-kanji)
("v" "}" "N`wj }" "N`wj }" jp-kanji)
("w" "" "N`wj " "N`wj " jp-kanji)
("x" "Cc" "Zum Cc" "Zum Cc" jp-kanji)
("y" "L" "Ecm L[W" "Ecm L[W" jp-kanji)
("z" "GC" "Cgim L[W" "Cgim L[W" jp-kanji)
("{" "V" "N`oVm V" "N`oVm V" jp-kanji)
("|" "ZC" "CiiNm ZC" "CiiNm ZC" jp-kanji)
("}" "`[" "AUPm `[" "AUPm `[" jp-kanji)
("~" "u" "N`wj iV" "N`wj iV" jp-kanji)
("" "C" "AAm C" "AAm C" jp-kanji)
("" "L" "cOm L" "cOm L" jp-kanji)
("" "V[" "E\uNm V[" "E\uNm V[" jp-kanji)
("" "[C" "Jm [C" "Jm [C" jp-kanji)
("" "\[" "TOm \[" "TOm \[" jp-kanji)
("" "R[" "R[Vm R[" "R[Vm R[" jp-kanji)
("" "eC" "N`wj eC" "N`wj eC" jp-kanji)
("" "q" "JJAm q" "JJAm q" jp-kanji)
("" "[" "[[m [" "[[m [" jp-kanji)
("" "eC" "NV~m eC" "NV~m eC" jp-kanji)
("" "eC" "NV~m ]NW" "NV~m ]NW" jp-kanji)
("" "G" "m~Rm G" "m~Rm G" jp-kanji)
("" "L[" "TLjm L[" "TLjm L[" jp-kanji)
("" "I[" "iNm I[" "iNm I[" jp-kanji)
("" "Q" "LrVCm L[W" "LrVCm L[W" jp-kanji)
("" "S[" "J}rXVC" "J}rXVC" jp-kanji)
("" "VN" "\VNm VN" "\VNm VN" jp-kanji)
("" "V[" "TTNm V[" "TTNm V[" jp-kanji)
("" "e" "TGYm e" "TGYm e" jp-kanji)
("" "QC" "^Sgm QC" "^Sgm QC" jp-kanji)
("" "\" "N`wj IN" "N`wj IN" jp-kanji)
("" "VN" "VNm L[W" "VNm L[W" jp-kanji)
("" "Qc" "JWm L[W" "JWm L[W" jp-kanji)
("" "C" "NjK}Gm C" "NjK}Gm C" jp-kanji)
("" "J" "Igm J" "Igm J" jp-kanji)
("" "C" "NjK}Gj C" "NjK}Gj C" jp-kanji)
("" "RN" "~cNjm Nj" "~cNjm Nj" jp-kanji)
("" "[" "NjK}Gj A" "NjK}Gj A" jp-kanji)
("" "S" "NjK}Gj " "NjK}Gj " jp-kanji)
("" "M" "NjK}Gj T`" "NjK}Gj T`" jp-kanji)
("" "P" "Pm L[W" "Pm L[W" jp-kanji)
("" "RN" "Njm L[W" "Njm L[W" jp-kanji)
("" "C" "JRm L[W" "JRm L[W" jp-kanji)
("" "G" "}hJm L[W" "}hJm L[W" jp-kanji)
("" "_" "J^}m L[W" "J^}m L[W" jp-kanji)
("" "Y" "nJm L[W" "nJm L[W" jp-kanji)
("" "VN" "VNm VN" "VNm VN" jp-kanji)
("" "G" "}Cm G" "}Cm G" jp-kanji)
("" "j[" "c`wj nC" "c`wj nC" jp-kanji)
("" "J" "c`wj V^" "c`wj V^" jp-kanji)
("" "T" "c`wj }" "c`wj }" jp-kanji)
("" "J" "JZCm J" "JZCm J" jp-kanji)
("" "L" "TJCm L" "TJCm L" jp-kanji)
("" "V" "W[Vm V" "W[Vm V" jp-kanji)
("" "nC" "gWm nC" "gWm nC" jp-kanji)
("" "J" "c{m J" "c{m J" jp-kanji)
("" "XC" "^m L[W" "^m L[W" jp-kanji)
("" "J" "Jj c`" "Jj c`" jp-kanji)
("" "n" "cc~m n" "cc~m n" jp-kanji)
("" "t" "c`wj t" "c`wj t" jp-kanji)
("" "z[" "c`wj cc" "c`wj cc" jp-kanji)
("" "KC" "INm ZoC" "INm ZoC" jp-kanji)
("" "M" "c`wj S" "c`wj S" jp-kanji)
("" "R[" "c`wj CN" "c`wj CN" jp-kanji)
("" "ec" "c`wj C^" "c`wj C^" jp-kanji)
("" "n" "c`wj wC" "c`wj wC" jp-kanji)
("" "g[Q" "^Im g[Q" "^Im g[Q" jp-kanji)
("" "AC" "`m AC" "`m AC" jp-kanji)
("" "JN" "c`wj JN" "c`wj JN" jp-kanji)
("" "z" "c`wj z" "c`wj z" jp-kanji)
("" "`" "`m ZCW" "`m ZCW" jp-kanji)
("" "`" "`iCm `" "`iCm `" jp-kanji)
("" "A" "Vc`m A" "Vc`m A" jp-kanji)
("" "J" "c`wj ni" "c`wj ni" jp-kanji)
("" "TC" "c`wj \c" "c`wj \c" jp-kanji)
("" "z[" "AY`m z[" "AY`m z[" jp-kanji)
("" "C" "tTOm C" "tTOm C" jp-kanji)
("" "J" "c{m J" "c{m J" jp-kanji)
("" "W[" "om L[W" "om L[W" jp-kanji)
("" "z" "gfm z" "gfm z" jp-kanji)
("" "I" "c`wj JX" "c`wj JX" jp-kanji)
("" "GC" "nJm GC" "nJm GC" jp-kanji)
("" "JC" "E~j c`" "E~j c`" jp-kanji)
("" "L" "Lz[wm L" "Lz[wm L" jp-kanji)
("" "V" "c`wj gL" "c`wj gL" jp-kanji)
("" "R[" "IJm R[" "IJm R[" jp-kanji)
("" "U" "US[m U" "US[m U" jp-kanji)
("" "" "mj c`" "mj c`" jp-kanji)
("" "J" "c`wj AC_" "c`wj AC_" jp-kanji)
("" "L" "nCLm L" "nCLm L" jp-kanji)
("" "\" "c`wj \" "c`wj \" jp-kanji)
("" "I[" "c`wj IN" "c`wj IN" jp-kanji)
("" "JC" "Rm L[W" "Rm L[W" jp-kanji)
("" "V[" "JLlm V[" "JLlm V[" jp-kanji)
("" "`" "c`wj `" "c`wj `" jp-kanji)
("" "_" "i}Pm L[W" "i}Pm L[W" jp-kanji)
("" "[" "tZOm [" "tZOm [" jp-kanji)
("" "Ac" "ITGm L[W" "ITGm L[W" jp-kanji)
("" "KN" "^jm KN" "^jm KN" jp-kanji)
("" "W" "c`wj cNX" "c`wj cNX" jp-kanji)
("" "R[" "c`wj R[" "c`wj R[" jp-kanji)
("" "C" "Cm L[W" "Cm L[W" jp-kanji)
("" "e" "c`wj e" "c`wj e" jp-kanji)
("" "^" "rdm r" "rdm r" jp-kanji)
("" "W[" "W[m L[W" "W[m L[W" jp-kanji)
("" "[" "c`j [" "c`j [" jp-kanji)
("" "\[" "\[m L[W" "\[m L[W" jp-kanji)
("" "R" "c{m L[W" "c{m L[W" jp-kanji)
("" "C`" "qgcm L[W" "qgcm L[W" jp-kanji)
("" "ZC" "Rm ]NW" "Rm ]NW" jp-kanji)
("" "R" "RNm R" "RNm R" jp-kanji)
("" "W" "RguLm L[W" "RguLm L[W" jp-kanji)
("" "`" "tKVm `" "tKVm `" jp-kanji)
("" "XC" "XCj[m XC" "XCj[m XC" jp-kanji)
("" "PC" "nJm PC" "nJm PC" jp-kanji)
("" "^" "IICm L[W" "IICm L[W" jp-kanji)
("" "" "m L[W" "m L[W" jp-kanji)
("" "J" "Ir^_VCm J" "Ir^_VCm J" jp-kanji)
("" "Pc" "Lm Pc" "Lm Pc" jp-kanji)
("" "[" "[Zcm [" "[Zcm [" jp-kanji)
("" "z" "gm L[W" "gm L[W" jp-kanji)
("" "R" "zRm R" "zRm R" jp-kanji)
("" "L[" "nTm L[" "nTm L[" jp-kanji)
("" "L" "Lm ]NW" "Lm ]NW" jp-kanji)
("" "GL" "oN`m GL" "oN`m GL" jp-kanji)
("" "J" "TJim J" "TJim J" jp-kanji)
("" "PC" "PCEm PC" "PCEm PC" jp-kanji)
("" "PC" "CYN]m PC" "CYN]m PC" jp-kanji)
("" "\[" "\[j IILC" "\[j IILC" jp-kanji)
("" "V" "ISm V" "ISm V" jp-kanji)
("" "e" "}cm e" "}cm e" jp-kanji)
("" "I[" "INm L[W" "INm L[W" jp-kanji)
("" "V[" "XXm L[W" "XXm L[W" jp-kanji)
("" "" "JK~oRm " "JK~oRm " jp-kanji)
("@" "J" "RV}m J" "RV}m J" jp-kanji)
("A" "VN" "oCVNm VN" "oCVNm VN" jp-kanji)
("B" "\[" "\IEm \[" "\IEm \[" jp-kanji)
("C" "C" "RV}m C" "RV}m C" jp-kanji)
("D" "C" "RV}m CW" "RV}m CW" jp-kanji)
("E" "q" "iL nnm q" "iL nnm q" jp-kanji)
("F" "_c" "_bLm _c" "_bLm _c" jp-kanji)
("G" "{" "Iiwj nn" "Iiwj nn" jp-kanji)
("H" "C" "Iom C" "Iom C" jp-kanji)
("I" "L[" "nWJ~m L[" "nWJ~m L[" jp-kanji)
("J" "P" "EcNVCm P" "EcNVCm P" jp-kanji)
("K" "j" "nm CW" "nm CW" jp-kanji)
("L" "[" "[R[m [" "[R[m [" jp-kanji)
("M" "K" "Iiwj " "Iiwj " jp-kanji)
("N" "P" "PPm P" "PPm P" jp-kanji)
("O" "V" "Vom V" "Vom V" jp-kanji)
("P" "_" "ViJm _" "ViJm _" jp-kanji)
("Q" "wC" "gm wC" "gm wC" jp-kanji)
("R" "i" "Iij IgR" "Iij IgR" jp-kanji)
("S" "A" "Iiwj A" "Iiwj A" jp-kanji)
("T" "C" "~_m L[W" "~_m L[W" jp-kanji)
("U" "G" "GLNm G" "GLNm G" jp-kanji)
("V" "V" "Iiwj g" "Iiwj g" jp-kanji)
("W" "V" "gm V" "gm V" jp-kanji)
("X" "q" "QWm q" "QWm q" jp-kanji)
("Y" "" "T{m " "T{m " jp-kanji)
("Z" "r" "Rrm r" "Rrm r" jp-kanji)
("[" "I[" "I[im I[" "I[im I[" jp-kanji)
("\" "R[" "CcNVm R[" "CcNVm R[" jp-kanji)
("]" "W[" "^IJm W[" "^IJm W[" jp-kanji)
("^" "\[" "Ajm \[" "Ajm \[" jp-kanji)
("_" "{" "Iiwj E}" "Iiwj E}" jp-kanji)
("`" "G" "G[m G" "G[m G" jp-kanji)
("a" "I[" "nnm I[" "nnm I[" jp-kanji)
("b" "R[" "Iiwj cl" "Iiwj cl" jp-kanji)
("c" "h" "JCm h" "JCm h" jp-kanji)
("d" "q[" "JCm q[" "JCm q[" jp-kanji)
("e" "J" "~rJm J" "~rJm J" jp-kanji)
("f" "J" "Jm CW" "Jm CW" jp-kanji)
("g" "L[" "i}JVC" "i}JVC" jp-kanji)
("h" "Z" "ZPm Z" "ZPm Z" jp-kanji)
("i" "wC" "wC`[m wC" "wC`[m wC" jp-kanji)
("j" "W[" "IgRm iu" "IgRm iu" jp-kanji)
("k" "W[" "Iim iu" "Iim iu" jp-kanji)
("l" "q" "qm q" "qm q" jp-kanji)
("m" "r" "Iiwj ni" "Iiwj ni" jp-kanji)
("n" "" "Iiwj C" "Iiwj C" jp-kanji)
("o" "W[" "Xm L[W" "Xm L[W" jp-kanji)
("p" "Z" "JCm Z" "JCm Z" jp-kanji)
("q" "\[" "m \[" "m \[" jp-kanji)
("r" "Qc" "Qccm Qc" "Qccm Qc" jp-kanji)
("s" "[" "nm [" "nm [" jp-kanji)
("t" "t" "^}Sm t" "^}Sm t" jp-kanji)
("u" "nC" "z[L{Vm nC" "z[L{Vm nC" jp-kanji)
("v" "h" "bRj V" "bRj V" jp-kanji)
("w" "KC" "~hSm KC" "~hSm KC" jp-kanji)
("x" "WN" "CYm WN" "CYm WN" jp-kanji)
("y" "W" "VQm W" "VQm W" jp-kanji)
("z" "t" "JGm t" "JGm t" jp-kanji)
("{" "KN" "}ium L[W" "}ium L[W" jp-kanji)
("|" "KN" "}ium ]NW" "}ium ]NW" jp-kanji)
("}" "W" "WVm W" "WVm W" jp-kanji)
("" "^" "zJm ^" "zJm ^" jp-kanji)
("" "J" "JKm J" "JKm J" jp-kanji)
("" "V" "Vscm V" "Vscm V" jp-kanji)
("" "G" "E~m ]NW" "E~m ]NW" jp-kanji)
("" "R[" "A_m ]NW" "A_m ]NW" jp-kanji)
("" "JN" "AKm JN" "AKm JN" jp-kanji)
("" "VN" "}Rgjm VN" "}Rgjm VN" jp-kanji)
("" "r" "lm r" "lm r" jp-kanji)
("" "S" "Tm S" "Tm S" jp-kanji)
("" "Wc" "~mm L[W" "~mm L[W" jp-kanji)
("" "V" "lm L[W" "lm L[W" jp-kanji)
("" "oN" "TrVCm oN" "TrVCm oN" jp-kanji)
("" "[" "TrVCm [" "TrVCm [" jp-kanji)
("" "V" "EcXm L[W" "EcXm L[W" jp-kanji)
("" "J" "JNm J" "JNm J" jp-kanji)
("" "z[" "^Jm L[W" "^Jm L[W" jp-kanji)
("" "z[" "^Jm ]NW" "^Jm ]NW" jp-kanji)
("" "RN" "Jcm RN" "Jcm RN" jp-kanji)
("" "V[" "V[m L[W" "V[m L[W" jp-kanji)
("" "Z" "bpm L[W" "bpm L[W" jp-kanji)
("" "^C" "cCm L[W" "cCm L[W" jp-kanji)
("" "W" "jm NW" "jm NW" jp-kanji)
("" "Z" "XNiCm Z" "XNiCm Z" jp-kanji)
("" "I[" "}QAVm I[" "}QAVm I[" jp-kanji)
("" "{[" "NCkm {[" "NCkm {[" jp-kanji)
("" "V" "VJolm V" "VJolm V" jp-kanji)
("" "C" "ITm C" "ITm C" jp-kanji)
("" "q" "wm q" "wm q" jp-kanji)
("" "JC" "ghPm L[W" "ghPm L[W" jp-kanji)
("" "V" "N\m V" "N\m V" jp-kanji)
("" "L" "qCLm L" "qCLm L" jp-kanji)
("" "PL" "nLmm PL" "nLmm PL" jp-kanji)
("" "wC" "r[um r[" "r[um r[" jp-kanji)
("" "Z" "Cm Z" "Cm Z" jp-kanji)
("" "VN" "]Nm L[W" "]Nm L[W" jp-kanji)
("" "ec" "ec" "ec" jp-kanji)
("" "KC" "}j co" "}j co" jp-kanji)
("" "g[" "}j J^i" "}j J^i" jp-kanji)
("" "Lc" "\rGm Lc" "\rGm Lc" jp-kanji)
("" "L[" "}j Iu" "}j Iu" jp-kanji)
("" "V" "~lm V" "~lm V" jp-kanji)
("" "^" "tj }" "tj }" jp-kanji)
("" "V" "}j Ii" "}j Ii" jp-kanji)
("" "V[" "V[Em V[" "V[Em V[" jp-kanji)
("" "W" "}m i}G" "}m i}G" jp-kanji)
("" "nN" "}wj V" "}wj V" jp-kanji)
("" "wC" "}wj ^C" "}wj ^C" jp-kanji)
("" "r" "rUm r" "rUm r" jp-kanji)
("" "x" "}wj x" "}wj x" jp-kanji)
("" "Z" "}wj Z" "}wj Z" jp-kanji)
("" "R[" "}j AE" "}j AE" jp-kanji)
("" "W" "}wj e" "}wj e" jp-kanji)
("" "K" "}j " "}j " jp-kanji)
("" "L[" "nU}m CW" "nU}m CW" jp-kanji)
("" "R[" "}wj T" "}wj T" jp-kanji)
("" "V[" "PVCm V[" "PVCm V[" jp-kanji)
("" "g[" "V}m ]NW" "V}m ]NW" jp-kanji)
("" "N" "}wj ^j" "}wj ^j" jp-kanji)
("" "J" "JUm J" "JUm J" jp-kanji)
("" "KC" "KPm KC" "KPm KC" jp-kanji)
("" "R[" "niIJm IJ" "niIJm IJ" jp-kanji)
("" "L" "~TLm ]NW" "~TLm ]NW" jp-kanji)
("" "M" "}j L" "}j L" jp-kanji)
("" "Nc" "\o_cm Nc" "\o_cm Nc" jp-kanji)
("" "R" "Rm R" "Rm R" jp-kanji)
("" "TC" "}j tg" "}j tg" jp-kanji)
("" "\[" "\[R[m \[" "\[R[m \[" jp-kanji)
("" "[" "}wj [" "}wj [" jp-kanji)
("" "" "Rm " "Rm " jp-kanji)
("" "" "m CW" "m CW" jp-kanji)
("" "J" "nRm J" "nRm J" jp-kanji)
("" "K" "Cm K" "Cm K" jp-kanji)
("" "O[" "}wj O[" "}wj O[" jp-kanji)
("" "r" "}wj r" "}wj r" jp-kanji)
("" "JC" "}j Ij" "}j Ij" jp-kanji)
("" "T" "}j T" "}j T" jp-kanji)
("" "WN" "}wj C" "}wj C" jp-kanji)
("" "N" "}wj N" "}wj N" jp-kanji)
("" "U" "U[m U" "U[m U" jp-kanji)
("" "V[" "}wj V[" "}wj V[" jp-kanji)
("" "M[" "}wj M[" "}wj M[" jp-kanji)
("" "g[" "}wj m {" "}wj m {" jp-kanji)
("" "M" "}wj M" "}wj M" jp-kanji)
("" "P" "PVCm P" "PVCm P" jp-kanji)
("" "KN" "^Pm L[W" "^Pm L[W" jp-kanji)
("" "[" "}j ^JV" "}j ^JV" jp-kanji)
("" "M" "}j E^KE" "}j E^KE" jp-kanji)
("" "V" "V}m V" "V}m V" jp-kanji)
("" "T" "TKm T" "TKm T" jp-kanji)
("" "M" "M[m M" "M[m M" jp-kanji)
("" "e" "C^_Lm e" "C^_Lm e" jp-kanji)
("" "" "z[m " "z[m " jp-kanji)
("" "K" "PVCm L[W" "PVCm L[W" jp-kanji)
("" "Z" "Jm Z" "Jm Z" jp-kanji)
("" "u" "~Rm u" "~Rm u" jp-kanji)
("" "C" "Gjm C" "Gjm C" jp-kanji)
("" "V" "TJYLm V" "TJYLm V" jp-kanji)
("" "V" "J~m CW" "J~m CW" jp-kanji)
("" "\[" "z[Lm \[" "z[Lm \[" jp-kanji)
("" "`c" "t~dc~m ec" "t~dc~m ec" jp-kanji)
("" "h" "JlCm h" "JlCm h" jp-kanji)
("" "nN" "Lkm nN" "Lkm nN" jp-kanji)
("" "^C" "Irm L[W" "Irm L[W" jp-kanji)
("" "C" "J^rm C" "J^rm C" jp-kanji)
("" "AN" "gom AN" "gom AN" jp-kanji)
("" "C" "gom C" "gom C" jp-kanji)
("" "eC" "nMkm eC" "nMkm eC" jp-kanji)
("" "xL" "JIJNVm xL" "JIJNVm xL" jp-kanji)
("" "JN" "nowj Nj" "nowj Nj" jp-kanji)
("" "}" "}}Nm }" "}}Nm }" jp-kanji)
("" "V" "m{m V" "m{m V" jp-kanji)
("" "g[" "n^m g[" "n^m g[" jp-kanji)
("" "wC" "kTm L[W" "kTm L[W" jp-kanji)
("" "z[" "^CR`m z[" "^CR`m z[" jp-kanji)
("" "P" "^Cm P" "^Cm P" jp-kanji)
("" "wC" "AZm wC" "AZm wC" jp-kanji)
("" "[" "CgKVm [" "CgKVm [" jp-kanji)
("" "}" "CJjm }" "CJjm }" jp-kanji)
("" "Q" "}_m Q" "}_m Q" jp-kanji)
("" "V[" "}_j qcW" "}_j qcW" jp-kanji)
("" "V" "Jm V" "Jm V" jp-kanji)
("" "V[" "}_j AE" "}_j AE" jp-kanji)
("" "J" "}_j ic" "}_j ic" jp-kanji)
("" "L[" "E}m L[" "E}m L[" jp-kanji)
("" "L[" "L[m CW" "L[m CW" jp-kanji)
("@" "[" "}_j [" "}_j [" jp-kanji)
("A" "R[" "qCm L[W" "qCm L[W" jp-kanji)
("B" "V" "Rmm V" "Rmm V" jp-kanji)
("C" "`[" "Nm CW" "Nm CW" jp-kanji)
("D" "e" "~Zm e" "~Zm e" jp-kanji)
("E" "nC" "X^m L[W" "X^m L[W" jp-kanji)
("F" "u" "}_j iV" "}_j iV" jp-kanji)
("G" "JC" "}_j gN" "}_j gN" jp-kanji)
("H" "" "Nm " "Nm " jp-kanji)
("I" "" "Um " "Um " jp-kanji)
("J" "[" "Om [" "Om [" jp-kanji)
("K" "`[" "`[m L[W" "`[m L[W" jp-kanji)
("L" "`[" "}_j LN" "}_j LN" jp-kanji)
("M" "C" "Gj[m C" "Gj[m C" jp-kanji)
("N" "eL" "~`m eL" "~`m eL" jp-kanji)
("O" "L[" "jW[AVm L[" "jW[AVm L[" jp-kanji)
("P" "L" "Xem ]NW" "Xem ]NW" jp-kanji)
("Q" "\[" "\[m L[W" "\[m L[W" jp-kanji)
("R" "C" "clm C" "clm C" jp-kanji)
("S" "C" "Cm ]NW" "Cm ]NW" jp-kanji)
("T" "N" "VLK}Gm N" "VLK}Gm N" jp-kanji)
("U" "V" "RXm V" "RXm V" jp-kanji)
("V" "e" "~j C`" "~j C`" jp-kanji)
("W" "h" "CV~m h" "CV~m h" jp-kanji)
("X" "r" "m r" "m r" jp-kanji)
("Y" "z[" "~wj z[" "~wj z[" jp-kanji)
("Z" "J" "~wj J" "~wj J" jp-kanji)
("[" "_" "qNm L[W" "qNm L[W" jp-kanji)
("\" "r" "m L[W" "m L[W" jp-kanji)
("]" "" "qNm L[W" "qNm L[W" jp-kanji)
("^" "" "qNm " "qNm " jp-kanji)
("_" "PC" "PCKVm PC" "PCKVm PC" jp-kanji)
("`" "^" "^Wm ^" "^Wm ^" jp-kanji)
("a" "XC" "XCZCm XC" "XCZCm XC" jp-kanji)
("b" "C" "nlY~m C" "nlY~m C" jp-kanji)
("c" "T" "TdNm T" "TdNm T" jp-kanji)
("d" "z[" "cd~m Ig" "cd~m Ig" jp-kanji)
("e" "eL" "M[jx" "M[jx" jp-kanji)
("f" "z[" "T}Em z[" "T}Em z[" jp-kanji)
("g" "I[" "Nm ]NW" "Nm ]NW" jp-kanji)
("h" "\" "IM[ \Cm \" "IM[ \Cm \" jp-kanji)
("i" "tc" "zgPm L[W" "zgPm L[W" jp-kanji)
("j" "JC" "nCJCm JC" "nCJCm JC" jp-kanji)
("k" "R" "nin_m R" "nin_m R" jp-kanji)
("l" "PC" "R~`m L[W" "R~`m L[W" jp-kanji)
("m" "W" "giGm W" "giGm W" jp-kanji)
("n" "W[" "V^KEm L[W" "V^KEm L[W" jp-kanji)
("o" "V" "Ecm V" "Ecm V" jp-kanji)
("p" "nC" "nCJCm nC" "nCJCm nC" jp-kanji)
("q" "C" "Nm RW" "Nm RW" jp-kanji)
("r" "R[" "z[R[m R[" "z[R[m R[" jp-kanji)
("s" "[" "uNm [" "uNm [" jp-kanji)
("t" "L[" "gm L[" "gm L[" jp-kanji)
("u" "\" "IVnJm \" "IVnJm \" jp-kanji)
("v" "L" "Vxj L" "Vxj L" jp-kanji)
("w" "S" "TJEm S" "TJEm S" jp-kanji)
("x" "WN" "WNW^m WN" "WNW^m WN" jp-kanji)
("y" "V" "}SRm V" "}SRm V" jp-kanji)
("z" "e" "J^WPiC" "J^WPiC" jp-kanji)
("{" "gN" "mm gN" "mm gN" jp-kanji)
("|" "t" "IRm t" "IRm t" jp-kanji)
("}" "C" "Rum C" "Rum C" jp-kanji)
("~" "JC" "AVCm CW" "AVCm CW" jp-kanji)
("" "R" "RWm R" "RWm R" jp-kanji)
("" "N" "bVxj N" "bVxj N" jp-kanji)
("" "W" "WNW^m W" "WNW^m W" jp-kanji)
("" "V" "CJfm V" "CJfm V" jp-kanji)
("" "\[" "jJm \[" "jJm \[" jp-kanji)
("" "^" "C^m ^" "C^m ^" jp-kanji)
("" "nN" "I\m nN" "I\m nN" jp-kanji)
("" "tc" "CJm tc" "CJm tc" jp-kanji)
("" "z[" "Vxj wC" "Vxj wC" jp-kanji)
("" "I[" "bVxj I[" "bVxj I[" jp-kanji)
("" "GC" "RGm GC" "RGm GC" jp-kanji)
("" "C" "Ctm C" "Ctm C" jp-kanji)
("" "j" "jm j" "jm j" jp-kanji)
("" "JN" "JNVNm JN" "JNVNm JN" jp-kanji)
("" "L[" "Xj RR" "Xj RR" jp-kanji)
("" "L[" "J}rXVC" "J}rXVC" jp-kanji)
("" "L[" "L[m ]NW" "L[m ]NW" jp-kanji)
("" "R[" "clm L[W" "clm L[W" jp-kanji)
("" "R[" "R[Rcm R[" "R[Rcm R[" jp-kanji)
("" "V" "zVC}}m V" "zVC}}m V" jp-kanji)
("" "W" "^mm W" "^mm W" jp-kanji)
("" "Wc" "Am Wc" "Am Wc" jp-kanji)
("" "V" "}Rgm V" "}Rgm V" jp-kanji)
("" "e" "XJm e" "XJm e" jp-kanji)
("" "h[" "IhXm h[" "IhXm h[" jp-kanji)
("" "[" "LKJm [" "LKJm [" jp-kanji)
("" "G" "CJm G" "CJm G" jp-kanji)
("" "J" "C}TVCm J" "C}TVCm J" jp-kanji)
("" "O" "bVxj O" "bVxj O" jp-kanji)
("" "R" "Rz[m R" "Rz[m R" jp-kanji)
("" "V[" "I\m V[" "I\m V[" jp-kanji)
("" "V[" "V[[m V[" "V[[m V[" jp-kanji)
("" "V" "A^m V" "A^m V" jp-kanji)
("" "nC" "gm nC" "gm nC" jp-kanji)
("" "o" "Vxj " "Vxj " jp-kanji)
("" "[" "EGm [" "EGm [" jp-kanji)
("" "" "JVRCm " "JVRCm " jp-kanji)
("" "" "l^m " "l^m " jp-kanji)
("" "AN" "Cm L[W" "Cm L[W" jp-kanji)
("" "L" "I\m L" "I\m L" jp-kanji)
("" "PC" "Om L[W" "Om L[W" jp-kanji)
("" "P" "Em P" "Em P" jp-kanji)
("" "XC" "ZKm XC" "ZKm XC" jp-kanji)
("" "XC" "V[XCm XC" "V[XCm XC" jp-kanji)
("" "ZC" "ZCTm ZC" "ZCTm ZC" jp-kanji)
("" "`[" "Em `[" "Em `[" jp-kanji)
("" "`[" "`[Rm `[" "`[Rm `[" jp-kanji)
("" "{[" "{[{[m {[" "{[{[m {[" jp-kanji)
("" "I" "CJm I" "CJm I" jp-kanji)
("" "KN" "IhNm KN" "IhNm KN" jp-kanji)
("" "P" "A}m P" "A}m P" jp-kanji)
("" "R[" "Aem R[" "Aem R[" jp-kanji)
("" "V" "IJm V" "IJm V" jp-kanji)
("" "V[" "Vxj AL" "Vxj AL" jp-kanji)
("" "YC" "I\m YC" "I\m YC" jp-kanji)
("" "ZC" "Vxj zV" "Vxj zV" jp-kanji)
("" "P" "Vxj Z" "Vxj Z" jp-kanji)
("" "\[" "bVxj \[" "bVxj \[" jp-kanji)
("" "\N" "\NCm \N" "\NCm \N" jp-kanji)
("" "m[" "im L[W" "im L[W" jp-kanji)
("" "~" "Am ~" "Am ~" jp-kanji)
("" "tN" "gm tN" "gm tN" jp-kanji)
("" "C" "lSm C" "lSm C" jp-kanji)
("" "KC" "bVxj L" "bVxj L" jp-kanji)
("" "JN" "}Rgm JN" "}Rgm JN" jp-kanji)
("" "L" "ULm L" "ULm L" jp-kanji)
("" "P" "AL^iC" "AL^iC" jp-kanji)
("" "Q" "ccVm Q" "ccVm Q" jp-kanji)
("" "V" "ccVm L[W" "ccVm L[W" jp-kanji)
("" "TN" "Eb^Gm TN" "Eb^Gm TN" jp-kanji)
("" "\[" "C^m \[" "C^m \[" jp-kanji)
("" "nN" "~NnNm nN" "~NnNm nN" jp-kanji)
("" "[" "XXm [" "XXm [" jp-kanji)
("" "c" "IrGm c" "IrGm c" jp-kanji)
("" "J" "uTJm J" "uTJm J" jp-kanji)
("" "R[" "iQNm R[" "iQNm R[" jp-kanji)
("" "T" "~Wm L[W" "~Wm L[W" jp-kanji)
("" "U" "nWm CW" "nWm CW" jp-kanji)
("" "U" "ULm U" "ULm U" jp-kanji)
("" "V[" "XXm V[" "XXm V[" jp-kanji)
("" "V[" "I\m V[" "I\m V[" jp-kanji)
("" "V[" "Vxj LY" "Vxj LY" jp-kanji)
("" "][" "^VJm ][" "^VJm ][" jp-kanji)
("" "^" "EGm ^" "EGm ^" jp-kanji)
("" "h[" "h[RNm h[" "h[RNm h[" jp-kanji)
("" "gN" "PKm gN" "PKm gN" jp-kanji)
("" "q[" "bVxj q[" "bVxj q[" jp-kanji)
("" "[" "mECm [" "mECm [" jp-kanji)
("" "L" "Ruj RR" "Ruj RR" jp-kanji)
("" "M" "VoNm M" "VoNm M" jp-kanji)
("" "PC" "CR[m ]NW" "CR[m ]NW" jp-kanji)
("" "PC" "ARKm PC" "ARKm PC" jp-kanji)
("" "V[" "cm V[" "cm V[" jp-kanji)
("" "^" "noJm ^" "noJm ^" jp-kanji)
("" "nC" "cJm nC" "cJm nC" jp-kanji)
("" "q[" "cNm q[" "cNm q[" jp-kanji)
("" "r" "Am r" "Am r" jp-kanji)
("" "u" "KbJXm u" "KbJXm u" jp-kanji)
("" "GL" "Rrm GL" "Rrm GL" jp-kanji)
("" "I[" "}km I[" "}km I[" jp-kanji)
("" "I[" "PCI[m I[" "PCI[m I[" jp-kanji)
("" "JC" "JCm L[W" "JCm L[W" jp-kanji)
("" "JC" "IR^m JC" "IR^m JC" jp-kanji)
("" "L" "cgm L" "cgm L" jp-kanji)
("" "\[" "bVxj \[" "bVxj \[" jp-kanji)
("" "^" "Vxj ^" "Vxj ^" jp-kanji)
("" "{[" "cgm {[" "cgm {[" jp-kanji)
("" "" "JJm " "JJm " jp-kanji)
("" "" "I\m " "I\m " jp-kanji)
("" "_" "INr[m _" "INr[m _" jp-kanji)
("" "}" "_Gm " "_Gm " jp-kanji)
("" "" "IR^m " "IR^m " jp-kanji)
("" "U" "NCm L[W" "NCm L[W" jp-kanji)
("" "U" "NCm U" "NCm U" jp-kanji)
("" "C" "CgNm C" "CgNm C" jp-kanji)
("" "J" "Rum J" "Rum J" jp-kanji)
("" "N" "N[m N" "N[m N" jp-kanji)
("" "V[" "I\m V[" "I\m V[" jp-kanji)
("" "" "RCm L[W" "RCm L[W" jp-kanji)
("" "J" "Jm zR" "Jm zR" jp-kanji)
("" "Gc" "}TJm Gc" "}TJm Gc" jp-kanji)
("" "W" "}m W" "}m W" jp-kanji)
("" "Wc" "W[jVm Ck" "W[jVm Ck" jp-kanji)
("" "T" "\RiEm T" "\RiEm T" jp-kanji)
("" "Jc" "RXm Jc" "RXm Jc" jp-kanji)
("@" "Jc" "Jcm ]NW" "Jcm ]NW" jp-kanji)
("A" "J" "RXm J" "RXm J" jp-kanji)
("B" "Zc" "Zc[m Zc" "Zc[m Zc" jp-kanji)
("C" "N" "TcNm N" "TcNm N" jp-kanji)
("D" "Z" "^^JEm L[W" "^^JEm L[W" jp-kanji)
("E" "M" "^m L[W" "^m L[W" jp-kanji)
("F" "^N" "TXm ^N" "TXm ^N" jp-kanji)
("G" "w" "wg[m w" "wg[m w" jp-kanji)
("H" "Tc" "ewj co" "ewj co" jp-kanji)
("I" "J" "tZOm J" "tZOm J" jp-kanji)
("J" "R[" "^^Nm R[" "^^Nm R[" jp-kanji)
("K" "R[" "AQm R[" "AQm R[" jp-kanji)
("L" "T" "Xm T" "Xm T" jp-kanji)
("M" "W" "RNWm Te" "RNWm Te" jp-kanji)
("N" "N" "NTcm N" "NTcm N" jp-kanji)
("O" "L[" "ewj I[" "ewj I[" jp-kanji)
("P" "Pc" "GOm Pc" "GOm Pc" jp-kanji)
("Q" "\[" "TKXm \[" "TKXm \[" jp-kanji)
("R" "W" "WW[m W" "WW[m W" jp-kanji)
("S" "\[" "c}m \[" "c}m \[" jp-kanji)
("T" "g" "g\[m g" "g\[m g" jp-kanji)
("U" "oc" "kNm L[W" "kNm L[W" jp-kanji)
("V" "x" "Ecm x" "Ecm x" jp-kanji)
("W" "z[" "z[hm z[" "z[hm z[" jp-kanji)
("X" "[" "Xlm [" "Xlm [" jp-kanji)
("Y" "J" "cOm J" "cOm J" jp-kanji)
("Z" "V" "ewj [X" "ewj [X" jp-kanji)
("[" "_" "gGm _" "gGm _" jp-kanji)
("\" "_" "_zXm _" "_zXm _" jp-kanji)
("]" "^N" "qNm ^N" "qNm ^N" jp-kanji)
("^" "^" "jiEm L[W" "jiEm L[W" jp-kanji)
("_" "f" "qm f" "qm f" jp-kanji)
("`" "nC" "IKm L[W" "IKm L[W" jp-kanji)
("a" "n" "JNnm n" "JNnm n" jp-kanji)
("b" "t" "ifm t" "ifm t" jp-kanji)
("c" "tc" "nEm L[W" "nEm L[W" jp-kanji)
("d" "{" "Irm {" "Irm {" jp-kanji)
("e" "z[" "iQXem z[" "iQXem z[" jp-kanji)
("f" "" "`Xm " "`Xm " jp-kanji)
("g" "JN" "Ecm JN" "Ecm JN" jp-kanji)
("h" "Lc" "nAEm Lc" "nAEm Lc" jp-kanji)
("i" "L[" "R}lNm L[" "R}lNm L[" jp-kanji)
("j" "E" "ewj n" "ewj n" jp-kanji)
("k" "PC" "JPm PC" "JPm PC" jp-kanji)
("l" "Pc" "qbTQm Pc" "qbTQm Pc" jp-kanji)
("m" "W[" "^XPm W[" "^XPm W[" jp-kanji)
("n" "\" "VcGm \" "VcGm \" jp-kanji)
("o" "G" "GLm G" "GLm G" jp-kanji)
("p" "L[" "nTm L[" "nTm L[" jp-kanji)
("q" "J" "tZOm J" "tZOm J" jp-kanji)
("r" "\[" "TKXm L[W" "TKXm L[W" jp-kanji)
("s" "lc" "lc][m lc" "lc][m lc" jp-kanji)
("t" "GL" "^XPm GL" "^XPm GL" jp-kanji)
("u" "L" "ewj YVC" "ewj YVC" jp-kanji)
("v" "L" "AQm L" "AQm L" jp-kanji)
("w" "V" "ewj g" "ewj g" jp-kanji)
("x" "XC" "` Ecm XC" "` Ecm XC" jp-kanji)
("y" "ZC" "qNm ZC" "qNm ZC" jp-kanji)
("z" "g[" "Xm X" "Xm X" jp-kanji)
("{" "g[" "tm g[" "tm g[" jp-kanji)
("|" "eC" "ILem eC" "ILem eC" jp-kanji)
("}" "C" "ewj Cm `" "ewj Cm `" jp-kanji)
("~" "" "qm " "qm " jp-kanji)
("" "c" "lWm c" "lWm c" jp-kanji)
("" "G" "G]Nm G" "G]Nm G" jp-kanji)
("" "JC" "JCVm JC" "JCVm JC" jp-kanji)
("" "J" "Gum J" "Gum J" jp-kanji)
("" "L" "qNV[ CbLm L" "qNV[ CbLm L" jp-kanji)
("" "V" "nJm V" "nJm V" jp-kanji)
("" "W[" "m W[" "m W[" jp-kanji)
("" "\[" "TXm L[W" "TXm L[W" jp-kanji)
("" "" "JJEm " "JJEm " jp-kanji)
("" "" "JJEm " "JJEm " jp-kanji)
("" "[" "m L[W" "m L[W" jp-kanji)
("" "P" "gm P" "gm P" jp-kanji)
("" "R[" "J}Gm R[" "J}Gm R[" jp-kanji)
("" "T" "ewj T" "ewj T" jp-kanji)
("" "WN" "Jm WN" "Jm WN" jp-kanji)
("" "\[" "ewj N" "ewj N" jp-kanji)
("" "Zc" "ITm L[W" "ITm L[W" jp-kanji)
("" "g[" "ewj V}" "ewj V}" jp-kanji)
("" "g[" "Xm g[" "Xm g[" jp-kanji)
("" "nN" "Ecm nN" "Ecm nN" jp-kanji)
("" "TC" "N_Nm TC" "N_Nm TC" jp-kanji)
("" "V" "gm V" "gm V" jp-kanji)
("" "^" "Ecm ^" "Ecm ^" jp-kanji)
("" "R[" "NNm R[" "NNm R[" jp-kanji)
("" "JN" "~_Xm L[W" "~_Xm L[W" jp-kanji)
("" "ZC" "ewj V" "ewj V" jp-kanji)
("" "h[" "^m h[" "^m h[" jp-kanji)
("" "nc" "o`m nc" "o`m nc" jp-kanji)
("" "[" "~_m [" "~_m [" jp-kanji)
("" "[" "gm [" "gm [" jp-kanji)
("" "J" "ESJXm J" "ESJXm J" jp-kanji)
("" "L" "m L[W" "m L[W" jp-kanji)
("" "L" "gRm L" "gRm L" jp-kanji)
("" "Z" "zVC}}m Z" "zVC}}m Z" jp-kanji)
("" "^N" "Gum L[W" "Gum L[W" jp-kanji)
("" "^c" "` Ecm ^c" "` Ecm ^c" jp-kanji)
("" "nN" "cUNm nN" "cUNm nN" jp-kanji)
("" "C" "ewj J~i" "ewj J~i" jp-kanji)
("" "JN" "tf INm IN" "tf INm IN" jp-kanji)
("" "L" "AQm L[W" "AQm L[W" jp-kanji)
("" "L" "AQm CW" "AQm CW" jp-kanji)
("" "ZC" "IXm ZC" "IXm ZC" jp-kanji)
("" "^C" "^Qm L[W" "^Qm L[W" jp-kanji)
("" "^C" "^Qm _C" "^Qm _C" jp-kanji)
("" "g[" "Ecm g[" "Ecm g[" jp-kanji)
("" "q" "V]Pm q" "V]Pm q" jp-kanji)
("" "" "gm " "gm " jp-kanji)
("" "Z" "^_Xm Z" "^_Xm Z" jp-kanji)
("" "JN" "qQm L[W" "qQm L[W" jp-kanji)
("" "eL" "eL_m eL" "eL_m eL" jp-kanji)
("" "nC" "qNm nC" "qNm nC" jp-kanji)
("" "n" "Wm{m n" "Wm{m n" jp-kanji)
("" "N" "Ecm N" "Ecm N" jp-kanji)
("" "W[" "W[Cm W[" "W[Cm W[" jp-kanji)
("" "PC" "^YTGm L[W" "^YTGm L[W" jp-kanji)
("" "T" "Ac}m T" "Ac}m T" jp-kanji)
("" "^" "qNm ^" "qNm ^" jp-kanji)
("" "" "qLcm " "qLcm " jp-kanji)
("" "JN" "cJm JN" "cJm JN" jp-kanji)
("" "{N" "g}^m {N" "g}^m {N" jp-kanji)
("" "{N" "mum {N" "mum {N" jp-kanji)
("" "R[" "JKGm RW" "JKGm RW" jp-kanji)
("" "V[" "ITm L[W" "ITm L[W" jp-kanji)
("" "[" "gRm [" "gRm [" jp-kanji)
("" "e" "^jm u" "^jm u" jp-kanji)
("" "R[" "LNm L[W" "LNm L[W" jp-kanji)
("" "S[" "A\um S[" "A\um S[" jp-kanji)
("" "`N" "C}Vm L[W" "C}Vm L[W" jp-kanji)
("" "W" "mxm ZCW" "mxm ZCW" jp-kanji)
("" "W" "mxm L[W" "mxm L[W" jp-kanji)
("" "V[" "qPm V[" "qPm V[" jp-kanji)
("" "wC" "um wC" "um wC" jp-kanji)
("" "R[" "XCR[m R[" "XCR[m R[" jp-kanji)
("" "X[" "JYm L[W" "JYm L[W" jp-kanji)
("" "" "ITm " "ITm " jp-kanji)
("" "wC" "^Im wC" "^Im wC" jp-kanji)
("" "w" "Jm L[W" "Jm L[W" jp-kanji)
("" "RN" "}Xm RN" "}Xm RN" jp-kanji)
("" "V" "Nm V" "Nm V" jp-kanji)
("" "VN" "Lm VN" "Lm VN" jp-kanji)
("" "_" "^cm L[W" "^cm L[W" jp-kanji)
("" "Z" "Z_m Z" "Z_m Z" jp-kanji)
("" "nC" "n^m nC" "n^m nC" jp-kanji)
("" "z[" "cNm z[" "cNm z[" jp-kanji)
("" "{[" "{[M[m {[" "{[M[m {[" jp-kanji)
("" "ZC" "n^m ZC" "n^m ZC" jp-kanji)
("" "[" "iKm [" "iKm [" jp-kanji)
("" "n" "nm ]NW" "nm ]NW" jp-kanji)
("" "n" "n^m n" "n^m n" jp-kanji)
("" "" "iCm RW" "iCm RW" jp-kanji)
("" "L" "Xfm cN" "Xfm cN" jp-kanji)
("" "J" "qfm J" "qfm J" jp-kanji)
("" "R[" "ALJm R[" "ALJm R[" jp-kanji)
("" "R[" "\m R[" "\m R[" jp-kanji)
("" "\N" "J^Nm \N" "J^Nm \N" jp-kanji)
("" "r" "\m r" "\m r" jp-kanji)
("" "[" "nJm [" "nJm [" jp-kanji)
("" "Wc" "`JdNm Wc" "`JdNm Wc" jp-kanji)
("" "`[" "qTVCm `[" "qTVCm `[" jp-kanji)
("" "{[" "Xom {[" "Xom {[" jp-kanji)
("" "[" "RUgiVm [" "RUgiVm [" jp-kanji)
("" "A" "AY~mm AY" "AY~mm AY" jp-kanji)
("" "R[" "qJm L[W" "qJm L[W" jp-kanji)
("" "V" "XXm ZCW" "XXm ZCW" jp-kanji)
("" "`[" "ZCm qgc" "ZCm qgc" jp-kanji)
("" "L" "JNm L" "JNm L" jp-kanji)
("" "`[" "qm L[W" "qm L[W" jp-kanji)
("" "S" "qwj " "qwj " jp-kanji)
("" "R[" "qwj cQ" "qwj cQ" jp-kanji)
("" "V" "AV^m V" "AV^m V" jp-kanji)
("" "ZC" "ALJm ZC" "ALJm ZC" jp-kanji)
("" "ZL" "ALJm ZL" "ALJm ZL" jp-kanji)
("" "ZL" "CZLm ZL" "CZLm ZL" jp-kanji)
("" "q" "qj AY" "qj AY" jp-kanji)
("" "E" "JTm E" "JTm E" jp-kanji)
("" "GC" "qwj GC" "qwj GC" jp-kanji)
("" "L" "JKNm L" "JKNm L" jp-kanji)
("" "P" "A^^Jm P" "A^^Jm P" jp-kanji)
("" "[" "qmfm [" "qmfm [" jp-kanji)
("" "C" "~m C" "~m C" jp-kanji)
("" "L" "Irm L" "Irm L" jp-kanji)
("" "Z" "XXm Z" "XXm Z" jp-kanji)
("" "M[" "AJcLm L[W" "AJcLm L[W" jp-kanji)
("" "g" "qwj g" "qwj g" jp-kanji)
("" "xc" "C`xcm xc" "C`xcm xc" jp-kanji)
("@" "[" "JKNm [" "JKNm [" jp-kanji)
("A" "[" "ALJm CW" "ALJm CW" jp-kanji)
("B" "AC" "AC}Cm AC" "AC}Cm AC" jp-kanji)
("C" "[" "[}Cm [" "[}Cm [" jp-kanji)
("D" "R[" "R[hm R[" "R[hm R[" jp-kanji)
("E" "R[" "R[m NW" "R[m NW" jp-kanji)
("F" "M" "^C[m M" "^C[m M" jp-kanji)
("G" "m[" "TLjm m[" "TLjm m[" jp-kanji)
("H" "Gc" "CNm Gc" "CNm Gc" jp-kanji)
("I" "GC" "qNm ]NW" "qNm ]NW" jp-kanji)
("J" "Jc" "CYN]m Jc" "CYN]m Jc" jp-kanji)
("K" "q" "~JdLm q" "~JdLm q" jp-kanji)
("L" "[" "zKJm L[W" "zKJm L[W" jp-kanji)
("M" "L" "Sm L[W" "Sm L[W" jp-kanji)
("N" "[" "I{m [" "I{m [" jp-kanji)
("O" "[" "[[m [" "[[m [" jp-kanji)
("P" "n" "n^KVm L[W" "n^KVm L[W" jp-kanji)
("Q" "Wc" "EPm Wc" "EPm Wc" jp-kanji)
("R" "V" "gQm V" "gQm V" jp-kanji)
("S" "_" "ESJXm _" "ESJXm _" jp-kanji)
("T" "j[" "Lwj nC" "Lwj nC" jp-kanji)
("U" "N" "Lwj `J" "Lwj `J" jp-kanji)
("V" "g[" "Lwj J^i" "Lwj J^i" jp-kanji)
("W" "J" "eRm J" "eRm J" jp-kanji)
("X" "L" "L[m L" "L[m L" jp-kanji)
("Y" "R[" "nVm R[" "nVm R[" jp-kanji)
("Z" "N" "NCm N" "NCm N" jp-kanji)
("[" "T" "Lwj }" "Lwj }" jp-kanji)
("\" "}" "Lm g`m CW" "Lm g`m CW" jp-kanji)
("]" "I[" "Lwj I[" "Lwj I[" jp-kanji)
("^" "Pc" "Pcm ]NW" "Pcm ]NW" jp-kanji)
("_" "V[" "Lm }cm CW" "Lm }cm CW" jp-kanji)
("`" "`" "NkMm ~" "NkMm ~" jp-kanji)
("a" "r[" "RYGm r[" "RYGm r[" jp-kanji)
("b" "t" "Lwj P" "Lwj P" jp-kanji)
("c" "z[" "Lwj z[" "Lwj z[" jp-kanji)
("d" "" "Lwj g" "Lwj g" jp-kanji)
("e" "V[" "Lwj }X" "Lwj }X" jp-kanji)
("f" "PC" "Lwj PC" "Lwj PC" jp-kanji)
("g" "J" "JVm J" "JVm J" jp-kanji)
("h" "J" "G_m J" "G_m J" jp-kanji)
("i" "JC" "cGm JC" "cGm JC" jp-kanji)
("j" "J" "Gum J" "Gum J" jp-kanji)
("k" "L" "Lm J^`" "Lm J^`" jp-kanji)
("l" "L[" "qcMm L[" "qcMm L[" jp-kanji)
("m" "N" "Lm P{iV" "Lm P{iV" jp-kanji)
("n" "T" "Lm R{P" "Lm R{P" jp-kanji)
("o" "TN" "Lm TN" "Lm TN" jp-kanji)
("p" "^N" "q[VMm ^N" "q[VMm ^N" jp-kanji)
("q" "eC" "lm eC" "lm eC" jp-kanji)
("r" "gc" "Lwj f" "Lwj f" jp-kanji)
("s" "zI" "Lm z" "Lm z" jp-kanji)
("t" "t" "Lwj cN" "Lwj cN" jp-kanji)
("u" "[" "Lwj ^c" "Lwj ^c" jp-kanji)
("v" "R" "Lwj E" "Lwj E" jp-kanji)
("w" "JC" "qm Lm L[W" "qm Lm L[W" jp-kanji)
("x" "J" "VIm J" "VIm J" jp-kanji)
("y" "L[" "J}`m L[" "J}`m L[" jp-kanji)
("z" "N" "Lwj n" "Lwj n" jp-kanji)
("{" "Pc" "ncPm Pc" "ncPm Pc" jp-kanji)
("|" "R" "Lwj nJ}" "Lwj nJ}" jp-kanji)
("}" "R[" "Lwj R[" "Lwj R[" jp-kanji)
("~" "Vc" "Lwj C^" "Lwj C^" jp-kanji)
("" "\" "NVm \" "NVm \" jp-kanji)
("" "Z" "Lwj \" "Lwj \" jp-kanji)
("" "{[" "zRm {[" "zRm {[" jp-kanji)
("" "g[" "Lwj A^" "Lwj A^" jp-kanji)
("" "JN" "^Lm JN" "^Lm JN" jp-kanji)
("" "J" "Lm J" "Lm J" jp-kanji)
("" "L[" "gm tN[" "gm tN[" jp-kanji)
("" "RN" "Lwj cQ" "Lwj cQ" jp-kanji)
("" "T" "qm T" "qm T" jp-kanji)
("" "V" "Lm N`iV" "Lm N`iV" jp-kanji)
("" "W[" "W[m L[W" "W[m L[W" jp-kanji)
("" "_" "Lm iM" "Lm iM" jp-kanji)
("" "eC" "eRm e" "eRm e" jp-kanji)
("" "g[" "LJum L[W" "LJum L[W" jp-kanji)
("" "r" "Lwj wC" "Lwj wC" jp-kanji)
("" "t" "CJ_m t" "CJ_m t" jp-kanji)
("" "{" "{m[m {" "{m[m {" jp-kanji)
("" "" "Lwj " "Lwj " jp-kanji)
("" "" "nVj V^" "nVj V^" jp-kanji)
("" "A" "Lwj A" "Lwj A" jp-kanji)
("" "G" "J}m Gm AE" "J}m Gm AE" jp-kanji)
("" "N" "Lwj L~" "Lwj L~" jp-kanji)
("" "JN" "qcMm JN" "qcMm JN" jp-kanji)
("" "L" "V[Mm CW" "V[Mm CW" jp-kanji)
("" "LN" "Lwj LN" "Lwj LN" jp-kanji)
("" "LN" "gQm LN" "gQm LN" jp-kanji)
("" "JN" "Lwj Nj" "Lwj Nj" jp-kanji)
("" "P" "Lwj P" "Lwj P" jp-kanji)
("" "R[" "Lwj IJ" "Lwj IJ" jp-kanji)
("" "R[" "Lwj \" "Lwj \" jp-kanji)
("" "R" "R{[m R" "R{[m R" jp-kanji)
("" "R" "Lwj R" "Lwj R" jp-kanji)
("" "T" "ToVm T" "ToVm T" jp-kanji)
("" "V" "Vm V" "Vm V" jp-kanji)
("" "V" "Vm CW" "Vm CW" jp-kanji)
("" "V[" "RV[m V[" "RV[m V[" jp-kanji)
("" "Zc" "cOm Zc" "cOm Zc" jp-kanji)
("" "\[" "Lm ic" "Lm ic" jp-kanji)
("" "eC" "jEm eC" "jEm eC" jp-kanji)
("" "`" "Lwj V" "Lwj V" jp-kanji)
("" "g[" "TIm g[" "TIm g[" jp-kanji)
("" "g[" "Lm }iV" "Lm }iV" jp-kanji)
("" "j" "Lwj l" "Lwj l" jp-kanji)
("" "g[" "Lwj t" "Lwj t" jp-kanji)
("" "wC" "Lwj iu" "Lwj iu" jp-kanji)
("" "L[" "Lm NkM" "Lm NkM" jp-kanji)
("" "e" "Lwj e" "Lwj e" jp-kanji)
("" "g[" "Lwj C^" "Lwj C^" jp-kanji)
("" "" "NXm Lm ^OC" "NXm Lm ^OC" jp-kanji)
("" "GC" "nVm GC" "nVm GC" jp-kanji)
("" "JC" "JCVm JC" "JCVm JC" jp-kanji)
("" "R" "Lwj R" "Lwj R" jp-kanji)
("" "V[" "Lwj AL" "Lwj AL" jp-kanji)
("" "V[" "JWm V[" "JWm V[" jp-kanji)
("" "Zc" "NTrm Zc" "NTrm Zc" jp-kanji)
("" "Z" "Lwj CY~" "Lwj CY~" jp-kanji)
("" "`" "Lm R[]" "Lm R[]" jp-kanji)
("" "W" "Lm T" "Lm T" jp-kanji)
("" "eC" "Lwj eC" "Lwj eC" jp-kanji)
("" "e" "^Lm e" "^Lm e" jp-kanji)
("" "{[" "TJGm {[" "TJGm {[" jp-kanji)
("" "" "Vm ~m " "Vm ~m " jp-kanji)
("" "" "Lm j" "Lm j" jp-kanji)
("" "K" "[Km K" "[Km K" jp-kanji)
("" "" "Lm I[`" "Lm I[`" jp-kanji)
("" "Vc" "Lwj Vc" "Lwj Vc" jp-kanji)
("" "[" "Lwj n" "Lwj n" jp-kanji)
("" "I" "Lwj I" "Lwj I" jp-kanji)
("" "GC" "TJGm L[W" "TJGm L[W" jp-kanji)
("" "JC" "Lm ViGW" "Lm ViGW" jp-kanji)
("" "KC" "nm Lm KC" "nm Lm KC" jp-kanji)
("" "R[" "Lwj ^JC" "Lwj ^JC" jp-kanji)
("" "R[" "R[Jm R[" "R[Jm R[" jp-kanji)
("" "Rc" "Lwj zl" "Lwj zl" jp-kanji)
("" "T" "Lwj T" "Lwj T" jp-kanji)
("" "TC" "gfm TC" "gfm TC" jp-kanji)
("" "TN" "zRm TN" "zRm TN" jp-kanji)
("" "g[" "Lwj V}" "Lwj V}" jp-kanji)
("" "g[" "RVJPm g[" "RVJPm g[" jp-kanji)
("" "n" "^Cm n" "^Cm n" jp-kanji)
("" "q" "Lm J" "Lm J" jp-kanji)
("" "G" "Lj P" "Lj P" jp-kanji)
("" "t" "Nm t" "Nm t" jp-kanji)
("" "xC" "Lwj C" "Lwj C" jp-kanji)
("" "{[" "t_m {[" "t_m {[" jp-kanji)
("" "[" "Lwj [" "Lwj [" jp-kanji)
("" "[" "Lm UN" "Lm UN" jp-kanji)
("" "[" "Lwj ^c" "Lwj ^c" jp-kanji)
("" "JN" "qcMm JN" "qcMm JN" jp-kanji)
("" "N" "^mVCm L[W" "^mVCm L[W" jp-kanji)
("" "L[" "}Km L[" "}Km L[" jp-kanji)
("" "L" "Lm NQ" "Lm NQ" jp-kanji)
("" "P" "Pm L[W" "Pm L[W" jp-kanji)
("" "R[" "Lwj R[" "Lwj R[" jp-kanji)
("" "RN" "Lm JV" "Lm JV" jp-kanji)
("" "[" "t_m [" "t_m [" jp-kanji)
("" "V[" "Lm ~" "Lm ~" jp-kanji)
("" "XC" "Lwj IgG" "Lwj IgG" jp-kanji)
("" "X[" "Jim L[W" "Jim L[W" jp-kanji)
("" "VN" "JGfm ^OC" "JGfm ^OC" jp-kanji)
("" "\[" "Lwj X" "Lwj X" jp-kanji)
("" "^" "qcMVm ^" "qcMVm ^" jp-kanji)
("" "n" "gJSm n" "gJSm n" jp-kanji)
("" "~c" "Lwj ~c" "Lwj ~c" jp-kanji)
("" "~c" "~cm CW" "~cm CW" jp-kanji)
("" "[" "T}m L[W" "T}m L[W" jp-kanji)
("" "[" "Om L[W" "Om L[W" jp-kanji)
("" "J" "Lwj J" "Lwj J" jp-kanji)
("" "J" "Lwj ckN" "Lwj ckN" jp-kanji)
("" "L" "Lwj Ru" "Lwj Ru" jp-kanji)
("" "TC" "Lwj TC" "Lwj TC" jp-kanji)
("" "V[" "Lwj V[" "Lwj V[" jp-kanji)
("" "[C" "\m [C" "\m [C" jp-kanji)
("" "_" "_Gm L[W" "_Gm L[W" jp-kanji)
("" "g[" "_C_Cm g[" "_C_Cm g[" jp-kanji)
("" "h[" "Lwj h[" "Lwj h[" jp-kanji)
("" "h[" "^m h[" "^m h[" jp-kanji)
("" "{N" "Lwj {N" "Lwj {N" jp-kanji)
("" "`[" "Lwj g" "Lwj g" jp-kanji)
("" "G" "qTVm G" "qTVm G" jp-kanji)
("" "IN" "Lm `" "Lm `" jp-kanji)
("" "PC" "gVrm PC" "gVrm PC" jp-kanji)
("" "QL" "QLum QL" "QLum QL" jp-kanji)
("" "P" "Vxm L[W" "Vxm L[W" jp-kanji)
("" "V[" "zoVm V[" "zoVm V[" jp-kanji)
("@" "nN" "Ln_m nN" "Ln_m nN" jp-kanji)
("A" "nN" "nNm CW" "nNm CW" jp-kanji)
("B" "J" "Im J" "Im J" jp-kanji)
("C" "L" "qcm L" "qcm L" jp-kanji)
("D" "g[" "Lm JC" "Lm JC" jp-kanji)
("E" "C" "m " "m " jp-kanji)
("F" "r" "r[Wm r" "r[Wm r" jp-kanji)
("G" "[" "m " "m " jp-kanji)
("H" "G" "Lwj G" "Lwj G" jp-kanji)
("I" "C" "^m C" "^m C" jp-kanji)
("J" "L" "Lm NkM" "Lm NkM" jp-kanji)
("K" "L" "Lm CW" "Lm CW" jp-kanji)
("L" "" "Vm " "Vm " jp-kanji)
("M" "L" "Lwj L" "Lwj L" jp-kanji)
("N" "I[" "TNm L[W" "TNm L[W" jp-kanji)
("O" "L" "Lm PL" "Lm PL" jp-kanji)
("P" "nN" "nNm CW" "nNm CW" jp-kanji)
("Q" "C" "Wm C" "Wm C" jp-kanji)
("R" "" "_m " "_m " jp-kanji)
("S" "" "Lwj " "Lwj " jp-kanji)
("T" "Ec" "VQm L[W" "VQm L[W" jp-kanji)
("U" "cL" "Lm cL" "Lm cL" jp-kanji)
("V" "AC" "iQNm AC" "iQNm AC" jp-kanji)
("W" "L" "XXiNm L" "XXiNm L" jp-kanji)
("X" "g[" "kXm L[W" "kXm L[W" jp-kanji)
("Y" "C" "\o_em C" "\o_em C" jp-kanji)
("Z" "C" "mm L[W" "mm L[W" jp-kanji)
("[" "Pc" "Xm Pc" "Xm Pc" jp-kanji)
("\" "\[" "XXm \[" "XXm \[" jp-kanji)
("]" "P" "AL^iC" "AL^iC" jp-kanji)
("^" "I[" "nNm L[W" "nNm L[W" jp-kanji)
("_" "L[" "Ac}m L[" "Ac}m L[" jp-kanji)
("`" "L" "XXiNm L" "XXiNm L" jp-kanji)
("a" "J" "m]m J" "m]m J" jp-kanji)
("b" "" "Jm " "Jm " jp-kanji)
("c" "J" "Rum L[W" "Rum L[W" jp-kanji)
("d" "L" "JGm L[W" "JGm L[W" jp-kanji)
("e" "Kc" "Vkm Kc" "Vkm Kc" jp-kanji)
("f" "{c" "iNim {c" "iNim {c" jp-kanji)
("g" "[" "JWjm [" "JWjm [" jp-kanji)
("h" "e" "cNXm e" "cNXm e" jp-kanji)
("i" "[" "UCm [" "UCm [" jp-kanji)
("j" "q[" "C`^wj t" "C`^wj t" jp-kanji)
("k" "U" "mRm L[W" "mRm L[W" jp-kanji)
("l" "t[" "NTm t[" "NTm t[" jp-kanji)
("m" "C" "I`m C" "I`m C" jp-kanji)
("n" "V[" "JWjm V[" "JWjm V[" jp-kanji)
("o" "GC" "^IXm GC" "^IXm GC" jp-kanji)
("p" "^" "cNXm ^" "cNXm ^" jp-kanji)
("q" "q" "qL[m q" "qL[m q" jp-kanji)
("r" "Z" "Zm ZCW" "Zm ZCW" jp-kanji)
("s" "Z" "z{Xm Z" "z{Xm Z" jp-kanji)
("t" "V" "}^m V" "}^m V" jp-kanji)
("u" "C" "Cm Njm C" "Cm Njm C" jp-kanji)
("v" "RN" "Jm L[W" "Jm L[W" jp-kanji)
("w" "I[" "iOm L[W" "iOm L[W" jp-kanji)
("x" "u" "iKm u" "iKm u" jp-kanji)
("y" "CN" "\_cm CN" "\_cm CN" jp-kanji)
("z" "Z" "P kNm V" "P kNm V" jp-kanji)
("{" "L[" "}m L[" "}m L[" jp-kanji)
("|" "S[" "tfm TLm S[" "tfm TLm S[" jp-kanji)
("}" "[C" "jRQm [C" "jRQm [C" jp-kanji)
("~" "^" "PImm ^" "PImm ^" jp-kanji)
("" "L" "LJm L" "LJm L" jp-kanji)
("" "Z" "[Zm Z" "[Zm Z" jp-kanji)
("" "{[" "\[{[m {[" "\[{[m {[" jp-kanji)
("" "L" "LK}Gm L" "LK}Gm L" jp-kanji)
("" "t" "UCm t" "UCm t" jp-kanji)
("" "C" "CR[m C" "CR[m C" jp-kanji)
("" "L" "CLm L[W" "CLm L[W" jp-kanji)
("" "R[" "XCMm R[" "XCMm R[" jp-kanji)
("" "T" "TYCj }" "TYCj }" jp-kanji)
("" "g" "TYCj c`" "TYCj c`" jp-kanji)
("" "I[" "TYCj I[" "TYCj I[" jp-kanji)
("" "L" "t`m L" "t`m L" jp-kanji)
("" "S" "TYCj S" "TYCj S" jp-kanji)
("" "V" "iMTm V" "iMTm V" jp-kanji)
("" "V" "V~m V" "V~m V" jp-kanji)
("" "nC" "TYCj C`" "TYCj C`" jp-kanji)
("" "t" "TYCj P" "TYCj P" jp-kanji)
("" "xL" "TYCj q" "TYCj q" jp-kanji)
("" "w" "TYCj n" "TYCj n" jp-kanji)
("" "{c" "{cm CW" "{cm CW" jp-kanji)
("" "N" "NNm N" "NNm N" jp-kanji)
("" "Zc" "nCZcm Zc" "nCZcm Zc" jp-kanji)
("" "I[" "TYCj I[" "TYCj I[" jp-kanji)
("" "I[" "~Y^}m I[" "~Y^}m I[" jp-kanji)
("" "R" "RPm R" "RPm R" jp-kanji)
("" "V" "TYCj " "TYCj " jp-kanji)
("" "V[" "TYCj V[" "TYCj V[" jp-kanji)
("" "\" "TJm{m \" "TJm{m \" jp-kanji)
("" "V" "nom V" "nom V" jp-kanji)
("" "_" "CPm _" "CPm _" jp-kanji)
("" "e" "EIEm e" "EIEm e" jp-kanji)
("" "e" "TYCj ^" "TYCj ^" jp-kanji)
("" "{[" "TYCj {[" "TYCj {[" jp-kanji)
("" "~" "zrm ~" "zrm ~" jp-kanji)
("" "z[" "TYCj ^C" "TYCj ^C" jp-kanji)
("" "C" "i~_m CW" "i~_m CW" jp-kanji)
("" "C" "ni~Ym C" "ni~Ym C" jp-kanji)
("" "G" "tGm G" "tGm G" jp-kanji)
("" "L[" "Nm L[" "Nm L[" jp-kanji)
("" "LN" "~]m LN" "~]m LN" jp-kanji)
("" "R[" "A}lNm R[" "A}lNm R[" jp-kanji)
("" "R[" "TYCj qJ" "TYCj qJ" jp-kanji)
("" "V" "TYCj V" "TYCj V" jp-kanji)
("" "W" "}Rgm W" "}Rgm W" jp-kanji)
("" "W" "TYCj m" "TYCj m" jp-kanji)
("" "V" "Vm V" "Vm V" jp-kanji)
("" "c" "TYCj c" "TYCj c" jp-kanji)
("" "J" "J`[m J" "J`[m J" jp-kanji)
("" "P" "PWm P" "PWm P" jp-kanji)
("" "R[" "TYCj qV" "TYCj qV" jp-kanji)
("" "V" "TEm V" "TEm V" jp-kanji)
("" "V[" "A}lVm V[" "A}lVm V[" jp-kanji)
("" "Zc" "TYCj I" "TYCj I" jp-kanji)
("" "Z" "_m G" "_m G" jp-kanji)
("" "eC" "i~_m eC" "i~_m eC" jp-kanji)
("" "g[" "i~m L[W" "i~m L[W" jp-kanji)
("" "l" "lnm l" "lnm l" jp-kanji)
("" "G" "Cm G" "Cm G" jp-kanji)
("" "G" "t`m CW" "t`m CW" jp-kanji)
("" "G" "t`m L[W" "t`m L[W" jp-kanji)
("" "J" "q^Xm J" "q^Xm J" jp-kanji)
("" "L" "LXCm L" "LXCm L" jp-kanji)
("" "J" "TYCj L" "TYCj L" jp-kanji)
("" "R" "qAKm R" "qAKm R" jp-kanji)
("" "R[" "}Wm R[" "}Wm R[" jp-kanji)
("" "TC" "TCCm TC" "TCCm TC" jp-kanji)
("" "V[" "TYCj }c" "TYCj }c" jp-kanji)
("" "V[" "IIi~m V[" "IIi~m V[" jp-kanji)
("" "W[" "LCm L[W" "LCm L[W" jp-kanji)
("" "ZC" "XSCm CW" "XSCm CW" jp-kanji)
("" "ZL" "gOm ZL" "gOm ZL" jp-kanji)
("" "Z" "ATCm L[W" "ATCm L[W" jp-kanji)
("" "\[" "\\Om \[" "\\Om \[" jp-kanji)
("" "I" "hm I" "hm I" jp-kanji)
("" "N" "TYCm N" "TYCm N" jp-kanji)
("" "" "VYm " "VYm " jp-kanji)
("" "C" "GiWm G" "GiWm G" jp-kanji)
("" "C" "TYCj C" "TYCj C" jp-kanji)
("" "C" "Ccm C" "Ccm C" jp-kanji)
("" "J" "TYCj J" "TYCj J" jp-kanji)
("" "J" "Jpcm J" "Jpcm J" jp-kanji)
("" "G" "LCm G" "LCm G" jp-kanji)
("" "R[" "TYCj R[" "TYCj R[" jp-kanji)
("" "R" "RVm R" "RVm R" jp-kanji)
("" "T" "JXm T" "JXm T" jp-kanji)
("" "V[" "TYCj AL" "TYCj AL" jp-kanji)
("" "Zc" "TEm Zc" "TEm Zc" jp-kanji)
("" "Z" "TYCj CY~" "TYCj CY~" jp-kanji)
("" "^" "nZm ^" "nZm ^" jp-kanji)
("" "eC" "gh}m eC" "gh}m eC" jp-kanji)
("" "nC" "TYCj IK" "TYCj IK" jp-kanji)
("" "r[" "nJm r[" "nJm r[" jp-kanji)
("" "" "TYCj " "TYCj " jp-kanji)
("" "{c" "{bJCm {c" "{bJCm {c" jp-kanji)
("" "}" "~cm L[W" "~cm L[W" jp-kanji)
("" "" "Jm " "Jm " jp-kanji)
("" "[" "IOm [" "IOm [" jp-kanji)
("" "c" "nccm c" "nccm c" jp-kanji)
("" "PC" "^jm L[W" "^jm L[W" jp-kanji)
("" "R[" "^`}`m R[" "^`}`m R[" jp-kanji)
("" "R[" "qCm R[" "qCm R[" jp-kanji)
("" "R" "PKm R" "PKm R" jp-kanji)
("" "V" "JXm V" "JXm V" jp-kanji)
("" "WN" "VAcCm WN" "VAcCm WN" jp-kanji)
("" "\" "TJm{m \" "TJm{m \" jp-kanji)
("" "\[" "\[JCm \[" "\[JCm \[" jp-kanji)
("" "\[" "TYCj \[" "TYCj \[" jp-kanji)
("" "g[" "~iMm g[" "~iMm g[" jp-kanji)
("" "g[" "Njm im g[" "Njm im g[" jp-kanji)
("" "g[" "CPm g[" "CPm g[" jp-kanji)
("" "t" "tem t" "tem t" jp-kanji)
("" "{[" "{[[m {[" "{[[m {[" jp-kanji)
("" "C" "NCm C" "NCm C" jp-kanji)
("" "GC" "mMm GC" "mMm GC" jp-kanji)
("" "KC" "JKCm KC" "JKCm KC" jp-kanji)
("" "J" "JKCm J" "JKCm J" jp-kanji)
("" "R" "VnCm CC" "VnCm CC" jp-kanji)
("" "R" "XCRfm R" "XCRfm R" jp-kanji)
("" "R" "^Mm R" "^Mm R" jp-kanji)
("" "V[" "m~mm V[" "m~mm V[" jp-kanji)
("" "V" "jWm V" "jWm V" jp-kanji)
("" "\[" "XXOm \[" "XXOm \[" jp-kanji)
("" "^C" "^Cm L[W" "^Cm L[W" jp-kanji)
("" "`[" "~iMm `[" "~iMm `[" jp-kanji)
("" "eL" "AEm eL" "AEm eL" jp-kanji)
("@" "[" "^_Em [" "^_Em [" jp-kanji)
("A" "" "V~m " "V~m " jp-kanji)
("B" "" "TYCj n" "TYCj n" jp-kanji)
("C" "M[" "EXCm M[" "EXCm M[" jp-kanji)
("D" "Z" "Z[m Z" "Z[m Z" jp-kanji)
("E" "T" "T[m T" "T[m T" jp-kanji)
("F" "W[" "VuCm CW" "VuCm CW" jp-kanji)
("G" "W[" "VuCm L[W" "VuCm L[W" jp-kanji)
("H" "W" "W[m W" "W[m W" jp-kanji)
("I" "Z" "Om L[W" "Om L[W" jp-kanji)
("J" "Z" "Om CW" "Om CW" jp-kanji)
("K" "^" "tJCm ^" "tJCm ^" jp-kanji)
("L" "`[" "Xm `[" "Xm `[" jp-kanji)
("M" "g[" "TYCj h[" "TYCj h[" jp-kanji)
("N" "n" "V~Ym n" "V~Ym n" jp-kanji)
("O" "z[" "TYCj z[" "TYCj z[" jp-kanji)
("P" "[" "^}m L[W" "^}m L[W" jp-kanji)
("Q" "" "EXCm " "EXCm " jp-kanji)
("R" "[" "^}~Ym [" "^}~Ym [" jp-kanji)
("S" "I[" "TYCj IN" "TYCj IN" jp-kanji)
("T" "J" "TYCj ~L" "TYCj ~L" jp-kanji)
("U" "\[" "AEm \[" "AEm \[" jp-kanji)
("V" "^N" "Tm L[W" "Tm L[W" jp-kanji)
("W" "^" "A^m ^" "A^m ^" jp-kanji)
("X" "t" "TYCj t" "TYCj t" jp-kanji)
("Y" "C" "~IcNVm ~I" "~IcNVm ~I" jp-kanji)
("Z" "TC" "Xm L[W" "Xm L[W" jp-kanji)
("[" "Vc" "Vm L[W" "Vm L[W" jp-kanji)
("\" "V" "TEm V" "TEm V" jp-kanji)
("]" "r" "rCm r" "rCm r" jp-kanji)
("^" "C" "kJ~m C" "kJ~m C" jp-kanji)
("_" "q" "n}m L[W" "n}m L[W" jp-kanji)
("`" "{N" "TYCj {N" "TYCj {N" jp-kanji)
("a" "[" "[}Cm [" "[}Cm [" jp-kanji)
("b" "V" "nNm V" "nNm V" jp-kanji)
("c" "V" "V[m V" "V[m V" jp-kanji)
("d" "Z" "\\Om Z" "\\Om Z" jp-kanji)
("e" "oN" "^Lm oN" "^Lm oN" jp-kanji)
("f" "[" "TYCj [" "TYCj [" jp-kanji)
("g" "[" "zKJm [" "zKJm [" jp-kanji)
("h" "" "RXm " "RXm " jp-kanji)
("i" "GC" "E~m GC" "E~m GC" jp-kanji)
("j" "J" "JJCm J" "JJCm J" jp-kanji)
("k" "`" "TYCj `" "TYCj `" jp-kanji)
("l" "L" "V^^m L" "V^^m L" jp-kanji)
("m" "" "XCm " "XCm " jp-kanji)
("n" "V[" "V[Vm V[" "V[Vm V[" jp-kanji)
("o" "r" "^m r" "^m r" jp-kanji)
("p" "" "i~m " "i~m " jp-kanji)
("q" "" "TYCj " "TYCj " jp-kanji)
("r" "TC" "VNm TC" "VNm TC" jp-kanji)
("s" "" "CGm L[W" "CGm L[W" jp-kanji)
("t" "V" "Aum V" "Aum V" jp-kanji)
("u" "\[" "C^m \[" "C^m \[" jp-kanji)
("v" "PC" "PCKm PC" "PCKm PC" jp-kanji)
("w" "PC" "PCm ]NW" "PCm ]NW" jp-kanji)
("x" "L" "R^cm R" "R^cm R" jp-kanji)
("y" "TN" "TNcm TN" "TNcm TN" jp-kanji)
("z" "wC" "ALJm wC" "ALJm wC" jp-kanji)
("{" "z[" "Aum z[" "Aum z[" jp-kanji)
("|" "G" "Pm CW" "Pm CW" jp-kanji)
("}" "L[" "Xj ce" "Xj ce" jp-kanji)
("~" "W[" "XXm W[" "XXm W[" jp-kanji)
("" "N" "NCm N" "NCm N" jp-kanji)
("" "G" "V[Gm G" "V[Gm G" jp-kanji)
("" "z[" "mVm z[" "mVm z[" jp-kanji)
("" "R" "qwj }W" "qwj }W" jp-kanji)
("" "z[" "Aum z[" "Aum z[" jp-kanji)
("" "J" "Jpcm J" "Jpcm J" jp-kanji)
("" "L" "qJm L" "qJm L" jp-kanji)
("" "L" "Lm CW" "Lm CW" jp-kanji)
("" "N" "A^^Jm N" "A^^Jm N" jp-kanji)
("" "PC" "qgm PC" "qgm PC" jp-kanji)
("" "R[" "JKNm R[" "JKNm R[" jp-kanji)
("" "_" "_m _" "_m _" jp-kanji)
("" "[" "Aum [" "Aum [" jp-kanji)
("" "N" "CuXm N" "CuXm N" jp-kanji)
("" "N" "CuXm CW" "CuXm CW" jp-kanji)
("" "\N" "LGm \N" "LGm \N" jp-kanji)
("" "R[" "qwj ~cO" "qwj ~cO" jp-kanji)
("" "C" "mVm C" "mVm C" jp-kanji)
("" "S[" "Cm S[" "Cm S[" jp-kanji)
("" "J" "A^^m J" "A^^m J" jp-kanji)
("" "L" "JXJim L" "JXJim L" jp-kanji)
("" "V" "TJm V" "TJm V" jp-kanji)
("" "V[" "Nm L[W" "Nm L[W" jp-kanji)
("" "g" "qwm g" "qwm g" jp-kanji)
("" "n" "Nm n" "Nm n" jp-kanji)
("" "[" "JKrm [" "JKrm [" jp-kanji)
("" "I[" "A^^Jm I[" "A^^Jm I[" jp-kanji)
("" "L" "Nm L" "Nm L" jp-kanji)
("" "XC" "qE`m XC" "qE`m XC" jp-kanji)
("" "^c" "R^cm ^c" "R^cm ^c" jp-kanji)
("" "W" "GJXm W" "GJXm W" jp-kanji)
("" "Z" "wCZm Z" "wCZm Z" jp-kanji)
("" "[" "JKNm [" "JKNm [" jp-kanji)
("" "VN" "JKNm VN" "JKNm VN" jp-kanji)
("" "" "Cm L[W" "Cm L[W" jp-kanji)
("" "" "}m " "}m " jp-kanji)
("" "T" "J}hm T" "J}hm T" jp-kanji)
("" "\[" "A\Em L[W" "A\Em L[W" jp-kanji)
("" "n" "n`[Cm n" "n`[Cm n" jp-kanji)
("" "G" "RRjm G" "RRjm G" jp-kanji)
("" "C" "^m L[W" "^m L[W" jp-kanji)
("" "R[" "}Wm R[" "}Wm R[" jp-kanji)
("" "\" "}iC^m \" "}iC^m \" jp-kanji)
("" "V[" "V[w" "V[w" jp-kanji)
("" "\[" "TJm L[W" "TJm L[W" jp-kanji)
("" "V[" "JLlm V[" "JLlm V[" jp-kanji)
("" "Z" "t_m Z" "t_m Z" jp-kanji)
("" "gN" "t_m gN" "t_m gN" jp-kanji)
("" "eC" "A^m eC" "A^m eC" jp-kanji)
("" "S" "EVwj " "EVwj " jp-kanji)
("" "C" "XLm C" "XLm C" jp-kanji)
("" "C" "Cm CW" "Cm CW" jp-kanji)
("" "z" "nVm z" "nVm z" jp-kanji)
("" "R[" "lMEm R[" "lMEm R[" jp-kanji)
("" "N" "}_EVm N" "}_EVm N" jp-kanji)
("" "gN" "R[Vm gN" "R[Vm gN" jp-kanji)
("" "M" "CPjGm L[W" "CPjGm L[W" jp-kanji)
("" "[" "Pmwj [" "Pmwj [" jp-kanji)
("" "TC" "}Ckm TC" "}Ckm TC" jp-kanji)
("" "W[" "im W[" "im W[" jp-kanji)
("" "`[" "Ckm `" "Ckm `" jp-kanji)
("" "eL" "GrXm eL" "GrXm eL" jp-kanji)
("" "R[" "im R[" "im R[" jp-kanji)
("" "q" "Tm qq" "Tm qq" jp-kanji)
("" "JN" "Wim oN" "Wim oN" jp-kanji)
("" "R" "nin_VCm R" "nin_VCm R" jp-kanji)
("" "R[" "YCm R[" "YCm R[" jp-kanji)
("" "L[" "Z}Cm L[W" "Z}Cm L[W" jp-kanji)
("" "P" "PJCm P" "PJCm P" jp-kanji)
("" "VN" "X~Jm VN" "X~Jm VN" jp-kanji)
("" "C" "Pmwj L" "Pmwj L" jp-kanji)
("" "QC" "QCJm QC" "QCJm QC" jp-kanji)
("" "TC" "E^KEm TC" "E^KEm TC" jp-kanji)
("" "V[" "V[Pcm V[" "V[Pcm V[" jp-kanji)
("" "\c" "jJm \c" "jJm \c" jp-kanji)
("" "R[" "Pmwj R[" "Pmwj R[" jp-kanji)
("" "^" "CmVVm ^" "CmVVm ^" jp-kanji)
("" "V[" "Pmwj zV" "Pmwj zV" jp-kanji)
("" "C" "~_m C" "~_m C" jp-kanji)
("" "Jc" "YCm Jc" "YCm Jc" jp-kanji)
("" "V[" "XXm L[W" "XXm L[W" jp-kanji)
("" "oN" "oNm CW" "oNm CW" jp-kanji)
("" "N" "_}m L[W" "_}m L[W" jp-kanji)
("" "Pc" "^Pm Pc" "^Pm Pc" jp-kanji)
("" "JC" "YCm JC" "YCm JC" jp-kanji)
("" "hN" "qgm L[W" "qgm L[W" jp-kanji)
("" "h[" "h[[m h[" "h[[m h[" jp-kanji)
("" "W[" "Pmm L[W" "Pmm L[W" jp-kanji)
("" "[" "Jm L[W" "Jm L[W" jp-kanji)
("" "P" "TTQm L[W" "TTQm L[W" jp-kanji)
("" "^c" "JE\m ^c" "JE\m ^c" jp-kanji)
("" "J" "R[q[m R" "R[q[m R" jp-kanji)
("" "^C" "^C}Cm ^C" "^C}Cm ^C" jp-kanji)
("" "`" "YVCm CW" "YVCm CW" jp-kanji)
("" "n" "KXm n" "KXm n" jp-kanji)
("" "nN" "RnNm nN" "RnNm nN" jp-kanji)
("" "W" "I[wj ~~" "I[wj ~~" jp-kanji)
("" "nC" "I[wj nC" "I[wj nC" jp-kanji)
("" "N" "I[wj JN" "I[wj JN" jp-kanji)
("" "" "m L[W" "m L[W" jp-kanji)
("" "[" "[Jm [" "[Jm [" jp-kanji)
("" "[" "[m L[W" "[m L[W" jp-kanji)
("" "R" "RnNm R" "RnNm R" jp-kanji)
("" "S" "I[wj " "I[wj " jp-kanji)
("" "q" "R[q[m q" "R[q[m q" jp-kanji)
("" "z[" "I[wj z[" "I[wj z[" jp-kanji)
("" "J" "LYm J" "LYm J" jp-kanji)
("" "R" "I[wj O" "I[wj O" jp-kanji)
("" "Vc" "LVcm Vc" "LVcm Vc" jp-kanji)
("" "m[" "m[m m[" "m[m m[" jp-kanji)
("" "{[" "I[wj IJX" "I[wj IJX" jp-kanji)
("" "" "I[wj " "I[wj " jp-kanji)
("" "GC" "JKNm GC" "JKNm GC" jp-kanji)
("" "JC" "I[wj Ij" "I[wj Ij" jp-kanji)
("" "T" "YVCm T" "YVCm T" jp-kanji)
("" "" "m[m " "m[m " jp-kanji)
("" "[" "^}m CW" "^}m CW" jp-kanji)
("" "L" "I[wj L" "I[wj L" jp-kanji)
("" "V[" "I[wj V[" "I[wj V[" jp-kanji)
("" "nN" "A^}m nN" "A^}m nN" jp-kanji)
("" "wL" "JyLm yL" "JyLm yL" jp-kanji)
("" "PC" "^}m PC" "^}m PC" jp-kanji)
("" "[" "I[wj ^c" "I[wj ^c" jp-kanji)
("" "GC" "NrJUm GC" "NrJUm GC" jp-kanji)
("" "GC" "GCm NW" "GCm NW" jp-kanji)
("@" "R" "qTSm R" "qTSm R" jp-kanji)
("A" "x" "xm L[W" "xm L[W" jp-kanji)
("C" "LO" "ITm ^C" "ITm ^C" jp-kanji)
("D" "I[" "Jm I[" "Jm I[" jp-kanji)
("E" "g" "ITm ^C" "ITm ^C" jp-kanji)
("G" "~O" "ITm ^C" "ITm ^C" jp-kanji)
("H" "wN^O" "ITm ^C" "ITm ^C" jp-kanji)
("I" "V" "Lmm V" "Lmm V" jp-kanji)
("J" "P" "XGmm P" "XGmm P" jp-kanji)
("K" "V[" "VLKm V[" "VLKm V[" jp-kanji)
("L" "Z`O" "ITm ^C" "ITm ^C" jp-kanji)
("M" "I[" "Jm I[" "Jm I[" jp-kanji)
("N" "Z" "Jm Z" "Jm Z" jp-kanji)
("O" "{[" "Jm {[" "Jm {[" jp-kanji)
("P" "I[" "Jm I[" "Jm I[" jp-kanji)
("Q" "wL" "VLKm wL" "VLKm wL" jp-kanji)
("R" "V[" "im CW" "im CW" jp-kanji)
("S" "\" "~KGm \" "~KGm \" jp-kanji)
("T" "[" "Nm [" "Nm [" jp-kanji)
("U" "`[" "}`m CW" "}`m CW" jp-kanji)
("V" "[" "ghm NW" "ghm NW" jp-kanji)
("W" "JC" "^wj JC" "^wj JC" jp-kanji)
("X" "R[" "^KXm R[" "^KXm R[" jp-kanji)
("Y" "t" "^wj Ibg" "^wj Ibg" jp-kanji)
("Z" "V" "VCLm V" "VCLm V" jp-kanji)
("[" "z" "Elm zW" "Elm zW" jp-kanji)
("\" "z" "bRm z" "bRm z" jp-kanji)
("]" "C" "^wj R" "^wj R" jp-kanji)
("^" "W" "^wj e" "^wj e" jp-kanji)
("_" "N" "A}Vm CW" "A}Vm CW" jp-kanji)
("`" "K" "GKNm L[W" "GKNm L[W" jp-kanji)
("a" "" "^wj A}" "^wj A}" jp-kanji)
("b" "L" "YVCm L" "YVCm L" jp-kanji)
("c" "g[" "A^m L[W" "A^m L[W" jp-kanji)
("d" "L[" "TJCm L[" "TJCm L[" jp-kanji)
("e" "`[" "TLjm `[" "TLjm `[" jp-kanji)
("f" "`[" "`[m NW" "`[m NW" jp-kanji)
("g" "W[" "^^~m L[W" "^^~m L[W" jp-kanji)
("h" "W[" "^^~m zW" "^^~m zW" jp-kanji)
("i" "W[" "^^~m W[" "^^~m W[" jp-kanji)
("j" "`[" "}C_j `[" "}C_j `[" jp-kanji)
("k" "L[" "}Cm L[" "}Cm L[" jp-kanji)
("l" "Z" "nC^m Z" "nC^m Z" jp-kanji)
("m" "JC" "JCZm JC" "JCZm JC" jp-kanji)
("n" "[" "C{m [" "C{m [" jp-kanji)
("o" "J" "}C_j J" "}C_j J" jp-kanji)
("p" "J" "qLcPm J" "qLcPm J" jp-kanji)
("q" "Q" "}C_j Q" "}C_j Q" jp-kanji)
("r" "V" "LYm V" "LYm V" jp-kanji)
("s" "\" "^\r[m \" "^\r[m \" jp-kanji)
("t" "^" "I[_m ^" "I[_m ^" jp-kanji)
("u" "g[" "EYNm g[" "EYNm g[" jp-kanji)
("v" "z[" "z[\[m z[" "z[\[m z[" jp-kanji)
("w" "C" "LYm C" "LYm C" jp-kanji)
("x" "Z" "PbZm Z" "PbZm Z" jp-kanji)
("y" "[" "JCm [" "JCm [" jp-kanji)
("z" "" "qLcm PC" "qLcm " jp-kanji)
("{" "V" "AUm V" "AUm V" jp-kanji)
("|" "q" "}C_j q" "}C_j q" jp-kanji)
("}" "A" "}Cm A" "}Cm A" jp-kanji)
("~" "C" "iGm C" "iGm C" jp-kanji)
("" "R" "iKYCm R" "iKYCm R" jp-kanji)
("" "XC" "cJm XC" "cJm XC" jp-kanji)
("" "^" "^com ^" "^com ^" jp-kanji)
("" "q" "J^}qm q" "J^}qm q" jp-kanji)
("" "}" "Vrm }" "Vrm }" jp-kanji)
("" "" "r[m " "r[m " jp-kanji)
("" "t[" "L[Wm t[" "L[Wm t[" jp-kanji)
("" "[" "nmm [" "nmm [" jp-kanji)
("" "" "iIm " "iIm " jp-kanji)
("" "I" "IGLm I" "IGLm I" jp-kanji)
("" "MN" "MNr[m MN" "MNr[m MN" jp-kanji)
("" "\[" "Zm \[" "Zm \[" jp-kanji)
("" "\[" "LYm \[" "LYm \[" jp-kanji)
("" "n" "Agm n" "Agm n" jp-kanji)
("" "[" "Rum [" "Rum [" jp-kanji)
("" "V[" "V[Lm V[" "V[Lm V[" jp-kanji)
("" "C" "CLm C" "CLm C" jp-kanji)
("" "[" "ZVm [" "ZVm [" jp-kanji)
("" "J" "JVNm J" "JVNm J" jp-kanji)
("" "nC" "nCWm nC" "nCWm nC" jp-kanji)
("" "[" "C^m [" "C^m [" jp-kanji)
("" "f" "}C_j hm" "}C_j hm" jp-kanji)
("" "C" "CLm C" "CLm C" jp-kanji)
("" "`" "IJm L[W" "IJm L[W" jp-kanji)
("" "[" "JCm CW" "JCm CW" jp-kanji)
("" "JN" "JNm JN" "JNm JN" jp-kanji)
("" "C" "Cr[m C" "Cr[m C" jp-kanji)
("" "VN" "JVNm VN" "JVNm VN" jp-kanji)
("" "L" "}C_j L" "}C_j L" jp-kanji)
("" "Z" "JCZm Z" "JCZm Z" jp-kanji)
("" "[" "[\m [" "[\m [" jp-kanji)
("" "e" "t[em e" "t[em e" jp-kanji)
("" "nc" "ncKV" "ncKV" jp-kanji)
("" "L" "~Ym gm L" "~Ym gm L" jp-kanji)
("" "nc" "nicm L[W" "nicm L[W" jp-kanji)
("" "L[" "JoVCm L[" "JoVCm L[" jp-kanji)
("" "{[" "J^hm CW" "J^hm CW" jp-kanji)
("" "L" "JGm CW" "JGm CW" jp-kanji)
("" "R[" "TcLm CW" "TcLm CW" jp-kanji)
("" "R[" "Vwj R[" "Vwj R[" jp-kanji)
("" "J" "Vwj J" "Vwj J" jp-kanji)
("" "R[" "Vwj cQ" "Vwj cQ" jp-kanji)
("" "ZL" "nNZLm ZL" "nNZLm ZL" jp-kanji)
("" "KC" "KC[m KC" "KC[m KC" jp-kanji)
("" "z[" "jLrm z[" "jLrm z[" jp-kanji)
("" "V" "qrm V" "qrm V" jp-kanji)
("" "N" "AJMm N" "AJMm N" jp-kanji)
("" "N" "Nm CW" "Nm CW" jp-kanji)
("" "V[" "Vm V[" "Vm V[" jp-kanji)
("" "E" "n`m E" "n`m E" jp-kanji)
("" "R[" "i]m R[" "i]m R[" jp-kanji)
("" "KC" "P_Vm CW" "P_Vm CW" jp-kanji)
("" "S[" "nS[m S[" "nS[m S[" jp-kanji)
("" "T" "TJYLm T" "TJYLm T" jp-kanji)
("" "W" "cLm L[W" "cLm L[W" jp-kanji)
("" "J" "^Cm J" "^Cm J" jp-kanji)
("" "" "ZCm " "ZCm " jp-kanji)
("" "g[" "ESNm g[" "ESNm g[" jp-kanji)
("" "g[" "g[m CW" "g[m CW" jp-kanji)
("" "PC" "wj PC" "wj PC" jp-kanji)
("" "^" "jm ^" "jm ^" jp-kanji)
("" "r[" "XKm r[" "XKm r[" jp-kanji)
("" "x" "Rxm x" "Rxm x" jp-kanji)
("" "Q" "}uVCm Q" "}uVCm Q" jp-kanji)
("" "C" "wj A}" "wj A}" jp-kanji)
("" "V" "}Rgm L[W" "}Rgm L[W" jp-kanji)
("" "ZC" "ZCm CW" "ZCm CW" jp-kanji)
("" "ZC" "}iWm ZC" "}iWm ZC" jp-kanji)
("" "}C" "NCm }C" "NCm }C" jp-kanji)
("" "P" "JG~m P" "JG~m P" jp-kanji)
("" "{[" "qg~m {[" "qg~m {[" jp-kanji)
("" "eC" "wj Ig[g" "wj Ig[g" jp-kanji)
("" "KC" "jm KC" "jm KC" jp-kanji)
("" "QC" "jm QC" "jm QC" jp-kanji)
("" "V[" "}cQm V[" "}cQm V[" jp-kanji)
("" "ZC" "qg~m ZC" "qg~m ZC" jp-kanji)
("" "wC" "wCQCm wC" "wCQCm wC" jp-kanji)
("" "GC" "GCm CW" "GCm CW" jp-kanji)
("" "R[" "R[Km R[" "R[Km R[" jp-kanji)
("" "g" "~m g" "~m g" jp-kanji)
("" "Jc" "wj KC" "wj KC" jp-kanji)
("" "V" "CJm V" "CJm V" jp-kanji)
("" "C" "C\[m C" "C\[m C" jp-kanji)
("" "h[" "h[Nm h[" "h[Nm h[" jp-kanji)
("" "}" "M}m }" "M}m }" jp-kanji)
("" "J" "~IXm J" "~IXm J" jp-kanji)
("" "L" "wj g[gC" "wj g[gC" jp-kanji)
("" "AC" "wj AC" "wj AC" jp-kanji)
("" "N" "N[m N" "N[m N" jp-kanji)
("" "P" "}u^m P" "}u^m P" jp-kanji)
("" "R" "m[~m I" "m[~m I" jp-kanji)
("" "Z" "Z{[m Z" "Z{[m Z" jp-kanji)
("" "[" "[}Cm [" "[}Cm [" jp-kanji)
("" "JN" "JNVNm JN" "JNVNm JN" jp-kanji)
("" "`N" "`NVcm `N" "`NVcm `N" jp-kanji)
("" "VN" "VNNm VN" "VNNm VN" jp-kanji)
("" "L" "ccVm L" "ccVm L" jp-kanji)
("" "C" "j " "j " jp-kanji)
("" "C" "CV[m C" "CV[m C" jp-kanji)
("" "R[" "CVwj R[" "CVwj R[" jp-kanji)
("" "ZC" "CVwj L" "CVwj L" jp-kanji)
("" "q" "q\m q" "q\m q" jp-kanji)
("" "R[" "AKlm R[" "AKlm R[" jp-kanji)
("" "V" "CV}m V" "CV}m V" jp-kanji)
("" "C" "gCVm g" "gCVm g" jp-kanji)
("" "PC" "PC\m PC" "PC\m PC" jp-kanji)
("" "TC" "N_Nm TC" "N_Nm TC" jp-kanji)
("" "JL" "CVwj ni" "CVwj ni" jp-kanji)
("" "n" "i~j CV" "i~j CV" jp-kanji)
("" "z[" "z[\m z[" "z[\m z[" jp-kanji)
("" "nC" "nCCm nC" "nCCm nC" jp-kanji)
("" "N" "N_Jm N" "N_Jm N" jp-kanji)
("" "Pc" "CVu~m Pc" "CVu~m Pc" jp-kanji)
("" "ZL" "CVwj eC" "CVwj eC" jp-kanji)
("" "`" "Lk^m CW" "Lk^m CW" jp-kanji)
("" "m[" "CVwj m[" "CVwj m[" jp-kanji)
("" "KC" "CVwj KC" "CVwj KC" jp-kanji)
("" "Jc" "CVwj zl" "CVwj zl" jp-kanji)
("" "T" "~KNm T" "~KNm T" jp-kanji)
("" "^N" "ncPm ^N" "ncPm ^N" jp-kanji)
("" "e" "CVwj e" "CVwj e" jp-kanji)
("" "l" "^Cm [h" "^Cm [h" jp-kanji)
("" "z[" "^Cm |h" "^Cm |h" jp-kanji)
("" "C" "CNm C" "CNm C" jp-kanji)
("" "PC" "PCZcm PC" "PCZcm PC" jp-kanji)
("@" "ZL" "CVwj ZL" "CVwj ZL" jp-kanji)
("A" "Z" "Jm Z" "Jm Z" jp-kanji)
("B" "R[" "R[JNm R[" "R[JNm R[" jp-kanji)
("C" "g[" "CVwj m{" "CVwj m{" jp-kanji)
("D" "CN" "^}j j^ CV" "^}j j^ CV" jp-kanji)
("E" "M" "C\m M" "C\m M" jp-kanji)
("F" "g[" "CVwj A^" "CVwj A^" jp-kanji)
("G" "KC" "CVwj M" "CVwj M" jp-kanji)
("H" "o" "~[om o" "~[om o" jp-kanji)
("I" "L" "cuem L" "cuem L" jp-kanji)
("J" "V" "}cm V" "}cm V" jp-kanji)
("K" "V" "zRm V" "zRm V" jp-kanji)
("L" "V" "ccVm V" "ccVm V" jp-kanji)
("M" "XC" "^^m XC" "^^m XC" jp-kanji)
("N" "\" "TCCm \" "TCCm \" jp-kanji)
("O" "q" "qm q" "qm q" jp-kanji)
("P" "tc" "nEm tc" "nEm tc" jp-kanji)
("Q" "L" "VXwj \m" "VXwj \m" jp-kanji)
("R" "N" "Nm L[W" "Nm L[W" jp-kanji)
("S" "PC" "~\Mm PC" "~\Mm PC" jp-kanji)
("T" "VN" "VXwm VN" "VXwm VN" jp-kanji)
("U" "L" "VXwj L" "VXwj L" jp-kanji)
("V" "TC" "TCm L[W" "TCm L[W" jp-kanji)
("W" "[" "[m L[W" "[m L[W" jp-kanji)
("X" "C" "Cm L[W" "Cm L[W" jp-kanji)
("Y" "W[" "nEm W[" "nEm W[" jp-kanji)
("Z" "E" "EI[m E" "EI[m E" jp-kanji)
("[" "O" "IiKUm O" "IiKUm O" jp-kanji)
("\" "wC" "gm wC" "gm wC" jp-kanji)
("]" "q" "VCim q" "VCim q" jp-kanji)
("^" "I[" "iGm I[" "iGm I[" jp-kanji)
("_" "L" "NLrm Lr" "NLrm Lr" jp-kanji)
("`" "nc" "C^m nc" "C^m nc" jp-kanji)
("a" "}c" "}OTm }c" "}OTm }c" jp-kanji)
("b" "J" "m J" "m J" jp-kanji)
("c" "V[" "m V[" "m V[" jp-kanji)
("d" "L" "mMwj \m" "mMwj \m" jp-kanji)
("e" "`N" "mMwj `N" "mMwj `N" jp-kanji)
("f" "`[" "mMwj V[" "mMwj V[" jp-kanji)
("g" "" "Mm " "Mm " jp-kanji)
("h" "" "m CW" "m CW" jp-kanji)
("i" "V[" "^^Gm L[W" "^^Gm L[W" jp-kanji)
("j" "g[" "Clm CW" "Clm CW" jp-kanji)
("k" "R[" "m R[" "m R[" jp-kanji)
("l" "VN" "Lrm VN" "Lrm VN" jp-kanji)
("m" "[" "mMwj [" "mMwj [" jp-kanji)
("n" "XC" "zm CW" "zm CW" jp-kanji)
("o" "`" "ITiCm CW" "ITiCm CW" jp-kanji)
("p" "VN" "VNtm VN" "VNtm VN" jp-kanji)
("q" "AC" "PKm AC" "PKm AC" jp-kanji)
("r" "I" "I_Jm L[W" "I_Jm L[W" jp-kanji)
("s" "V[" "ALm L[W" "ALm L[W" jp-kanji)
("t" "W[" "~mm L[W" "~mm L[W" jp-kanji)
("u" "L[" "L[em L[" "L[em L[" jp-kanji)
("v" "ZC" "IgVAim ZC" "IgVAim ZC" jp-kanji)
("w" "[" "[`[m [" "[`[m [" jp-kanji)
("x" "\[" "}hm L[W" "}hm L[W" jp-kanji)
("y" "`[" "[`[m `[" "[`[m `[" jp-kanji)
("z" "L" "NVm L" "NVm L" jp-kanji)
("{" "R[" "AiOm R[" "AiOm R[" jp-kanji)
("|" "J" "Aim J" "Aim J" jp-kanji)
("}" "\[" "J}hm L[W" "J}hm L[W" jp-kanji)
("~" "[" "J}m L[W" "J}m L[W" jp-kanji)
("" "N" "cm N" "cm N" jp-kanji)
("" "L[" "Aim L[" "Aim L[" jp-kanji)
("" "U" "Uj[m U" "Uj[m U" jp-kanji)
("" "[" "Aij [" "Aij [" jp-kanji)
("" "XC" "tJCm XC" "tJCm XC" jp-kanji)
("" "g[" "Aim g[" "Aim g[" jp-kanji)
("" "Zc" "kXm L[W" "kXm L[W" jp-kanji)
("" "fJbg" "^CZLm ^C" "^CZLm ^C" jp-kanji)
("" "Lbg" "^CZLm ^C" "^CZLm ^C" jp-kanji)
("" "fVbg" "^CZLm ^C" "^CZLm ^C" jp-kanji)
("" "~bg" "^CZLm ^C" "^CZLm ^C" jp-kanji)
("" "^" "^cm ^" "^cm ^" jp-kanji)
("" "`" "^^Ym `" "^^Ym `" jp-kanji)
("" "wC" "ium L[W" "ium L[W" jp-kanji)
("" "wNgbg" "^CZLm ^C" "^CZLm ^C" jp-kanji)
("" "V" "}cm V" "}cm V" jp-kanji)
("" "V[" "V[[m V[" "V[[m V[" jp-kanji)
("" "Pc" "cNXm Pc" "cNXm Pc" jp-kanji)
("" "Z`bg" "^CZLm ^C" "^CZLm ^C" jp-kanji)
("" "K" "^Pj }" "^Pj }" jp-kanji)
("" "Rc" "VNm Rc" "VNm Rc" jp-kanji)
("" "\[" "Um \[" "Um \[" jp-kanji)
("" "n" "^Pj gG" "^Pj gG" jp-kanji)
("" "J" "tGm CbVm J" "tGm CbVm J" jp-kanji)
("" "Z" "^Pj V" "^Pj V" jp-kanji)
("" "V[" "tGm V[" "tGm V[" jp-kanji)
("" "`" "`m `" "`m `" jp-kanji)
("" "n" "^Pj n" "^Pj n" jp-kanji)
("" "z" "^Pj z" "^Pj z" jp-kanji)
("" "V" "^PJj " "^PJj " jp-kanji)
("" "L[" "JSm L[" "JSm L[" jp-kanji)
("" "L[" "em A L[" "em A L[" jp-kanji)
("" "PC" "JUVm PC" "JUVm PC" jp-kanji)
("" "V" "^PmRm V" "^PmRm V" jp-kanji)
("" "\[" "Rgm \[" "Rgm \[" jp-kanji)
("" "Z" "tZSm Z" "tZSm Z" jp-kanji)
("" "Z" "TTm Z" "TTm Z" jp-kanji)
("" "G" "Vm G" "Vm G" jp-kanji)
("" "L" "nRm L" "nRm L" jp-kanji)
("" "L[" "^Pj L[" "^Pj L[" jp-kanji)
("" "P" "JPqm P" "JPqm P" jp-kanji)
("" "TN" "^Pj cN" "^Pj cN" jp-kanji)
("" "V[" "Vmm CW" "Vmm CW" jp-kanji)
("" "ZC" "^Pj i" "^Pj i" jp-kanji)
("" "ZC" "EiEm ZC" "EiEm ZC" jp-kanji)
("" "J" "JR[m J" "JR[m J" jp-kanji)
("" "L" "^Pj L" "^Pj L" jp-kanji)
("" "L" "^Pj R" "^Pj R" jp-kanji)
("" "R" "^Km R" "^Km R" jp-kanji)
("" "N" "^Pj \" "^Pj \" jp-kanji)
("" "g[" "TXm g[" "TXm g[" jp-kanji)
("" "Z" "t_m Z" "t_m Z" jp-kanji)
("" "\[" "z[Lm \[" "z[Lm \[" jp-kanji)
("" "\[" "Rgm \[" "Rgm \[" jp-kanji)
("" "\[" "\[m ]NW" "\[m ]NW" jp-kanji)
("" "tN" "Grm tN" "Grm tN" jp-kanji)
("" "L[" "JSm L[" "JSm L[" jp-kanji)
("" "R[" "^Jm R[" "^Jm R[" jp-kanji)
("" "R[" "^Pj R[" "^Pj R[" jp-kanji)
("" "J" "nRm J" "nRm J" jp-kanji)
("" "V" "C}Vm V" "C}Vm V" jp-kanji)
("" "e" "eRNm e" "eRNm e" jp-kanji)
("" "R[" "JKrm JK" "JKrm JK" jp-kanji)
("" "V" "tCm V" "tCm V" jp-kanji)
("" "T" "^Pm ~m" "^Pm ~m" jp-kanji)
("" "T" "~mm ]NW" "~mm ]NW" jp-kanji)
("" "wC" "JUVm wC" "JUVm wC" jp-kanji)
("" "c" "^Pj N" "^Pj N" jp-kanji)
("" "[" "JSm L[W" "JSm L[W" jp-kanji)
("" "TN" "XmRm T" "XmRm T" jp-kanji)
("" "\[" "Km \[" "Km \[" jp-kanji)
("" "`[" "^Pj z" "^Pj z" jp-kanji)
("" "qc" "Com qc" "Com qc" jp-kanji)
("" "z[" "g}m z[" "g}m z[" jp-kanji)
("" "[" "im [" "im [" jp-kanji)
("" "" "^PJSm " "^PJSm " jp-kanji)
("" "G" "^Pj G" "^Pj G" jp-kanji)
("" "L" "bRm L" "bRm L" jp-kanji)
("" "R[" "tGm V^m R[" "tGm V^m R[" jp-kanji)
("" "V" "JUVm V" "JUVm V" jp-kanji)
("" "e" "Vm e" "Vm e" jp-kanji)
("" "G" "mLm G" "mLm G" jp-kanji)
("" "V[" "tGm V[" "tGm V[" jp-kanji)
("" "Z" "ZI[m Z" "ZI[m Z" jp-kanji)
("" "`[" "nJSgm `[" "nJSgm `[" jp-kanji)
("" "" "JSm " "JSm " jp-kanji)
("" "\[" "um L[W" "um L[W" jp-kanji)
("" "L" "^Pj n^" "^Pj n^" jp-kanji)
("" "`[" "^Pj [" "^Pj [" jp-kanji)
("" "g[" "cm g[" "cm g[" jp-kanji)
("" "g[" "cm CW" "cm CW" jp-kanji)
("" "C" "^Pj C" "^Pj C" jp-kanji)
("" "Z" "I~NWm Z" "I~NWm Z" jp-kanji)
("" "Z" "I~NWm ZCW" "I~NWm ZCW" jp-kanji)
("" "N" "KbLm N" "KbLm N" jp-kanji)
("" "" "}KLm " "}KLm " jp-kanji)
("" "q" "VCim q" "VCim q" jp-kanji)
("" "g" "Rwj g" "Rwj g" jp-kanji)
("" "Gc" "Jgm CC" "Jgm CC" jp-kanji)
("" "S[" "Rwj S[" "Rwj S[" jp-kanji)
("" "V" "Lrm V" "Lrm V" jp-kanji)
("" "W" "Rj VJVe" "Rj VJVe" jp-kanji)
("" "g[" "`}Lm g[" "`}Lm g[" jp-kanji)
("" "R[" "E`m R[" "E`m R[" jp-kanji)
("" "T" "JKNm T" "JKNm T" jp-kanji)
("" "[" "Am [" "Am [" jp-kanji)
("" "[" "Jem CW" "Jem CW" jp-kanji)
("" "XC" "CLm CW" "CLm CW" jp-kanji)
("" "\[" "`}Lm \[" "`}Lm \[" jp-kanji)
("" "J" "Rwj ni" "Rwj ni" jp-kanji)
("" "W[" "}Wm W[" "}Wm W[" jp-kanji)
("" "T" "Rwj W" "Rwj W" jp-kanji)
("" "J" "Rwj CG" "Rwj CG" jp-kanji)
("" "r" "zVCCm r" "zVCCm r" jp-kanji)
("" "r" "^_m r" "^_m r" jp-kanji)
("" "" "Rwj " "Rwj " jp-kanji)
("" "VN" "Jm CW" "Jm CW" jp-kanji)
("" "_" "`Sm _" "`Sm _" jp-kanji)
("" "C" "NSm C" "NSm C" jp-kanji)
("" "eL" "JClm eL" "JClm eL" jp-kanji)
("" "`[" "Elm `[" "Elm `[" jp-kanji)
("" "L[" "AUiEm L[" "AUiEm L[" jp-kanji)
("" "E" "}Km E" "}Km E" jp-kanji)
("@" "`[" "`[I[m `[" "`[I[m `[" jp-kanji)
("A" "E" "Cgwj C[" "Cgwj C[" jp-kanji)
("B" "q" "Cgwj R" "Cgwj R" jp-kanji)
("C" "r" "~_m r" "~_m r" jp-kanji)
("D" "PC" "qLVm PC" "qLVm PC" jp-kanji)
("E" "R[" "nbR[m R[" "nbR[m R[" jp-kanji)
("F" "Tc" "gh}m Tc" "gh}m Tc" jp-kanji)
("G" "Zc" "LYim Zc" "LYim Zc" jp-kanji)
("H" "^C" "Cgwj _C" "Cgwj _C" jp-kanji)
("I" "`" "ATkmm `" "ATkmm `" jp-kanji)
("J" "n" "LYim n" "LYim n" jp-kanji)
("K" "R[" "AJCm R[" "AJCm R[" jp-kanji)
("L" "R[" "Cgwj qJ" "Cgwj qJ" jp-kanji)
("M" "R[" "Cgwj CN" "Cgwj CN" jp-kanji)
("N" "V" "Cgm L[W" "Cgm L[W" jp-kanji)
("O" "W[" "W[^m W[" "W[^m W[" jp-kanji)
("P" "W" "^m W" "^m W" jp-kanji)
("Q" "Zc" "Zcm ]NW" "Zcm ]NW" jp-kanji)
("R" "z[" "JXm z[" "JXm z[" jp-kanji)
("S" "PC" "wm L[W" "wm L[W" jp-kanji)
("T" "V[" "VV[m ]NW" "VV[m ]NW" jp-kanji)
("U" "W[" "Ti_m W[" "Ti_m W[" jp-kanji)
("V" "XC" "XJm XC" "XJm XC" jp-kanji)
("W" "" "LkImm " "LkImm " jp-kanji)
("X" "j" "Cgwj Vmu" "Cgwj Vmu" jp-kanji)
("Y" "L" "Am L" "Am L" jp-kanji)
("Z" "PC" "L[Vm PC" "L[Vm PC" jp-kanji)
("[" "P" "Cgwj }N" "Cgwj }N" jp-kanji)
("\" "TC" "Am TC" "Am TC" jp-kanji)
("]" "V" "NMkm V" "NMkm V" jp-kanji)
("^" "VN" "A_im A_" "A_im A_" jp-kanji)
("_" "Z" "Zm L[W" "Zm L[W" jp-kanji)
("`" "\[" "Xxem L[W" "Xxem L[W" jp-kanji)
("a" "`[" "hXm `[" "hXm `[" jp-kanji)
("b" "g[" "iEm g[" "iEm g[" jp-kanji)
("c" "x" "^m zW" "^m zW" jp-kanji)
("d" "" "Vm " "Vm " jp-kanji)
("e" "C" "Cgwj h" "Cgwj h" jp-kanji)
("f" "" "ciOm " "ciOm " jp-kanji)
("g" "J" "gWm J" "gWm J" jp-kanji)
("h" "V[" "gGm V[" "gGm V[" jp-kanji)
("i" "Zc" "Zcm CW" "Zcm CW" jp-kanji)
("j" "^" "W[^m ^" "W[^m ^" jp-kanji)
("k" "`" "Cgwj C^" "Cgwj C^" jp-kanji)
("l" "r[" "nJm r[" "nJm r[" jp-kanji)
("m" "r" "cCgm r" "cCgm r" jp-kanji)
("n" "C" "Cgwj C" "Cgwj C" jp-kanji)
("o" "GC" "Nrm GC" "Nrm GC" jp-kanji)
("p" "P" "AK^m L[W" "AK^m L[W" jp-kanji)
("q" "TC" "RgLm TC" "RgLm TC" jp-kanji)
("r" "V" "m V" "m V" jp-kanji)
("s" "W[" "^em L[W" "^em L[W" jp-kanji)
("t" "WN" "YVC" "YVC" jp-kanji)
("u" "V" "AJCLkm V" "AJCLkm V" jp-kanji)
("v" "cC" "XKm cC" "XKm cC" jp-kanji)
("w" "g[" "JoLm g[" "JoLm g[" jp-kanji)
("x" "r[" "A}m r[" "A}m r[" jp-kanji)
("y" "L[" "Cgwj cC" "Cgwj cC" jp-kanji)
("z" "r" "ciOm r" "ciOm r" jp-kanji)
("{" "}" "Wm Lkm }" "Wm Lkm }" jp-kanji)
("|" "q[" "ni_m q[" "ni_m q[" jp-kanji)
("}" "z[" "Cgj NY" "Cgj NY" jp-kanji)
("~" "" "Qm " "Qm " jp-kanji)
("" "C" "ciOm C" "ciOm C" jp-kanji)
("" "" "cm " "cm " jp-kanji)
("" "E" "Cgwj N" "Cgwj N" jp-kanji)
("" "J" "jVLm A" "jVLm A" jp-kanji)
("" "T" "Cgwj `" "Cgwj `" jp-kanji)
("" "W[" "Om W[" "Om W[" jp-kanji)
("" "n" "qgNm n" "qgNm n" jp-kanji)
("" "[" "[m [" "[m [" jp-kanji)
("" "GL" "^Ylm GL" "^Ylm GL" jp-kanji)
("" "JC" "Gm L[W" "Gm L[W" jp-kanji)
("" "W[" "im L[W" "im L[W" jp-kanji)
("" "PC" "cOm L[W" "cOm L[W" jp-kanji)
("" "V" "EXMkm V" "EXMkm V" jp-kanji)
("" "ZC" "JXm zW" "JXm zW" jp-kanji)
("" "ZC" "JXm CW" "JXm CW" jp-kanji)
("" "q" "qum q" "qum q" jp-kanji)
("" "x" "xpcm x" "xpcm x" jp-kanji)
("" "" "{m " "{m " jp-kanji)
("" "Pc" "R[Pcm Pc" "R[Pcm Pc" jp-kanji)
("" "T" "cOm T" "cOm T" jp-kanji)
("" "]N" "cdNm L[W" "cdNm L[W" jp-kanji)
("" "e" "}g[m e" "}g[m e" jp-kanji)
("" "R[" "R[Pcm R[" "R[Pcm R[" jp-kanji)
("" "GC" "iKCm GC" "iKCm GC" jp-kanji)
("" "TC" "YJjm TC" "YJjm TC" jp-kanji)
("" "Z" "Zm ZCW" "Zm ZCW" jp-kanji)
("" "Z" "Zm L[W" "Zm L[W" jp-kanji)
("" "g[" "n^m g[" "n^m g[" jp-kanji)
("" "" "gdim " "gdim " jp-kanji)
("" "R[" "Jm R[" "Jm R[" jp-kanji)
("" "Pc" "JPm L[W" "JPm L[W" jp-kanji)
("" "J" "qrm J" "qrm J" jp-kanji)
("" "I[" "PVm P" "PVm P" jp-kanji)
("" "C" "TJ_m C" "TJ_m C" jp-kanji)
("" "h" "rm CW" "rm CW" jp-kanji)
("" "J" "Jm L[W" "Jm L[W" jp-kanji)
("" "{[" "A~KVm {[" "A~KVm {[" jp-kanji)
("" "J" "}jm J" "}jm J" jp-kanji)
("" "[" "A~m [" "A~m [" jp-kanji)
("" "t" "KVj t" "KVj t" jp-kanji)
("" "R" "A~m R" "A~m R" jp-kanji)
("" "r" "lY~im i" "lY~im i" jp-kanji)
("" "A" "A~m A" "A~m A" jp-kanji)
("" "g[" "JSm g[" "JSm g[" jp-kanji)
("" "" "j nV" "j nV" jp-kanji)
("" "oc" "c~m ]NW" "c~m ]NW" jp-kanji)
("" "P" "j Lk" "j Lk" jp-kanji)
("" "q" "h[ucm qO}" "h[ucm qO}" jp-kanji)
("" "xL" "Lm xL" "Lm xL" jp-kanji)
("" "L" "^dim ZCW" "^dim ZCW" jp-kanji)
("" "L" "Lm L" "Lm L" jp-kanji)
("" "L[" "GrXm L[" "GrXm L[" jp-kanji)
("" "R[" "RqcWm R[" "RqcWm R[" jp-kanji)
("" "V[" "nWm V[" "nWm V[" jp-kanji)
("" "eC" "IqcWm eC" "IqcWm eC" jp-kanji)
("" "C" "JVJm C" "JVJm C" jp-kanji)
("" "O" "m CW" "m CW" jp-kanji)
("" "Jc" "LZCV^ qcW" "LZCV^ qcW" jp-kanji)
("" "M" "tNMm M" "tNMm M" jp-kanji)
("" "R[" "Acmm R[" "Acmm R[" jp-kanji)
("" "R[" "R[m CW" "R[m CW" jp-kanji)
("" "Z" "i}OTCm Z" "i}OTCm Z" jp-kanji)
("" "C" "Zm C" "Zm C" jp-kanji)
("" "[" "Cm L[W" "Cm L[W" jp-kanji)
("" "V" "qm V" "qm V" jp-kanji)
("" "XC" "JZ~m XC" "JZ~m XC" jp-kanji)
("" "N" "^XPm N" "^XPm N" jp-kanji)
("" "L[" "Ac}m L[" "Ac}m L[" jp-kanji)
("" "V[" "no^Nm V[" "no^Nm V[" jp-kanji)
("" "q" "JZ~m q" "JZ~m q" jp-kanji)
("" "Z" "Lm ZCW" "Lm ZCW" jp-kanji)
("" "w" "qKGm w" "qKGm w" jp-kanji)
("" "GC" "JQm GC" "JQm GC" jp-kanji)
("" "M[" "AQm M[" "AQm M[" jp-kanji)
("" "z" "qKGm z" "qKGm z" jp-kanji)
("" "L" "gVm L" "gVm L" jp-kanji)
("" "[" "IC{m [" "IC{m [" jp-kanji)
("" "ec" "gVm ec" "gVm ec" jp-kanji)
("" "C" "XLm C" "XLm C" jp-kanji)
("" "E" "NTMm E" "NTMm E" jp-kanji)
("" "n" "XLwj gG" "XLwj gG" jp-kanji)
("" "V" "XLm V" "XLm V" jp-kanji)
("" "W" "XNm W" "XNm W" jp-kanji)
("" "WN" "XNm WN" "XNm WN" jp-kanji)
("" "R[" "ALJm R[" "ALJm R[" jp-kanji)
("" "`" "nWm CW" "nWm CW" jp-kanji)
("" "[" "u[m [" "u[m [" jp-kanji)
("" "C" "LNm C" "LNm C" jp-kanji)
("" "Jc" "J}rXVC" "J}rXVC" jp-kanji)
("" "wC" "}lNm wC" "}lNm wC" jp-kanji)
("" "W" "Ac}m W" "Ac}m W" jp-kanji)
("" "ZC" "Rm CW" "Rm CW" jp-kanji)
("" "W[" "~~j T_}" "~~j T_}" jp-kanji)
("" "" "cim CW" "cim CW" jp-kanji)
("" "V[" "\rGm V[" "\rGm V[" jp-kanji)
("" "ZC" "RGm L[W" "RGm L[W" jp-kanji)
("" "\[" "TgVm L[W" "TgVm L[W" jp-kanji)
("" "W[" "TTNm W[" "TTNm W[" jp-kanji)
("" "fC" "~~AJm fC" "~~AJm fC" jp-kanji)
("" "`[" "LNm L[W" "LNm L[W" jp-kanji)
("" "Cc" "tfdNm Cc" "tfdNm Cc" jp-kanji)
("" "C" "iEm C" "iEm C" jp-kanji)
("" "V" "~Zm V" "~Zm V" jp-kanji)
("" "VN" "ccVm L[W" "ccVm L[W" jp-kanji)
("" "R[" "R[m R[" "R[m R[" jp-kanji)
("" "R[" "R[[m [" "R[[m [" jp-kanji)
("" "g" "nm g" "nm g" jp-kanji)
("" "gc" "cLwj E`" "cLwj E`" jp-kanji)
("" "{[" "IJXm CW" "IJXm CW" jp-kanji)
("" "[" "C{m [" "C{m [" jp-kanji)
("" "R[" "cLwj R[" "cLwj R[" jp-kanji)
("" "V" "Vm V" "Vm V" jp-kanji)
("" "TN" "qmMm TN" "qmMm TN" jp-kanji)
("" "`" "^Rm `" "^Rm `" jp-kanji)
("" "`[" "Jb`[m `[" "Jb`[m `[" jp-kanji)
("" "nC" "nCKm nC" "nCKm nC" jp-kanji)
("" "n" "^Jm n" "^Jm n" jp-kanji)
("" "~N" "~Nm ]NW" "~Nm ]NW" jp-kanji)
("" "R" "}^m R" "}^m R" jp-kanji)
("" "R[" "{[R[m R[" "{[R[m R[" jp-kanji)
("" "PC" "Xlm PC" "Xlm PC" jp-kanji)
("" "V[" "ITm V[" "ITm V[" jp-kanji)
("" "V" "N`rm CW" "N`rm CW" jp-kanji)
("" "z" "zWVm z" "zWVm z" jp-kanji)
("" "GL" "Lm V^m L" "Lm V^m L" jp-kanji)
("@" "YC" "g[m }Gm YC" "g[m }Gm YC" jp-kanji)
("A" "e" "AcCm e" "AcCm e" jp-kanji)
("B" "q" "q][m q" "q][m q" jp-kanji)
("C" "q" "qRcm q" "qRcm q" jp-kanji)
("D" "t" "n^m t" "n^m t" jp-kanji)
("E" "w" "^Rm w" "^Rm w" jp-kanji)
("F" "P" "XWm P" "XWm P" jp-kanji)
("G" "TC" "Gm TC" "Gm TC" jp-kanji)
("H" "ZC" "i}OTCm ZC" "i}OTCm ZC" jp-kanji)
("I" "m[" "m[m L[W" "m[m L[W" jp-kanji)
("J" "" "RGm " "RGm " jp-kanji)
("K" "Ic" "IbgZCm Ic" "IbgZCm Ic" jp-kanji)
("L" "JN" "JN}Nm JN" "JN}Nm JN" jp-kanji)
("M" "nN" "W[nNm nN" "W[nNm nN" jp-kanji)
("N" "{[" "{[R[m {[" "{[R[m {[" jp-kanji)
("O" "" "Z{lm " "Z{lm " jp-kanji)
("P" "R[" "jJm R[" "jJm R[" jp-kanji)
("Q" "RN" "cLwj Nj" "cLwj Nj" jp-kanji)
("R" "Zc" "cLwj L" "cLwj L" jp-kanji)
("S" "`c" "`cm ZCW" "`cm ZCW" jp-kanji)
("T" "`c" "WZCLm `c" "WZCLm `c" jp-kanji)
("U" "`[" "n^m CW" "n^m CW" jp-kanji)
("V" "W" "AuMm W" "AuMm W" jp-kanji)
("W" "n" "qmMm n" "qmMm n" jp-kanji)
("X" "XC" "XC][m XC" "XC][m XC" jp-kanji)
("Y" "JC" "i}Xm JC" "i}Xm JC" jp-kanji)
("Z" "YC" "Xlm CW" "Xlm CW" jp-kanji)
("[" "^" "Lm CW" "Lm CW" jp-kanji)
("\" "f" "Vm f" "Vm f" jp-kanji)
("]" "q" "qWm q" "qWm q" jp-kanji)
("^" "[" "A^m [" "A^m [" jp-kanji)
("_" "P" "JIm P" "JIm P" jp-kanji)
("`" "ZC" "z]m ZC" "z]m ZC" jp-kanji)
("a" "W" "Xlm W" "Xlm W" jp-kanji)
("b" "G" "mhm G" "mhm G" jp-kanji)
("c" "[" "[Qcm [" "[Qcm [" jp-kanji)
("d" "[" "W[[m [" "W[[m [" jp-kanji)
("e" "" "cLwj " "cLwj " jp-kanji)
("f" "][" "n^m L[W" "n^m L[W" jp-kanji)
("g" "" "R}Mm " "R}Mm " jp-kanji)
("h" "][" "Cm ][" "Cm ][" jp-kanji)
("i" "_C" "_Cm L[W" "_Cm L[W" jp-kanji)
("j" "V" "C^m V" "C^m V" jp-kanji)
("k" "" "qLgm " "qLgm " jp-kanji)
("l" "" "JSm " "JSm " jp-kanji)
("m" "V[" "EXYNm V[" "EXYNm V[" jp-kanji)
("n" "L[" "V[gm L[" "V[gm L[" jp-kanji)
("o" "" "A^Gm L[W" "A^Gm L[W" jp-kanji)
("p" "L[" "tCm L[W" "tCm L[W" jp-kanji)
("q" "V" "hm L[W" "hm L[W" jp-kanji)
("r" "V" "im V" "im V" jp-kanji)
("s" "z" "~Zm L[W" "~Zm L[W" jp-kanji)
("t" "Z" "tlwj L~" "tlwj L~" jp-kanji)
("u" "z[" "tlwj z[" "tlwj z[" jp-kanji)
("v" "J" "tlwj J" "tlwj J" jp-kanji)
("w" "`N" "wTLm `N" "wTLm `N" jp-kanji)
("x" "t" "nVPm t" "nVPm t" jp-kanji)
("y" "\[" "Z\[m \[" "Z\[m \[" jp-kanji)
("z" "\[" "tl J]G" "tl J]G" jp-kanji)
("{" "Z" "tlwj L" "tlwj L" jp-kanji)
("|" "\[" "tlwj \[" "tlwj \[" jp-kanji)
("}" "g[" "tlwm h[" "tlwm h[" jp-kanji)
("~" "M" "tlm \[r" "tlm \[r" jp-kanji)
("" "V[" "tlwj V[" "tlwj V[" jp-kanji)
("" "[" "[V[m [" "[V[m [" jp-kanji)
("" "" "tlwj " "tlwj " jp-kanji)
("" "" "gdim g" "gdim g" jp-kanji)
("" "" "gm NW" "gm NW" jp-kanji)
("" "J" "Jim J" "Jim J" jp-kanji)
("" "G" "Gm L[W" "Gm L[W" jp-kanji)
("" "\[" "NTm \[" "NTm \[" jp-kanji)
("" "KC" "Mm KC" "Mm KC" jp-kanji)
("" "VN" "VNNm VN" "VNNm VN" jp-kanji)
("" "{[" "XXLm {[" "XXLm {[" jp-kanji)
("" "J" "NTj Q" "NTj Q" jp-kanji)
("" "T" "Jm T" "Jm T" jp-kanji)
("" "X[" "nX[m X[" "nX[m X[" jp-kanji)
("" "t" "JIm t" "JIm t" jp-kanji)
("" "C" "IIoRm C" "IIoRm C" jp-kanji)
("" "L" "NTJj L" "NTJj L" jp-kanji)
("" "R[" "CVNm R[" "CVNm R[" jp-kanji)
("" "[" "[WNm [" "[WNm [" jp-kanji)
("" "V" "ATm V" "ATm V" jp-kanji)
("" "g[" "tLm g[" "tLm g[" jp-kanji)
("" "}C" "C`Sm }C" "C`Sm }C" jp-kanji)
("" "}C" "C`Sm ZCW" "C`Sm ZCW" jp-kanji)
("" "n" "ZCm qgc" "ZCm qgc" jp-kanji)
("" "t" "NTJj t" "NTJj t" jp-kanji)
("" "wC" "ELNTm wC" "ELNTm wC" jp-kanji)
("" "z[" "cc~m z[" "cc~m z[" jp-kanji)
("" "{[" "WTCm {[" "WTCm {[" jp-kanji)
("" "N" "NTJj " "NTJj " jp-kanji)
("" "oc" "WX~m oc" "WX~m oc" jp-kanji)
("" "[" "NTj ^c" "NTj ^c" jp-kanji)
("" "C" "Vglm C" "Vglm C" jp-kanji)
("" "JC" "ECL[m JC" "ECL[m JC" jp-kanji)
("" "JN" "}jm JN" "}jm JN" jp-kanji)
("" "V" "RRjm V" "RRjm V" jp-kanji)
("" "V" "O~m V" "O~m V" jp-kanji)
("" "W" "WVm W" "WVm W" jp-kanji)
("" "W" "fm W" "fm W" jp-kanji)
("" "Z" "VLjm Z" "VLjm Z" jp-kanji)
("" "g[" "NTj S[" "NTj S[" jp-kanji)
("" "tN" "NTj tZ" "NTj tZ" jp-kanji)
("" "{[" "{[[m {[" "{[[m {[" jp-kanji)
("" "C" "~[Km C" "~[Km C" jp-kanji)
("" "C" "IIjm C" "IIjm C" jp-kanji)
("" "" "NTj NC" "NTj NC" jp-kanji)
("" "G" "Vm G" "Vm G" jp-kanji)
("" "K" "cm Mm K" "cm Mm K" jp-kanji)
("" "K" "c{~m K" "c{~m K" jp-kanji)
("" "L[" "Tm L[" "Tm L[" jp-kanji)
("" "PC" "NLm L[W" "NLm L[W" jp-kanji)
("" "S" "NTj N" "NTj N" jp-kanji)
("" "T" "NTJj T" "NTJj T" jp-kanji)
("" "`" "NRm `" "NRm `" jp-kanji)
("" "\[" "VLm L[W" "VLm L[W" jp-kanji)
("" "g" "NTj A}" "NTj A}" jp-kanji)
("" "g" "ETMm CW" "ETMm CW" jp-kanji)
("" "g[" "}m g[" "}m g[" jp-kanji)
("" "W" "VmuOTm W" "VmuOTm W" jp-kanji)
("" "[" "lRWVm [" "lRWVm [" jp-kanji)
("" "" "WX~m " "WX~m " jp-kanji)
("" "[" "^oRm [" "^oRm [" jp-kanji)
("" "A" "CIm L[W" "CIm L[W" jp-kanji)
("" "M" "XiOTm M" "XiOTm M" jp-kanji)
("" "L" "X~m L" "X~m L" jp-kanji)
("" "R" "JIOTm R" "JIOTm R" jp-kanji)
("" "VN" "}m VN" "}m VN" jp-kanji)
("" "XC" "Ac}m XC" "Ac}m XC" jp-kanji)
("" "X[" "XYim X[" "XYim X[" jp-kanji)
("" "ZC" "NTj c}" "NTj c}" jp-kanji)
("" "ZC" "Jum ZC" "Jum ZC" jp-kanji)
("" "V[" "z[Lm V[" "z[Lm V[" jp-kanji)
("" "`[" "NTj iKC" "NTj iKC" jp-kanji)
("" "n" "NTj i~" "NTj i~" jp-kanji)
("" "q" "NTj AY" "NTj AY" jp-kanji)
("" "wC" "ELNTm wC" "ELNTm wC" jp-kanji)
("" "z[" "NTj A" "NTj A" jp-kanji)
("" "z[" "oGm z[" "oGm z[" jp-kanji)
("" "[" "NTm [" "NTm [" jp-kanji)
("" "" "N\[m im " "N\[m im " jp-kanji)
("" "[" "qVm [" "qVm [" jp-kanji)
("" "" "NTj nV" "NTj nV" jp-kanji)
("" "J" "Vm J" "Vm J" jp-kanji)
("" "J" "NTJj J" "NTJj J" jp-kanji)
("" "KN" "Eeim KN" "Eeim KN" jp-kanji)
("" "KN" "KNm L[W" "KNm L[W" jp-kanji)
("" "J" "NTj J" "NTj J" jp-kanji)
("" "N" "NVm N" "NVm N" jp-kanji)
("" "R" "jjNm N" "jjNm N" jp-kanji)
("" "X[" "zVOTm X[" "zVOTm X[" jp-kanji)
("" "^" "NQm ^" "NQm ^" jp-kanji)
("" "eC" "w^m eC" "w^m eC" jp-kanji)
("" "n" "Jxm n" "Jxm n" jp-kanji)
("" "z[" "JNXm z[" "JNXm z[" jp-kanji)
("" "}" "}m L[W" "}m L[W" jp-kanji)
("" "N" "IVxm Z^" "IVxm Z^" jp-kanji)
("" "V" "NTj zhRX" "NTj zhRX" jp-kanji)
("" "" "`Tm " "`Tm " jp-kanji)
("" "I[" "NTj ILi" "NTj ILi" jp-kanji)
("" "KC" "t^m CW" "t^m CW" jp-kanji)
("" "P" "NTj Jl" "NTj Jl" jp-kanji)
("" "R[" "Mm R[" "Mm R[" jp-kanji)
("" "R" "RjNm R" "RjNm R" jp-kanji)
("" "U" "NTj X" "NTj X" jp-kanji)
("" "V" "gMm V" "gMm V" jp-kanji)
("" "WN" "RjNm jN" "RjNm jN" jp-kanji)
("" "V[" "NTj IT" "NTj IT" jp-kanji)
("" "WN" "Vglm WN" "Vglm WN" jp-kanji)
("" "V" "NTm V" "NTm V" jp-kanji)
("" "ZL" "Vm ZL" "Vm ZL" jp-kanji)
("" "q" "q}m q" "q}m q" jp-kanji)
("" "{[" "S{[m {[" "S{[m {[" jp-kanji)
("" "TC" "NTj }c" "NTj }c" jp-kanji)
("" "VN" "NTj h" "NTj h" jp-kanji)
("" "W" "im V" "im V" jp-kanji)
("" "V" "Vg[m V" "Vg[m V" jp-kanji)
("" "T" "jWm W" "jWm W" jp-kanji)
("" "\" "AImm \" "AImm \" jp-kanji)
("" "\[" "Ac}m \[" "Ac}m \[" jp-kanji)
("" "^C" "w^m ^C" "w^m ^C" jp-kanji)
("" "tN" "ztNm tN" "ztNm tN" jp-kanji)
("" "[" "^fVim ^f" "^fVim ^f" jp-kanji)
("" "LN" "NTj LN" "NTj LN" jp-kanji)
("" "V" "NQm V" "NQm V" jp-kanji)
("" "W[" "^LMm W[" "^LMm W[" jp-kanji)
("" "V" "Lm Rm V" "Lm Rm V" jp-kanji)
("@" "W" "CNTm W" "CNTm W" jp-kanji)
("A" "YC" "Vxm YC" "Vxm YC" jp-kanji)
("B" "YC" "YCm ]NW" "YCm ]NW" jp-kanji)
("C" "[" "JKl\[" "JKl\[" jp-kanji)
("D" "E" "}cm E" "}cm E" jp-kanji)
("E" "JC" "bL[m JC" "bL[m JC" jp-kanji)
("F" "JC" "VQm JC" "VQm JC" jp-kanji)
("G" "L[" "nWJ~m L[" "nWJ~m L[" jp-kanji)
("H" "PC" "AU~m PC" "AU~m PC" jp-kanji)
("I" "R[" "~}Jm R[" "~}Jm R[" jp-kanji)
("J" "V[" "Mm V[" "Mm V[" jp-kanji)
("K" "VN" "om o" "om o" jp-kanji)
("L" "Zc" "Mm Zc" "Mm Zc" jp-kanji)
("M" "\[" "um L[W" "um L[W" jp-kanji)
("N" "r" "om " "om " jp-kanji)
("O" "wC" "wCm wC" "wCm wC" jp-kanji)
("P" "" "NTj AYP" "NTj AYP" jp-kanji)
("Q" "C" "c{~m C" "c{~m C" jp-kanji)
("R" "[" "NTj [" "NTj [" jp-kanji)
("S" "ZL" "[[Lm [L" "[[Lm [L" jp-kanji)
("T" "ZC" "iYim ZC" "iYim ZC" jp-kanji)
("U" "][" "Nm L[W" "Nm L[W" jp-kanji)
("V" "^C" "tLmg[m g[" "tLmg[m g[" jp-kanji)
("W" "r[" "JYm r[" "JYm r[" jp-kanji)
("X" "O[" "nXlm O[" "nXlm O[" jp-kanji)
("Y" "QC" "QCm L[W" "QCm L[W" jp-kanji)
("Z" "N" "NXm L[W" "NXm L[W" jp-kanji)
("[" "C" "AJUm C" "AJUm C" jp-kanji)
("\" "AC" "VQm AC" "VQm AC" jp-kanji)
("]" "E" "cm E" "cm E" jp-kanji)
("^" "\" "~KGm CW" "~KGm CW" jp-kanji)
("_" "q" "J^o~m q" "J^o~m q" jp-kanji)
("`" "C" "JM" "JM" jp-kanji)
("a" "" "COTm " "COTm " jp-kanji)
("b" "" "AVm L[W" "AVm L[W" jp-kanji)
("c" "[" "IIP_em [" "IIP_em [" jp-kanji)
("d" "Z" "RPm Z" "RPm Z" jp-kanji)
("e" "}" "NTm Jc" "NTm Jc" jp-kanji)
("f" "" "JYm " "JYm " jp-kanji)
("g" "R" "gKVm R" "gKVm R" jp-kanji)
("h" "R" "gm CW" "gm CW" jp-kanji)
("i" "P" "ccVm P" "ccVm P" jp-kanji)
("j" "S[" "TPum L[W" "TPum L[W" jp-kanji)
("k" "L" "JPm L" "JPm L" jp-kanji)
("l" "Vc" "V~m Vc" "V~m Vc" jp-kanji)
("m" "C" "~~Ym C" "~~Ym C" jp-kanji)
("n" "R[" "Jfm R[" "Jfm R[" jp-kanji)
("o" "V" "Em V" "Em V" jp-kanji)
("p" "g[" "Vwj g[" "Vwj g[" jp-kanji)
("q" "[C" "um [C" "um [C" jp-kanji)
("r" "z[" "huKCm z[" "huKCm z[" jp-kanji)
("s" "J" "Vwj A}C" "Vwj A}C" jp-kanji)
("t" "L[" "~~Ym L[" "~~Ym L[" jp-kanji)
("u" "R" "Pm R" "Pm R" jp-kanji)
("v" "V" "EWm V" "EWm V" jp-kanji)
("w" "[" "Vwj " "Vwj " jp-kanji)
("x" "C" "JQ[m [" "JQ[m [" jp-kanji)
("y" "C" "JLm C" "JLm C" jp-kanji)
("z" "z[" "Vwj cc" "Vwj cc" jp-kanji)
("{" "JC" "nm Vm JC" "nm Vm JC" jp-kanji)
("|" "Jc" "iNWm Jc" "iNWm Jc" jp-kanji)
("}" "L[" "RIMm L[" "RIMm L[" jp-kanji)
("~" "L[" "L[Im L[" "L[Im L[" jp-kanji)
("" "R[" "~Y`m R[" "~Y`m R[" jp-kanji)
("" "V" "Nm V" "Nm V" jp-kanji)
("" "[" "Vwj IC" "Vwj IC" jp-kanji)
("" "G" "Vwj m r" "Vwj m r" jp-kanji)
("" "P" "VW~m P" "VW~m P" jp-kanji)
("" "S" "SR[m S" "SR[m S" jp-kanji)
("" "VN" "CVm VN" "CVm VN" jp-kanji)
("" "V" "VL[m V" "VL[m V" jp-kanji)
("" "[C" "kPKm [C" "kPKm [C" jp-kanji)
("" "^" "^Wm ^" "^Wm ^" jp-kanji)
("" "t" "JQ[m JQ" "JQ[m JQ" jp-kanji)
("" "" "Vwj A}" "Vwj A}" jp-kanji)
("" "[" "TiMm [" "TiMm [" jp-kanji)
("" "" "ATm " "ATm " jp-kanji)
("" "GL" "Vwj GL" "Vwj GL" jp-kanji)
("" "G" "Vwj Ae" "Vwj Ae" jp-kanji)
("" "P" "jim P" "jim P" jp-kanji)
("" "ZC" "g{m ZC" "g{m ZC" jp-kanji)
("" "ZL" "gJQm ZL" "gJQm ZL" jp-kanji)
("" "`[" "qOVm `[" "qOVm `[" jp-kanji)
("" "q" "AuVm q" "AuVm q" jp-kanji)
("" "tN" "R[m " "R[m " jp-kanji)
("" "C" "CV[m C" "CV[m C" jp-kanji)
("" "J" "J^cm J" "J^cm J" jp-kanji)
("" "J" "I^}WNVm J" "I^}WNVm J" jp-kanji)
("" "Jc" "T\m Jc" "T\m Jc" jp-kanji)
("" "R" "R`[m m R" "R`[m m R" jp-kanji)
("" "R[" "CiSm R[" "CiSm R[" jp-kanji)
("" "Vc" "V~m CW" "V~m CW" jp-kanji)
("" "tN" "}Vm tN" "}Vm tN" jp-kanji)
("" "w" "R[m R[" "R[m R[" jp-kanji)
("" "" "Vwj " "Vwj " jp-kanji)
("" "[" "JQ[m [" "JQ[m [" jp-kanji)
("" "g[" "Nm CbVm g[" "Nm CbVm g[" jp-kanji)
("" "[" "nGm L[W" "nGm L[W" jp-kanji)
("" "PC" "z^m L[W" "z^m L[W" jp-kanji)
("" "C" "YCVm C" "YCVm C" jp-kanji)
("" "[" "g[[m [" "g[[m [" jp-kanji)
("" "S[" "nT~m S[" "nT~m S[" jp-kanji)
("" "Vc" "LMXm Vc" "LMXm Vc" jp-kanji)
("" "V[" "CiSm V[" "CiSm V[" jp-kanji)
("" "Vc" "Vwj \c" "Vwj \c" jp-kanji)
("" "W[" "Vwj cl" "Vwj cl" jp-kanji)
("" "XC" "CGhm XC" "CGhm XC" jp-kanji)
("" "ZL" "TXm ZL" "TXm ZL" jp-kanji)
("" "`c" "`bLm `c" "`bLm `c" jp-kanji)
("" "g[" "Vwj h[" "Vwj h[" jp-kanji)
("" "oN" "qLKGm oN" "qLKGm oN" jp-kanji)
("" "oN" "oNm CW" "oNm CW" jp-kanji)
("" "[" "IPm [" "IPm [" jp-kanji)
("" "M[" "M[`[m M[" "M[`[m M[" jp-kanji)
("" "`[" "Vm L[W" "Vm L[W" jp-kanji)
("" "n" "_J}m n" "_J}m n" jp-kanji)
("" "JC" "Jjm CW" "Jjm CW" jp-kanji)
("" "Jc" "T\m Jc" "T\m Jc" jp-kanji)
("" "Z" "qLKGm Z" "qLKGm Z" jp-kanji)
("" "eC" "}em eC" "}em eC" jp-kanji)
("" "g[" "g[[m g[" "g[[m g[" jp-kanji)
("" "{[" "Eo~m {[" "Eo~m {[" jp-kanji)
("" "{[" "{[m CW" "{[m CW" jp-kanji)
("" "GC" "Vwj TJG" "Vwj TJG" jp-kanji)
("" "JN" "VNgV" "VNgV" jp-kanji)
("" "[" "ESNm [" "ESNm [" jp-kanji)
("" "V" "ESNm V" "ESNm V" jp-kanji)
("" "C" "qTSm C" "qTSm C" jp-kanji)
("" "R" "}hXm R" "}hXm R" jp-kanji)
("" "T" "JCRm L[W" "JCRm L[W" jp-kanji)
("" "g" "gm ZCW" "gm ZCW" jp-kanji)
("" "g" "LNCVm g" "LNCVm g" jp-kanji)
("" "o" "GrXm L[W" "GrXm L[W" jp-kanji)
("" "WN" "NWPm WN" "NWPm WN" jp-kanji)
("" "WN" "NWPm CW" "NWPm CW" jp-kanji)
("" "Q" "eEm Q" "eEm Q" jp-kanji)
("" "K" "KiCm K" "KiCm K" jp-kanji)
("" "GC" "}m L[W" "}m L[W" jp-kanji)
("" "N" "`}^m N" "`}^m N" jp-kanji)
("" "T" "Wom T" "Wom T" jp-kanji)
("" "G" "GZCKC" "GZCKC" jp-kanji)
("" "L" "h[Lm L" "h[Lm L" jp-kanji)
("" "R" "RVNm R" "RVNm R" jp-kanji)
("" "Wc" "ARm Wc" "ARm Wc" jp-kanji)
("" "W" "Gm W" "Gm W" jp-kanji)
("" "W" "Wm CW" "Wm CW" jp-kanji)
("" "m[" "PTm m[" "PTm m[" jp-kanji)
("" "Pc" "^gm Pc" "^gm Pc" jp-kanji)
("" "V" "qgGmm V" "qgGmm V" jp-kanji)
("" "^" "n_kOm ^" "n_kOm ^" jp-kanji)
("" "l" "Rwj V[" "Rwj V[" jp-kanji)
("" "n" "Rwj V" "Rwj V" jp-kanji)
("" "n" "iKWom o" "iKWom o" jp-kanji)
("" "z[" "^Cm z[" "^Cm z[" jp-kanji)
("" "{[" "iKTm {[" "iKTm {[" jp-kanji)
("" "{" "nnj R" "nnj R" jp-kanji)
("" "PC" "E`JPm PC" "E`JPm PC" jp-kanji)
("" "tN" "tNTm tN" "tNTm tN" jp-kanji)
("" "J~V" "Rj W[Q" "Rj W[Q" jp-kanji)
("" "R[" "Rj CN" "Rj CN" jp-kanji)
("" "GC" "X\m GC" "X\m GC" jp-kanji)
("" "L[" "JSm L[" "JSm L[" jp-kanji)
("" "N" "X\m N" "X\m N" jp-kanji)
("" "\[" "\IEm L[W" "\IEm L[W" jp-kanji)
("" "J" "ccm J" "ccm J" jp-kanji)
("" "JC" "EMm JC" "EMm JC" jp-kanji)
("" "ZL" "n_kOm ZL" "n_kOm ZL" jp-kanji)
("" "nC" "iKC Lm" "iKC Lm" jp-kanji)
("" "q" "^XPm q" "^XPm q" jp-kanji)
("" "[" "E`JPm [" "E`JPm [" jp-kanji)
("" "TC" "Rj c}" "Rj c}" jp-kanji)
("" "R" "thVm R" "thVm R" jp-kanji)
("" "w" "Z}Cm w" "Z}Cm w" jp-kanji)
("" "z" "llRm z" "llRm z" jp-kanji)
("" "z[" "zm L[W" "zm L[W" jp-kanji)
("" "I" "hem I" "hem I" jp-kanji)
("" "WN" "WN\[m WN" "WN\[m WN" jp-kanji)
("" "^C" "Rj V]N" "Rj V]N" jp-kanji)
("" "`" "EoEm `" "EoEm `" jp-kanji)
("" "L[" "Rj cC" "Rj cC" jp-kanji)
("" "W[" "m{m W[" "m{m W[" jp-kanji)
("" "Zc" "CZcm Zc" "CZcm Zc" jp-kanji)
("" "V[" "q_m V[" "q_m V[" jp-kanji)
("" "" "Gm " "Gm " jp-kanji)
("" "^" "qgGm ^" "qgGm ^" jp-kanji)
("" "^" "^m NW" "^m NW" jp-kanji)
("" "g[" "E`JPm g[" "E`JPm g[" jp-kanji)
("" "wL" "q_m wL" "q_m wL" jp-kanji)
("@" "W" "iKWom W" "iKWom W" jp-kanji)
("A" "" "{m " "{m " jp-kanji)
("B" "Pc" "c}oTm Pc" "c}oTm Pc" jp-kanji)
("C" "xc" "^rm xc" "^rm xc" jp-kanji)
("D" "V" "n_Mm V" "n_Mm V" jp-kanji)
("E" "" "Rj " "Rj " jp-kanji)
("F" "L" "Rj AQ" "Rj AQ" jp-kanji)
("G" "A" "IIEm A" "IIEm A" jp-kanji)
("H" "^" "tJNe qC" "tJNe qC" jp-kanji)
("I" "JN" "Vxm JN" "Vxm JN" jp-kanji)
("J" "L" "^Yim L" "^Yim L" jp-kanji)
("K" "xL" "gm xL" "gm xL" jp-kanji)
("L" "e" "EJKEm e" "EJKEm e" jp-kanji)
("M" "QL" "IgRm ~R" "IgRm ~R" jp-kanji)
("N" "g" "~m g" "~m g" jp-kanji)
("O" "" "RClKEm " "RClKEm " jp-kanji)
("P" "L" "EJKEm L" "EJKEm L" jp-kanji)
("Q" "R[" "tg~m R[" "tg~m R[" jp-kanji)
("R" "L" "}~Gm L" "}~Gm L" jp-kanji)
("S" "JN" "I{Gm L[W" "I{Gm L[W" jp-kanji)
("T" "" "~m L[W" "~m L[W" jp-kanji)
("U" "eL" "}~Gm eL" "}~Gm eL" jp-kanji)
("V" "J" "~m L[W" "~m L[W" jp-kanji)
("W" "R" "TJYLm R" "TJYLm R" jp-kanji)
("X" "V" "N`oVm V" "N`oVm V" jp-kanji)
("Y" "eC" "cmwm eC" "cmwm eC" jp-kanji)
("Z" "JC" "cmwj qcW" "cmwj qcW" jp-kanji)
("[" "V[" "TJYLm V[" "TJYLm V[" jp-kanji)
("\" "VN" "Tm L[W" "Tm L[W" jp-kanji)
("]" "t" "tz[m t" "tz[m t" jp-kanji)
("^" "Lc" "Im Lc" "Im Lc" jp-kanji)
("_" "Pc" "AoNm Pc" "AoNm Pc" jp-kanji)
("`" "R[" "NYm R[" "NYm R[" jp-kanji)
("a" "J" "i}m J" "i}m J" jp-kanji)
("b" "J" "CuJm J" "CuJm J" jp-kanji)
("c" "gc" "hm gc" "hm gc" jp-kanji)
("d" "J" "VJm J" "VJm J" jp-kanji)
("e" "R" "~m R" "~m R" jp-kanji)
("f" "\" "mEm \" "mEm \" jp-kanji)
("g" "^C" "mRXm ^C" "mRXm ^C" jp-kanji)
("h" "eC" "\Vm eC" "\Vm eC" jp-kanji)
("i" "" "mmVm " "mmVm " jp-kanji)
("j" "JC" "IhPm JC" "IhPm JC" jp-kanji)
("k" "L" "\Nm L" "\Nm L" jp-kanji)
("l" "S" "nYJVm S" "nYJVm S" jp-kanji)
("m" "W" "nJm W" "nJm W" jp-kanji)
("n" "`[" "Zm `[" "Zm `[" jp-kanji)
("o" "`[" "AcGm `[" "AcGm `[" jp-kanji)
("p" "C" "CVm C" "CVm C" jp-kanji)
("q" "JC" "IVGm JC" "IVGm JC" jp-kanji)
("r" "JC" "C}Vm JC" "C}Vm JC" jp-kanji)
("s" "L[" "^uJXm L[" "^uJXm L[" jp-kanji)
("t" "R[" "cQm R[" "cQm R[" jp-kanji)
("u" "V[" "giGm V[" "giGm V[" jp-kanji)
("v" "V[" "Zm V[" "Zm V[" jp-kanji)
("w" "u" "VCm u" "VCm u" jp-kanji)
("x" "W" "NhCm W" "NhCm W" jp-kanji)
("y" "\[" "CTJEm \[" "CTJEm \[" jp-kanji)
("z" "e" "wcEm e" "wcEm e" jp-kanji)
("{" "W[" "VJgm W[" "VJgm W[" jp-kanji)
("|" "J" "CTm CW" "CTm CW" jp-kanji)
("}" "A" "\Wm A" "\Wm A" jp-kanji)
("~" "JC" "nCJCm JC" "nCJCm JC" jp-kanji)
("" "KN" "`NQm KN" "`NQm KN" jp-kanji)
("" "L" "Cm L" "Cm L" jp-kanji)
("" "MN" "^m MN" "^m MN" jp-kanji)
("" "P" "J}rXVC" "J}rXVC" jp-kanji)
("" "R" "IhPm R" "IhPm R" jp-kanji)
("" "t[" "t[Vm t[" "t[Vm t[" jp-kanji)
("" "w" "wQm w" "wQm w" jp-kanji)
("" "[" "wcEm [" "wcEm [" jp-kanji)
("" "J" "E^m J" "E^m J" jp-kanji)
("" "P" "}Rgm P" "}Rgm P" jp-kanji)
("" "V" "INim V" "INim V" jp-kanji)
("" "V" "Vm CW" "Vm CW" jp-kanji)
("" "VN" "^cm VN" "^cm VN" jp-kanji)
("" "qc" "XJm qc" "XJm qc" jp-kanji)
("" "{[" "\Vm {[" "\Vm {[" jp-kanji)
("" "[" "E^Em [" "E^Em [" jp-kanji)
("" "I[" "E^Em I[" "E^Em I[" jp-kanji)
("" "LN" "Lm LN" "Lm LN" jp-kanji)
("" "PC" "VuLm PC" "VuLm PC" jp-kanji)
("" "^N" "Zm ^N" "Zm ^N" jp-kanji)
("" "}" "Aihm }" "Aihm }" jp-kanji)
("" "{" "nJm {" "nJm {" jp-kanji)
("" "J" "ETCm J" "ETCm J" jp-kanji)
("" "J" "i}m J" "i}m J" jp-kanji)
("" "L" "\Vm L" "\Vm L" jp-kanji)
("" "Lc" "Ccm Lc" "Ccm Lc" jp-kanji)
("" "V[" "AJVm L[W" "AJVm L[W" jp-kanji)
("" "Z" "Zm CW" "Zm CW" jp-kanji)
("" "Z" "\Vm Z" "\Vm Z" jp-kanji)
("" "^" "niVm ^" "niVm ^" jp-kanji)
("" "Z" "^Sgm Z" "^Sgm Z" jp-kanji)
("" "\[" "TOm \[" "TOm \[" jp-kanji)
("" "q" "^gGm q" "^gGm q" jp-kanji)
("" "N" "Pm L[W" "Pm L[W" jp-kanji)
("" "P" "Zm P" "Zm P" jp-kanji)
("" "" "z}m L[W" "z}m L[W" jp-kanji)
("" "hN" "~Em ~" "~Em ~" jp-kanji)
("" "G" "TJm G" "TJm G" jp-kanji)
("" "V[" "J^Lm L[W" "J^Lm L[W" jp-kanji)
("" "U" "\Vm U" "\Vm U" jp-kanji)
("" "W[" "Ym L[W" "Ym L[W" jp-kanji)
("" "V" "VVm V" "VVm V" jp-kanji)
("" "J" "Rum J" "Rum J" jp-kanji)
("" "T" "^^Gm L[W" "^^Gm L[W" jp-kanji)
("" "J" "R_}m J" "R_}m J" jp-kanji)
("" "Jc" "qCm Jc" "qCm Jc" jp-kanji)
("" "PC" "^jm L[W" "^jm L[W" jp-kanji)
("" "L" "Ajm L" "Ajm L" jp-kanji)
("" "G" "Gh[m G" "Gh[m G" jp-kanji)
("" "W" "^em L[W" "^em L[W" jp-kanji)
("" "z[" "^Jm L[W" "^Jm L[W" jp-kanji)
("" "V" "CmRm V" "CmRm V" jp-kanji)
("" "P" "ViEm P" "ViEm P" jp-kanji)
("" "`" "CmVVm L[W" "CmVVm L[W" jp-kanji)
("" "`" "Wim `" "Wim `" jp-kanji)
("" "TC" "}Ckm TC" "}Ckm TC" jp-kanji)
("" "`[" "h[ucm `[" "h[ucm `[" jp-kanji)
("" "JN" "h[ucm Wi" "h[ucm Wi" jp-kanji)
("" "L[" "Wij X" "Wij X" jp-kanji)
("" "nN" "Pmm i}G" "Pmm i}G" jp-kanji)
("" "" "^kLm L[W" "^kLm L[W" jp-kanji)
("" "QC" "VJm Rm QC" "VJm Rm QC" jp-kanji)
("" "q" "qm ZCW" "qm ZCW" jp-kanji)
("" "q" "[W[m i" "[W[m i" jp-kanji)
("" "oN" "h[ucm oN" "h[ucm oN" jp-kanji)
("" "UC" "^Jm L[W" "^Jm L[W" jp-kanji)
("" "Vc" "^_Xm L[W" "^_Xm L[W" jp-kanji)
("" "h" "T{m h" "T{m h" jp-kanji)
("" "C" "INm C" "INm C" jp-kanji)
("" "V" "^Jm V" "^Jm V" jp-kanji)
("" "j[" "t^cm L[W" "t^cm L[W" jp-kanji)
("" "j" "t^cm CW" "t^cm CW" jp-kanji)
("" "w" "IgVm w" "IgVm w" jp-kanji)
("" "R" "V[jm R" "V[jm R" jp-kanji)
("" "z" "JUm z" "JUm z" jp-kanji)
("" "Z" "CVCm Z" "CVCm Z" jp-kanji)
("" "oC" "Em L[W" "Em L[W" jp-kanji)
("" "C" "^}m C" "^}m C" jp-kanji)
("" "TC" "TCZm TC" "TCZm TC" jp-kanji)
("" "^" "XJXm P" "XJXm P" jp-kanji)
("" "t" "INm t" "INm t" jp-kanji)
("" "V" "CPjGm jG" "CPjGm jG" jp-kanji)
("" "[C" "_m [C" "_m [C" jp-kanji)
("" "T" "^XPm ZCW" "^XPm ZCW" jp-kanji)
("" "C" "EcNVC T}" "EcNVC T}" jp-kanji)
("" "GC" "jVm " "jVm " jp-kanji)
("" "Z" "jMXm Z" "jMXm Z" jp-kanji)
("" "W" "niPm W" "niPm W" jp-kanji)
("" "ZC" "^Xm ZC" "^Xm ZC" jp-kanji)
("" "][" "][UCm ][" "][UCm ][" jp-kanji)
("" "\[" "JCwj V[" "JCwj V[" jp-kanji)
("" "q" "qCLm qC" "qCLm qC" jp-kanji)
("" "VN" "AKiEm VN" "AKiEm VN" jp-kanji)
("" "^" "AJm ^" "AJm ^" jp-kanji)
("" "V" "AJCm V" "AJCm V" jp-kanji)
("" "\[" "nVm CW" "nVm CW" jp-kanji)
("" "L[" "^P_PVC" "^P_PVC" jp-kanji)
("" "`" "nVm `" "nVm `" jp-kanji)
("" "`[" "RNCm `[" "RNCm `[" jp-kanji)
("" "L" "c}_em L" "c}_em L" jp-kanji)
("" "V" "AVm V" "AVm V" jp-kanji)
("" "t" "AOm t" "AOm t" jp-kanji)
("" "J" "Jtm J" "Jtm J" jp-kanji)
("" "T" "AVwj Tc" "AVwj Tc" jp-kanji)
("" "ZL" "AVwj CV" "AVwj CV" jp-kanji)
("" "ec" "c}YNm ec" "c}YNm ec" jp-kanji)
("" "n" "nR[m n" "nR[m n" jp-kanji)
("" "oc" "ocum oc" "ocum oc" jp-kanji)
("" "L" "qU}YNm L" "qU}YNm L" jp-kanji)
("" "L[" "AVIgm L[" "AVIgm L[" jp-kanji)
("" "R" "cPm R" "cPm R" jp-kanji)
("" "Z" "n_Vm Z" "n_Vm Z" jp-kanji)
("" "LN" "JKm LN" "JKm LN" jp-kanji)
("" "\" "EgCm CW" "EgCm CW" jp-kanji)
("" "[" "Nm [" "Nm [" jp-kanji)
("" "g" "AVwj nV" "AVwj nV" jp-kanji)
("" "J" "NuVm J" "NuVm J" jp-kanji)
("" "L" "EYN}m L" "EYN}m L" jp-kanji)
("" "Z" "IRiEm L[W" "IRiEm L[W" jp-kanji)
("" "`" "AVwj V" "AVwj V" jp-kanji)
("" "W[" "t~jWm W[" "t~jWm W[" jp-kanji)
("" "V[" "JJgm V[" "JJgm V[" jp-kanji)
("" "" "RGm " "RGm " jp-kanji)
("" "[" "Ihm CW" "Ihm CW" jp-kanji)
("" "PC" "~`m PC" "~`m PC" jp-kanji)
("@" "P" "PPm P" "PPm P" jp-kanji)
("A" "T" "c}YNm T" "c}YNm T" jp-kanji)
("B" "\[" "Nm \[" "Nm \[" jp-kanji)
("C" "ZL" "AVwj ZL" "AVwj ZL" jp-kanji)
("D" "g[" "tm CW" "tm CW" jp-kanji)
("E" "VN" "Z}m VN" "Z}m VN" jp-kanji)
("F" "V[" "Agm V[" "Agm V[" jp-kanji)
("G" "ZL" "AVEm ZL" "AVEm ZL" jp-kanji)
("H" "\[" "AVwj \[" "AVwj \[" jp-kanji)
("I" "}" "Nm }" "Nm }" jp-kanji)
("J" "qc" "TLoCm qc" "TLoCm qc" jp-kanji)
("K" "Pc" "c}YNm Pc" "c}YNm Pc" jp-kanji)
("L" "\" "EYN}m \" "EYN}m \" jp-kanji)
("M" "{N" "~YJLm zN" "~YJLm zN" jp-kanji)
("N" "\[" "TOm \[" "TOm \[" jp-kanji)
("O" "`" "^Em `" "^Em `" jp-kanji)
("P" "`N" "eL`Nm `N" "eL`Nm `N" jp-kanji)
("Q" "wL" "CUm wL" "CUm wL" jp-kanji)
("R" "ZC" "m{m ZC" "m{m ZC" jp-kanji)
("S" "`[" "^Em `[" "^Em `[" jp-kanji)
("T" "`" "c}YNm `" "c}YNm `" jp-kanji)
("U" "eL" "eL`Nm eL" "eL`Nm eL" jp-kanji)
("V" "e" "tm e" "tm e" jp-kanji)
("W" "" "tm " "tm " jp-kanji)
("X" "" "m CW" "m CW" jp-kanji)
("Y" "W[" "tm W[" "tm W[" jp-kanji)
("Z" "L[" "~YJm L[" "~YJm L[" jp-kanji)
("[" "^C" "J_m CW" "J_m CW" jp-kanji)
("\" "^C" "J_m L[W" "J_m L[W" jp-kanji)
("]" "^" "JXm ^" "JXm ^" jp-kanji)
("^" "r" "~wj EcNVC" "~wj EcNVC" jp-kanji)
("_" "J" "~wj J" "~wj J" jp-kanji)
("`" "I[" "~wj I[" "~wj I[" jp-kanji)
("a" "Ac" "LVm Ac" "LVm Ac" jp-kanji)
("b" "N" "NrLm N" "NrLm N" jp-kanji)
("c" "S[" "ghNm NW" "ghNm NW" jp-kanji)
("d" "ec" "N}wj TL" "N}wj TL" jp-kanji)
("e" "J" "N}wj J" "N}wj J" jp-kanji)
("f" "V" "C^m V" "C^m V" jp-kanji)
("g" "VN" "N}wj VL" "N}wj VL" jp-kanji)
("h" "`" "N}j C^" "N}j C^" jp-kanji)
("i" "JN" "N}wj JN" "N}wj JN" jp-kanji)
("j" "PC" "JCm L[W" "JCm L[W" jp-kanji)
("k" "`[" "Xi`m `[" "Xi`m `[" jp-kanji)
("l" "`[" "`[m ]NW" "`[m ]NW" jp-kanji)
("m" "o" "qNm o" "qNm o" jp-kanji)
("n" "V" "jO}m V" "jO}m V" jp-kanji)
("o" "ec" "ghm ec" "ghm ec" jp-kanji)
("p" "[" "[m L[W" "[m L[W" jp-kanji)
("q" "[" "V[m [" "V[m [" jp-kanji)
("r" "" "erLO}" "erLO}" jp-kanji)
("s" "\[" "Ac}m \[" "Ac}m \[" jp-kanji)
("t" "tN" "tNVm tN" "tNVm tN" jp-kanji)
("u" "tN" "N}j tN" "N}j tN" jp-kanji)
("v" "G" "iKGm G" "iKGm G" jp-kanji)
("w" "RN" "RVLm RN" "RVLm RN" jp-kanji)
("x" "e" "LVm e" "LVm e" jp-kanji)
("y" "V" "N}wj L" "N}wj L" jp-kanji)
("z" "e" "RKm L[W" "RKm L[W" jp-kanji)
("{" "N" "Nm N" "Nm N" jp-kanji)
("|" "L[" "JSm L[" "JSm L[" jp-kanji)
("}" "J" "tEm J" "tEm J" jp-kanji)
("~" "W" "qcMO}m W" "qcMO}m W" jp-kanji)
("" "L" "qNm L" "qNm L" jp-kanji)
("" "L" "N}wj L" "N}wj L" jp-kanji)
("" "" "Nm " "Nm " jp-kanji)
("" "R" "c~m R" "c~m R" jp-kanji)
("" "wL" "eVm wL" "eVm wL" jp-kanji)
("" "c" "JCm c" "JCm c" jp-kanji)
("" "W" "m L[W" "m L[W" jp-kanji)
("" "x" "xm L[W" "xm L[W" jp-kanji)
("" "Cc" "Vj[j C`" "Vj[j C`" jp-kanji)
("" "`[" "Vj[j iJ" "Vj[j iJ" jp-kanji)
("" "PC" "nJm PC" "nJm PC" jp-kanji)
("" "`[" "nJm `[" "nJm `[" jp-kanji)
("" "eL" "~`rNm eL" "~`rNm eL" jp-kanji)
("" "g[" "Vj[j \g" "Vj[j \g" jp-kanji)
("" "j[" "jm L[W" "jm L[W" jp-kanji)
("" "JC" "Vj[j JC" "Vj[j JC" jp-kanji)
("" "R[" "OAEm R[" "OAEm R[" jp-kanji)
("" "ZL" "Agm ZL" "Agm ZL" jp-kanji)
("" "iC" "Xi`m iC" "Xi`m iC" jp-kanji)
("" "L[" "Vj[j g" "Vj[j g" jp-kanji)
("" "PC" "R~`m CW" "R~`m CW" jp-kanji)
("" "V" "VWm V" "VWm V" jp-kanji)
("" "V[" "V[[m V[" "V[[m V[" jp-kanji)
("" "eC" "^N}VCm eC" "^N}VCm eC" jp-kanji)
("" "eL" "nJm eL" "nJm eL" jp-kanji)
("" "z" "mKm z" "mKm z" jp-kanji)
("" "RN" "Vj[j ^j" "Vj[j ^j" jp-kanji)
("" "C" "iij CNm C" "iij CNm C" jp-kanji)
("" "L" "~`m L" "~`m L" jp-kanji)
("" "^c" "^bXm L[W" "^bXm L[W" jp-kanji)
("" "z[" "zgoVm z[" "zgoVm z[" jp-kanji)
("" "Ac" "gm Ac" "gm Ac" jp-kanji)
("" "J" "nJm J" "nJm J" jp-kanji)
("" "R[" "Cg}m R[" "Cg}m R[" jp-kanji)
("" "V[" "V[m CW" "V[m CW" jp-kanji)
("" "V[" "cCm V[" "cCm V[" jp-kanji)
("" "eC" "TXKjm eC" "TXKjm eC" jp-kanji)
("" "" "RGm " "RGm " jp-kanji)
("" "i" "Vj[j ~i~" "Vj[j ~i~" jp-kanji)
("" "R[" "AEm R[" "AEm R[" jp-kanji)
("" "eC" "eCm L[W" "eCm L[W" jp-kanji)
("" "S[" "A\um S[" "A\um S[" jp-kanji)
("" "g" "mKm g" "mKm g" jp-kanji)
("" "W[" "Om W[" "Om W[" jp-kanji)
("" "YC" "YCm CW" "YCm CW" jp-kanji)
("" "`" "INm L[W" "INm L[W" jp-kanji)
("" "JC" "AEm JC" "AEm JC" jp-kanji)
("" "L" "X~Jjm L" "X~Jjm L" jp-kanji)
("" "}C" "XMm }C" "XMm }C" jp-kanji)
("" "[" "JGm [" "JGm [" jp-kanji)
("" "w" "A^m L[W" "A^m L[W" jp-kanji)
("" "w" "A^m CW" "A^m CW" jp-kanji)
("" "" "Om " "Om " jp-kanji)
("" "g" "m g" "m g" jp-kanji)
("" "J" "J^m J" "J^m J" jp-kanji)
("" "L[" "IJm L[" "IJm L[" jp-kanji)
("" "V[" "ZCm qgc" "ZCm qgc" jp-kanji)
("" "GC" "\m ~Rm i" "\m ~Rm i" jp-kanji)
("" "QL" "XL}m QL" "XL}m QL" jp-kanji)
("" "R" "ghm R" "ghm R" jp-kanji)
("" "t" "Nm t" "Nm t" jp-kanji)
("" "KN" "Cm Njm i" "Cm Njm i" jp-kanji)
("" "X[" "[Vm ZC`" "[Vm ZC`" jp-kanji)
("" "q" "CiJm q" "CiJm q" jp-kanji)
("" "^" "J^m ^" "J^m ^" jp-kanji)
("" "" "gim CW" "gim CW" jp-kanji)
("" "eC" "Em eC" "Em eC" jp-kanji)
("" "^" "^fLm ^" "^fLm ^" jp-kanji)
("" "g[" "g[Vm g[" "g[Vm g[" jp-kanji)
("" "J" "^Pim J" "^Pim J" jp-kanji)
("" "\" "TPwj m M" "TPwj m M" jp-kanji)
("" "C" "Em C" "Em C" jp-kanji)
("" "C" "XYNm C" "XYNm C" jp-kanji)
("" "eC" "tcJCm eC" "tcJCm eC" jp-kanji)
("" "TN" "Xm CW" "Xm CW" jp-kanji)
("" "XC" "Em L[W" "Em L[W" jp-kanji)
("" "" "~m " "~m " jp-kanji)
("" "JC" "VIJm JC" "VIJm JC" jp-kanji)
("" "C" "CXm L[W" "CXm L[W" jp-kanji)
("" "PC" "Xm PC" "Xm PC" jp-kanji)
("" "[" "huNm [" "huNm [" jp-kanji)
("" "L" "LLm L" "LLm L" jp-kanji)
("" "C" "A}UPm C" "A}UPm C" jp-kanji)
("" "N" "Em N" "Em N" jp-kanji)
("" "W[" "JXm L[W" "JXm L[W" jp-kanji)
("" "L" "q}m L" "q}m L" jp-kanji)
("" "[" "EOXm [" "EOXm [" jp-kanji)
("" "VN" "Xm L[W" "Xm L[W" jp-kanji)
("" "" "ITm " "ITm " jp-kanji)
("" "g[" "Jlwj J^i" "Jlwj J^i" jp-kanji)
("" "nc" "Jlwj n`" "Jlwj n`" jp-kanji)
("" "t" "J}m CW" "J}m CW" jp-kanji)
("" "RN" "Jlwj `J" "Jlwj `J" jp-kanji)
("" "P" "cMm CW" "cMm CW" jp-kanji)
("" "T" "JUVm T" "JUVm T" jp-kanji)
("" "V" "Jlwj i" "Jlwj i" jp-kanji)
("" "L" "qgVCm L" "qgVCm L" jp-kanji)
("" "L" "^`Lm L" "^`Lm L" jp-kanji)
("" "V[" "XNCgm V[" "XNCgm V[" jp-kanji)
("" "^N" "^Nm NW" "^Nm NW" jp-kanji)
("" "`[" "{^m `[" "{^m `[" jp-kanji)
("" "o" "C^Klm o" "C^Klm o" jp-kanji)
("" "Gc" "}TJm Gc" "}TJm Gc" jp-kanji)
("" "J" "NrJZm J" "NrJZm J" jp-kanji)
("" "L" "IILCm L" "IILCm L" jp-kanji)
("" "Q" "Jlwj Q" "Jlwj Q" jp-kanji)
("" "N" "JMm N" "JMm N" jp-kanji)
("" "V" "i^m V" "i^m V" jp-kanji)
("" "ec" "NKlm ec" "NKlm ec" jp-kanji)
("" "e" "Jlwj ^" "Jlwj ^" jp-kanji)
("" "z[" "Jim z[" "Jim z[" jp-kanji)
("" "ZL" "Jlwj CV" "Jlwj CV" jp-kanji)
("" "J" "Ncm J" "Ncm J" jp-kanji)
("" "V" "Jlwj V" "Jlwj V" jp-kanji)
("" "Z" "nJm Z" "nJm Z" jp-kanji)
("" "Z" "mm Z" "mm Z" jp-kanji)
("" "[" "Jlwj E" "Jlwj E" jp-kanji)
("" "L[" "nT~m L[" "nT~m L[" jp-kanji)
("" "V[" "Trm V[" "Trm V[" jp-kanji)
("" "V[" "gPm V[" "gPm V[" jp-kanji)
("" "{[" "LbTLm {[" "LbTLm {[" jp-kanji)
("" "A" "VRm A" "VRm A" jp-kanji)
("" "G" "Ji}m G" "Ji}m G" jp-kanji)
("" "L[" "Jlwj L[" "Jlwj L[" jp-kanji)
("" "R" "tTOm R" "tTOm R" jp-kanji)
("@" "V" "J^m ^C" "J^m ^C" jp-kanji)
("A" "Z" "[jm L[W" "[jm L[W" jp-kanji)
("B" "\[" "hm \[" "hm \[" jp-kanji)
("C" "eC" "VRm eC" "VRm eC" jp-kanji)
("D" "L`" "Jlwj V" "Jlwj V" jp-kanji)
("E" "J" "Jlwj ni" "Jlwj ni" jp-kanji)
("F" "u" "Jlwj u" "Jlwj u" jp-kanji)
("G" "J" "Jlwj J" "Jlwj J" jp-kanji)
("H" "R[" "Jlwj R[" "Jlwj R[" jp-kanji)
("I" "V" "VL[m n" "VL[m n" jp-kanji)
("J" "`[" "V`[m `[" "V`[m `[" jp-kanji)
("K" "`" "Jlwj W" "Jlwj W" jp-kanji)
("L" "Cc" "Jlwj }X" "Jlwj }X" jp-kanji)
("M" "R[" "ixVmMm R[" "ixVmMm R[" jp-kanji)
("N" "`" "VYm L[W" "VYm L[W" jp-kanji)
("O" "[" "CK^m [" "CK^m [" jp-kanji)
("P" "\[" "ecwj IN" "ecwj IN" jp-kanji)
("Q" "I[" "~iSVm I[" "~iSVm I[" jp-kanji)
("R" "R[" "Jlwj J^C" "Jlwj J^C" jp-kanji)
("S" "T" "^Klm T" "^Klm T" jp-kanji)
("T" "V[" "Jlwj h" "Jlwj h" jp-kanji)
("U" "V[" "Jlwj V[" "Jlwj V[" jp-kanji)
("V" "\N" "Wm \N" "Wm \N" jp-kanji)
("W" "}" "Rem }" "Rem }" jp-kanji)
("X" "[" "CV~m w" "CV~m w" jp-kanji)
("Y" "" "NTm " "NTm " jp-kanji)
("Z" "[" "zm [" "zm [" jp-kanji)
("[" "A" "VRm A" "VRm A" jp-kanji)
("\" "^" "com ^" "com ^" jp-kanji)
("]" "^C" "CVYLm ^C" "CVYLm ^C" jp-kanji)
("^" "h[" "hm h[" "hm h[" jp-kanji)
("_" "n" "Jlwj o" "Jlwj o" jp-kanji)
("`" "[" "NTm [" "NTm [" jp-kanji)
("a" "J" "rm J" "rm J" jp-kanji)
("b" "Z" "m~m Z" "m~m Z" jp-kanji)
("c" "ec" "ecm L[W" "ecm L[W" jp-kanji)
("d" "ec" "ecm CW" "ecm CW" jp-kanji)
("e" "g[" "RWm g[" "RWm g[" jp-kanji)
("f" "o" "E}m NrJU" "E}m NrJU" jp-kanji)
("g" "J" "JK~m CW" "JK~m CW" jp-kanji)
("h" "`[" "Cm L[W" "Cm L[W" jp-kanji)
("i" "R[" "AKlm L[W" "AKlm L[W" jp-kanji)
("j" "VN" "gJXm VN" "gJXm VN" jp-kanji)
("k" "" "Xm " "Xm " jp-kanji)
("l" "[" "XYm [" "XYm [" jp-kanji)
("m" "" "Cm " "Cm " jp-kanji)
("n" "" "Cm NW" "Cm NW" jp-kanji)
("o" "N" "JMm N" "JMm N" jp-kanji)
("p" "J" "uLJm J" "uLJm J" jp-kanji)
("q" "W[" "PkLm W[" "PkLm W[" jp-kanji)
("r" "T" "Lm L[W" "Lm L[W" jp-kanji)
("s" "T" "Lm T" "Lm T" jp-kanji)
("t" "" "hm " "hm " jp-kanji)
("u" "" "XYm " "XYm " jp-kanji)
("v" "JN" "Nm JN" "Nm JN" jp-kanji)
("w" "TN" "EKcm TN" "EKcm TN" jp-kanji)
("x" "T" "JkLm T" "JkLm T" jp-kanji)
("y" "wC" "gWm CW" "gWm CW" jp-kanji)
("z" "Z" "K}Gj }" "K}Gj }" jp-kanji)
("{" "r" "EGj r" "EGj r" jp-kanji)
("|" "XC" "K}Gj ~Y" "K}Gj ~Y" jp-kanji)
("}" "R[" "XCm R[" "XCm R[" jp-kanji)
("~" "h[" "TKVCm h[" "TKVCm h[" jp-kanji)
("" "MN" "K}Gj ^}" "K}Gj ^}" jp-kanji)
("" "PC" "PCV[m PC" "PCV[m PC" jp-kanji)
("" "R[" "J`hLm R[" "J`hLm R[" jp-kanji)
("" "" "R[m " "R[m " jp-kanji)
("" "Ac" "tTOm Ac" "tTOm Ac" jp-kanji)
("" "G" "G}m G" "G}m G" jp-kanji)
("" "G" "LZCXm G" "LZCXm G" jp-kanji)
("" "CL" "VLCm CL" "VLCm CL" jp-kanji)
("" "Jc" "Jb^cm Jc" "Jb^cm Jc" jp-kanji)
("" "Jc" "Jcm CW" "Jcm CW" jp-kanji)
("" "PL" "VXJm PL" "VXJm PL" jp-kanji)
("" "g" "K}Gj m" "K}Gj m" jp-kanji)
("" "" "^Pim " "^Pim " jp-kanji)
("" "Pc" "JPm Pc" "JPm Pc" jp-kanji)
("" "R[" "m gr" "m gr" jp-kanji)
("" "`" "`j[m `" "`j[m `" jp-kanji)
("" "J" "ZLm L[W" "ZLm L[W" jp-kanji)
("" "Z" "ALJm Z" "ALJm Z" jp-kanji)
("" "^c" "K}Gj ^c" "K}Gj ^c" jp-kanji)
("" "wL" "qNm wL" "qNm wL" jp-kanji)
("" "Z" "~`m Z" "~`m Z" jp-kanji)
("" "N" "tTKm N" "tTKm N" jp-kanji)
("" "Q" "Cm RNC" "Cm RNC" jp-kanji)
("" "V" "Agm V" "Agm V" jp-kanji)
("" "n" "cc~m n" "cc~m n" jp-kanji)
("" "nN" "RUgwj qN" "RUgwj qN" jp-kanji)
("" "^" "RUgwj A" "RUgwj A" jp-kanji)
("" "[" "CVCm [" "CVCm [" jp-kanji)
("" "J" "I`Cm CW" "I`Cm CW" jp-kanji)
("" "L[" "}ACm L[" "}ACm L[" jp-kanji)
("" "V[" "m{m V[" "m{m V[" jp-kanji)
("" "Z" "ZZCV[" "ZZCV[" jp-kanji)
("" "`N" "m{m `N" "m{m `N" jp-kanji)
("" "g[" "RUgwj W" "RUgwj W" jp-kanji)
("" "XC" "zgm XC" "zgm XC" jp-kanji)
("" "X[" "X~m X[" "X~m X[" jp-kanji)
("" "R[" "zm R[" "zm R[" jp-kanji)
("" "AC" "Z}Cm AC" "Z}Cm AC" jp-kanji)
("" "C" "CZLm C" "CZLm C" jp-kanji)
("" "JC" "RUgwj Ij" "RUgwj Ij" jp-kanji)
("" "P" "PVCm L[W" "PVCm L[W" jp-kanji)
("" "XC" "glm YC" "glm YC" jp-kanji)
("" "C" "JNm L[W" "JNm L[W" jp-kanji)
("" "Vc" "T_m Vc" "T_m Vc" jp-kanji)
("" "Vc" "T`m Vc" "T`m Vc" jp-kanji)
("" "[" "IJm [" "IJm [" jp-kanji)
("" "^C" "Ium ^C" "Ium ^C" jp-kanji)
("" "C" "V^KEm L[W" "V^KEm L[W" jp-kanji)
("" "XC" "gm XC" "gm XC" jp-kanji)
("" "V" "~nm V" "~nm V" jp-kanji)
("" "V" "XO^m V" "XO^m V" jp-kanji)
("" "`" "LWm `" "LWm `" jp-kanji)
("" "[" "Om [" "Om [" jp-kanji)
("" "][" "Rwj V[" "Rwj V[" jp-kanji)
("" "Uc" "}Wm L[W" "}Wm L[W" jp-kanji)
("" "JN" "jJm JN" "jJm JN" jp-kanji)
("" "`[" "`[nm `[" "`[nm `[" jp-kanji)
("" "nN" "q[m nN" "q[m nN" jp-kanji)
("" "V[" "\m V[" "\m V[" jp-kanji)
("" "eC" "CJY`m eC" "CJY`m eC" jp-kanji)
("" "nC" "IIAm nC" "IIAm nC" jp-kanji)
("" "QC" "jWm QC" "jWm QC" jp-kanji)
("" "V[" "VoVm \[" "VoVm \[" jp-kanji)
("" "e" "EIXm e" "EIXm e" jp-kanji)
("" "q" "m q" "m q" jp-kanji)
("" "" "iKAm " "iKAm " jp-kanji)
("" "GC" "~]m GC" "~]m GC" jp-kanji)
("" "[" "A}_m [" "A}_m [" jp-kanji)
("" "C" "iKAm C" "iKAm C" jp-kanji)
("" "T" "Am T" "Am T" jp-kanji)
("" "wL" "CJY`m wL" "CJY`m wL" jp-kanji)
("" "ZC" "nm ZC" "nm ZC" jp-kanji)
("" "oC" "c`Om oC" "c`Om oC" jp-kanji)
("" "AC" "m AC" "m AC" jp-kanji)
("" "^C" "AC^Cm ^C" "AC^Cm ^C" jp-kanji)
("" "C" "^}m L[W" "^}m L[W" jp-kanji)
("" "L" "Nj L" "Nj L" jp-kanji)
("" "AC" "AC^Cm AC" "AC^Cm AC" jp-kanji)
("" "ZC" "VYJm L[W" "VYJm L[W" jp-kanji)
("" "R[" "^KEm R[" "^KEm R[" jp-kanji)
("" "z[" "jLrm z[" "jLrm z[" jp-kanji)
("" "e" "wj ~" "wj ~" jp-kanji)
("" "[" "GN{m [" "GN{m [" jp-kanji)
("" "N" "Ncm N" "Ncm N" jp-kanji)
("" "W" "Wm CW" "Wm CW" jp-kanji)
("" "W" "ViJm W" "ViJm W" jp-kanji)
("" "iC" "Jwj E`" "Jwj E`" jp-kanji)
("" "I[" "iKCm I[" "iKCm I[" jp-kanji)
("" "^" "iVKm ^" "iVKm ^" jp-kanji)
("" "q" "Jwj J" "Jwj J" jp-kanji)
("" "}c" "Jwj XG" "Jwj XG" jp-kanji)
("" "wC" "Jwj wC" "Jwj wC" jp-kanji)
("" "AC" "Wm AC" "Wm AC" jp-kanji)
("" "L[" "^olm L[" "^olm L[" jp-kanji)
("" "Rn[" "Jwj W[Q" "Jwj W[Q" jp-kanji)
("" "g[" "Ncm g[" "Ncm g[" jp-kanji)
("" "Jc" "JOcm Jc" "JOcm Jc" jp-kanji)
("" "V[" "VKCm V[" "VKCm V[" jp-kanji)
("" "W[" "iXm W[" "iXm W[" jp-kanji)
("" "g[" "wCLm g[" "wCLm g[" jp-kanji)
("" "q" "tCSm q" "tCSm q" jp-kanji)
("" "_c" "_^Wm _c" "_^Wm _c" jp-kanji)
("" "Z" "Jwj Z" "Jwj Z" jp-kanji)
("" "oc" "NcV^m oc" "NcV^m oc" jp-kanji)
("" "C" "iVKm C" "iVKm C" jp-kanji)
("" "g[" "g[JCm g[" "g[JCm g[" jp-kanji)
("" "LN" "jm LN" "jm LN" jp-kanji)
("" "ZC" "i}Xm ZC" "i}Xm ZC" jp-kanji)
("" "ZC" "i}Xm CW" "i}Xm CW" jp-kanji)
("" "L[" "cCjm L[" "cCjm L[" jp-kanji)
("" "V[" "EcNVCm V[" "EcNVCm V[" jp-kanji)
("" "C" "qrNm CW" "qrNm CW" jp-kanji)
("" "R[" "mhm R[" "mhm R[" jp-kanji)
("" "V[" "zm V[" "zm V[" jp-kanji)
("" "PC" "PCYCm PC" "PCYCm PC" jp-kanji)
("" "C" "ASm C" "ASm C" jp-kanji)
("" "Lc" "NrXWm Lc" "NrXWm Lc" jp-kanji)
("" "J" "EiYNm J" "EiYNm J" jp-kanji)
("" "^C" "NYm ^C" "NYm ^C" jp-kanji)
("" "J" "cum J" "cum J" jp-kanji)
("" "K" "JIm ZCW" "JIm ZCW" jp-kanji)
("" "TC" "Gm TC" "Gm TC" jp-kanji)
("" "Z" "tGm Z" "tGm Z" jp-kanji)
("" "P" "ALm L[W" "ALm L[W" jp-kanji)
("" "r" "VJm r" "VJm r" jp-kanji)
("@" "" "`[Rcm " "`[Rcm " jp-kanji)
("A" "J" "zI{lm J" "zI{lm J" jp-kanji)
("B" "V[" "RJ~m V[" "RJ~m V[" jp-kanji)
("C" "J" "V^j J[" "V^j J[" jp-kanji)
("D" "Tc" "nem Tc" "nem Tc" jp-kanji)
("E" "^C" "^Ct[m ^C" "^Ct[m ^C" jp-kanji)
("F" "N" "cWJ[m N" "cWJ[m N" jp-kanji)
("G" "q[" "qKGm q[" "qKGm q[" jp-kanji)
("H" "q[" "q[m CW" "q[m CW" jp-kanji)
("I" "q[" "{[t[m q[" "{[t[m q[" jp-kanji)
("J" "g" "V}W[" "V}W[" jp-kanji)
("K" "I" "ALm I" "ALm I" jp-kanji)
("L" "R[" "M[Um R[" "M[Um R[" jp-kanji)
("M" "Q" "Vm Q" "Vm Q" jp-kanji)
("N" "_C" "EGm _C" "EGm _C" jp-kanji)
("O" "z" "[Vm z" "[Vm z" jp-kanji)
("P" "" "A}m L[W" "A}m L[W" jp-kanji)
("Q" "A" "ARm A" "ARm A" jp-kanji)
("R" "VN" "JUm VN" "JUm VN" jp-kanji)
("S" "Z" "niPm Z" "niPm Z" jp-kanji)
("T" "^" "XXm ^" "XXm ^" jp-kanji)
("U" "wC" "`m wC" "`m wC" jp-kanji)
("V" "R" "Jm R" "Jm R" jp-kanji)
("W" "ec" "T{^x" "T{^x" jp-kanji)
("X" "L" "LKm L" "LKm L" jp-kanji)
("Y" "[" "VNwj [" "VNwj [" jp-kanji)
("Z" "E" "Ehm E" "Ehm E" jp-kanji)
("[" "L" "EGm L" "EGm L" jp-kanji)
("\" "}" "}W[m }" "}W[m }" jp-kanji)
("]" "C" "XGm C" "XGm C" jp-kanji)
("^" "L" "INmm L" "INmm L" jp-kanji)
("_" "L" "EGm L" "EGm L" jp-kanji)
("`" "W[" "^Jm W[" "^Jm W[" jp-kanji)
("a" "Z" "\iGm Z" "\iGm Z" jp-kanji)
("b" "g[" "T{m g[" "T{m g[" jp-kanji)
("c" "L" "zI{lm L" "zI{lm L" jp-kanji)
("d" "JN" "NrLm JN" "NrLm JN" jp-kanji)
("e" "tN" "JoVCm tN" "JoVCm tN" jp-kanji)
("f" "M" "Acm M" "Acm M" jp-kanji)
("g" "q[" "Vm Om q[" "Vm Om q[" jp-kanji)
("h" "u" "E}wj t~" "E}wj t~" jp-kanji)
("i" "V" "E}wj " "E}wj " jp-kanji)
("j" "V" "nCm V" "nCm V" jp-kanji)
("k" "_" "N_m _" "N_m _" jp-kanji)
("l" "^C" "juCm ^C" "juCm ^C" jp-kanji)
("m" "h" "juCm h" "juCm h" jp-kanji)
("n" "JC" "IhNm JC" "IhNm JC" jp-kanji)
("o" "nN" "}_m nN" "}_m nN" jp-kanji)
("p" "N" "N_m N" "N_m N" jp-kanji)
("q" "V[" "E}wj V[" "E}wj V[" jp-kanji)
("r" "J" "AE}m J" "AE}m J" jp-kanji)
("s" "V" "nCm V" "nCm V" jp-kanji)
("t" "eC" "nZm eC" "nZm eC" jp-kanji)
("u" "L" "Lm L" "Lm L" jp-kanji)
("v" "XC" "AVQm XC" "AVQm XC" jp-kanji)
("w" "w" "ium w" "ium w" jp-kanji)
("x" "w" "_}Xm w" "_}Xm w" jp-kanji)
("y" "P" "A}`m P" "A}`m P" jp-kanji)
("z" "\[" "TOm L[W" "TOm L[W" jp-kanji)
("{" "N" "JPm L[W" "JPm L[W" jp-kanji)
("|" "T" "\GE}m T" "\GE}m T" jp-kanji)
("}" "oN" "}bVOm oN" "}bVOm oN" jp-kanji)
("~" "q[" "VJQm q[" "VJQm q[" jp-kanji)
("" "" "om " "om " jp-kanji)
("" "L[" "ISm L[" "ISm L[" jp-kanji)
("" "M[" "cCm M[" "cCm M[" jp-kanji)
("" "GL" "GLm L[W" "GLm L[W" jp-kanji)
("" "P" "VVm L[W" "VVm L[W" jp-kanji)
("" "V[" "jJm V[" "jJm V[" jp-kanji)
("" "" "om " "om " jp-kanji)
("" "L" "Zm E}m L" "Zm E}m L" jp-kanji)
("" "W[" "E}wj W[" "E}wj W[" jp-kanji)
("" "J" "Rum J" "Rum J" jp-kanji)
("" "q[" "E} TrL" "E} TrL" jp-kanji)
("" "" "ixm " "ixm " jp-kanji)
("" "J" "zlwj zX" "zlwj zX" jp-kanji)
("" "TC" "TCRm TC" "TCRm TC" jp-kanji)
("" "JN" "NTb^ zlJN" "NTb^ zlJN" jp-kanji)
("" "q" "m q" "m q" jp-kanji)
("" "" "hNm " "hNm " jp-kanji)
("" "hN" "hNm hN" "hNm hN" jp-kanji)
("" "YC" "Xlm L[W" "Xlm L[W" jp-kanji)
("" "^C" "J_m L[W" "J_m L[W" jp-kanji)
("" "\[" "^JCj \[" "^JCj \[" jp-kanji)
("" "q[" "J~KVm q[" "J~KVm q[" jp-kanji)
("" "eC" "JWm eC" "JWm eC" jp-kanji)
("" "z[" "je Cm z[" "je Cm z[" jp-kanji)
("" "{[" "^K~m {[" "^K~m {[" jp-kanji)
("" "[" "qQm [" "qQm [" jp-kanji)
("" "`[" "EiCm `[" "EiCm `[" jp-kanji)
("" "nc" "J~m L[W" "J~m L[W" jp-kanji)
("" "tc" "jeCm tc" "jeCm tc" jp-kanji)
("" "z[" "^om z[" "^om z[" jp-kanji)
("" "LN" "}Qm LN" "}Qm LN" jp-kanji)
("" "Lc" "^uTm Lc" "^uTm Lc" jp-kanji)
("" "V[" "Xm V[" "Xm V[" jp-kanji)
("" "}" "Jcm }" "Jcm }" jp-kanji)
("" "V" "qQm V" "qQm V" jp-kanji)
("" "J" "ghm J" "ghm J" jp-kanji)
("" "q" "rdm q" "rdm q" jp-kanji)
("" "[" "^eK~m [" "^eK~m [" jp-kanji)
("" "g[" "g[K}Gm g[" "g[K}Gm g[" jp-kanji)
("" "h[" "TOm h[" "TOm h[" jp-kanji)
("" "R[" "J`hLm R[" "J`hLm R[" jp-kanji)
("" "PL" "ZOm PL" "ZOm PL" jp-kanji)
("" "g[" "^^JEm L[W" "^^JEm L[W" jp-kanji)
("" "L[" "NWm L[" "NWm L[" jp-kanji)
("" "`[" "uNm `[" "uNm `[" jp-kanji)
("" "JN" "J}m JN" "J}m JN" jp-kanji)
("" "nN" "^}VCm nN" "^}VCm nN" jp-kanji)
("" "oc" "qfm oc" "qfm oc" jp-kanji)
("" "M" "MVm M" "MVm M" jp-kanji)
("" "[" "[[m [" "[[m [" jp-kanji)
("" "[" "[[m [" "[[m [" jp-kanji)
("" "`" "`~m `" "`~m `" jp-kanji)
("" "G" "EiTm G" "EiTm G" jp-kanji)
("" "z[" "TJim z[" "TJim z[" jp-kanji)
("" "T" "XVm T" "XVm T" jp-kanji)
("" "q[" "TJim q" "TJim q" jp-kanji)
("" "z[" "TJim Ar" "TJim Ar" jp-kanji)
("" "V[" "TJim JWJ" "TJim JWJ" jp-kanji)
("" "g[" "TJim RmV" "TJim RmV" jp-kanji)
("" "A" "TJim AR[" "TJim AR[" jp-kanji)
("" "KC" "TJim n" "TJim n" jp-kanji)
("" "V" "XVm V" "XVm V" jp-kanji)
("" "L[" "TJim o" "TJim o" jp-kanji)
("" "R" "TJiwj PC" "TJiwj PC" jp-kanji)
("" "V" "TJim n[" "TJim n[" jp-kanji)
("" "V[" "TJim ^R" "TJim ^R" jp-kanji)
("" "z" "TJim CJ" "TJim CJ" jp-kanji)
("" "o" "TJim EOC" "TJim EOC" jp-kanji)
("" "L" "TJim JYmR" "TJim JYmR" jp-kanji)
("" "" "TJim R`" "TJim R`" jp-kanji)
("" "GL" "TJim X" "TJim X" jp-kanji)
("" "QC" "TV[EI" "TV[EI" jp-kanji)
("" "R" "TJim nS" "TJim nS" jp-kanji)
("" "V" "TJim {" "TJim {" jp-kanji)
("" "q" "TJim jV" "TJim jV" jp-kanji)
("" "\[" "TJim AW" "TJim AW" jp-kanji)
("" "I" "TJim hW[" "TJim hW[" jp-kanji)
("" "R" "TJim V`" "TJim V`" jp-kanji)
("" "l" "TJim i}Y" "TJim i}Y" jp-kanji)
("" "J" "TJim Gr" "TJim Gr" jp-kanji)
("" "J" "TJim ^" "TJim ^" jp-kanji)
("" "R[" "TJim qKC" "TJim qKC" jp-kanji)
("" "TC" "Gm TC" "Gm TC" jp-kanji)
("" "V[" "TJim hW[" "TJim hW[" jp-kanji)
("" "V" "TJim T" "TJim T" jp-kanji)
("" "`[" "TJim JC" "TJim JC" jp-kanji)
("" "tN" "TJim Ar" "TJim Ar" jp-kanji)
("" "" "TJim jV" "TJim jV" jp-kanji)
("" "C" "TJim C" "TJim C" jp-kanji)
("" "I" "TJim CV" "TJim CV" jp-kanji)
("" "I" "CVm CW" "CVm CW" jp-kanji)
("" "J" "TJim }" "TJim }" jp-kanji)
("" "V" "TJim u" "TJim u" jp-kanji)
("" "[" "TJij gh}" "TJij gh}" jp-kanji)
("" "W" "TJim n^n^" "TJim n^n^" jp-kanji)
("" "R[" "TJim AR[" "TJim AR[" jp-kanji)
("" "S[" "h[ucm Xb|" "h[ucm Xb|" jp-kanji)
("" "V[" "TJim ^R" "TJim ^R" jp-kanji)
("" "q[" "ELuNm q[" "ELuNm q[" jp-kanji)
("" "L" "TJim LX" "TJim LX" jp-kanji)
("" "JC" "TJim i}X" "TJim i}X" jp-kanji)
("" "C" "TJim n" "TJim n" jp-kanji)
("" "V[" "TJim tJ" "TJim tJ" jp-kanji)
("" "" "TJim XYL" "TJim XYL" jp-kanji)
("" "t" "gm J" "gm J" jp-kanji)
("" "t" "Jm ]NW" "Jm ]NW" jp-kanji)
("" "j" "gm jI" "gm jI" jp-kanji)
("" "A" "gm JX" "gm JX" jp-kanji)
("" "K" "Jm CW" "Jm CW" jp-kanji)
("" "K" "Jm NW" "Jm NW" jp-kanji)
("" "PL" "gm Y" "gm Y" jp-kanji)
("" "`" "gm `" "gm `" jp-kanji)
("" "Cc" "nCm Cc" "nCm Cc" jp-kanji)
("" "I[" "gm IVh" "gm IVh" jp-kanji)
("" "I[" "EOCXm L[W" "EOCXm L[W" jp-kanji)
("" "R" "gm VR" "gm VR" jp-kanji)
("" "V" "gm tN[" "gm tN[" jp-kanji)
("" "V" "LVm V" "LVm V" jp-kanji)
("" "_" "_`[m _" "_`[m _" jp-kanji)
("" "C" "gm ZLC" "gm ZLC" jp-kanji)
("" "R[" "gm SCTM" "gm SCTM" jp-kanji)
("" "R[" "gm CGog" "gm CGog" jp-kanji)
("" "{[" "gm gL" "gm gL" jp-kanji)
("" "`" "gm `h" "gm `h" jp-kanji)
("" "`[" "~~wj g" "~~wj g" jp-kanji)
("@" "K" "gm K`[" "gm K`[" jp-kanji)
("A" "K" "K`[m K" "K`[m K" jp-kanji)
("B" "JN" "Jhjg" "Jhjg" jp-kanji)
("C" "P" "^IThm P" "^IThm P" jp-kanji)
("D" "u" "tiVEYm u" "tiVEYm u" jp-kanji)
("E" "PL" "gm Y" "gm Y" jp-kanji)
("F" "WN" "gm JTTM" "gm JTTM" jp-kanji)
("G" "V" "gm EY" "gm EY" jp-kanji)
("H" "g[" "gm cO~" "gm cO~" jp-kanji)
("I" "g[" "cO~m CW" "cO~m CW" jp-kanji)
("J" "q" "gm qh" "gm qh" jp-kanji)
("K" "" "Gm " "Gm " jp-kanji)
("L" "KN" "gm ~TS" "gm ~TS" jp-kanji)
("M" "E" "g[}m E" "g[}m E" jp-kanji)
("N" "u" "gm Aq" "gm Aq" jp-kanji)
("O" "I[" "gm I[" "gm I[" jp-kanji)
("P" "PC" "jgm L[W" "jgm L[W" jp-kanji)
("Q" "QL" "~Yhm i}G" "~Yhm i}G" jp-kanji)
("R" "Rc" "gm Jh" "gm Jh" jp-kanji)
("S" "WN" "gm q" "gm q" jp-kanji)
("T" "ZL" "gm ZLC" "gm ZLC" jp-kanji)
("U" "e" "^Jm L[W" "^Jm L[W" jp-kanji)
("V" "e" "gm ^J" "gm ^J" jp-kanji)
("W" "[" "gm nV^J" "gm nV^J" jp-kanji)
("X" "V" "gm Ah" "gm Ah" jp-kanji)
("Y" "V" "gm VR" "gm VR" jp-kanji)
("Z" "Cc" "gm VM" "gm VM" jp-kanji)
("[" "V[" "gm ~\TUC" "gm ~\TUC" jp-kanji)
("\" "o" "gm n" "gm n" jp-kanji)
("]" "[" "gm VL" "gm VL" jp-kanji)
("^" "KN" "gm E\" "gm E\" jp-kanji)
("_" "I[" "gm I[" "gm I[" jp-kanji)
("`" "J" "gm R[mg" "gm R[mg" jp-kanji)
("a" "" "C`[m " "C`[m " jp-kanji)
("b" "" "VIm " "VIm " jp-kanji)
("c" "J" "VIPm J" "VIPm J" jp-kanji)
("d" "G" "VIm ZCW" "VIm ZCW" jp-kanji)
("e" "\" "ACm \" "ACm \" jp-kanji)
("f" "V" "IIVJm V" "IIVJm V" jp-kanji)
("g" "r" "giJCm r" "giJCm r" jp-kanji)
("h" "S" "IWJm S" "IWJm S" jp-kanji)
("i" "L" "Lm L" "Lm L" jp-kanji)
("j" "L" "LV[m L" "LV[m L" jp-kanji)
("k" "QC" "JmRm QC" "JmRm QC" jp-kanji)
("l" "W" "WR[WJm W" "WR[WJm W" jp-kanji)
("m" "oN" "Mm L[W" "Mm L[W" jp-kanji)
("n" "t" "tX}m t" "tX}m t" jp-kanji)
("o" "t" "tX}m CW" "tX}m CW" jp-kanji)
("p" "" "\om " "\om " jp-kanji)
("q" "z[" "Ri`m z[" "Ri`m z[" jp-kanji)
("r" "q" "irNm q" "irNm q" jp-kanji)
("s" "R[" "}irm R[" "}irm R[" jp-kanji)
("t" "C" "CCm C" "CCm C" jp-kanji)
("u" "l" "lom l" "lom l" jp-kanji)
("v" "`" "g`m `" "g`m `" jp-kanji)
("w" "P" "NCm P" "NCm P" jp-kanji)
("x" "`c" "V]Pm `c" "V]Pm `c" jp-kanji)
("y" "e" "em L[W" "em L[W" jp-kanji)
("z" "[" "AIOCm [" "AIOCm [" jp-kanji)
("{" "Jc" "KVRC" "KVRC" jp-kanji)
("|" "PC" "CY~m PC" "CY~m PC" jp-kanji)
("}" "g[" "g[m L[W" "g[m L[W" jp-kanji)
("~" "A" "NCm A" "NCm A" jp-kanji)
("" "oC" "Jrm oC" "Jrm oC" jp-kanji)
("" "A" "zNm A" "zNm A" jp-kanji)
("" "gN" "PKm gN" "PKm gN" jp-kanji)
("" "`" "kCgm `" "kCgm `" jp-kanji)
("" "tc" "qUJPm tc" "qUJPm tc" jp-kanji)
("" "z" "CtNm z" "CtNm z" jp-kanji)
("" "{[" "cgm {[" "cgm {[" jp-kanji)
("" "S[" "IIXb|m S[" "IIXb|m S[" jp-kanji)
("" "xc" "xbR[m xc" "xbR[m xc" jp-kanji)
("" "R" "cd~m CW" "cd~m CW" jp-kanji)
("" "g[" "cd~m Ig" "cd~m Ig" jp-kanji)
("" "\" "lY~m NW" "lY~m NW" jp-kanji)
("" "" "C^`m " "C^`m " jp-kanji)
("" "J" "CrLm J" "CrLm J" jp-kanji)
("" "ZC" "\Em L[W" "\Em L[W" jp-kanji)
("" "V" "nm L[W" "nm L[W" jp-kanji)
("" "V" "nKm V" "nKm V" jp-kanji)
("" "ZL" "R}m ZL" "R}m ZL" jp-kanji)
("" "\" "\VNm \" "\VNm \" jp-kanji)
("" "`[" "nKm `[" "nKm `[" jp-kanji)
("" "C" "Cm L[W" "Cm L[W" jp-kanji)
("" "R" "nOLm R" "nOLm R" jp-kanji)
("" "Pc" "JWm Pc" "JWm Pc" jp-kanji)
("" "S" "NC`KCm S" "NC`KCm S" jp-kanji)
("" "TN" "R_m TN" "R_m TN" jp-kanji)
("" "AN" "ANTNm AN" "ANTNm AN" jp-kanji)
("" "E" "Vom E" "Vom E" jp-kanji)
("" "KN" "nOLm KN" "nOLm KN" jp-kanji)
("" "J" "YVm K" "YVm K" jp-kanji)
("" "L" "Jm L[W" "Jm L[W" jp-kanji)
("" "N" "tGm N" "tGm N" jp-kanji)
("" "ME" "^JVm ME" "^JVm ME" jp-kanji)
("" "}L" "RYGm }L" "RYGm }L" jp-kanji)
("" "E" "EnCm E" "EnCm E" jp-kanji)
("" "E" "EcNVC ^}m E" "EcNVC ^}m E" jp-kanji)
("" "" "qLV}m " "qLV}m " jp-kanji)
("" "L" "ALJm L" "ALJm L" jp-kanji)
))
(provide 'auditory-disp-table-jp)
